/* Copyright (c) 2018, 2019, 2020 Evan Nemerson <evan@nemerson.com>
 *
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use, copy,
 * modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
 * BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

#define SIMDE_TESTS_CURRENT_ISAX avx512bw
#include <simde/x86/avx512bw.h>
#include <test/x86/test-avx512.h>

static int
test_simde_mm512_mask_set1_epi8(SIMDE_MUNIT_TEST_ARGS) {
  const struct {
    simde__m512i src;
    simde__mmask64 k;
    int8_t a;
    simde__m512i r;
  } test_vec[8] = {
    { simde_mm512_set_epi8(INT8_C(  80), INT8_C(  13), INT8_C( -86), INT8_C( 103),
                           INT8_C(  30), INT8_C(  88), INT8_C( -63), INT8_C( -16),
                           INT8_C( -68), INT8_C( -20), INT8_C(  48), INT8_C( -36),
                           INT8_C( -97), INT8_C(-103), INT8_C(-104), INT8_C( -61),
                           INT8_C(-122), INT8_C( -83), INT8_C(  -3), INT8_C(-115),
                           INT8_C(  29), INT8_C(-112), INT8_C( 118), INT8_C(  53),
                           INT8_C(-107), INT8_C(-126), INT8_C(  41), INT8_C(-117),
                           INT8_C(  -4), INT8_C( -72), INT8_C(  -9), INT8_C(   2),
                           INT8_C(  10), INT8_C( -61), INT8_C( 116), INT8_C(   1),
                           INT8_C(  35), INT8_C( -78), INT8_C(  17), INT8_C( -82),
                           INT8_C( -14), INT8_C( 120), INT8_C( 120), INT8_C(  33),
                           INT8_C(  97), INT8_C(   4), INT8_C(-104), INT8_C(  67),
                           INT8_C( -86), INT8_C( -90), INT8_C( -95), INT8_C(  51),
                           INT8_C( -83), INT8_C(-120), INT8_C( 123), INT8_C(  -4),
                           INT8_C(  51), INT8_C( -66), INT8_C( -91), INT8_C(  51),
                           INT8_C(  -1), INT8_C(  32), INT8_C(  30), INT8_C(  92)),
      UINT64_C(12701675613368776088),
      INT8_C( -94),
      simde_mm512_set_epi8(INT8_C( -94), INT8_C(  13), INT8_C( -94), INT8_C( -94),
                           INT8_C(  30), INT8_C(  88), INT8_C( -63), INT8_C( -16),
                           INT8_C( -68), INT8_C( -94), INT8_C(  48), INT8_C( -36),
                           INT8_C( -97), INT8_C( -94), INT8_C(-104), INT8_C( -94),
                           INT8_C(-122), INT8_C( -94), INT8_C( -94), INT8_C(-115),
                           INT8_C( -94), INT8_C(-112), INT8_C( -94), INT8_C(  53),
                           INT8_C( -94), INT8_C(-126), INT8_C( -94), INT8_C(-117),
                           INT8_C( -94), INT8_C( -94), INT8_C(  -9), INT8_C(   2),
                           INT8_C( -94), INT8_C( -61), INT8_C( 116), INT8_C(   1),
                           INT8_C( -94), INT8_C( -78), INT8_C( -94), INT8_C( -94),
                           INT8_C( -14), INT8_C( 120), INT8_C( 120), INT8_C( -94),
                           INT8_C(  97), INT8_C( -94), INT8_C( -94), INT8_C(  67),
                           INT8_C( -86), INT8_C( -94), INT8_C( -94), INT8_C( -94),
                           INT8_C( -83), INT8_C( -94), INT8_C( 123), INT8_C( -94),
                           INT8_C( -94), INT8_C( -66), INT8_C( -91), INT8_C( -94),
                           INT8_C( -94), INT8_C(  32), INT8_C(  30), INT8_C(  92)) },
    { simde_mm512_set_epi8(INT8_C( -64), INT8_C( -80), INT8_C(  33), INT8_C(  -9),
                           INT8_C(   3), INT8_C(  93), INT8_C(  13), INT8_C( -28),
                           INT8_C(  79), INT8_C(  10), INT8_C( -42), INT8_C(-127),
                           INT8_C( 114), INT8_C(  78), INT8_C(  61), INT8_C(  67),
                           INT8_C(  95), INT8_C(  14), INT8_C(  28), INT8_C(  56),
                           INT8_C(  43), INT8_C( -20), INT8_C( -77), INT8_C(  83),
                           INT8_C( -68), INT8_C(  87), INT8_C( -96), INT8_C(  13),
                           INT8_C(  40), INT8_C( 107), INT8_C( -63), INT8_C(  -1),
                           INT8_C(  77), INT8_C(  21), INT8_C( -46), INT8_C( -12),
                           INT8_C(  42), INT8_C(  69), INT8_C(  51), INT8_C(  11),
                           INT8_C(-120), INT8_C(  65), INT8_C( -70), INT8_C( -19),
                           INT8_C( -95), INT8_C(  43), INT8_C(  -2), INT8_C( -62),
                           INT8_C( -16), INT8_C(  28), INT8_C(  29), INT8_C( -11),
                           INT8_C(  17), INT8_C( -18), INT8_C( 105), INT8_C(-119),
                           INT8_C(  60), INT8_C( 120), INT8_C(  38), INT8_C( -41),
                           INT8_C(  20), INT8_C( -30), INT8_C(  15), INT8_C( 112)),
      UINT64_C(15052494645983188959),
      INT8_C( -73),
      simde_mm512_set_epi8(INT8_C( -73), INT8_C( -73), INT8_C(  33), INT8_C( -73),
                           INT8_C(   3), INT8_C(  93), INT8_C(  13), INT8_C( -28),
                           INT8_C( -73), INT8_C( -73), INT8_C( -73), INT8_C(-127),
                           INT8_C( 114), INT8_C( -73), INT8_C(  61), INT8_C( -73),
                           INT8_C(  95), INT8_C(  14), INT8_C( -73), INT8_C( -73),
                           INT8_C(  43), INT8_C( -73), INT8_C( -77), INT8_C(  83),
                           INT8_C( -68), INT8_C(  87), INT8_C( -73), INT8_C(  13),
                           INT8_C(  40), INT8_C( 107), INT8_C( -63), INT8_C( -73),
                           INT8_C(  77), INT8_C(  21), INT8_C( -46), INT8_C( -12),
                           INT8_C(  42), INT8_C( -73), INT8_C(  51), INT8_C( -73),
                           INT8_C(-120), INT8_C( -73), INT8_C( -70), INT8_C( -19),
                           INT8_C( -73), INT8_C( -73), INT8_C(  -2), INT8_C( -62),
                           INT8_C( -16), INT8_C(  28), INT8_C(  29), INT8_C( -73),
                           INT8_C(  17), INT8_C( -73), INT8_C( -73), INT8_C( -73),
                           INT8_C( -73), INT8_C( -73), INT8_C(  38), INT8_C( -73),
                           INT8_C( -73), INT8_C( -73), INT8_C( -73), INT8_C( -73)) },
    { simde_mm512_set_epi8(INT8_C( 107), INT8_C( 126), INT8_C( -33), INT8_C(  83),
                           INT8_C(  46), INT8_C(  62), INT8_C( -81), INT8_C(  33),
                           INT8_C( -68), INT8_C(-126), INT8_C( -41), INT8_C( 125),
                           INT8_C( -96), INT8_C( -20), INT8_C(  62), INT8_C( -19),
                           INT8_C(  29), INT8_C( -96), INT8_C(  68), INT8_C( 119),
                           INT8_C( -36), INT8_C( -62), INT8_C( -27), INT8_C(-112),
                           INT8_C(-123), INT8_C(  55), INT8_C(-119), INT8_C(  -4),
                           INT8_C(  58), INT8_C(  28), INT8_C( -84), INT8_C( -38),
                           INT8_C(   1), INT8_C( -25), INT8_C( 107), INT8_C( -63),
                           INT8_C( -86), INT8_C(  88), INT8_C(  36), INT8_C(  53),
                           INT8_C( 109), INT8_C( -36), INT8_C( -70), INT8_C(-125),
                           INT8_C(  -3), INT8_C(-109), INT8_C( 121), INT8_C( -63),
                           INT8_C( 113), INT8_C( -92), INT8_C(  -4), INT8_C(-105),
                           INT8_C( -65), INT8_C(  26), INT8_C( -36), INT8_C(  87),
                           INT8_C(-101), INT8_C( -70), INT8_C(  -3), INT8_C(  26),
                           INT8_C( -88), INT8_C( -51), INT8_C(-123), INT8_C(  93)),
      UINT64_C( 2985661334514035835),
      INT8_C( 111),
      simde_mm512_set_epi8(INT8_C( 107), INT8_C( 126), INT8_C( 111), INT8_C(  83),
                           INT8_C( 111), INT8_C(  62), INT8_C( -81), INT8_C( 111),
                           INT8_C( -68), INT8_C( 111), INT8_C( 111), INT8_C( 125),
                           INT8_C( 111), INT8_C( 111), INT8_C( 111), INT8_C( 111),
                           INT8_C(  29), INT8_C( -96), INT8_C( 111), INT8_C( 111),
                           INT8_C( -36), INT8_C( -62), INT8_C( 111), INT8_C( 111),
                           INT8_C(-123), INT8_C(  55), INT8_C( 111), INT8_C(  -4),
                           INT8_C( 111), INT8_C(  28), INT8_C( 111), INT8_C( -38),
                           INT8_C(   1), INT8_C( -25), INT8_C( 111), INT8_C( 111),
                           INT8_C( 111), INT8_C( 111), INT8_C( 111), INT8_C( 111),
                           INT8_C( 109), INT8_C( 111), INT8_C( -70), INT8_C( 111),
                           INT8_C(  -3), INT8_C(-109), INT8_C( 111), INT8_C( 111),
                           INT8_C( 111), INT8_C( 111), INT8_C( 111), INT8_C(-105),
                           INT8_C( 111), INT8_C( 111), INT8_C( -36), INT8_C(  87),
                           INT8_C(-101), INT8_C( 111), INT8_C( 111), INT8_C( 111),
                           INT8_C( 111), INT8_C( -51), INT8_C( 111), INT8_C( 111)) },
    { simde_mm512_set_epi8(INT8_C( -63), INT8_C(  92), INT8_C( -41), INT8_C( -80),
                           INT8_C(-101), INT8_C(  86), INT8_C(  45), INT8_C(  45),
                           INT8_C( -41), INT8_C(-113), INT8_C( -17), INT8_C(-101),
                           INT8_C(-113), INT8_C( -69), INT8_C(  73), INT8_C(-124),
                           INT8_C(  90), INT8_C(-118), INT8_C(  31), INT8_C(-124),
                           INT8_C( -88), INT8_C(-116), INT8_C(   8), INT8_C( -37),
                           INT8_C( -41), INT8_C(  93), INT8_C( -86), INT8_C(  61),
                           INT8_C( -70), INT8_C( -88), INT8_C(  44), INT8_C( -34),
                           INT8_C( -21), INT8_C(-121), INT8_C(-124), INT8_C(-114),
                           INT8_C(  73), INT8_C(  92), INT8_C( -92), INT8_C(-115),
                           INT8_C(   6), INT8_C(-120), INT8_C(  89), INT8_C(-102),
                           INT8_C( -43), INT8_C(  33), INT8_C(  15), INT8_C(  -6),
                           INT8_C(-105), INT8_C(  66), INT8_C( -60), INT8_C(  54),
                           INT8_C( -95), INT8_C(  49), INT8_C(   1), INT8_C( 118),
                           INT8_C( -33), INT8_C( -35), INT8_C( -34), INT8_C( -10),
                           INT8_C( -70), INT8_C(  74), INT8_C( -10), INT8_C(  97)),
      UINT64_C(12556192675989742329),
      INT8_C(-120),
      simde_mm512_set_epi8(INT8_C(-120), INT8_C(  92), INT8_C(-120), INT8_C( -80),
                           INT8_C(-120), INT8_C(-120), INT8_C(-120), INT8_C(  45),
                           INT8_C( -41), INT8_C(-120), INT8_C( -17), INT8_C(-101),
                           INT8_C(-113), INT8_C( -69), INT8_C(  73), INT8_C(-124),
                           INT8_C(-120), INT8_C(-118), INT8_C(  31), INT8_C(-124),
                           INT8_C(-120), INT8_C(-120), INT8_C(-120), INT8_C( -37),
                           INT8_C(-120), INT8_C(  93), INT8_C(-120), INT8_C(-120),
                           INT8_C( -70), INT8_C(-120), INT8_C(-120), INT8_C( -34),
                           INT8_C(-120), INT8_C(-121), INT8_C(-124), INT8_C(-120),
                           INT8_C(  73), INT8_C(-120), INT8_C(-120), INT8_C(-120),
                           INT8_C(-120), INT8_C(-120), INT8_C(-120), INT8_C(-120),
                           INT8_C(-120), INT8_C(  33), INT8_C(-120), INT8_C(  -6),
                           INT8_C(-120), INT8_C(-120), INT8_C(-120), INT8_C(  54),
                           INT8_C( -95), INT8_C(  49), INT8_C(-120), INT8_C( 118),
                           INT8_C(-120), INT8_C(-120), INT8_C(-120), INT8_C(-120),
                           INT8_C(-120), INT8_C(  74), INT8_C( -10), INT8_C(-120)) },
    { simde_mm512_set_epi8(INT8_C(  21), INT8_C(  17), INT8_C(  22), INT8_C(-115),
                           INT8_C( 101), INT8_C(  -2), INT8_C( -32), INT8_C( -27),
                           INT8_C( -14), INT8_C(  47), INT8_C( 110), INT8_C( -88),
                           INT8_C(  23), INT8_C( -87), INT8_C( -20), INT8_C( 115),
                           INT8_C( 108), INT8_C( -54), INT8_C(-105), INT8_C( -94),
                           INT8_C(  96), INT8_C(-110), INT8_C( -87), INT8_C( 119),
                           INT8_C( 110), INT8_C( -13), INT8_C(  53), INT8_C( -27),
                           INT8_C( -59), INT8_C(  57), INT8_C( -46), INT8_C( -24),
                           INT8_C(  35), INT8_C(  26), INT8_C( 124), INT8_C( -28),
                           INT8_C( -68), INT8_C( -57), INT8_C(  75), INT8_C( -25),
                           INT8_C(-112), INT8_C( 112), INT8_C( 123), INT8_C(-108),
                           INT8_C( 115), INT8_C(  -6), INT8_C(  43), INT8_C(  52),
                           INT8_C( -91), INT8_C( -17), INT8_C(  93), INT8_C(  -2),
                           INT8_C( 116), INT8_C( -51), INT8_C(  70), INT8_C(  98),
                           INT8_C( 104), INT8_C( -69), INT8_C(-102), INT8_C(  77),
                           INT8_C(  82), INT8_C( 125), INT8_C(  42), INT8_C(  83)),
      UINT64_C(12090133344763257330),
      INT8_C(  55),
      simde_mm512_set_epi8(INT8_C(  55), INT8_C(  17), INT8_C(  55), INT8_C(-115),
                           INT8_C( 101), INT8_C(  55), INT8_C(  55), INT8_C(  55),
                           INT8_C(  55), INT8_C(  55), INT8_C( 110), INT8_C( -88),
                           INT8_C(  55), INT8_C( -87), INT8_C( -20), INT8_C( 115),
                           INT8_C(  55), INT8_C(  55), INT8_C(-105), INT8_C( -94),
                           INT8_C(  55), INT8_C(-110), INT8_C( -87), INT8_C( 119),
                           INT8_C( 110), INT8_C( -13), INT8_C(  55), INT8_C(  55),
                           INT8_C(  55), INT8_C(  57), INT8_C( -46), INT8_C( -24),
                           INT8_C(  55), INT8_C(  26), INT8_C( 124), INT8_C( -28),
                           INT8_C( -68), INT8_C(  55), INT8_C(  75), INT8_C(  55),
                           INT8_C(  55), INT8_C( 112), INT8_C(  55), INT8_C(  55),
                           INT8_C(  55), INT8_C(  -6), INT8_C(  43), INT8_C(  52),
                           INT8_C( -91), INT8_C( -17), INT8_C(  55), INT8_C(  -2),
                           INT8_C( 116), INT8_C( -51), INT8_C(  70), INT8_C(  55),
                           INT8_C(  55), INT8_C(  55), INT8_C(  55), INT8_C(  55),
                           INT8_C(  82), INT8_C( 125), INT8_C(  55), INT8_C(  83)) },
    { simde_mm512_set_epi8(INT8_C(-124), INT8_C( -37), INT8_C( -61), INT8_C( -35),
                           INT8_C( -22), INT8_C( -85), INT8_C(-117), INT8_C(-105),
                           INT8_C(  99), INT8_C( -62), INT8_C( 102), INT8_C( -31),
                           INT8_C(  82), INT8_C(  39), INT8_C(  49), INT8_C(  43),
                           INT8_C(  21), INT8_C(  16), INT8_C(  12), INT8_C(-125),
                           INT8_C(   2), INT8_C(-106), INT8_C(  -4), INT8_C( 100),
                           INT8_C( -12), INT8_C(  30), INT8_C( -39), INT8_C( -37),
                           INT8_C(  92), INT8_C( -43), INT8_C(  33), INT8_C(-124),
                           INT8_C(  48), INT8_C(   4), INT8_C(  31), INT8_C(  78),
                           INT8_C(-113), INT8_C( 115), INT8_C( 116), INT8_C( -62),
                           INT8_C(-109), INT8_C( -66), INT8_C(  43), INT8_C(-118),
                           INT8_C(-105), INT8_C( -11), INT8_C( 100), INT8_C(  41),
                           INT8_C(-104), INT8_C(-114), INT8_C(-105), INT8_C(  88),
                           INT8_C( -33), INT8_C(  -8), INT8_C(  41), INT8_C(  16),
                           INT8_C(   4), INT8_C(  89), INT8_C(  66), INT8_C(  27),
                           INT8_C( -63), INT8_C(  30), INT8_C( -95), INT8_C(  33)),
      UINT64_C(13436704833767296949),
      INT8_C(  18),
      simde_mm512_set_epi8(INT8_C(  18), INT8_C( -37), INT8_C(  18), INT8_C(  18),
                           INT8_C(  18), INT8_C( -85), INT8_C(  18), INT8_C(-105),
                           INT8_C(  99), INT8_C(  18), INT8_C(  18), INT8_C(  18),
                           INT8_C(  18), INT8_C(  39), INT8_C(  49), INT8_C(  43),
                           INT8_C(  18), INT8_C(  18), INT8_C(  12), INT8_C(-125),
                           INT8_C(   2), INT8_C(-106), INT8_C(  18), INT8_C(  18),
                           INT8_C(  18), INT8_C(  18), INT8_C( -39), INT8_C(  18),
                           INT8_C(  18), INT8_C( -43), INT8_C(  18), INT8_C(  18),
                           INT8_C(  48), INT8_C(   4), INT8_C(  31), INT8_C(  78),
                           INT8_C(  18), INT8_C( 115), INT8_C( 116), INT8_C( -62),
                           INT8_C(-109), INT8_C(  18), INT8_C(  18), INT8_C(  18),
                           INT8_C(  18), INT8_C( -11), INT8_C( 100), INT8_C(  18),
                           INT8_C(-104), INT8_C(  18), INT8_C(-105), INT8_C(  88),
                           INT8_C(  18), INT8_C(  18), INT8_C(  18), INT8_C(  18),
                           INT8_C(  18), INT8_C(  89), INT8_C(  18), INT8_C(  18),
                           INT8_C( -63), INT8_C(  18), INT8_C( -95), INT8_C(  18)) },
    { simde_mm512_set_epi8(INT8_C( -30), INT8_C( 101), INT8_C(  64), INT8_C( 107),
                           INT8_C( -34), INT8_C( -67), INT8_C( -96), INT8_C(  35),
                           INT8_C( 117), INT8_C(  76), INT8_C( 106), INT8_C( -82),
                           INT8_C( -48), INT8_C(  63), INT8_C(  11), INT8_C(  22),
                           INT8_C(  41), INT8_C(  95), INT8_C(-123), INT8_C( -90),
                           INT8_C(  67), INT8_C( -76), INT8_C(-105), INT8_C(  -7),
                           INT8_C( 115), INT8_C( 121), INT8_C( -52), INT8_C( -95),
                           INT8_C(-101), INT8_C(  64), INT8_C( -67), INT8_C( 107),
                           INT8_C(-104), INT8_C(  56), INT8_C(  89), INT8_C( -95),
                           INT8_C(  21), INT8_C( -42), INT8_C( -75), INT8_C(  45),
                           INT8_C( -86), INT8_C(  32), INT8_C(  27), INT8_C(-119),
                           INT8_C( -68), INT8_C(   5), INT8_C( -78), INT8_C( -36),
                           INT8_C( 125), INT8_C( 117), INT8_C( -63), INT8_C( -68),
                           INT8_C( -45), INT8_C( -77), INT8_C(   6), INT8_C(  68),
                           INT8_C(  79), INT8_C( -92), INT8_C(  67), INT8_C(  61),
                           INT8_C(  42), INT8_C(  26), INT8_C(-117), INT8_C( -55)),
      UINT64_C(14020412538477965079),
      INT8_C( -46),
      simde_mm512_set_epi8(INT8_C( -46), INT8_C( -46), INT8_C(  64), INT8_C( 107),
                           INT8_C( -34), INT8_C( -67), INT8_C( -46), INT8_C(  35),
                           INT8_C( -46), INT8_C(  76), INT8_C( 106), INT8_C( -46),
                           INT8_C( -48), INT8_C(  63), INT8_C( -46), INT8_C(  22),
                           INT8_C( -46), INT8_C(  95), INT8_C(-123), INT8_C( -90),
                           INT8_C(  67), INT8_C( -76), INT8_C( -46), INT8_C(  -7),
                           INT8_C( -46), INT8_C( -46), INT8_C( -46), INT8_C( -95),
                           INT8_C( -46), INT8_C(  64), INT8_C( -46), INT8_C( -46),
                           INT8_C( -46), INT8_C(  56), INT8_C( -46), INT8_C( -95),
                           INT8_C(  21), INT8_C( -42), INT8_C( -75), INT8_C(  45),
                           INT8_C( -86), INT8_C( -46), INT8_C( -46), INT8_C(-119),
                           INT8_C( -46), INT8_C(   5), INT8_C( -78), INT8_C( -46),
                           INT8_C( 125), INT8_C( -46), INT8_C( -46), INT8_C( -68),
                           INT8_C( -46), INT8_C( -46), INT8_C( -46), INT8_C( -46),
                           INT8_C(  79), INT8_C( -92), INT8_C(  67), INT8_C( -46),
                           INT8_C(  42), INT8_C( -46), INT8_C( -46), INT8_C( -46)) },
    { simde_mm512_set_epi8(INT8_C( -83), INT8_C( -73), INT8_C( -22), INT8_C(  98),
                           INT8_C( 126), INT8_C(  41), INT8_C( -28), INT8_C( 126),
                           INT8_C( -75), INT8_C(  91), INT8_C( -33), INT8_C( 103),
                           INT8_C( -63), INT8_C(  62), INT8_C(  83), INT8_C(   4),
                           INT8_C(  65), INT8_C( -22), INT8_C( 107), INT8_C(   8),
                           INT8_C(  31), INT8_C(-111), INT8_C(-114), INT8_C(-118),
                           INT8_C(   2), INT8_C(  76), INT8_C(  19), INT8_C( 127),
                           INT8_C( -37), INT8_C( -41), INT8_C(  91), INT8_C( -64),
                           INT8_C(-105), INT8_C( 127), INT8_C(-121), INT8_C(  84),
                           INT8_C( 124), INT8_C(  50), INT8_C( -86), INT8_C(-101),
                           INT8_C( -82), INT8_C( 121), INT8_C(  18), INT8_C( -17),
                           INT8_C( -55), INT8_C(-102), INT8_C( -81), INT8_C( -54),
                           INT8_C( -56), INT8_C(  -2), INT8_C( -68), INT8_C( 105),
                           INT8_C( -48), INT8_C( -90), INT8_C( -46), INT8_C(  63),
                           INT8_C( 126), INT8_C( -93), INT8_C(  46), INT8_C(-114),
                           INT8_C(  58), INT8_C( 110), INT8_C( 102), INT8_C( -93)),
      UINT64_C(14839809536761107867),
      INT8_C( 106),
      simde_mm512_set_epi8(INT8_C( 106), INT8_C( 106), INT8_C( -22), INT8_C(  98),
                           INT8_C( 106), INT8_C( 106), INT8_C( -28), INT8_C( 106),
                           INT8_C( 106), INT8_C( 106), INT8_C( 106), INT8_C( 106),
                           INT8_C( -63), INT8_C(  62), INT8_C(  83), INT8_C( 106),
                           INT8_C( 106), INT8_C( -22), INT8_C( 107), INT8_C( 106),
                           INT8_C( 106), INT8_C(-111), INT8_C(-114), INT8_C(-118),
                           INT8_C(   2), INT8_C(  76), INT8_C( 106), INT8_C( 127),
                           INT8_C( -37), INT8_C( 106), INT8_C( 106), INT8_C( -64),
                           INT8_C(-105), INT8_C( 127), INT8_C( 106), INT8_C(  84),
                           INT8_C( 124), INT8_C( 106), INT8_C( -86), INT8_C( 106),
                           INT8_C( -82), INT8_C( 121), INT8_C(  18), INT8_C( 106),
                           INT8_C( 106), INT8_C(-102), INT8_C( -81), INT8_C( 106),
                           INT8_C( 106), INT8_C(  -2), INT8_C( -68), INT8_C( 106),
                           INT8_C( -48), INT8_C( 106), INT8_C( -46), INT8_C( 106),
                           INT8_C( 106), INT8_C( -93), INT8_C(  46), INT8_C( 106),
                           INT8_C( 106), INT8_C( 110), INT8_C( 106), INT8_C( 106)) }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])); i++) {
    simde__m512i r = simde_mm512_mask_set1_epi8(test_vec[i].src, test_vec[i].k, test_vec[i].a);
    simde_assert_m512i_i8(r, ==, test_vec[i].r);
  }

  return 0;
}

static int
test_simde_mm512_maskz_set1_epi8(SIMDE_MUNIT_TEST_ARGS) {
  const struct {
    simde__mmask64 k;
    int8_t a;
    simde__m512i r;
  } test_vec[8] = {
   { UINT64_C( 2901368310709582274),
      INT8_C( -37),
      simde_mm512_set_epi8(INT8_C(   0), INT8_C(   0), INT8_C( -37), INT8_C(   0),
                           INT8_C( -37), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C( -37), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C( -37), INT8_C( -37),
                           INT8_C( -37), INT8_C(   0), INT8_C( -37), INT8_C( -37),
                           INT8_C( -37), INT8_C(   0), INT8_C( -37), INT8_C( -37),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C( -37),
                           INT8_C( -37), INT8_C(   0), INT8_C( -37), INT8_C( -37),
                           INT8_C(   0), INT8_C( -37), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C( -37), INT8_C(   0),
                           INT8_C(   0), INT8_C( -37), INT8_C( -37), INT8_C(   0),
                           INT8_C( -37), INT8_C(   0), INT8_C( -37), INT8_C( -37),
                           INT8_C(   0), INT8_C( -37), INT8_C( -37), INT8_C( -37),
                           INT8_C( -37), INT8_C(   0), INT8_C(   0), INT8_C( -37),
                           INT8_C( -37), INT8_C( -37), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C( -37), INT8_C(   0)) },
    { UINT64_C(15800639674747260058),
      INT8_C(  63),
      simde_mm512_set_epi8(INT8_C(  63), INT8_C(  63), INT8_C(   0), INT8_C(  63),
                           INT8_C(  63), INT8_C(   0), INT8_C(  63), INT8_C(  63),
                           INT8_C(   0), INT8_C(  63), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(  63), INT8_C(  63), INT8_C(  63),
                           INT8_C(   0), INT8_C(   0), INT8_C(  63), INT8_C(   0),
                           INT8_C(   0), INT8_C(  63), INT8_C(  63), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(  63),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(  63),
                           INT8_C(  63), INT8_C(   0), INT8_C(   0), INT8_C(  63),
                           INT8_C(  63), INT8_C(  63), INT8_C(   0), INT8_C(  63),
                           INT8_C(   0), INT8_C(  63), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(  63),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(  63), INT8_C(  63), INT8_C(   0), INT8_C(   0),
                           INT8_C(  63), INT8_C(   0), INT8_C(   0), INT8_C(  63),
                           INT8_C(  63), INT8_C(   0), INT8_C(  63), INT8_C(   0)) },
    { UINT64_C(12860739080443979541),
      INT8_C(  53),
      simde_mm512_set_epi8(INT8_C(  53), INT8_C(   0), INT8_C(  53), INT8_C(  53),
                           INT8_C(   0), INT8_C(   0), INT8_C(  53), INT8_C(   0),
                           INT8_C(   0), INT8_C(  53), INT8_C(  53), INT8_C(  53),
                           INT8_C(  53), INT8_C(   0), INT8_C(  53), INT8_C(   0),
                           INT8_C(  53), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(  53), INT8_C(  53), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(  53), INT8_C(  53), INT8_C(   0), INT8_C(  53),
                           INT8_C(  53), INT8_C(  53), INT8_C(  53), INT8_C(  53),
                           INT8_C(   0), INT8_C(  53), INT8_C(  53), INT8_C(   0),
                           INT8_C(  53), INT8_C(  53), INT8_C(   0), INT8_C(  53),
                           INT8_C(  53), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(  53), INT8_C(  53), INT8_C(  53), INT8_C(   0),
                           INT8_C(   0), INT8_C(  53), INT8_C(  53), INT8_C(  53),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(  53),
                           INT8_C(   0), INT8_C(  53), INT8_C(   0), INT8_C(  53)) },
    { UINT64_C( 2595884503750725802),
      INT8_C(  78),
      simde_mm512_set_epi8(INT8_C(   0), INT8_C(   0), INT8_C(  78), INT8_C(   0),
                           INT8_C(   0), INT8_C(  78), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(  78), INT8_C(  78), INT8_C(   0),
                           INT8_C(   0), INT8_C(  78), INT8_C(  78), INT8_C(   0),
                           INT8_C(  78), INT8_C(  78), INT8_C(  78), INT8_C(  78),
                           INT8_C(   0), INT8_C(   0), INT8_C(  78), INT8_C(  78),
                           INT8_C(   0), INT8_C(   0), INT8_C(  78), INT8_C(  78),
                           INT8_C(  78), INT8_C(  78), INT8_C(   0), INT8_C(  78),
                           INT8_C(  78), INT8_C(  78), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(  78), INT8_C(  78), INT8_C(   0), INT8_C(  78),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(  78), INT8_C(   0), INT8_C(  78), INT8_C(   0),
                           INT8_C(  78), INT8_C(   0), INT8_C(  78), INT8_C(   0)) },
    { UINT64_C(13286373173549182748),
      INT8_C( -67),
      simde_mm512_set_epi8(INT8_C( -67), INT8_C(   0), INT8_C( -67), INT8_C( -67),
                           INT8_C( -67), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C( -67), INT8_C( -67), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C( -67), INT8_C(   0),
                           INT8_C( -67), INT8_C(   0), INT8_C( -67), INT8_C(   0),
                           INT8_C( -67), INT8_C( -67), INT8_C( -67), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C( -67),
                           INT8_C( -67), INT8_C( -67), INT8_C(   0), INT8_C( -67),
                           INT8_C(   0), INT8_C(   0), INT8_C( -67), INT8_C(   0),
                           INT8_C( -67), INT8_C(   0), INT8_C( -67), INT8_C(   0),
                           INT8_C( -67), INT8_C( -67), INT8_C(   0), INT8_C( -67),
                           INT8_C( -67), INT8_C(   0), INT8_C( -67), INT8_C(   0),
                           INT8_C( -67), INT8_C( -67), INT8_C( -67), INT8_C( -67),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C( -67),
                           INT8_C( -67), INT8_C( -67), INT8_C(   0), INT8_C(   0)) },
    { UINT64_C(16804997844821669286),
      INT8_C( -98),
      simde_mm512_set_epi8(INT8_C( -98), INT8_C( -98), INT8_C( -98), INT8_C(   0),
                           INT8_C( -98), INT8_C(   0), INT8_C(   0), INT8_C( -98),
                           INT8_C(   0), INT8_C(   0), INT8_C( -98), INT8_C( -98),
                           INT8_C(   0), INT8_C( -98), INT8_C( -98), INT8_C( -98),
                           INT8_C(   0), INT8_C( -98), INT8_C(   0), INT8_C( -98),
                           INT8_C( -98), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C( -98), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C( -98), INT8_C( -98), INT8_C(   0), INT8_C(   0),
                           INT8_C( -98), INT8_C( -98), INT8_C( -98), INT8_C( -98),
                           INT8_C( -98), INT8_C( -98), INT8_C(   0), INT8_C(   0),
                           INT8_C( -98), INT8_C( -98), INT8_C(   0), INT8_C(   0),
                           INT8_C( -98), INT8_C( -98), INT8_C( -98), INT8_C( -98),
                           INT8_C(   0), INT8_C( -98), INT8_C(   0), INT8_C( -98),
                           INT8_C( -98), INT8_C(   0), INT8_C( -98), INT8_C(   0),
                           INT8_C(   0), INT8_C( -98), INT8_C( -98), INT8_C(   0)) },
    { UINT64_C(14388383136321922859),
      INT8_C( -31),
      simde_mm512_set_epi8(INT8_C( -31), INT8_C( -31), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C( -31), INT8_C( -31), INT8_C( -31),
                           INT8_C( -31), INT8_C(   0), INT8_C( -31), INT8_C(   0),
                           INT8_C( -31), INT8_C( -31), INT8_C(   0), INT8_C( -31),
                           INT8_C( -31), INT8_C( -31), INT8_C(   0), INT8_C(   0),
                           INT8_C( -31), INT8_C( -31), INT8_C( -31), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C( -31), INT8_C( -31),
                           INT8_C( -31), INT8_C(   0), INT8_C( -31), INT8_C(   0),
                           INT8_C( -31), INT8_C( -31), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C( -31), INT8_C(   0), INT8_C(   0),
                           INT8_C( -31), INT8_C(   0), INT8_C( -31), INT8_C( -31),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C( -31), INT8_C( -31), INT8_C(   0),
                           INT8_C(   0), INT8_C( -31), INT8_C( -31), INT8_C( -31),
                           INT8_C(   0), INT8_C(   0), INT8_C( -31), INT8_C(   0),
                           INT8_C( -31), INT8_C(   0), INT8_C( -31), INT8_C( -31)) },
    { UINT64_C( 9693935732927043828),
      INT8_C(  57),
      simde_mm512_set_epi8(INT8_C(  57), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(  57), INT8_C(  57), INT8_C(   0),
                           INT8_C(  57), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(  57), INT8_C(  57), INT8_C(  57),
                           INT8_C(  57), INT8_C(  57), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(  57), INT8_C(  57), INT8_C(  57),
                           INT8_C(   0), INT8_C(   0), INT8_C(  57), INT8_C(  57),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(  57), INT8_C(  57),
                           INT8_C(  57), INT8_C(  57), INT8_C(   0), INT8_C(   0),
                           INT8_C(  57), INT8_C(   0), INT8_C(   0), INT8_C(  57),
                           INT8_C(   0), INT8_C(  57), INT8_C(   0), INT8_C(  57),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(  57),
                           INT8_C(  57), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(  57), INT8_C(  57), INT8_C(  57), INT8_C(  57),
                           INT8_C(   0), INT8_C(  57), INT8_C(   0), INT8_C(   0)) }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])); i++) {
    simde__m512i r = simde_mm512_maskz_set1_epi8(test_vec[i].k, test_vec[i].a);
    simde_assert_m512i_i8(r, ==, test_vec[i].r);
  }

  return 0;
}

static int
test_simde_mm512_mask_set1_epi16(SIMDE_MUNIT_TEST_ARGS) {
  const struct {
    simde__m512i src;
    simde__mmask32 k;
    int16_t a;
    simde__m512i r;
  } test_vec[8] = {
    { simde_mm512_set_epi16(INT16_C(   874), INT16_C( 15357), INT16_C(  3602), INT16_C( 11090),
                            INT16_C( 31475), INT16_C( 20808), INT16_C(-26328), INT16_C(-21794),
                            INT16_C(-24829), INT16_C(-15530), INT16_C( -9785), INT16_C( 22806),
                            INT16_C( -6385), INT16_C(-26604), INT16_C(-15351), INT16_C(-18936),
                            INT16_C( 28985), INT16_C( 24045), INT16_C(-25535), INT16_C(-25436),
                            INT16_C(   749), INT16_C( 15517), INT16_C(-24369), INT16_C(-27864),
                            INT16_C(  6864), INT16_C( 16553), INT16_C(  -407), INT16_C(-28514),
                            INT16_C( -9423), INT16_C(-29018), INT16_C(-11420), INT16_C(-22112)),
      UINT32_C(1121120418),
      INT16_C(-24380),
      simde_mm512_set_epi16(INT16_C(   874), INT16_C(-24380), INT16_C(  3602), INT16_C( 11090),
                            INT16_C( 31475), INT16_C( 20808), INT16_C(-24380), INT16_C(-21794),
                            INT16_C(-24380), INT16_C(-24380), INT16_C( -9785), INT16_C(-24380),
                            INT16_C( -6385), INT16_C(-26604), INT16_C(-24380), INT16_C(-18936),
                            INT16_C(-24380), INT16_C(-24380), INT16_C(-24380), INT16_C(-24380),
                            INT16_C(   749), INT16_C( 15517), INT16_C(-24369), INT16_C(-27864),
                            INT16_C(-24380), INT16_C( 16553), INT16_C(-24380), INT16_C(-28514),
                            INT16_C( -9423), INT16_C(-29018), INT16_C(-24380), INT16_C(-22112)) },
    { simde_mm512_set_epi16(INT16_C( 21630), INT16_C(    53), INT16_C(-30787), INT16_C( 11298),
                            INT16_C( 13120), INT16_C(-15891), INT16_C( 20834), INT16_C(  5170),
                            INT16_C( 11237), INT16_C(-32025), INT16_C(  2036), INT16_C(-32146),
                            INT16_C(  6820), INT16_C( 29964), INT16_C(-20673), INT16_C( -6255),
                            INT16_C( 12677), INT16_C(  5934), INT16_C( 18392), INT16_C(-16008),
                            INT16_C( -6967), INT16_C(-23263), INT16_C( 28759), INT16_C(  4932),
                            INT16_C(-20928), INT16_C(-12287), INT16_C(-21100), INT16_C(-15604),
                            INT16_C(-25734), INT16_C(-27889), INT16_C( 22154), INT16_C( 16749)),
      UINT32_C( 442706120),
      INT16_C(-18045),
      simde_mm512_set_epi16(INT16_C( 21630), INT16_C(    53), INT16_C(-30787), INT16_C(-18045),
                            INT16_C(-18045), INT16_C(-15891), INT16_C(-18045), INT16_C(  5170),
                            INT16_C( 11237), INT16_C(-18045), INT16_C(-18045), INT16_C(-32146),
                            INT16_C(  6820), INT16_C( 29964), INT16_C(-18045), INT16_C(-18045),
                            INT16_C( 12677), INT16_C(  5934), INT16_C(-18045), INT16_C(-16008),
                            INT16_C(-18045), INT16_C(-23263), INT16_C( 28759), INT16_C(  4932),
                            INT16_C(-18045), INT16_C(-18045), INT16_C(-21100), INT16_C(-15604),
                            INT16_C(-18045), INT16_C(-27889), INT16_C( 22154), INT16_C( 16749)) },
    { simde_mm512_set_epi16(INT16_C(-12675), INT16_C(-13885), INT16_C( -4000), INT16_C( 31908),
                            INT16_C( 16178), INT16_C( -8662), INT16_C(-27877), INT16_C(-11427),
                            INT16_C(-10847), INT16_C(  7965), INT16_C(-13767), INT16_C( 14192),
                            INT16_C( -3024), INT16_C(-20651), INT16_C(  1677), INT16_C(-14378),
                            INT16_C( 13823), INT16_C(-21716), INT16_C(-14569), INT16_C( 19205),
                            INT16_C(-19335), INT16_C( 31769), INT16_C(-13133), INT16_C(-12032),
                            INT16_C(-27851), INT16_C(-12954), INT16_C(-30941), INT16_C( 26210),
                            INT16_C( 10250), INT16_C(-12883), INT16_C(-31618), INT16_C(  -328)),
      UINT32_C(3083705480),
      INT16_C(  4440),
      simde_mm512_set_epi16(INT16_C(  4440), INT16_C(-13885), INT16_C(  4440), INT16_C(  4440),
                            INT16_C( 16178), INT16_C(  4440), INT16_C(  4440), INT16_C(  4440),
                            INT16_C(  4440), INT16_C(  4440), INT16_C(-13767), INT16_C( 14192),
                            INT16_C(  4440), INT16_C(  4440), INT16_C(  1677), INT16_C(  4440),
                            INT16_C(  4440), INT16_C(-21716), INT16_C(-14569), INT16_C(  4440),
                            INT16_C(  4440), INT16_C(  4440), INT16_C(-13133), INT16_C(-12032),
                            INT16_C(  4440), INT16_C(-12954), INT16_C(-30941), INT16_C( 26210),
                            INT16_C(  4440), INT16_C(-12883), INT16_C(-31618), INT16_C(  -328)) },
    { simde_mm512_set_epi16(INT16_C(-23201), INT16_C(  4909), INT16_C(-10596), INT16_C( 25003),
                            INT16_C( 25193), INT16_C(-28193), INT16_C(  7484), INT16_C( 22842),
                            INT16_C( 12827), INT16_C(-21490), INT16_C(-19021), INT16_C( 17939),
                            INT16_C( 14187), INT16_C( 31294), INT16_C(-22999), INT16_C( 25206),
                            INT16_C(-22002), INT16_C( 23505), INT16_C(-20713), INT16_C( 22238),
                            INT16_C( 29284), INT16_C( 28054), INT16_C(-21727), INT16_C( 30369),
                            INT16_C( 19358), INT16_C(  -623), INT16_C(  2386), INT16_C(  9395),
                            INT16_C(-11819), INT16_C( 28599), INT16_C(-11863), INT16_C( -4500)),
      UINT32_C(1729799485),
      INT16_C(   -51),
      simde_mm512_set_epi16(INT16_C(-23201), INT16_C(   -51), INT16_C(   -51), INT16_C( 25003),
                            INT16_C( 25193), INT16_C(   -51), INT16_C(   -51), INT16_C(   -51),
                            INT16_C( 12827), INT16_C(-21490), INT16_C(-19021), INT16_C(   -51),
                            INT16_C(   -51), INT16_C( 31294), INT16_C(   -51), INT16_C( 25206),
                            INT16_C(   -51), INT16_C( 23505), INT16_C(   -51), INT16_C( 22238),
                            INT16_C( 29284), INT16_C(   -51), INT16_C(-21727), INT16_C(   -51),
                            INT16_C( 19358), INT16_C(  -623), INT16_C(   -51), INT16_C(   -51),
                            INT16_C(   -51), INT16_C(   -51), INT16_C(-11863), INT16_C(   -51)) },
    { simde_mm512_set_epi16(INT16_C(-12929), INT16_C( -9559), INT16_C( -1255), INT16_C(-25300),
                            INT16_C( 24130), INT16_C( 22555), INT16_C(-26496), INT16_C(  4179),
                            INT16_C( 25227), INT16_C( 31028), INT16_C( 12492), INT16_C(-27096),
                            INT16_C( 22382), INT16_C( -5113), INT16_C(-30455), INT16_C( 15691),
                            INT16_C(-18605), INT16_C( -4278), INT16_C( 11441), INT16_C(-26478),
                            INT16_C( 11388), INT16_C(-27754), INT16_C(   607), INT16_C( -1601),
                            INT16_C(-14454), INT16_C(  1251), INT16_C( 27178), INT16_C( 11399),
                            INT16_C(  -184), INT16_C( 17990), INT16_C(-12132), INT16_C(-20400)),
      UINT32_C(3701546889),
      INT16_C( 26765),
      simde_mm512_set_epi16(INT16_C( 26765), INT16_C( 26765), INT16_C( -1255), INT16_C( 26765),
                            INT16_C( 26765), INT16_C( 26765), INT16_C(-26496), INT16_C(  4179),
                            INT16_C( 26765), INT16_C( 31028), INT16_C( 26765), INT16_C(-27096),
                            INT16_C( 22382), INT16_C( -5113), INT16_C(-30455), INT16_C( 26765),
                            INT16_C(-18605), INT16_C( -4278), INT16_C( 11441), INT16_C( 26765),
                            INT16_C( 26765), INT16_C( 26765), INT16_C( 26765), INT16_C( 26765),
                            INT16_C( 26765), INT16_C(  1251), INT16_C( 27178), INT16_C( 11399),
                            INT16_C( 26765), INT16_C( 17990), INT16_C(-12132), INT16_C( 26765)) },
    { simde_mm512_set_epi16(INT16_C( 23556), INT16_C( 11192), INT16_C(-13439), INT16_C( -2357),
                            INT16_C(   858), INT16_C( 27575), INT16_C( 20368), INT16_C(-20256),
                            INT16_C(-11019), INT16_C( -7073), INT16_C(-32385), INT16_C( 27749),
                            INT16_C( 17332), INT16_C(-28131), INT16_C( 22510), INT16_C(  -872),
                            INT16_C( 20986), INT16_C(-25896), INT16_C(  7561), INT16_C(-22951),
                            INT16_C( -9997), INT16_C( 18542), INT16_C( -1921), INT16_C(-16319),
                            INT16_C(-24759), INT16_C( 10467), INT16_C(  8453), INT16_C(  5278),
                            INT16_C(-22217), INT16_C( 17080), INT16_C( 16797), INT16_C( -9777)),
      UINT32_C(3298748633),
      INT16_C( -5240),
      simde_mm512_set_epi16(INT16_C( -5240), INT16_C( -5240), INT16_C(-13439), INT16_C( -2357),
                            INT16_C(   858), INT16_C( -5240), INT16_C( 20368), INT16_C(-20256),
                            INT16_C( -5240), INT16_C( -7073), INT16_C(-32385), INT16_C( -5240),
                            INT16_C( -5240), INT16_C( -5240), INT16_C( -5240), INT16_C(  -872),
                            INT16_C( -5240), INT16_C( -5240), INT16_C( -5240), INT16_C(-22951),
                            INT16_C( -5240), INT16_C( 18542), INT16_C( -1921), INT16_C(-16319),
                            INT16_C( -5240), INT16_C( -5240), INT16_C(  8453), INT16_C( -5240),
                            INT16_C( -5240), INT16_C( 17080), INT16_C( 16797), INT16_C( -5240)) },
    { simde_mm512_set_epi16(INT16_C(  -894), INT16_C( 15324), INT16_C(-23364), INT16_C( 25648),
                            INT16_C(  -512), INT16_C( 12172), INT16_C(-27706), INT16_C(-10514),
                            INT16_C(  1026), INT16_C( 20384), INT16_C(-25471), INT16_C( -3464),
                            INT16_C( 14827), INT16_C( 18045), INT16_C(-25826), INT16_C( 12664),
                            INT16_C(-16682), INT16_C( 16498), INT16_C( 29333), INT16_C(  -511),
                            INT16_C( 15382), INT16_C(-19710), INT16_C(-14139), INT16_C( 14459),
                            INT16_C( 16092), INT16_C(-12889), INT16_C(  -337), INT16_C( 29893),
                            INT16_C(-29467), INT16_C( -8274), INT16_C( 30322), INT16_C(-19138)),
      UINT32_C(3605268017),
      INT16_C(-14523),
      simde_mm512_set_epi16(INT16_C(-14523), INT16_C(-14523), INT16_C(-23364), INT16_C(-14523),
                            INT16_C(  -512), INT16_C(-14523), INT16_C(-14523), INT16_C(-10514),
                            INT16_C(-14523), INT16_C(-14523), INT16_C(-14523), INT16_C( -3464),
                            INT16_C( 14827), INT16_C(-14523), INT16_C(-25826), INT16_C( 12664),
                            INT16_C(-16682), INT16_C( 16498), INT16_C( 29333), INT16_C(  -511),
                            INT16_C( 15382), INT16_C(-14523), INT16_C(-14523), INT16_C( 14459),
                            INT16_C( 16092), INT16_C(-12889), INT16_C(-14523), INT16_C(-14523),
                            INT16_C(-29467), INT16_C( -8274), INT16_C( 30322), INT16_C(-14523)) },
    { simde_mm512_set_epi16(INT16_C( -6967), INT16_C(-20070), INT16_C( -8289), INT16_C(  -479),
                            INT16_C(-18969), INT16_C( -6012), INT16_C( 11721), INT16_C( 13564),
                            INT16_C( 19765), INT16_C( 23581), INT16_C(-21527), INT16_C( -2847),
                            INT16_C( 23178), INT16_C(-14967), INT16_C( 17682), INT16_C( 28255),
                            INT16_C(  8882), INT16_C( 14691), INT16_C(-27903), INT16_C( 28973),
                            INT16_C(   619), INT16_C(-10329), INT16_C( 25572), INT16_C(-13439),
                            INT16_C( -3930), INT16_C(  5659), INT16_C(  -675), INT16_C(-18004),
                            INT16_C(-26191), INT16_C(  5303), INT16_C(-13369), INT16_C( 21695)),
      UINT32_C( 349570055),
      INT16_C( 24210),
      simde_mm512_set_epi16(INT16_C( -6967), INT16_C(-20070), INT16_C( -8289), INT16_C( 24210),
                            INT16_C(-18969), INT16_C( 24210), INT16_C( 11721), INT16_C( 13564),
                            INT16_C( 24210), INT16_C( 24210), INT16_C(-21527), INT16_C( 24210),
                            INT16_C( 23178), INT16_C( 24210), INT16_C( 24210), INT16_C( 28255),
                            INT16_C(  8882), INT16_C( 14691), INT16_C(-27903), INT16_C( 28973),
                            INT16_C(   619), INT16_C( 24210), INT16_C( 25572), INT16_C(-13439),
                            INT16_C( -3930), INT16_C(  5659), INT16_C(  -675), INT16_C(-18004),
                            INT16_C(-26191), INT16_C( 24210), INT16_C( 24210), INT16_C( 24210)) }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])); i++) {
    simde__m512i r = simde_mm512_mask_set1_epi16(test_vec[i].src, test_vec[i].k, test_vec[i].a);
    simde_assert_m512i_i16(r, ==, test_vec[i].r);
  }

  return 0;
}

static int
test_simde_mm512_maskz_set1_epi16(SIMDE_MUNIT_TEST_ARGS) {
  const struct {
    simde__mmask32 k;
    int16_t a;
    simde__m512i r;
  } test_vec[8] = {
   {  UINT32_C( 693683203),
      INT16_C(-16188),
      simde_mm512_set_epi16(INT16_C(     0), INT16_C(     0), INT16_C(-16188), INT16_C(     0),
                            INT16_C(-16188), INT16_C(     0), INT16_C(     0), INT16_C(-16188),
                            INT16_C(     0), INT16_C(-16188), INT16_C(     0), INT16_C(-16188),
                            INT16_C(-16188), INT16_C(     0), INT16_C(     0), INT16_C(     0),
                            INT16_C(-16188), INT16_C(-16188), INT16_C(     0), INT16_C(     0),
                            INT16_C(     0), INT16_C(-16188), INT16_C(     0), INT16_C(     0),
                            INT16_C(     0), INT16_C(     0), INT16_C(     0), INT16_C(     0),
                            INT16_C(     0), INT16_C(     0), INT16_C(-16188), INT16_C(-16188)) },
   {  UINT32_C(2322862674),
      INT16_C(-31832),
      simde_mm512_set_epi16(INT16_C(-31832), INT16_C(     0), INT16_C(     0), INT16_C(     0),
                            INT16_C(-31832), INT16_C(     0), INT16_C(-31832), INT16_C(     0),
                            INT16_C(     0), INT16_C(-31832), INT16_C(-31832), INT16_C(-31832),
                            INT16_C(     0), INT16_C(-31832), INT16_C(     0), INT16_C(     0),
                            INT16_C(     0), INT16_C(     0), INT16_C(     0), INT16_C(-31832),
                            INT16_C(     0), INT16_C(     0), INT16_C(-31832), INT16_C(     0),
                            INT16_C(     0), INT16_C(-31832), INT16_C(     0), INT16_C(-31832),
                            INT16_C(     0), INT16_C(     0), INT16_C(-31832), INT16_C(     0)) },
   {  UINT32_C(3196780114),
      INT16_C(  8083),
      simde_mm512_set_epi16(INT16_C(  8083), INT16_C(     0), INT16_C(  8083), INT16_C(  8083),
                            INT16_C(  8083), INT16_C(  8083), INT16_C(  8083), INT16_C(     0),
                            INT16_C(  8083), INT16_C(     0), INT16_C(     0), INT16_C(     0),
                            INT16_C(  8083), INT16_C(     0), INT16_C(  8083), INT16_C(     0),
                            INT16_C(  8083), INT16_C(  8083), INT16_C(  8083), INT16_C(  8083),
                            INT16_C(  8083), INT16_C(  8083), INT16_C(  8083), INT16_C(     0),
                            INT16_C(     0), INT16_C(  8083), INT16_C(     0), INT16_C(  8083),
                            INT16_C(     0), INT16_C(     0), INT16_C(  8083), INT16_C(     0)) },
   {  UINT32_C( 962615778),
      INT16_C( 10134),
      simde_mm512_set_epi16(INT16_C(     0), INT16_C(     0), INT16_C( 10134), INT16_C( 10134),
                            INT16_C( 10134), INT16_C(     0), INT16_C(     0), INT16_C( 10134),
                            INT16_C(     0), INT16_C( 10134), INT16_C( 10134), INT16_C(     0),
                            INT16_C(     0), INT16_C(     0), INT16_C(     0), INT16_C(     0),
                            INT16_C(     0), INT16_C( 10134), INT16_C(     0), INT16_C( 10134),
                            INT16_C( 10134), INT16_C(     0), INT16_C(     0), INT16_C( 10134),
                            INT16_C( 10134), INT16_C( 10134), INT16_C( 10134), INT16_C(     0),
                            INT16_C(     0), INT16_C(     0), INT16_C( 10134), INT16_C(     0)) },
   {  UINT32_C(3651012064),
      INT16_C(-28841),
      simde_mm512_set_epi16(INT16_C(-28841), INT16_C(-28841), INT16_C(     0), INT16_C(-28841),
                            INT16_C(-28841), INT16_C(     0), INT16_C(     0), INT16_C(-28841),
                            INT16_C(-28841), INT16_C(     0), INT16_C(     0), INT16_C(-28841),
                            INT16_C(-28841), INT16_C(-28841), INT16_C(-28841), INT16_C(     0),
                            INT16_C(     0), INT16_C(     0), INT16_C(     0), INT16_C(     0),
                            INT16_C(     0), INT16_C(-28841), INT16_C(     0), INT16_C(-28841),
                            INT16_C(-28841), INT16_C(-28841), INT16_C(-28841), INT16_C(     0),
                            INT16_C(     0), INT16_C(     0), INT16_C(     0), INT16_C(     0)) },
   {  UINT32_C(1153035128),
      INT16_C(  9546),
      simde_mm512_set_epi16(INT16_C(     0), INT16_C(  9546), INT16_C(     0), INT16_C(     0),
                            INT16_C(     0), INT16_C(  9546), INT16_C(     0), INT16_C(     0),
                            INT16_C(  9546), INT16_C(     0), INT16_C(  9546), INT16_C(  9546),
                            INT16_C(  9546), INT16_C(     0), INT16_C(     0), INT16_C(  9546),
                            INT16_C(  9546), INT16_C(  9546), INT16_C(  9546), INT16_C(     0),
                            INT16_C(  9546), INT16_C(     0), INT16_C(  9546), INT16_C(  9546),
                            INT16_C(     0), INT16_C(  9546), INT16_C(  9546), INT16_C(  9546),
                            INT16_C(  9546), INT16_C(     0), INT16_C(     0), INT16_C(     0)) },
   {  UINT32_C(2648275992),
      INT16_C(-29002),
      simde_mm512_set_epi16(INT16_C(-29002), INT16_C(     0), INT16_C(     0), INT16_C(-29002),
                            INT16_C(-29002), INT16_C(-29002), INT16_C(     0), INT16_C(-29002),
                            INT16_C(-29002), INT16_C(-29002), INT16_C(     0), INT16_C(-29002),
                            INT16_C(-29002), INT16_C(     0), INT16_C(     0), INT16_C(-29002),
                            INT16_C(     0), INT16_C(-29002), INT16_C(-29002), INT16_C(-29002),
                            INT16_C(-29002), INT16_C(-29002), INT16_C(     0), INT16_C(     0),
                            INT16_C(     0), INT16_C(     0), INT16_C(     0), INT16_C(-29002),
                            INT16_C(-29002), INT16_C(     0), INT16_C(     0), INT16_C(     0)) },
   {  UINT32_C(1548742660),
      INT16_C( 11362),
      simde_mm512_set_epi16(INT16_C(     0), INT16_C( 11362), INT16_C(     0), INT16_C( 11362),
                            INT16_C( 11362), INT16_C( 11362), INT16_C(     0), INT16_C(     0),
                            INT16_C(     0), INT16_C( 11362), INT16_C(     0), INT16_C(     0),
                            INT16_C( 11362), INT16_C( 11362), INT16_C( 11362), INT16_C( 11362),
                            INT16_C( 11362), INT16_C( 11362), INT16_C( 11362), INT16_C( 11362),
                            INT16_C(     0), INT16_C(     0), INT16_C(     0), INT16_C(     0),
                            INT16_C(     0), INT16_C(     0), INT16_C(     0), INT16_C(     0),
                            INT16_C(     0), INT16_C( 11362), INT16_C(     0), INT16_C(     0)) }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])); i++) {
    simde__m512i r = simde_mm512_maskz_set1_epi16(test_vec[i].k, test_vec[i].a);
    simde_assert_m512i_i16(r, ==, test_vec[i].r);
  }

  return 0;
}

static int
test_simde_mm512_abs_epi8(SIMDE_MUNIT_TEST_ARGS) {
  const struct {
    simde__m512i a;
    simde__m512i r;
  } test_vec[8] = {
    { simde_mm512_set_epi8(INT8_C( -97), INT8_C(  22), INT8_C(  -8), INT8_C(-101),
                           INT8_C( -18), INT8_C( 124), INT8_C( -73), INT8_C( -35),
                           INT8_C(-107), INT8_C( 125), INT8_C( -49), INT8_C( -14),
                           INT8_C( -55), INT8_C(  -2), INT8_C(   3), INT8_C( -86),
                           INT8_C( -70), INT8_C( -16), INT8_C(  -3), INT8_C( -98),
                           INT8_C( -20), INT8_C( -18), INT8_C( -58), INT8_C( -57),
                           INT8_C( 119), INT8_C(  17), INT8_C( -79), INT8_C(  80),
                           INT8_C(  82), INT8_C(   3), INT8_C( -18), INT8_C( -99),
                           INT8_C(  25), INT8_C(  25), INT8_C(  83), INT8_C(  88),
                           INT8_C( 117), INT8_C(-128), INT8_C(  16), INT8_C( -42),
                           INT8_C( 114), INT8_C(  -1), INT8_C(-110), INT8_C(  53),
                           INT8_C( 127), INT8_C( -61), INT8_C( -68), INT8_C(  74),
                           INT8_C( 103), INT8_C(  92), INT8_C(-115), INT8_C( -60),
                           INT8_C( -23), INT8_C(  82), INT8_C(-123), INT8_C(  21),
                           INT8_C( -37), INT8_C( 119), INT8_C( -39), INT8_C( -31),
                           INT8_C(  25), INT8_C( -69), INT8_C( -57), INT8_C(  30)),
      simde_mm512_set_epi8(INT8_C(  97), INT8_C(  22), INT8_C(   8), INT8_C( 101),
                           INT8_C(  18), INT8_C( 124), INT8_C(  73), INT8_C(  35),
                           INT8_C( 107), INT8_C( 125), INT8_C(  49), INT8_C(  14),
                           INT8_C(  55), INT8_C(   2), INT8_C(   3), INT8_C(  86),
                           INT8_C(  70), INT8_C(  16), INT8_C(   3), INT8_C(  98),
                           INT8_C(  20), INT8_C(  18), INT8_C(  58), INT8_C(  57),
                           INT8_C( 119), INT8_C(  17), INT8_C(  79), INT8_C(  80),
                           INT8_C(  82), INT8_C(   3), INT8_C(  18), INT8_C(  99),
                           INT8_C(  25), INT8_C(  25), INT8_C(  83), INT8_C(  88),
                           INT8_C( 117), INT8_C(-128), INT8_C(  16), INT8_C(  42),
                           INT8_C( 114), INT8_C(   1), INT8_C( 110), INT8_C(  53),
                           INT8_C( 127), INT8_C(  61), INT8_C(  68), INT8_C(  74),
                           INT8_C( 103), INT8_C(  92), INT8_C( 115), INT8_C(  60),
                           INT8_C(  23), INT8_C(  82), INT8_C( 123), INT8_C(  21),
                           INT8_C(  37), INT8_C( 119), INT8_C(  39), INT8_C(  31),
                           INT8_C(  25), INT8_C(  69), INT8_C(  57), INT8_C(  30)) },
    { simde_mm512_set_epi8(INT8_C( 122), INT8_C(  62), INT8_C( -43), INT8_C( -88),
                           INT8_C(  92), INT8_C(-116), INT8_C(  -6), INT8_C(  36),
                           INT8_C(  10), INT8_C(   2), INT8_C( -66), INT8_C( 108),
                           INT8_C( -38), INT8_C( 112), INT8_C( 123), INT8_C(  87),
                           INT8_C(  99), INT8_C( -46), INT8_C( -53), INT8_C(  41),
                           INT8_C(-105), INT8_C( -98), INT8_C(  18), INT8_C( -12),
                           INT8_C( -82), INT8_C( 126), INT8_C( -77), INT8_C( -19),
                           INT8_C(  18), INT8_C(  16), INT8_C(  35), INT8_C( -10),
                           INT8_C( -58), INT8_C(  48), INT8_C(-120), INT8_C(  38),
                           INT8_C(  62), INT8_C(  17), INT8_C(  33), INT8_C(-120),
                           INT8_C( 106), INT8_C(  25), INT8_C( -91), INT8_C(  15),
                           INT8_C( 101), INT8_C( 114), INT8_C( -46), INT8_C( -58),
                           INT8_C( 113), INT8_C(   4), INT8_C(  50), INT8_C(  42),
                           INT8_C(  -1), INT8_C( -29), INT8_C( -27), INT8_C( -23),
                           INT8_C( -69), INT8_C(  92), INT8_C( -67), INT8_C(  89),
                           INT8_C( -10), INT8_C( -42), INT8_C(  79), INT8_C( 112)),
      simde_mm512_set_epi8(INT8_C( 122), INT8_C(  62), INT8_C(  43), INT8_C(  88),
                           INT8_C(  92), INT8_C( 116), INT8_C(   6), INT8_C(  36),
                           INT8_C(  10), INT8_C(   2), INT8_C(  66), INT8_C( 108),
                           INT8_C(  38), INT8_C( 112), INT8_C( 123), INT8_C(  87),
                           INT8_C(  99), INT8_C(  46), INT8_C(  53), INT8_C(  41),
                           INT8_C( 105), INT8_C(  98), INT8_C(  18), INT8_C(  12),
                           INT8_C(  82), INT8_C( 126), INT8_C(  77), INT8_C(  19),
                           INT8_C(  18), INT8_C(  16), INT8_C(  35), INT8_C(  10),
                           INT8_C(  58), INT8_C(  48), INT8_C( 120), INT8_C(  38),
                           INT8_C(  62), INT8_C(  17), INT8_C(  33), INT8_C( 120),
                           INT8_C( 106), INT8_C(  25), INT8_C(  91), INT8_C(  15),
                           INT8_C( 101), INT8_C( 114), INT8_C(  46), INT8_C(  58),
                           INT8_C( 113), INT8_C(   4), INT8_C(  50), INT8_C(  42),
                           INT8_C(   1), INT8_C(  29), INT8_C(  27), INT8_C(  23),
                           INT8_C(  69), INT8_C(  92), INT8_C(  67), INT8_C(  89),
                           INT8_C(  10), INT8_C(  42), INT8_C(  79), INT8_C( 112)) },
    { simde_mm512_set_epi8(INT8_C(-115), INT8_C( 121), INT8_C( -28), INT8_C( -32),
                           INT8_C(  39), INT8_C(  97), INT8_C( 104), INT8_C( -44),
                           INT8_C( 120), INT8_C( -11), INT8_C( -74), INT8_C( -63),
                           INT8_C( -24), INT8_C( -35), INT8_C(-108), INT8_C(  -9),
                           INT8_C(  30), INT8_C( -94), INT8_C(  96), INT8_C(-119),
                           INT8_C( -14), INT8_C( -94), INT8_C(  34), INT8_C(-111),
                           INT8_C(  86), INT8_C(  -6), INT8_C(-116), INT8_C(  56),
                           INT8_C(  -2), INT8_C(  -8), INT8_C( -66), INT8_C(  73),
                           INT8_C(-111), INT8_C(  20), INT8_C( 114), INT8_C(  16),
                           INT8_C(  71), INT8_C(  17), INT8_C( -13), INT8_C(-101),
                           INT8_C(  32), INT8_C(  52), INT8_C(  -6), INT8_C( -16),
                           INT8_C(  78), INT8_C(  58), INT8_C(  14), INT8_C( -85),
                           INT8_C( -58), INT8_C( 120), INT8_C( 102), INT8_C(-125),
                           INT8_C(  73), INT8_C(-121), INT8_C(-118), INT8_C( -77),
                           INT8_C(  84), INT8_C(  62), INT8_C( 100), INT8_C(-122),
                           INT8_C( -17), INT8_C(  81), INT8_C( 105), INT8_C( -71)),
      simde_mm512_set_epi8(INT8_C( 115), INT8_C( 121), INT8_C(  28), INT8_C(  32),
                           INT8_C(  39), INT8_C(  97), INT8_C( 104), INT8_C(  44),
                           INT8_C( 120), INT8_C(  11), INT8_C(  74), INT8_C(  63),
                           INT8_C(  24), INT8_C(  35), INT8_C( 108), INT8_C(   9),
                           INT8_C(  30), INT8_C(  94), INT8_C(  96), INT8_C( 119),
                           INT8_C(  14), INT8_C(  94), INT8_C(  34), INT8_C( 111),
                           INT8_C(  86), INT8_C(   6), INT8_C( 116), INT8_C(  56),
                           INT8_C(   2), INT8_C(   8), INT8_C(  66), INT8_C(  73),
                           INT8_C( 111), INT8_C(  20), INT8_C( 114), INT8_C(  16),
                           INT8_C(  71), INT8_C(  17), INT8_C(  13), INT8_C( 101),
                           INT8_C(  32), INT8_C(  52), INT8_C(   6), INT8_C(  16),
                           INT8_C(  78), INT8_C(  58), INT8_C(  14), INT8_C(  85),
                           INT8_C(  58), INT8_C( 120), INT8_C( 102), INT8_C( 125),
                           INT8_C(  73), INT8_C( 121), INT8_C( 118), INT8_C(  77),
                           INT8_C(  84), INT8_C(  62), INT8_C( 100), INT8_C( 122),
                           INT8_C(  17), INT8_C(  81), INT8_C( 105), INT8_C(  71)) },
    { simde_mm512_set_epi8(INT8_C( 104), INT8_C(  89), INT8_C(  23), INT8_C( -69),
                           INT8_C( -81), INT8_C( -18), INT8_C(-115), INT8_C(  45),
                           INT8_C( 111), INT8_C(  97), INT8_C( -96), INT8_C( -52),
                           INT8_C( 117), INT8_C( -89), INT8_C(  83), INT8_C(  55),
                           INT8_C( -79), INT8_C( -41), INT8_C(  65), INT8_C( -18),
                           INT8_C( -14), INT8_C( -36), INT8_C(  -5), INT8_C(-118),
                           INT8_C( 102), INT8_C(  66), INT8_C(   6), INT8_C(  63),
                           INT8_C(   2), INT8_C(  71), INT8_C( -79), INT8_C( 103),
                           INT8_C(  99), INT8_C(  75), INT8_C(  18), INT8_C(-125),
                           INT8_C(  89), INT8_C(  97), INT8_C( -12), INT8_C( -68),
                           INT8_C( -29), INT8_C(  64), INT8_C(  90), INT8_C( 106),
                           INT8_C( -66), INT8_C(  46), INT8_C( -67), INT8_C(-122),
                           INT8_C(  35), INT8_C(  89), INT8_C(-123), INT8_C(  49),
                           INT8_C(  79), INT8_C(-111), INT8_C( 102), INT8_C(  13),
                           INT8_C(  18), INT8_C(   7), INT8_C(  11), INT8_C( -54),
                           INT8_C(  79), INT8_C( -18), INT8_C(  80), INT8_C(  58)),
      simde_mm512_set_epi8(INT8_C( 104), INT8_C(  89), INT8_C(  23), INT8_C(  69),
                           INT8_C(  81), INT8_C(  18), INT8_C( 115), INT8_C(  45),
                           INT8_C( 111), INT8_C(  97), INT8_C(  96), INT8_C(  52),
                           INT8_C( 117), INT8_C(  89), INT8_C(  83), INT8_C(  55),
                           INT8_C(  79), INT8_C(  41), INT8_C(  65), INT8_C(  18),
                           INT8_C(  14), INT8_C(  36), INT8_C(   5), INT8_C( 118),
                           INT8_C( 102), INT8_C(  66), INT8_C(   6), INT8_C(  63),
                           INT8_C(   2), INT8_C(  71), INT8_C(  79), INT8_C( 103),
                           INT8_C(  99), INT8_C(  75), INT8_C(  18), INT8_C( 125),
                           INT8_C(  89), INT8_C(  97), INT8_C(  12), INT8_C(  68),
                           INT8_C(  29), INT8_C(  64), INT8_C(  90), INT8_C( 106),
                           INT8_C(  66), INT8_C(  46), INT8_C(  67), INT8_C( 122),
                           INT8_C(  35), INT8_C(  89), INT8_C( 123), INT8_C(  49),
                           INT8_C(  79), INT8_C( 111), INT8_C( 102), INT8_C(  13),
                           INT8_C(  18), INT8_C(   7), INT8_C(  11), INT8_C(  54),
                           INT8_C(  79), INT8_C(  18), INT8_C(  80), INT8_C(  58)) },
    { simde_mm512_set_epi8(INT8_C( -69), INT8_C( -18), INT8_C( -24), INT8_C(  31),
                           INT8_C(-118), INT8_C(  28), INT8_C( 111), INT8_C(   9),
                           INT8_C( -62), INT8_C(   2), INT8_C(  24), INT8_C(  57),
                           INT8_C(  60), INT8_C(  85), INT8_C(-124), INT8_C(   4),
                           INT8_C( -47), INT8_C(  -2), INT8_C( -42), INT8_C(   4),
                           INT8_C(-111), INT8_C(   1), INT8_C(  -7), INT8_C(  49),
                           INT8_C(  87), INT8_C(-117), INT8_C(  70), INT8_C( -68),
                           INT8_C(  92), INT8_C(  73), INT8_C( 108), INT8_C(   6),
                           INT8_C( 108), INT8_C( -36), INT8_C(  61), INT8_C(  29),
                           INT8_C(  87), INT8_C(  64), INT8_C(-117), INT8_C(  17),
                           INT8_C( -12), INT8_C(  46), INT8_C( -75), INT8_C(  42),
                           INT8_C(  80), INT8_C( -38), INT8_C(  85), INT8_C(-124),
                           INT8_C(-126), INT8_C( -12), INT8_C(  41), INT8_C(  12),
                           INT8_C( -57), INT8_C( -47), INT8_C(  80), INT8_C( -60),
                           INT8_C(  24), INT8_C(  89), INT8_C( -45), INT8_C(-122),
                           INT8_C( -52), INT8_C(  21), INT8_C(  54), INT8_C( 124)),
      simde_mm512_set_epi8(INT8_C(  69), INT8_C(  18), INT8_C(  24), INT8_C(  31),
                           INT8_C( 118), INT8_C(  28), INT8_C( 111), INT8_C(   9),
                           INT8_C(  62), INT8_C(   2), INT8_C(  24), INT8_C(  57),
                           INT8_C(  60), INT8_C(  85), INT8_C( 124), INT8_C(   4),
                           INT8_C(  47), INT8_C(   2), INT8_C(  42), INT8_C(   4),
                           INT8_C( 111), INT8_C(   1), INT8_C(   7), INT8_C(  49),
                           INT8_C(  87), INT8_C( 117), INT8_C(  70), INT8_C(  68),
                           INT8_C(  92), INT8_C(  73), INT8_C( 108), INT8_C(   6),
                           INT8_C( 108), INT8_C(  36), INT8_C(  61), INT8_C(  29),
                           INT8_C(  87), INT8_C(  64), INT8_C( 117), INT8_C(  17),
                           INT8_C(  12), INT8_C(  46), INT8_C(  75), INT8_C(  42),
                           INT8_C(  80), INT8_C(  38), INT8_C(  85), INT8_C( 124),
                           INT8_C( 126), INT8_C(  12), INT8_C(  41), INT8_C(  12),
                           INT8_C(  57), INT8_C(  47), INT8_C(  80), INT8_C(  60),
                           INT8_C(  24), INT8_C(  89), INT8_C(  45), INT8_C( 122),
                           INT8_C(  52), INT8_C(  21), INT8_C(  54), INT8_C( 124)) },
    { simde_mm512_set_epi8(INT8_C(  23), INT8_C( -45), INT8_C( -87), INT8_C(-128),
                           INT8_C(  79), INT8_C(  64), INT8_C( -72), INT8_C( 109),
                           INT8_C(  -1), INT8_C( 120), INT8_C( -18), INT8_C(-122),
                           INT8_C( -56), INT8_C(   0), INT8_C( 100), INT8_C(  60),
                           INT8_C( -78), INT8_C( -63), INT8_C(  26), INT8_C(  35),
                           INT8_C( -65), INT8_C(  72), INT8_C(  38), INT8_C( -77),
                           INT8_C(-123), INT8_C( 106), INT8_C(   7), INT8_C(  83),
                           INT8_C(  87), INT8_C( 105), INT8_C( -86), INT8_C(  65),
                           INT8_C( -41), INT8_C( 111), INT8_C( -74), INT8_C( -72),
                           INT8_C(  30), INT8_C( -92), INT8_C(  62), INT8_C( -69),
                           INT8_C( -56), INT8_C( 120), INT8_C(  86), INT8_C(  20),
                           INT8_C( -82), INT8_C(  72), INT8_C(  45), INT8_C(  66),
                           INT8_C( -71), INT8_C(-128), INT8_C( -35), INT8_C(  10),
                           INT8_C( -92), INT8_C( -41), INT8_C( 102), INT8_C( -89),
                           INT8_C(  47), INT8_C(  44), INT8_C(  12), INT8_C(  18),
                           INT8_C( -29), INT8_C( 113), INT8_C( -21), INT8_C( 122)),
      simde_mm512_set_epi8(INT8_C(  23), INT8_C(  45), INT8_C(  87), INT8_C(-128),
                           INT8_C(  79), INT8_C(  64), INT8_C(  72), INT8_C( 109),
                           INT8_C(   1), INT8_C( 120), INT8_C(  18), INT8_C( 122),
                           INT8_C(  56), INT8_C(   0), INT8_C( 100), INT8_C(  60),
                           INT8_C(  78), INT8_C(  63), INT8_C(  26), INT8_C(  35),
                           INT8_C(  65), INT8_C(  72), INT8_C(  38), INT8_C(  77),
                           INT8_C( 123), INT8_C( 106), INT8_C(   7), INT8_C(  83),
                           INT8_C(  87), INT8_C( 105), INT8_C(  86), INT8_C(  65),
                           INT8_C(  41), INT8_C( 111), INT8_C(  74), INT8_C(  72),
                           INT8_C(  30), INT8_C(  92), INT8_C(  62), INT8_C(  69),
                           INT8_C(  56), INT8_C( 120), INT8_C(  86), INT8_C(  20),
                           INT8_C(  82), INT8_C(  72), INT8_C(  45), INT8_C(  66),
                           INT8_C(  71), INT8_C(-128), INT8_C(  35), INT8_C(  10),
                           INT8_C(  92), INT8_C(  41), INT8_C( 102), INT8_C(  89),
                           INT8_C(  47), INT8_C(  44), INT8_C(  12), INT8_C(  18),
                           INT8_C(  29), INT8_C( 113), INT8_C(  21), INT8_C( 122)) },
    { simde_mm512_set_epi8(INT8_C(   6), INT8_C( -58), INT8_C( -97), INT8_C(  99),
                           INT8_C(  24), INT8_C( 108), INT8_C( -42), INT8_C( 116),
                           INT8_C( -51), INT8_C(  37), INT8_C(  17), INT8_C(  87),
                           INT8_C( 119), INT8_C(  22), INT8_C(  38), INT8_C( -86),
                           INT8_C(  70), INT8_C( -19), INT8_C( 116), INT8_C(   4),
                           INT8_C( -77), INT8_C( -68), INT8_C(  19), INT8_C( -39),
                           INT8_C(  -4), INT8_C(-120), INT8_C(  84), INT8_C( -27),
                           INT8_C( -68), INT8_C( 120), INT8_C(-117), INT8_C( -33),
                           INT8_C(   3), INT8_C( 109), INT8_C(  85), INT8_C( -14),
                           INT8_C( 121), INT8_C(  30), INT8_C( 108), INT8_C(  -1),
                           INT8_C( 114), INT8_C( -61), INT8_C(  46), INT8_C(  93),
                           INT8_C(  48), INT8_C( -57), INT8_C( -97), INT8_C(-100),
                           INT8_C(  84), INT8_C(   0), INT8_C( -87), INT8_C( -47),
                           INT8_C(  85), INT8_C(   2), INT8_C( 125), INT8_C(  35),
                           INT8_C( -12), INT8_C(  -7), INT8_C(   3), INT8_C(   4),
                           INT8_C(  86), INT8_C( 111), INT8_C( -66), INT8_C(  29)),
      simde_mm512_set_epi8(INT8_C(   6), INT8_C(  58), INT8_C(  97), INT8_C(  99),
                           INT8_C(  24), INT8_C( 108), INT8_C(  42), INT8_C( 116),
                           INT8_C(  51), INT8_C(  37), INT8_C(  17), INT8_C(  87),
                           INT8_C( 119), INT8_C(  22), INT8_C(  38), INT8_C(  86),
                           INT8_C(  70), INT8_C(  19), INT8_C( 116), INT8_C(   4),
                           INT8_C(  77), INT8_C(  68), INT8_C(  19), INT8_C(  39),
                           INT8_C(   4), INT8_C( 120), INT8_C(  84), INT8_C(  27),
                           INT8_C(  68), INT8_C( 120), INT8_C( 117), INT8_C(  33),
                           INT8_C(   3), INT8_C( 109), INT8_C(  85), INT8_C(  14),
                           INT8_C( 121), INT8_C(  30), INT8_C( 108), INT8_C(   1),
                           INT8_C( 114), INT8_C(  61), INT8_C(  46), INT8_C(  93),
                           INT8_C(  48), INT8_C(  57), INT8_C(  97), INT8_C( 100),
                           INT8_C(  84), INT8_C(   0), INT8_C(  87), INT8_C(  47),
                           INT8_C(  85), INT8_C(   2), INT8_C( 125), INT8_C(  35),
                           INT8_C(  12), INT8_C(   7), INT8_C(   3), INT8_C(   4),
                           INT8_C(  86), INT8_C( 111), INT8_C(  66), INT8_C(  29)) },
    { simde_mm512_set_epi8(INT8_C(  48), INT8_C(  61), INT8_C( 127), INT8_C(  76),
                           INT8_C( -86), INT8_C( 122), INT8_C( -96), INT8_C(-118),
                           INT8_C( -38), INT8_C(  -8), INT8_C(  56), INT8_C(-108),
                           INT8_C(   1), INT8_C(   8), INT8_C(  22), INT8_C(-116),
                           INT8_C( -52), INT8_C(  92), INT8_C(  68), INT8_C( 112),
                           INT8_C( -94), INT8_C( -84), INT8_C(  98), INT8_C( -49),
                           INT8_C( -43), INT8_C( 105), INT8_C(  71), INT8_C(  34),
                           INT8_C(-126), INT8_C(  -5), INT8_C(   5), INT8_C( -61),
                           INT8_C(-125), INT8_C( -31), INT8_C(-128), INT8_C( -41),
                           INT8_C(  82), INT8_C(  17), INT8_C( -47), INT8_C(-121),
                           INT8_C(   0), INT8_C( 118), INT8_C( -18), INT8_C( -96),
                           INT8_C(  45), INT8_C(  28), INT8_C( 105), INT8_C(-104),
                           INT8_C( -15), INT8_C(  24), INT8_C(  94), INT8_C( 103),
                           INT8_C( -54), INT8_C(-112), INT8_C(  15), INT8_C( 123),
                           INT8_C( -27), INT8_C( 121), INT8_C(-118), INT8_C(-112),
                           INT8_C( -70), INT8_C(  97), INT8_C(  58), INT8_C( -42)),
      simde_mm512_set_epi8(INT8_C(  48), INT8_C(  61), INT8_C( 127), INT8_C(  76),
                           INT8_C(  86), INT8_C( 122), INT8_C(  96), INT8_C( 118),
                           INT8_C(  38), INT8_C(   8), INT8_C(  56), INT8_C( 108),
                           INT8_C(   1), INT8_C(   8), INT8_C(  22), INT8_C( 116),
                           INT8_C(  52), INT8_C(  92), INT8_C(  68), INT8_C( 112),
                           INT8_C(  94), INT8_C(  84), INT8_C(  98), INT8_C(  49),
                           INT8_C(  43), INT8_C( 105), INT8_C(  71), INT8_C(  34),
                           INT8_C( 126), INT8_C(   5), INT8_C(   5), INT8_C(  61),
                           INT8_C( 125), INT8_C(  31), INT8_C(-128), INT8_C(  41),
                           INT8_C(  82), INT8_C(  17), INT8_C(  47), INT8_C( 121),
                           INT8_C(   0), INT8_C( 118), INT8_C(  18), INT8_C(  96),
                           INT8_C(  45), INT8_C(  28), INT8_C( 105), INT8_C( 104),
                           INT8_C(  15), INT8_C(  24), INT8_C(  94), INT8_C( 103),
                           INT8_C(  54), INT8_C( 112), INT8_C(  15), INT8_C( 123),
                           INT8_C(  27), INT8_C( 121), INT8_C( 118), INT8_C( 112),
                           INT8_C(  70), INT8_C(  97), INT8_C(  58), INT8_C(  42)) }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])); i++) {
    simde__m512i r = simde_mm512_abs_epi8(test_vec[i].a);
    simde_assert_m512i_i8(r, ==, test_vec[i].r);
  }

  return 0;
}

static int
test_simde_mm512_mask_abs_epi8(SIMDE_MUNIT_TEST_ARGS) {
  const struct {
    simde__m512i src;
    simde__mmask64 k;
    simde__m512i a;
    simde__m512i r;
  } test_vec[8] = {
    { simde_mm512_set_epi8(INT8_C( 117), INT8_C(-104), INT8_C( -35), INT8_C( -40),
                           INT8_C(  -1), INT8_C(  43), INT8_C(  10), INT8_C( -45),
                           INT8_C( -42), INT8_C(  80), INT8_C( -69), INT8_C( -15),
                           INT8_C( -14), INT8_C(-122), INT8_C(  60), INT8_C(  93),
                           INT8_C(  23), INT8_C( 122), INT8_C(  10), INT8_C( 108),
                           INT8_C( -24), INT8_C( -65), INT8_C( -39), INT8_C( -98),
                           INT8_C( -57), INT8_C(  -6), INT8_C(  81), INT8_C( -45),
                           INT8_C( -27), INT8_C(  28), INT8_C( -85), INT8_C(  15),
                           INT8_C(-118), INT8_C(  52), INT8_C(  10), INT8_C(-116),
                           INT8_C(  26), INT8_C( -43), INT8_C( -38), INT8_C( -27),
                           INT8_C(  66), INT8_C( -52), INT8_C(   5), INT8_C(  -1),
                           INT8_C( -28), INT8_C(   3), INT8_C( 123), INT8_C(-116),
                           INT8_C( -34), INT8_C( -32), INT8_C(  98), INT8_C( 103),
                           INT8_C( -19), INT8_C(-118), INT8_C( -77), INT8_C( -32),
                           INT8_C(  60), INT8_C( -80), INT8_C(  22), INT8_C( -26),
                           INT8_C(  60), INT8_C( -12), INT8_C( -65), INT8_C(  88)),
      UINT64_C(          2117573942),
      simde_mm512_set_epi8(INT8_C(  32), INT8_C(  22), INT8_C(  88), INT8_C( -34),
                           INT8_C(  12), INT8_C(  90), INT8_C(-101), INT8_C(  -4),
                           INT8_C( -14), INT8_C(  42), INT8_C( -87), INT8_C( 105),
                           INT8_C(  22), INT8_C(  34), INT8_C( 113), INT8_C( -72),
                           INT8_C( -40), INT8_C( -70), INT8_C( -24), INT8_C( -97),
                           INT8_C( -68), INT8_C(  -6), INT8_C(  98), INT8_C(-124),
                           INT8_C( -35), INT8_C(  11), INT8_C(-118), INT8_C( -49),
                           INT8_C( -42), INT8_C(  24), INT8_C( -34), INT8_C(  73),
                           INT8_C(  -3), INT8_C( -72), INT8_C(-103), INT8_C(  26),
                           INT8_C( -36), INT8_C(-109), INT8_C(  37), INT8_C(  50),
                           INT8_C(  26), INT8_C(  78), INT8_C(  33), INT8_C(  67),
                           INT8_C(  -8), INT8_C( -66), INT8_C(  29), INT8_C(  31),
                           INT8_C(  34), INT8_C(  40), INT8_C( -67), INT8_C(  86),
                           INT8_C(  38), INT8_C(-128), INT8_C(-106), INT8_C( -15),
                           INT8_C( 100), INT8_C(  53), INT8_C(  42), INT8_C(  55),
                           INT8_C(  87), INT8_C( -15), INT8_C(  -5), INT8_C( -85)),
      simde_mm512_set_epi8(INT8_C( 117), INT8_C(-104), INT8_C( -35), INT8_C( -40),
                           INT8_C(  -1), INT8_C(  43), INT8_C(  10), INT8_C( -45),
                           INT8_C( -42), INT8_C(  80), INT8_C( -69), INT8_C( -15),
                           INT8_C( -14), INT8_C(-122), INT8_C(  60), INT8_C(  93),
                           INT8_C(  23), INT8_C( 122), INT8_C(  10), INT8_C( 108),
                           INT8_C( -24), INT8_C( -65), INT8_C( -39), INT8_C( -98),
                           INT8_C( -57), INT8_C(  -6), INT8_C(  81), INT8_C( -45),
                           INT8_C( -27), INT8_C(  28), INT8_C( -85), INT8_C(  15),
                           INT8_C(-118), INT8_C(  72), INT8_C( 103), INT8_C(  26),
                           INT8_C(  36), INT8_C( 109), INT8_C(  37), INT8_C( -27),
                           INT8_C(  66), INT8_C( -52), INT8_C(  33), INT8_C(  67),
                           INT8_C( -28), INT8_C(  66), INT8_C(  29), INT8_C(  31),
                           INT8_C(  34), INT8_C( -32), INT8_C(  98), INT8_C(  86),
                           INT8_C(  38), INT8_C(-128), INT8_C( -77), INT8_C(  15),
                           INT8_C(  60), INT8_C( -80), INT8_C(  42), INT8_C(  55),
                           INT8_C(  60), INT8_C(  15), INT8_C(   5), INT8_C(  88)) },
    { simde_mm512_set_epi8(INT8_C( -27), INT8_C(-108), INT8_C(-117), INT8_C( -88),
                           INT8_C(-107), INT8_C(  53), INT8_C( -16), INT8_C(  -1),
                           INT8_C( -92), INT8_C(-119), INT8_C(  17), INT8_C(-122),
                           INT8_C(  22), INT8_C( -13), INT8_C(   7), INT8_C(-126),
                           INT8_C( -24), INT8_C( -51), INT8_C( -29), INT8_C(-114),
                           INT8_C( 100), INT8_C( -53), INT8_C(   0), INT8_C(-112),
                           INT8_C( -80), INT8_C(  89), INT8_C(  91), INT8_C(   1),
                           INT8_C( 102), INT8_C(  -2), INT8_C( -67), INT8_C( -88),
                           INT8_C(  -5), INT8_C( -85), INT8_C(  24), INT8_C(  13),
                           INT8_C(  67), INT8_C(  49), INT8_C(  20), INT8_C( -71),
                           INT8_C( -24), INT8_C(  19), INT8_C( -18), INT8_C(  58),
                           INT8_C( 109), INT8_C(-116), INT8_C(  95), INT8_C(  71),
                           INT8_C(  47), INT8_C( 118), INT8_C( -15), INT8_C( -31),
                           INT8_C( -70), INT8_C( -81), INT8_C(  45), INT8_C(  88),
                           INT8_C( -92), INT8_C(  95), INT8_C(  -3), INT8_C( -29),
                           INT8_C(  20), INT8_C( -86), INT8_C(  -5), INT8_C(  57)),
      UINT64_C(          3796566764),
      simde_mm512_set_epi8(INT8_C( -74), INT8_C(   1), INT8_C( -40), INT8_C(  93),
                           INT8_C(  28), INT8_C(  66), INT8_C(  14), INT8_C( 119),
                           INT8_C(  -8), INT8_C(-103), INT8_C( 124), INT8_C( -64),
                           INT8_C(  -5), INT8_C(  73), INT8_C(  83), INT8_C(-107),
                           INT8_C( -64), INT8_C( -31), INT8_C(  11), INT8_C(  45),
                           INT8_C( -14), INT8_C(-110), INT8_C( 100), INT8_C(  -6),
                           INT8_C( -50), INT8_C(-123), INT8_C( -94), INT8_C(  12),
                           INT8_C( -29), INT8_C(-100), INT8_C(  97), INT8_C(-115),
                           INT8_C( 103), INT8_C( -79), INT8_C( 102), INT8_C(  -6),
                           INT8_C( -20), INT8_C(-105), INT8_C(  -6), INT8_C(  69),
                           INT8_C(  19), INT8_C( 102), INT8_C(-126), INT8_C( -17),
                           INT8_C(  26), INT8_C(-105), INT8_C(  91), INT8_C( -38),
                           INT8_C( 106), INT8_C(   8), INT8_C(  85), INT8_C( -66),
                           INT8_C(  40), INT8_C( -49), INT8_C(  10), INT8_C(  15),
                           INT8_C(  30), INT8_C(  97), INT8_C( -48), INT8_C(  26),
                           INT8_C(  77), INT8_C( 104), INT8_C(-118), INT8_C(  49)),
      simde_mm512_set_epi8(INT8_C( -27), INT8_C(-108), INT8_C(-117), INT8_C( -88),
                           INT8_C(-107), INT8_C(  53), INT8_C( -16), INT8_C(  -1),
                           INT8_C( -92), INT8_C(-119), INT8_C(  17), INT8_C(-122),
                           INT8_C(  22), INT8_C( -13), INT8_C(   7), INT8_C(-126),
                           INT8_C( -24), INT8_C( -51), INT8_C( -29), INT8_C(-114),
                           INT8_C( 100), INT8_C( -53), INT8_C(   0), INT8_C(-112),
                           INT8_C( -80), INT8_C(  89), INT8_C(  91), INT8_C(   1),
                           INT8_C( 102), INT8_C(  -2), INT8_C( -67), INT8_C( -88),
                           INT8_C( 103), INT8_C(  79), INT8_C( 102), INT8_C(  13),
                           INT8_C(  67), INT8_C(  49), INT8_C(   6), INT8_C( -71),
                           INT8_C( -24), INT8_C( 102), INT8_C( -18), INT8_C(  58),
                           INT8_C(  26), INT8_C(-116), INT8_C(  91), INT8_C(  38),
                           INT8_C(  47), INT8_C( 118), INT8_C( -15), INT8_C( -31),
                           INT8_C( -70), INT8_C( -81), INT8_C(  10), INT8_C(  88),
                           INT8_C(  30), INT8_C(  97), INT8_C(  48), INT8_C( -29),
                           INT8_C(  77), INT8_C( 104), INT8_C(  -5), INT8_C(  57)) },
    { simde_mm512_set_epi8(INT8_C(  64), INT8_C(  45), INT8_C( -70), INT8_C(  94),
                           INT8_C( 127), INT8_C( -70), INT8_C( 127), INT8_C( -78),
                           INT8_C( -58), INT8_C(  92), INT8_C( -25), INT8_C(  -8),
                           INT8_C(  21), INT8_C(  89), INT8_C(   8), INT8_C(   1),
                           INT8_C(  85), INT8_C(   5), INT8_C( 111), INT8_C( 109),
                           INT8_C(   6), INT8_C( -27), INT8_C(  18), INT8_C(  62),
                           INT8_C(  -7), INT8_C( 126), INT8_C( -22), INT8_C( -36),
                           INT8_C( -10), INT8_C(  -1), INT8_C(   1), INT8_C( 115),
                           INT8_C(  87), INT8_C(  93), INT8_C( -71), INT8_C(-100),
                           INT8_C( -92), INT8_C( 103), INT8_C( -19), INT8_C(  -4),
                           INT8_C( 126), INT8_C( 112), INT8_C( -72), INT8_C(  45),
                           INT8_C(  61), INT8_C( -10), INT8_C(  68), INT8_C( -93),
                           INT8_C(   5), INT8_C( 127), INT8_C( 109), INT8_C( -62),
                           INT8_C( -89), INT8_C(-117), INT8_C(-126), INT8_C(  52),
                           INT8_C(  -8), INT8_C( -92), INT8_C( -23), INT8_C( -48),
                           INT8_C( 104), INT8_C(-120), INT8_C(  -2), INT8_C(-108)),
      UINT64_C(          2131497860),
      simde_mm512_set_epi8(INT8_C(  85), INT8_C( 118), INT8_C( 120), INT8_C( -48),
                           INT8_C( 112), INT8_C(  80), INT8_C( -83), INT8_C(  55),
                           INT8_C(  10), INT8_C(-104), INT8_C(  -7), INT8_C(-106),
                           INT8_C(  -6), INT8_C(   9), INT8_C( -88), INT8_C(  52),
                           INT8_C(  69), INT8_C(  91), INT8_C(-122), INT8_C(  83),
                           INT8_C(  54), INT8_C( -42), INT8_C(   9), INT8_C( 100),
                           INT8_C(  84), INT8_C(  66), INT8_C(  99), INT8_C( -57),
                           INT8_C(  20), INT8_C( -56), INT8_C( -41), INT8_C(  34),
                           INT8_C(  96), INT8_C( 125), INT8_C(  40), INT8_C( -10),
                           INT8_C(  37), INT8_C( -54), INT8_C( -41), INT8_C( 111),
                           INT8_C( -17), INT8_C(  73), INT8_C(  10), INT8_C(  78),
                           INT8_C( -64), INT8_C(  57), INT8_C(  95), INT8_C(  52),
                           INT8_C(-123), INT8_C( 102), INT8_C( -91), INT8_C( -25),
                           INT8_C( -74), INT8_C(  23), INT8_C(-127), INT8_C( -43),
                           INT8_C( 123), INT8_C( -21), INT8_C( -69), INT8_C(  72),
                           INT8_C( -86), INT8_C(  39), INT8_C( -52), INT8_C(  88)),
      simde_mm512_set_epi8(INT8_C(  64), INT8_C(  45), INT8_C( -70), INT8_C(  94),
                           INT8_C( 127), INT8_C( -70), INT8_C( 127), INT8_C( -78),
                           INT8_C( -58), INT8_C(  92), INT8_C( -25), INT8_C(  -8),
                           INT8_C(  21), INT8_C(  89), INT8_C(   8), INT8_C(   1),
                           INT8_C(  85), INT8_C(   5), INT8_C( 111), INT8_C( 109),
                           INT8_C(   6), INT8_C( -27), INT8_C(  18), INT8_C(  62),
                           INT8_C(  -7), INT8_C( 126), INT8_C( -22), INT8_C( -36),
                           INT8_C( -10), INT8_C(  -1), INT8_C(   1), INT8_C( 115),
                           INT8_C(  87), INT8_C( 125), INT8_C(  40), INT8_C(  10),
                           INT8_C(  37), INT8_C(  54), INT8_C(  41), INT8_C( 111),
                           INT8_C( 126), INT8_C( 112), INT8_C( -72), INT8_C(  45),
                           INT8_C(  64), INT8_C(  57), INT8_C(  68), INT8_C( -93),
                           INT8_C(   5), INT8_C( 127), INT8_C( 109), INT8_C(  25),
                           INT8_C( -89), INT8_C(-117), INT8_C( 127), INT8_C(  43),
                           INT8_C( 123), INT8_C( -92), INT8_C( -23), INT8_C( -48),
                           INT8_C( 104), INT8_C(  39), INT8_C(  -2), INT8_C(-108)) },
    { simde_mm512_set_epi8(INT8_C( -39), INT8_C(-117), INT8_C( -99), INT8_C( -55),
                           INT8_C(   3), INT8_C( -15), INT8_C( 113), INT8_C(  -3),
                           INT8_C( -35), INT8_C( 100), INT8_C( -74), INT8_C(-107),
                           INT8_C(  44), INT8_C( -58), INT8_C(  20), INT8_C(  23),
                           INT8_C( 105), INT8_C( -68), INT8_C( 118), INT8_C( -13),
                           INT8_C( -81), INT8_C(  41), INT8_C( -73), INT8_C(-115),
                           INT8_C(-111), INT8_C(  21), INT8_C(  99), INT8_C( 117),
                           INT8_C( -14), INT8_C(-112), INT8_C(  71), INT8_C(  21),
                           INT8_C(-114), INT8_C( -75), INT8_C(  66), INT8_C(-119),
                           INT8_C( -62), INT8_C( -30), INT8_C(  86), INT8_C(-128),
                           INT8_C( 109), INT8_C(  15), INT8_C( -69), INT8_C(  22),
                           INT8_C( -13), INT8_C(  38), INT8_C( -93), INT8_C( -41),
                           INT8_C(  96), INT8_C(  79), INT8_C( -24), INT8_C( -40),
                           INT8_C(  90), INT8_C(  31), INT8_C( -35), INT8_C(  22),
                           INT8_C(-112), INT8_C( -37), INT8_C(  29), INT8_C(  29),
                           INT8_C(   7), INT8_C(   8), INT8_C( 106), INT8_C( -46)),
      UINT64_C(           127712386),
      simde_mm512_set_epi8(INT8_C(  68), INT8_C( 120), INT8_C( -69), INT8_C( -50),
                           INT8_C( 102), INT8_C(-123), INT8_C(  95), INT8_C( 110),
                           INT8_C(  90), INT8_C( -66), INT8_C( -52), INT8_C(  44),
                           INT8_C(-111), INT8_C(  10), INT8_C(-111), INT8_C(  20),
                           INT8_C( -11), INT8_C(-128), INT8_C( -17), INT8_C( -40),
                           INT8_C( -41), INT8_C(   0), INT8_C( -15), INT8_C( 105),
                           INT8_C(  81), INT8_C(   3), INT8_C(  23), INT8_C( 107),
                           INT8_C( -18), INT8_C(  80), INT8_C(-106), INT8_C(  52),
                           INT8_C(  80), INT8_C( 120), INT8_C(  83), INT8_C(-117),
                           INT8_C(  84), INT8_C( -78), INT8_C(  47), INT8_C( -33),
                           INT8_C( 103), INT8_C(  66), INT8_C(  79), INT8_C(  53),
                           INT8_C( -45), INT8_C(  20), INT8_C( 111), INT8_C( -59),
                           INT8_C( -18), INT8_C(  30), INT8_C(  70), INT8_C( -25),
                           INT8_C( -57), INT8_C(  18), INT8_C(  -4), INT8_C( 101),
                           INT8_C(  75), INT8_C(  12), INT8_C(  85), INT8_C(  93),
                           INT8_C( -79), INT8_C( -13), INT8_C(  43), INT8_C(  45)),
      simde_mm512_set_epi8(INT8_C( -39), INT8_C(-117), INT8_C( -99), INT8_C( -55),
                           INT8_C(   3), INT8_C( -15), INT8_C( 113), INT8_C(  -3),
                           INT8_C( -35), INT8_C( 100), INT8_C( -74), INT8_C(-107),
                           INT8_C(  44), INT8_C( -58), INT8_C(  20), INT8_C(  23),
                           INT8_C( 105), INT8_C( -68), INT8_C( 118), INT8_C( -13),
                           INT8_C( -81), INT8_C(  41), INT8_C( -73), INT8_C(-115),
                           INT8_C(-111), INT8_C(  21), INT8_C(  99), INT8_C( 117),
                           INT8_C( -14), INT8_C(-112), INT8_C(  71), INT8_C(  21),
                           INT8_C(-114), INT8_C( -75), INT8_C(  66), INT8_C(-119),
                           INT8_C( -62), INT8_C(  78), INT8_C(  47), INT8_C(  33),
                           INT8_C( 103), INT8_C(  15), INT8_C( -69), INT8_C(  53),
                           INT8_C(  45), INT8_C(  20), INT8_C( -93), INT8_C( -41),
                           INT8_C(  18), INT8_C(  79), INT8_C(  70), INT8_C(  25),
                           INT8_C(  57), INT8_C(  18), INT8_C( -35), INT8_C(  22),
                           INT8_C(  75), INT8_C( -37), INT8_C(  29), INT8_C(  29),
                           INT8_C(   7), INT8_C(   8), INT8_C(  43), INT8_C( -46)) },
    { simde_mm512_set_epi8(INT8_C( -81), INT8_C(  98), INT8_C(  23), INT8_C(-108),
                           INT8_C(-126), INT8_C(  95), INT8_C( -44), INT8_C( -56),
                           INT8_C(  42), INT8_C(  32), INT8_C( -91), INT8_C(-126),
                           INT8_C( 119), INT8_C(  88), INT8_C( 110), INT8_C(  93),
                           INT8_C(  75), INT8_C( -49), INT8_C( -63), INT8_C( -42),
                           INT8_C(  54), INT8_C( -71), INT8_C(  87), INT8_C(  -1),
                           INT8_C( -25), INT8_C( -60), INT8_C( 102), INT8_C( -98),
                           INT8_C( -95), INT8_C( -34), INT8_C( -46), INT8_C(  94),
                           INT8_C( 118), INT8_C( 127), INT8_C( -62), INT8_C( -70),
                           INT8_C(  80), INT8_C( 125), INT8_C( -12), INT8_C(  33),
                           INT8_C( 110), INT8_C(  -9), INT8_C( -29), INT8_C(-115),
                           INT8_C(-117), INT8_C(  52), INT8_C(-126), INT8_C( -15),
                           INT8_C(-118), INT8_C(-123), INT8_C( -16), INT8_C(  72),
                           INT8_C(  84), INT8_C(  54), INT8_C(  76), INT8_C( -48),
                           INT8_C( -79), INT8_C( 100), INT8_C( -58), INT8_C(  30),
                           INT8_C(  35), INT8_C(  68), INT8_C( -40), INT8_C(   8)),
      UINT64_C(           522030218),
      simde_mm512_set_epi8(INT8_C(  -1), INT8_C( -56), INT8_C( -80), INT8_C(  17),
                           INT8_C( 127), INT8_C(  83), INT8_C(  -9), INT8_C(   0),
                           INT8_C(  -1), INT8_C( 117), INT8_C( -15), INT8_C(  26),
                           INT8_C(  30), INT8_C( -32), INT8_C(  47), INT8_C(  99),
                           INT8_C( -59), INT8_C( -81), INT8_C( -58), INT8_C(  71),
                           INT8_C(-119), INT8_C( -65), INT8_C( -78), INT8_C(-101),
                           INT8_C( -14), INT8_C(   4), INT8_C( -24), INT8_C( -95),
                           INT8_C( 106), INT8_C(  31), INT8_C( 104), INT8_C(  20),
                           INT8_C(  65), INT8_C(  -8), INT8_C( -75), INT8_C(-128),
                           INT8_C( -81), INT8_C(  68), INT8_C( -86), INT8_C(  98),
                           INT8_C( -55), INT8_C(  10), INT8_C(  75), INT8_C(  51),
                           INT8_C( -57), INT8_C(-111), INT8_C(  87), INT8_C(  47),
                           INT8_C( -21), INT8_C( 105), INT8_C(  17), INT8_C( 107),
                           INT8_C(-119), INT8_C( -18), INT8_C(-123), INT8_C(  81),
                           INT8_C(  54), INT8_C(-122), INT8_C( -83), INT8_C(  81),
                           INT8_C(  21), INT8_C(  13), INT8_C(   6), INT8_C( -56)),
      simde_mm512_set_epi8(INT8_C( -81), INT8_C(  98), INT8_C(  23), INT8_C(-108),
                           INT8_C(-126), INT8_C(  95), INT8_C( -44), INT8_C( -56),
                           INT8_C(  42), INT8_C(  32), INT8_C( -91), INT8_C(-126),
                           INT8_C( 119), INT8_C(  88), INT8_C( 110), INT8_C(  93),
                           INT8_C(  75), INT8_C( -49), INT8_C( -63), INT8_C( -42),
                           INT8_C(  54), INT8_C( -71), INT8_C(  87), INT8_C(  -1),
                           INT8_C( -25), INT8_C( -60), INT8_C( 102), INT8_C( -98),
                           INT8_C( -95), INT8_C( -34), INT8_C( -46), INT8_C(  94),
                           INT8_C( 118), INT8_C( 127), INT8_C( -62), INT8_C(-128),
                           INT8_C(  81), INT8_C(  68), INT8_C(  86), INT8_C(  98),
                           INT8_C( 110), INT8_C(  -9), INT8_C( -29), INT8_C(  51),
                           INT8_C(  57), INT8_C( 111), INT8_C(-126), INT8_C(  47),
                           INT8_C(  21), INT8_C(-123), INT8_C( -16), INT8_C(  72),
                           INT8_C( 119), INT8_C(  18), INT8_C(  76), INT8_C( -48),
                           INT8_C(  54), INT8_C( 100), INT8_C( -58), INT8_C(  30),
                           INT8_C(  21), INT8_C(  68), INT8_C(   6), INT8_C(   8)) },
    { simde_mm512_set_epi8(INT8_C(-112), INT8_C( -53), INT8_C(-107), INT8_C(  41),
                           INT8_C( -50), INT8_C( -58), INT8_C(  56), INT8_C(  54),
                           INT8_C(-101), INT8_C(-123), INT8_C(  64), INT8_C( -70),
                           INT8_C( -46), INT8_C(  -1), INT8_C(  70), INT8_C( -46),
                           INT8_C(  96), INT8_C(  45), INT8_C(  57), INT8_C(  -8),
                           INT8_C(  23), INT8_C(  34), INT8_C( -16), INT8_C( -48),
                           INT8_C(  74), INT8_C(  85), INT8_C(-106), INT8_C(  98),
                           INT8_C(  81), INT8_C(-107), INT8_C( -43), INT8_C(  64),
                           INT8_C(-110), INT8_C( 124), INT8_C(-122), INT8_C(-123),
                           INT8_C(  20), INT8_C( 122), INT8_C(  57), INT8_C( -15),
                           INT8_C(  58), INT8_C(  90), INT8_C(-103), INT8_C(  57),
                           INT8_C(  51), INT8_C(-118), INT8_C(  37), INT8_C( -79),
                           INT8_C(  13), INT8_C( 116), INT8_C( -79), INT8_C( -18),
                           INT8_C( -87), INT8_C( -79), INT8_C( -83), INT8_C( -25),
                           INT8_C( -30), INT8_C( -40), INT8_C( 126), INT8_C(  80),
                           INT8_C( -74), INT8_C(  71), INT8_C( -68), INT8_C(  53)),
      UINT64_C(          2821348422),
      simde_mm512_set_epi8(INT8_C(-126), INT8_C(  -8), INT8_C(  35), INT8_C( 112),
                           INT8_C( -78), INT8_C(  75), INT8_C( -25), INT8_C(   1),
                           INT8_C( -27), INT8_C( -67), INT8_C(  49), INT8_C(  75),
                           INT8_C( -39), INT8_C( -68), INT8_C( -51), INT8_C(  42),
                           INT8_C( -30), INT8_C(   1), INT8_C( -18), INT8_C(  -4),
                           INT8_C(  39), INT8_C(  85), INT8_C(  69), INT8_C(  68),
                           INT8_C(-113), INT8_C( -38), INT8_C(  28), INT8_C(  83),
                           INT8_C( -31), INT8_C(  61), INT8_C(  37), INT8_C(  67),
                           INT8_C(  46), INT8_C( -43), INT8_C(  32), INT8_C( -73),
                           INT8_C( -26), INT8_C(   2), INT8_C(  -6), INT8_C( 122),
                           INT8_C( -51), INT8_C( 118), INT8_C(   3), INT8_C(  17),
                           INT8_C(  32), INT8_C(  82), INT8_C(  40), INT8_C(   0),
                           INT8_C(  28), INT8_C(  37), INT8_C(  -3), INT8_C( -85),
                           INT8_C( -92), INT8_C(  45), INT8_C( -23), INT8_C( -58),
                           INT8_C(-108), INT8_C(  44), INT8_C(  28), INT8_C(  77),
                           INT8_C(  12), INT8_C(  81), INT8_C(-103), INT8_C(   7)),
      simde_mm512_set_epi8(INT8_C(-112), INT8_C( -53), INT8_C(-107), INT8_C(  41),
                           INT8_C( -50), INT8_C( -58), INT8_C(  56), INT8_C(  54),
                           INT8_C(-101), INT8_C(-123), INT8_C(  64), INT8_C( -70),
                           INT8_C( -46), INT8_C(  -1), INT8_C(  70), INT8_C( -46),
                           INT8_C(  96), INT8_C(  45), INT8_C(  57), INT8_C(  -8),
                           INT8_C(  23), INT8_C(  34), INT8_C( -16), INT8_C( -48),
                           INT8_C(  74), INT8_C(  85), INT8_C(-106), INT8_C(  98),
                           INT8_C(  81), INT8_C(-107), INT8_C( -43), INT8_C(  64),
                           INT8_C(  46), INT8_C( 124), INT8_C(  32), INT8_C(-123),
                           INT8_C(  26), INT8_C( 122), INT8_C(  57), INT8_C( -15),
                           INT8_C(  58), INT8_C(  90), INT8_C(   3), INT8_C(  57),
                           INT8_C(  32), INT8_C(-118), INT8_C(  40), INT8_C( -79),
                           INT8_C(  13), INT8_C(  37), INT8_C( -79), INT8_C(  85),
                           INT8_C(  92), INT8_C(  45), INT8_C( -83), INT8_C( -25),
                           INT8_C( -30), INT8_C(  44), INT8_C( 126), INT8_C(  80),
                           INT8_C( -74), INT8_C(  81), INT8_C( 103), INT8_C(  53)) },
    { simde_mm512_set_epi8(INT8_C( 115), INT8_C( -13), INT8_C( 104), INT8_C(  83),
                           INT8_C(  80), INT8_C(-118), INT8_C(  34), INT8_C(  48),
                           INT8_C(  50), INT8_C( -65), INT8_C(  88), INT8_C(  76),
                           INT8_C( -17), INT8_C( -86), INT8_C( -68), INT8_C(  75),
                           INT8_C( 121), INT8_C(   9), INT8_C( -63), INT8_C( 106),
                           INT8_C(  93), INT8_C(  44), INT8_C(   0), INT8_C( -33),
                           INT8_C( -53), INT8_C( 101), INT8_C(  76), INT8_C(  37),
                           INT8_C(  94), INT8_C( -32), INT8_C(-104), INT8_C( -20),
                           INT8_C( -48), INT8_C(  45), INT8_C(  88), INT8_C( -93),
                           INT8_C( 104), INT8_C(  42), INT8_C( -99), INT8_C(  59),
                           INT8_C(  90), INT8_C( -69), INT8_C( 107), INT8_C(  16),
                           INT8_C(-118), INT8_C(-119), INT8_C( -60), INT8_C(  51),
                           INT8_C( 126), INT8_C( -78), INT8_C( 114), INT8_C( -75),
                           INT8_C( -75), INT8_C(  19), INT8_C( 113), INT8_C(  84),
                           INT8_C(  47), INT8_C( -83), INT8_C( -26), INT8_C( -38),
                           INT8_C(  64), INT8_C(-106), INT8_C( 107), INT8_C(  56)),
      UINT64_C(          1977462364),
      simde_mm512_set_epi8(INT8_C(-106), INT8_C( -34), INT8_C( 105), INT8_C( -49),
                           INT8_C( -33), INT8_C( 121), INT8_C(   0), INT8_C( 127),
                           INT8_C( -65), INT8_C( -90), INT8_C(-123), INT8_C( 112),
                           INT8_C( -57), INT8_C(  77), INT8_C(  42), INT8_C(  34),
                           INT8_C( -12), INT8_C( -47), INT8_C( 117), INT8_C(  40),
                           INT8_C(  42), INT8_C(  16), INT8_C( -26), INT8_C( 122),
                           INT8_C( 122), INT8_C( -37), INT8_C( -98), INT8_C( -20),
                           INT8_C(  86), INT8_C( -87), INT8_C( -90), INT8_C(-112),
                           INT8_C(-115), INT8_C(  79), INT8_C( 123), INT8_C(  33),
                           INT8_C( -55), INT8_C(-125), INT8_C( 102), INT8_C(  59),
                           INT8_C( -57), INT8_C(  19), INT8_C(  -4), INT8_C( -55),
                           INT8_C( -86), INT8_C(  88), INT8_C( -47), INT8_C(  29),
                           INT8_C(-116), INT8_C( -58), INT8_C( 115), INT8_C( -63),
                           INT8_C( -15), INT8_C( -54), INT8_C(  84), INT8_C(  -1),
                           INT8_C(   5), INT8_C( -33), INT8_C( -96), INT8_C(  93),
                           INT8_C(  97), INT8_C( 124), INT8_C(  26), INT8_C( -34)),
      simde_mm512_set_epi8(INT8_C( 115), INT8_C( -13), INT8_C( 104), INT8_C(  83),
                           INT8_C(  80), INT8_C(-118), INT8_C(  34), INT8_C(  48),
                           INT8_C(  50), INT8_C( -65), INT8_C(  88), INT8_C(  76),
                           INT8_C( -17), INT8_C( -86), INT8_C( -68), INT8_C(  75),
                           INT8_C( 121), INT8_C(   9), INT8_C( -63), INT8_C( 106),
                           INT8_C(  93), INT8_C(  44), INT8_C(   0), INT8_C( -33),
                           INT8_C( -53), INT8_C( 101), INT8_C(  76), INT8_C(  37),
                           INT8_C(  94), INT8_C( -32), INT8_C(-104), INT8_C( -20),
                           INT8_C( -48), INT8_C(  79), INT8_C( 123), INT8_C(  33),
                           INT8_C( 104), INT8_C( 125), INT8_C( -99), INT8_C(  59),
                           INT8_C(  57), INT8_C(  19), INT8_C( 107), INT8_C(  55),
                           INT8_C(  86), INT8_C(  88), INT8_C( -60), INT8_C(  29),
                           INT8_C( 116), INT8_C( -78), INT8_C( 115), INT8_C( -75),
                           INT8_C(  15), INT8_C(  54), INT8_C(  84), INT8_C(  84),
                           INT8_C(  47), INT8_C(  33), INT8_C( -26), INT8_C(  93),
                           INT8_C(  97), INT8_C( 124), INT8_C( 107), INT8_C(  56)) },
    { simde_mm512_set_epi8(INT8_C(   2), INT8_C(  -4), INT8_C( 108), INT8_C(  27),
                           INT8_C( -49), INT8_C(  69), INT8_C( -84), INT8_C(  82),
                           INT8_C(   9), INT8_C(   0), INT8_C(  42), INT8_C( 118),
                           INT8_C(  -3), INT8_C( -67), INT8_C(   6), INT8_C(  30),
                           INT8_C( -88), INT8_C( -69), INT8_C( 118), INT8_C(  36),
                           INT8_C( 110), INT8_C(  81), INT8_C( -37), INT8_C(  36),
                           INT8_C( -74), INT8_C(-109), INT8_C(  47), INT8_C(  12),
                           INT8_C( -29), INT8_C( -81), INT8_C(  76), INT8_C( -22),
                           INT8_C(  91), INT8_C( 125), INT8_C(  98), INT8_C(  17),
                           INT8_C( 115), INT8_C(  58), INT8_C(-107), INT8_C(  90),
                           INT8_C( 115), INT8_C( -24), INT8_C(  83), INT8_C(  17),
                           INT8_C( -11), INT8_C(  20), INT8_C(  81), INT8_C(  54),
                           INT8_C( -59), INT8_C( 112), INT8_C(-102), INT8_C(  13),
                           INT8_C(   8), INT8_C(-105), INT8_C( -27), INT8_C(-127),
                           INT8_C(-112), INT8_C( 125), INT8_C(  21), INT8_C(  55),
                           INT8_C(  24), INT8_C(  58), INT8_C(   7), INT8_C( 127)),
      UINT64_C(           751965274),
      simde_mm512_set_epi8(INT8_C(  90), INT8_C(  75), INT8_C( -70), INT8_C(  89),
                           INT8_C(  25), INT8_C( -86), INT8_C( -40), INT8_C(  -9),
                           INT8_C(-119), INT8_C( -19), INT8_C( 110), INT8_C( -26),
                           INT8_C(-126), INT8_C( 124), INT8_C(   6), INT8_C( -11),
                           INT8_C( -92), INT8_C(  66), INT8_C( -68), INT8_C(  20),
                           INT8_C(  35), INT8_C(  35), INT8_C(  58), INT8_C(  98),
                           INT8_C(  84), INT8_C( -34), INT8_C(  36), INT8_C(-124),
                           INT8_C(  32), INT8_C( -74), INT8_C(  73), INT8_C( -74),
                           INT8_C(  77), INT8_C( 116), INT8_C(  50), INT8_C(  82),
                           INT8_C(  68), INT8_C(  72), INT8_C(  23), INT8_C(  32),
                           INT8_C( -54), INT8_C(  82), INT8_C(  53), INT8_C(  71),
                           INT8_C(  22), INT8_C(  92), INT8_C(  42), INT8_C(-123),
                           INT8_C( -41), INT8_C(  34), INT8_C(  75), INT8_C(  63),
                           INT8_C(-117), INT8_C(  23), INT8_C(-115), INT8_C(  66),
                           INT8_C( -90), INT8_C(  99), INT8_C( -73), INT8_C( -19),
                           INT8_C( -43), INT8_C( -64), INT8_C( -21), INT8_C(  20)),
      simde_mm512_set_epi8(INT8_C(   2), INT8_C(  -4), INT8_C( 108), INT8_C(  27),
                           INT8_C( -49), INT8_C(  69), INT8_C( -84), INT8_C(  82),
                           INT8_C(   9), INT8_C(   0), INT8_C(  42), INT8_C( 118),
                           INT8_C(  -3), INT8_C( -67), INT8_C(   6), INT8_C(  30),
                           INT8_C( -88), INT8_C( -69), INT8_C( 118), INT8_C(  36),
                           INT8_C( 110), INT8_C(  81), INT8_C( -37), INT8_C(  36),
                           INT8_C( -74), INT8_C(-109), INT8_C(  47), INT8_C(  12),
                           INT8_C( -29), INT8_C( -81), INT8_C(  76), INT8_C( -22),
                           INT8_C(  91), INT8_C( 125), INT8_C(  50), INT8_C(  17),
                           INT8_C(  68), INT8_C(  72), INT8_C(-107), INT8_C(  90),
                           INT8_C(  54), INT8_C(  82), INT8_C(  83), INT8_C(  71),
                           INT8_C( -11), INT8_C(  20), INT8_C(  42), INT8_C(  54),
                           INT8_C( -59), INT8_C( 112), INT8_C(-102), INT8_C(  63),
                           INT8_C(   8), INT8_C(  23), INT8_C( -27), INT8_C(-127),
                           INT8_C(-112), INT8_C(  99), INT8_C(  21), INT8_C(  19),
                           INT8_C(  43), INT8_C(  58), INT8_C(  21), INT8_C( 127)) }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])); i++) {
    simde__m512i r = simde_mm512_mask_abs_epi8(test_vec[i].src, test_vec[i].k, test_vec[i].a);
    simde_assert_m512i_i32(r, ==, test_vec[i].r);
  }

  return 0;
}

static int
test_simde_mm512_maskz_abs_epi8(SIMDE_MUNIT_TEST_ARGS) {
  const struct {
    simde__mmask64 k;
    simde__m512i a;
    simde__m512i r;
  } test_vec[8] = {
    { UINT64_C(          1713497089),
      simde_mm512_set_epi8(INT8_C(-105), INT8_C(  80), INT8_C( -16), INT8_C(-124),
                           INT8_C( -48), INT8_C(  76), INT8_C( -91), INT8_C(-128),
                           INT8_C(  54), INT8_C(  63), INT8_C( 114), INT8_C( -73),
                           INT8_C( -26), INT8_C( -48), INT8_C( -24), INT8_C( -13),
                           INT8_C(   5), INT8_C( 123), INT8_C( -45), INT8_C( -57),
                           INT8_C(-107), INT8_C(  47), INT8_C(  90), INT8_C( -54),
                           INT8_C(   1), INT8_C( 118), INT8_C(  37), INT8_C(  -7),
                           INT8_C(  83), INT8_C(  31), INT8_C( -23), INT8_C( -20),
                           INT8_C(-104), INT8_C( 114), INT8_C(  63), INT8_C(  25),
                           INT8_C( -80), INT8_C(  17), INT8_C(  37), INT8_C( -44),
                           INT8_C(-112), INT8_C(  41), INT8_C( -18), INT8_C(  86),
                           INT8_C( 114), INT8_C( -23), INT8_C( -86), INT8_C( -99),
                           INT8_C( 114), INT8_C(  25), INT8_C(  94), INT8_C(  34),
                           INT8_C( -48), INT8_C(  -4), INT8_C(-123), INT8_C( -44),
                           INT8_C( -68), INT8_C(  19), INT8_C(  47), INT8_C(-122),
                           INT8_C( 117), INT8_C(  69), INT8_C(-121), INT8_C(  66)),
      simde_mm512_set_epi8(INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C( 114), INT8_C(  63), INT8_C(   0),
                           INT8_C(   0), INT8_C(  17), INT8_C(  37), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(  18), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(  99),
                           INT8_C( 114), INT8_C(  25), INT8_C(  94), INT8_C(   0),
                           INT8_C(   0), INT8_C(   4), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(  66)) },
    { UINT64_C(           549841533),
      simde_mm512_set_epi8(INT8_C( -84), INT8_C(  24), INT8_C(  17), INT8_C( -28),
                           INT8_C(  -3), INT8_C(  88), INT8_C(  98), INT8_C( -52),
                           INT8_C( -76), INT8_C( -19), INT8_C( 100), INT8_C(  59),
                           INT8_C( -64), INT8_C( -60), INT8_C( -53), INT8_C(  16),
                           INT8_C(   0), INT8_C( -89), INT8_C(  13), INT8_C(  17),
                           INT8_C( 116), INT8_C(  41), INT8_C(  54), INT8_C(  -8),
                           INT8_C(-112), INT8_C( 109), INT8_C(  94), INT8_C(  19),
                           INT8_C(  46), INT8_C( -55), INT8_C( 103), INT8_C(   7),
                           INT8_C( -15), INT8_C( -12), INT8_C( -22), INT8_C( 127),
                           INT8_C( -48), INT8_C( -83), INT8_C(  -9), INT8_C( -85),
                           INT8_C( -79), INT8_C( -12), INT8_C(  76), INT8_C( -65),
                           INT8_C( -90), INT8_C(  19), INT8_C(  33), INT8_C( -50),
                           INT8_C(  89), INT8_C( -40), INT8_C(-117), INT8_C( 111),
                           INT8_C(  48), INT8_C( 119), INT8_C( -55), INT8_C(  66),
                           INT8_C( 113), INT8_C(  -2), INT8_C( -49), INT8_C(-110),
                           INT8_C( -55), INT8_C(  44), INT8_C( 125), INT8_C( -61)),
      simde_mm512_set_epi8(INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(  22), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(  79), INT8_C(  12), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(  19), INT8_C(   0), INT8_C(  50),
                           INT8_C(  89), INT8_C(  40), INT8_C( 117), INT8_C(   0),
                           INT8_C(  48), INT8_C(   0), INT8_C(  55), INT8_C(   0),
                           INT8_C(   0), INT8_C(   2), INT8_C(  49), INT8_C( 110),
                           INT8_C(  55), INT8_C(  44), INT8_C(   0), INT8_C(  61)) },
    { UINT64_C(          2304862624),
      simde_mm512_set_epi8(INT8_C(  71), INT8_C( -17), INT8_C(   0), INT8_C( -82),
                           INT8_C( -27), INT8_C( 124), INT8_C(  45), INT8_C(  57),
                           INT8_C( 107), INT8_C( -93), INT8_C( -77), INT8_C(  53),
                           INT8_C( 126), INT8_C(  10), INT8_C( 123), INT8_C(-113),
                           INT8_C( -41), INT8_C(-108), INT8_C( -59), INT8_C( -36),
                           INT8_C( -24), INT8_C( -51), INT8_C( -68), INT8_C( -38),
                           INT8_C(  19), INT8_C( 120), INT8_C(-118), INT8_C(  63),
                           INT8_C(  24), INT8_C(  72), INT8_C(  39), INT8_C(  31),
                           INT8_C( -92), INT8_C(  52), INT8_C(  81), INT8_C(  39),
                           INT8_C( -70), INT8_C(  73), INT8_C(  76), INT8_C( 114),
                           INT8_C(  -7), INT8_C(   4), INT8_C( -55), INT8_C( -68),
                           INT8_C( 120), INT8_C(  98), INT8_C(-115), INT8_C( -56),
                           INT8_C(  93), INT8_C(  -2), INT8_C(  78), INT8_C(  16),
                           INT8_C(  88), INT8_C(  71), INT8_C(-112), INT8_C(-118),
                           INT8_C(   4), INT8_C( -88), INT8_C(  76), INT8_C(  88),
                           INT8_C( -97), INT8_C( 107), INT8_C( -28), INT8_C( -59)),
      simde_mm512_set_epi8(INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(  92), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(  70), INT8_C(   0), INT8_C(   0), INT8_C( 114),
                           INT8_C(   0), INT8_C(   4), INT8_C(  55), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(  56),
                           INT8_C(   0), INT8_C(   2), INT8_C(  78), INT8_C(   0),
                           INT8_C(  88), INT8_C(   0), INT8_C(   0), INT8_C( 118),
                           INT8_C(   4), INT8_C(   0), INT8_C(  76), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0)) },
    { UINT64_C(          2156618221),
      simde_mm512_set_epi8(INT8_C( -88), INT8_C( -28), INT8_C( -75), INT8_C(  34),
                           INT8_C( -30), INT8_C(  -1), INT8_C(  52), INT8_C( -92),
                           INT8_C( -85), INT8_C(  43), INT8_C(   9), INT8_C(  24),
                           INT8_C( -64), INT8_C( 107), INT8_C( -57), INT8_C(  38),
                           INT8_C(  95), INT8_C( -18), INT8_C(  11), INT8_C(  96),
                           INT8_C(  -4), INT8_C( -94), INT8_C( 116), INT8_C( -31),
                           INT8_C(  52), INT8_C(  -2), INT8_C(  98), INT8_C(  10),
                           INT8_C(   5), INT8_C(  19), INT8_C( -65), INT8_C(  10),
                           INT8_C(-109), INT8_C(  52), INT8_C( -85), INT8_C( -32),
                           INT8_C(  38), INT8_C(  92), INT8_C(   6), INT8_C( -71),
                           INT8_C( -79), INT8_C(  79), INT8_C( -94), INT8_C( 113),
                           INT8_C(-117), INT8_C(  20), INT8_C( -82), INT8_C(  82),
                           INT8_C(-120), INT8_C( 114), INT8_C( -52), INT8_C( -68),
                           INT8_C( -20), INT8_C( -47), INT8_C( -90), INT8_C( -87),
                           INT8_C(  79), INT8_C( -37), INT8_C(  63), INT8_C( -89),
                           INT8_C( -40), INT8_C( -67), INT8_C( -69), INT8_C(-117)),
      simde_mm512_set_epi8(INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C( 109), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(  79), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C( 117), INT8_C(   0), INT8_C(  82), INT8_C(  82),
                           INT8_C(   0), INT8_C( 114), INT8_C(  52), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(  87),
                           INT8_C(  79), INT8_C(  37), INT8_C(  63), INT8_C(   0),
                           INT8_C(  40), INT8_C(  67), INT8_C(   0), INT8_C( 117)) },
    { UINT64_C(          2985927056),
      simde_mm512_set_epi8(INT8_C(-128), INT8_C(  11), INT8_C( -31), INT8_C( 116),
                           INT8_C( -77), INT8_C(  97), INT8_C(  87), INT8_C(  53),
                           INT8_C( -33), INT8_C(  37), INT8_C(  28), INT8_C(  24),
                           INT8_C(-103), INT8_C(  99), INT8_C( -75), INT8_C(  41),
                           INT8_C(  83), INT8_C(  39), INT8_C( 120), INT8_C( 115),
                           INT8_C( -51), INT8_C( -28), INT8_C( 102), INT8_C( -98),
                           INT8_C( -77), INT8_C( 121), INT8_C(  42), INT8_C( 114),
                           INT8_C(  -1), INT8_C( 112), INT8_C(  17), INT8_C( -31),
                           INT8_C( 108), INT8_C( -27), INT8_C(  66), INT8_C(  23),
                           INT8_C(  69), INT8_C( -90), INT8_C( -46), INT8_C( -91),
                           INT8_C( -81), INT8_C( -87), INT8_C(   1), INT8_C( -11),
                           INT8_C(  84), INT8_C(-117), INT8_C(  79), INT8_C(-110),
                           INT8_C( -44), INT8_C( -30), INT8_C(  33), INT8_C(  53),
                           INT8_C(  64), INT8_C( -16), INT8_C(-111), INT8_C( -41),
                           INT8_C(-102), INT8_C(  13), INT8_C(  97), INT8_C( -55),
                           INT8_C(  19), INT8_C( -16), INT8_C( -68), INT8_C( -83)),
      simde_mm512_set_epi8(INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C( 108), INT8_C(   0), INT8_C(  66), INT8_C(  23),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(  91),
                           INT8_C(  81), INT8_C(  87), INT8_C(   1), INT8_C(  11),
                           INT8_C(  84), INT8_C(   0), INT8_C(   0), INT8_C( 110),
                           INT8_C(  44), INT8_C(   0), INT8_C(  33), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(  41),
                           INT8_C( 102), INT8_C(   0), INT8_C(   0), INT8_C(  55),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0)) },
    { UINT64_C(           390836854),
      simde_mm512_set_epi8(INT8_C(  -6), INT8_C( 127), INT8_C(-110), INT8_C(  -8),
                           INT8_C( 106), INT8_C(  95), INT8_C(-126), INT8_C(-127),
                           INT8_C(-103), INT8_C( -21), INT8_C( -20), INT8_C( -71),
                           INT8_C( 106), INT8_C(  23), INT8_C( -51), INT8_C( -47),
                           INT8_C(-107), INT8_C(  61), INT8_C( -93), INT8_C(  10),
                           INT8_C(   4), INT8_C( 110), INT8_C( -43), INT8_C(  40),
                           INT8_C(  60), INT8_C( -40), INT8_C(  36), INT8_C( -39),
                           INT8_C( -80), INT8_C(-110), INT8_C(  14), INT8_C( -61),
                           INT8_C( -39), INT8_C( -70), INT8_C(-116), INT8_C( -99),
                           INT8_C( -82), INT8_C(-113), INT8_C(-120), INT8_C(-116),
                           INT8_C( -58), INT8_C(  18), INT8_C(  72), INT8_C(  23),
                           INT8_C(-117), INT8_C(-105), INT8_C(  83), INT8_C(   3),
                           INT8_C(-104), INT8_C(  34), INT8_C(  72), INT8_C( -33),
                           INT8_C(  84), INT8_C( -90), INT8_C(-116), INT8_C( -46),
                           INT8_C( -18), INT8_C(  96), INT8_C( -46), INT8_C(-109),
                           INT8_C(-103), INT8_C( -18), INT8_C( -39), INT8_C(  67)),
      simde_mm512_set_epi8(INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(  99),
                           INT8_C(   0), INT8_C( 113), INT8_C( 120), INT8_C( 116),
                           INT8_C(   0), INT8_C(  18), INT8_C(   0), INT8_C(   0),
                           INT8_C( 117), INT8_C(   0), INT8_C(  83), INT8_C(   3),
                           INT8_C( 104), INT8_C(   0), INT8_C(  72), INT8_C(  33),
                           INT8_C(   0), INT8_C(   0), INT8_C( 116), INT8_C(   0),
                           INT8_C(   0), INT8_C(  96), INT8_C(  46), INT8_C( 109),
                           INT8_C(   0), INT8_C(  18), INT8_C(  39), INT8_C(   0)) },
    { UINT64_C(           189869641),
      simde_mm512_set_epi8(INT8_C(  28), INT8_C(-101), INT8_C(-104), INT8_C(-117),
                           INT8_C(  24), INT8_C( -55), INT8_C(  82), INT8_C(-100),
                           INT8_C( -42), INT8_C(  62), INT8_C(-113), INT8_C( 110),
                           INT8_C( -92), INT8_C( 127), INT8_C( -92), INT8_C(  20),
                           INT8_C( -35), INT8_C(  35), INT8_C(  30), INT8_C( -86),
                           INT8_C( 120), INT8_C(  91), INT8_C( -69), INT8_C( -49),
                           INT8_C(  19), INT8_C( -87), INT8_C(  42), INT8_C(-110),
                           INT8_C(  68), INT8_C(  97), INT8_C(-125), INT8_C(  75),
                           INT8_C(  30), INT8_C( -54), INT8_C( -38), INT8_C( -20),
                           INT8_C( -96), INT8_C(  84), INT8_C( 108), INT8_C(  24),
                           INT8_C( -54), INT8_C( -26), INT8_C(-125), INT8_C( -53),
                           INT8_C(  48), INT8_C( -78), INT8_C( -96), INT8_C(  82),
                           INT8_C( -16), INT8_C( -68), INT8_C( -65), INT8_C(  28),
                           INT8_C( -82), INT8_C(-116), INT8_C( 119), INT8_C(-113),
                           INT8_C( 102), INT8_C(  90), INT8_C(  86), INT8_C( -14),
                           INT8_C( -49), INT8_C(  71), INT8_C(   2), INT8_C(  28)),
      simde_mm512_set_epi8(INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(  96), INT8_C(   0), INT8_C( 108), INT8_C(  24),
                           INT8_C(   0), INT8_C(  26), INT8_C(   0), INT8_C(  53),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(  82),
                           INT8_C(   0), INT8_C(   0), INT8_C(  65), INT8_C(   0),
                           INT8_C(  82), INT8_C( 116), INT8_C( 119), INT8_C(   0),
                           INT8_C(   0), INT8_C(  90), INT8_C(   0), INT8_C(   0),
                           INT8_C(  49), INT8_C(   0), INT8_C(   0), INT8_C(  28)) },
    { UINT64_C(          2755545546),
      simde_mm512_set_epi8(INT8_C( -71), INT8_C(  48), INT8_C(  -1), INT8_C( -17),
                           INT8_C( -90), INT8_C(   3), INT8_C( -34), INT8_C(  36),
                           INT8_C( -17), INT8_C( -38), INT8_C( 100), INT8_C( -30),
                           INT8_C( 118), INT8_C(  42), INT8_C( -25), INT8_C( -45),
                           INT8_C(   4), INT8_C(   8), INT8_C(  53), INT8_C(  84),
                           INT8_C(-120), INT8_C(  61), INT8_C(  90), INT8_C( -19),
                           INT8_C(  31), INT8_C(-108), INT8_C( -76), INT8_C(  95),
                           INT8_C( 101), INT8_C( -99), INT8_C( -14), INT8_C(  26),
                           INT8_C( -35), INT8_C( -61), INT8_C(  15), INT8_C(  71),
                           INT8_C( 113), INT8_C( 109), INT8_C(  91), INT8_C(-117),
                           INT8_C(   0), INT8_C( 121), INT8_C(  48), INT8_C( 109),
                           INT8_C(  55), INT8_C( 125), INT8_C(-112), INT8_C(  80),
                           INT8_C(  48), INT8_C(  40), INT8_C(  32), INT8_C( -98),
                           INT8_C(  64), INT8_C( -31), INT8_C( -10), INT8_C(  -6),
                           INT8_C( -40), INT8_C(  37), INT8_C(  76), INT8_C( -51),
                           INT8_C(  27), INT8_C(  -2), INT8_C(-101), INT8_C( -10)),
      simde_mm512_set_epi8(INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(  35), INT8_C(   0), INT8_C(  15), INT8_C(   0),
                           INT8_C(   0), INT8_C( 109), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(  48), INT8_C( 109),
                           INT8_C(  55), INT8_C( 125), INT8_C( 112), INT8_C(   0),
                           INT8_C(   0), INT8_C(  40), INT8_C(   0), INT8_C(   0),
                           INT8_C(  64), INT8_C(   0), INT8_C(   0), INT8_C(   6),
                           INT8_C(  40), INT8_C(  37), INT8_C(   0), INT8_C(   0),
                           INT8_C(  27), INT8_C(   0), INT8_C( 101), INT8_C(   0)) }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])); i++) {
    simde__m512i r = simde_mm512_maskz_abs_epi8(test_vec[i].k, test_vec[i].a);
    simde_assert_m512i_i8(r, ==, test_vec[i].r);
  }

  return 0;
}

static int
test_simde_mm512_abs_epi16(SIMDE_MUNIT_TEST_ARGS) {
  const struct {
    simde__m512i a;
    simde__m512i r;
  } test_vec[8] = {
    { simde_mm512_set_epi16(INT16_C(-24810), INT16_C( -1893), INT16_C( -4484), INT16_C(-18467),
                            INT16_C(-27267), INT16_C(-12302), INT16_C(-13826), INT16_C(   938),
                            INT16_C(-17680), INT16_C(  -610), INT16_C( -4882), INT16_C(-14649),
                            INT16_C( 30481), INT16_C(-20144), INT16_C( 20995), INT16_C( -4451),
                            INT16_C(  6425), INT16_C( 21336), INT16_C( 30080), INT16_C(  4310),
                            INT16_C( 29439), INT16_C(-28107), INT16_C( 32707), INT16_C(-17334),
                            INT16_C( 26460), INT16_C(-29244), INT16_C( -5806), INT16_C(-31467),
                            INT16_C( -9353), INT16_C( -9759), INT16_C(  6587), INT16_C(-14562)),
      simde_mm512_set_epi16(INT16_C( 24810), INT16_C(  1893), INT16_C(  4484), INT16_C( 18467),
                            INT16_C( 27267), INT16_C( 12302), INT16_C( 13826), INT16_C(   938),
                            INT16_C( 17680), INT16_C(   610), INT16_C(  4882), INT16_C( 14649),
                            INT16_C( 30481), INT16_C( 20144), INT16_C( 20995), INT16_C(  4451),
                            INT16_C(  6425), INT16_C( 21336), INT16_C( 30080), INT16_C(  4310),
                            INT16_C( 29439), INT16_C( 28107), INT16_C( 32707), INT16_C( 17334),
                            INT16_C( 26460), INT16_C( 29244), INT16_C(  5806), INT16_C( 31467),
                            INT16_C(  9353), INT16_C(  9759), INT16_C(  6587), INT16_C( 14562)) },
    { simde_mm512_set_epi16(INT16_C( 31294), INT16_C(-10840), INT16_C( 23692), INT16_C( -1500),
                            INT16_C(  2562), INT16_C(-16788), INT16_C( -9616), INT16_C( 31575),
                            INT16_C( 25554), INT16_C(-13527), INT16_C(-26722), INT16_C(  4852),
                            INT16_C(-20866), INT16_C(-19475), INT16_C(  4624), INT16_C(  9206),
                            INT16_C(-14800), INT16_C(-30682), INT16_C( 15889), INT16_C(  8584),
                            INT16_C( 27161), INT16_C(-23281), INT16_C( 25970), INT16_C(-11578),
                            INT16_C( 28932), INT16_C( 12842), INT16_C(   -29), INT16_C( -6679),
                            INT16_C(-17572), INT16_C(-17063), INT16_C( -2346), INT16_C( 20336)),
      simde_mm512_set_epi16(INT16_C( 31294), INT16_C( 10840), INT16_C( 23692), INT16_C(  1500),
                            INT16_C(  2562), INT16_C( 16788), INT16_C(  9616), INT16_C( 31575),
                            INT16_C( 25554), INT16_C( 13527), INT16_C( 26722), INT16_C(  4852),
                            INT16_C( 20866), INT16_C( 19475), INT16_C(  4624), INT16_C(  9206),
                            INT16_C( 14800), INT16_C( 30682), INT16_C( 15889), INT16_C(  8584),
                            INT16_C( 27161), INT16_C( 23281), INT16_C( 25970), INT16_C( 11578),
                            INT16_C( 28932), INT16_C( 12842), INT16_C(    29), INT16_C(  6679),
                            INT16_C( 17572), INT16_C( 17063), INT16_C(  2346), INT16_C( 20336)) },
    { simde_mm512_set_epi16(INT16_C(-29319), INT16_C( -6944), INT16_C( 10081), INT16_C( 26836),
                            INT16_C( 30965), INT16_C(-18751), INT16_C( -5923), INT16_C(-27401),
                            INT16_C(  7842), INT16_C( 24713), INT16_C( -3422), INT16_C(  8849),
                            INT16_C( 22266), INT16_C(-29640), INT16_C(  -264), INT16_C(-16823),
                            INT16_C(-28396), INT16_C( 29200), INT16_C( 18193), INT16_C( -3173),
                            INT16_C(  8244), INT16_C( -1296), INT16_C( 20026), INT16_C(  3755),
                            INT16_C(-14728), INT16_C( 26243), INT16_C( 18823), INT16_C(-30029),
                            INT16_C( 21566), INT16_C( 25734), INT16_C( -4271), INT16_C( 27065)),
      simde_mm512_set_epi16(INT16_C( 29319), INT16_C(  6944), INT16_C( 10081), INT16_C( 26836),
                            INT16_C( 30965), INT16_C( 18751), INT16_C(  5923), INT16_C( 27401),
                            INT16_C(  7842), INT16_C( 24713), INT16_C(  3422), INT16_C(  8849),
                            INT16_C( 22266), INT16_C( 29640), INT16_C(   264), INT16_C( 16823),
                            INT16_C( 28396), INT16_C( 29200), INT16_C( 18193), INT16_C(  3173),
                            INT16_C(  8244), INT16_C(  1296), INT16_C( 20026), INT16_C(  3755),
                            INT16_C( 14728), INT16_C( 26243), INT16_C( 18823), INT16_C( 30029),
                            INT16_C( 21566), INT16_C( 25734), INT16_C(  4271), INT16_C( 27065)) },
    { simde_mm512_set_epi16(INT16_C( 26713), INT16_C(  6075), INT16_C(-20498), INT16_C(-29395),
                            INT16_C( 28513), INT16_C(-24372), INT16_C( 30119), INT16_C( 21303),
                            INT16_C(-20009), INT16_C( 16878), INT16_C( -3364), INT16_C( -1142),
                            INT16_C( 26178), INT16_C(  1599), INT16_C(   583), INT16_C(-20121),
                            INT16_C( 25419), INT16_C(  4739), INT16_C( 22881), INT16_C( -2884),
                            INT16_C( -7360), INT16_C( 23146), INT16_C(-16850), INT16_C(-17018),
                            INT16_C(  9049), INT16_C(-31439), INT16_C( 20369), INT16_C( 26125),
                            INT16_C(  4615), INT16_C(  3018), INT16_C( 20462), INT16_C( 20538)),
      simde_mm512_set_epi16(INT16_C( 26713), INT16_C(  6075), INT16_C( 20498), INT16_C( 29395),
                            INT16_C( 28513), INT16_C( 24372), INT16_C( 30119), INT16_C( 21303),
                            INT16_C( 20009), INT16_C( 16878), INT16_C(  3364), INT16_C(  1142),
                            INT16_C( 26178), INT16_C(  1599), INT16_C(   583), INT16_C( 20121),
                            INT16_C( 25419), INT16_C(  4739), INT16_C( 22881), INT16_C(  2884),
                            INT16_C(  7360), INT16_C( 23146), INT16_C( 16850), INT16_C( 17018),
                            INT16_C(  9049), INT16_C( 31439), INT16_C( 20369), INT16_C( 26125),
                            INT16_C(  4615), INT16_C(  3018), INT16_C( 20462), INT16_C( 20538)) },
    { simde_mm512_set_epi16(INT16_C(-17426), INT16_C( -6113), INT16_C(-30180), INT16_C( 28425),
                            INT16_C(-15870), INT16_C(  6201), INT16_C( 15445), INT16_C(-31740),
                            INT16_C(-11778), INT16_C(-10748), INT16_C(-28415), INT16_C( -1743),
                            INT16_C( 22411), INT16_C( 18108), INT16_C( 23625), INT16_C( 27654),
                            INT16_C( 27868), INT16_C( 15645), INT16_C( 22336), INT16_C(-29935),
                            INT16_C( -3026), INT16_C(-19158), INT16_C( 20698), INT16_C( 21892),
                            INT16_C(-32012), INT16_C( 10508), INT16_C(-14383), INT16_C( 20676),
                            INT16_C(  6233), INT16_C(-11386), INT16_C(-13291), INT16_C( 13948)),
      simde_mm512_set_epi16(INT16_C( 17426), INT16_C(  6113), INT16_C( 30180), INT16_C( 28425),
                            INT16_C( 15870), INT16_C(  6201), INT16_C( 15445), INT16_C( 31740),
                            INT16_C( 11778), INT16_C( 10748), INT16_C( 28415), INT16_C(  1743),
                            INT16_C( 22411), INT16_C( 18108), INT16_C( 23625), INT16_C( 27654),
                            INT16_C( 27868), INT16_C( 15645), INT16_C( 22336), INT16_C( 29935),
                            INT16_C(  3026), INT16_C( 19158), INT16_C( 20698), INT16_C( 21892),
                            INT16_C( 32012), INT16_C( 10508), INT16_C( 14383), INT16_C( 20676),
                            INT16_C(  6233), INT16_C( 11386), INT16_C( 13291), INT16_C( 13948)) },
    { simde_mm512_set_epi16(INT16_C(  6099), INT16_C(-22144), INT16_C( 20288), INT16_C(-18323),
                            INT16_C(  -136), INT16_C( -4474), INT16_C(-14336), INT16_C( 25660),
                            INT16_C(-19775), INT16_C(  6691), INT16_C(-16568), INT16_C(  9907),
                            INT16_C(-31382), INT16_C(  1875), INT16_C( 22377), INT16_C(-21951),
                            INT16_C(-10385), INT16_C(-18760), INT16_C(  7844), INT16_C( 16059),
                            INT16_C(-14216), INT16_C( 22036), INT16_C(-20920), INT16_C( 11586),
                            INT16_C(-18048), INT16_C( -8950), INT16_C(-23337), INT16_C( 26279),
                            INT16_C( 12076), INT16_C(  3090), INT16_C( -7311), INT16_C( -5254)),
      simde_mm512_set_epi16(INT16_C(  6099), INT16_C( 22144), INT16_C( 20288), INT16_C( 18323),
                            INT16_C(   136), INT16_C(  4474), INT16_C( 14336), INT16_C( 25660),
                            INT16_C( 19775), INT16_C(  6691), INT16_C( 16568), INT16_C(  9907),
                            INT16_C( 31382), INT16_C(  1875), INT16_C( 22377), INT16_C( 21951),
                            INT16_C( 10385), INT16_C( 18760), INT16_C(  7844), INT16_C( 16059),
                            INT16_C( 14216), INT16_C( 22036), INT16_C( 20920), INT16_C( 11586),
                            INT16_C( 18048), INT16_C(  8950), INT16_C( 23337), INT16_C( 26279),
                            INT16_C( 12076), INT16_C(  3090), INT16_C(  7311), INT16_C(  5254)) },
    { simde_mm512_set_epi16(INT16_C(  1734), INT16_C(-24733), INT16_C(  6252), INT16_C(-10636),
                            INT16_C(-13019), INT16_C(  4439), INT16_C( 30486), INT16_C(  9898),
                            INT16_C( 18157), INT16_C( 29700), INT16_C(-19524), INT16_C(  5081),
                            INT16_C(  -888), INT16_C( 21733), INT16_C(-17288), INT16_C(-29729),
                            INT16_C(   877), INT16_C( 22002), INT16_C( 31006), INT16_C( 27903),
                            INT16_C( 29379), INT16_C( 11869), INT16_C( 12487), INT16_C(-24676),
                            INT16_C( 21504), INT16_C(-22063), INT16_C( 21762), INT16_C( 32035),
                            INT16_C( -2823), INT16_C(   772), INT16_C( 22127), INT16_C(-16867)),
      simde_mm512_set_epi16(INT16_C(  1734), INT16_C( 24733), INT16_C(  6252), INT16_C( 10636),
                            INT16_C( 13019), INT16_C(  4439), INT16_C( 30486), INT16_C(  9898),
                            INT16_C( 18157), INT16_C( 29700), INT16_C( 19524), INT16_C(  5081),
                            INT16_C(   888), INT16_C( 21733), INT16_C( 17288), INT16_C( 29729),
                            INT16_C(   877), INT16_C( 22002), INT16_C( 31006), INT16_C( 27903),
                            INT16_C( 29379), INT16_C( 11869), INT16_C( 12487), INT16_C( 24676),
                            INT16_C( 21504), INT16_C( 22063), INT16_C( 21762), INT16_C( 32035),
                            INT16_C(  2823), INT16_C(   772), INT16_C( 22127), INT16_C( 16867)) },
    { simde_mm512_set_epi16(INT16_C( 12349), INT16_C( 32588), INT16_C(-21894), INT16_C(-24438),
                            INT16_C( -9480), INT16_C( 14484), INT16_C(   264), INT16_C(  5772),
                            INT16_C(-13220), INT16_C( 17520), INT16_C(-23892), INT16_C( 25295),
                            INT16_C(-10903), INT16_C( 18210), INT16_C(-32005), INT16_C(  1475),
                            INT16_C(-31775), INT16_C(-32553), INT16_C( 21009), INT16_C(-11897),
                            INT16_C(   118), INT16_C( -4448), INT16_C( 11548), INT16_C( 27032),
                            INT16_C( -3816), INT16_C( 24167), INT16_C(-13680), INT16_C(  3963),
                            INT16_C( -6791), INT16_C(-30064), INT16_C(-17823), INT16_C( 15062)),
      simde_mm512_set_epi16(INT16_C( 12349), INT16_C( 32588), INT16_C( 21894), INT16_C( 24438),
                            INT16_C(  9480), INT16_C( 14484), INT16_C(   264), INT16_C(  5772),
                            INT16_C( 13220), INT16_C( 17520), INT16_C( 23892), INT16_C( 25295),
                            INT16_C( 10903), INT16_C( 18210), INT16_C( 32005), INT16_C(  1475),
                            INT16_C( 31775), INT16_C( 32553), INT16_C( 21009), INT16_C( 11897),
                            INT16_C(   118), INT16_C(  4448), INT16_C( 11548), INT16_C( 27032),
                            INT16_C(  3816), INT16_C( 24167), INT16_C( 13680), INT16_C(  3963),
                            INT16_C(  6791), INT16_C( 30064), INT16_C( 17823), INT16_C( 15062)) }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])); i++) {
    simde__m512i r = simde_mm512_abs_epi16(test_vec[i].a);
    simde_assert_m512i_i16(r, ==, test_vec[i].r);
  }

  return 0;
}

static int
test_simde_mm512_mask_abs_epi16 (SIMDE_MUNIT_TEST_ARGS) {
  static const struct {
    const int16_t src[32];
    const simde__mmask32 k;
    const int16_t a[32];
    const int16_t r[32];
  } test_vec[] = {
    { { -INT16_C(  5316), -INT16_C( 21434),  INT16_C( 23082), -INT16_C( 11070), -INT16_C( 21411), -INT16_C(  1395),  INT16_C( 31798), -INT16_C( 18159),
        -INT16_C( 19036), -INT16_C( 29365),  INT16_C( 11378),  INT16_C( 16016), -INT16_C( 11452), -INT16_C( 20127),  INT16_C( 12785),  INT16_C( 11729),
         INT16_C(  5916),  INT16_C( 18393), -INT16_C( 25742), -INT16_C( 12517), -INT16_C( 22456),  INT16_C( 32458), -INT16_C(  9436), -INT16_C( 14025),
        -INT16_C( 32112),  INT16_C(   598), -INT16_C(  6225), -INT16_C(  3264), -INT16_C( 24134), -INT16_C( 21596),  INT16_C( 30418), -INT16_C(  4136) },
      UINT32_C(4281774477),
      {  INT16_C( 20812), -INT16_C( 27441), -INT16_C( 26119),  INT16_C(  7442),  INT16_C( 18804),  INT16_C(  1254),  INT16_C( 15820),  INT16_C( 31494),
         INT16_C( 17956), -INT16_C(  8594),  INT16_C(  4839), -INT16_C( 18039),  INT16_C( 24968),  INT16_C(  5800), -INT16_C(  8686),  INT16_C( 24085),
        -INT16_C(  7121),  INT16_C( 10483),  INT16_C(  1405), -INT16_C(  3770),  INT16_C( 11343),  INT16_C(  7157), -INT16_C(  1175), -INT16_C( 29290),
         INT16_C(  1089),  INT16_C( 10347), -INT16_C(  3050), -INT16_C( 24606), -INT16_C( 30123),  INT16_C( 26549), -INT16_C( 13719), -INT16_C( 26426) },
      {  INT16_C( 20812), -INT16_C( 21434),  INT16_C( 26119),  INT16_C(  7442), -INT16_C( 21411), -INT16_C(  1395),  INT16_C( 31798),  INT16_C( 31494),
         INT16_C( 17956), -INT16_C( 29365),  INT16_C( 11378),  INT16_C( 16016),  INT16_C( 24968),  INT16_C(  5800),  INT16_C( 12785),  INT16_C( 24085),
         INT16_C(  5916),  INT16_C( 10483),  INT16_C(  1405), -INT16_C( 12517),  INT16_C( 11343),  INT16_C(  7157), -INT16_C(  9436), -INT16_C( 14025),
         INT16_C(  1089),  INT16_C( 10347),  INT16_C(  3050),  INT16_C( 24606),  INT16_C( 30123),  INT16_C( 26549),  INT16_C( 13719),  INT16_C( 26426) } },
    { { -INT16_C( 18001),  INT16_C( 11457),  INT16_C(  1982),  INT16_C(  3358),  INT16_C(  4915), -INT16_C( 25304), -INT16_C( 16881),  INT16_C( 20522),
        -INT16_C( 26942), -INT16_C(  9863),  INT16_C( 23434), -INT16_C(  8072),  INT16_C( 11749),  INT16_C( 20039),  INT16_C(  3575), -INT16_C( 22809),
        -INT16_C( 22330), -INT16_C( 31277), -INT16_C(  3665), -INT16_C(  7534), -INT16_C( 17660),  INT16_C(  4991), -INT16_C( 21895),  INT16_C( 15460),
        -INT16_C(  8896), -INT16_C( 13803), -INT16_C( 29384),  INT16_C(  7594), -INT16_C(  3398), -INT16_C( 20116),  INT16_C( 21503), -INT16_C( 14760) },
      UINT32_C(2857053179),
      { -INT16_C(  8932),  INT16_C(  8332),  INT16_C(  3224),  INT16_C(  4660), -INT16_C( 26442), -INT16_C(  2482),  INT16_C( 25461), -INT16_C( 21056),
         INT16_C( 27632), -INT16_C( 21814),  INT16_C( 13917),  INT16_C( 23643), -INT16_C( 19575), -INT16_C( 31710),  INT16_C( 28126), -INT16_C(  1490),
        -INT16_C( 17589), -INT16_C(  7397),  INT16_C( 20423),  INT16_C( 32245),  INT16_C( 17383),  INT16_C( 23667),  INT16_C( 13222), -INT16_C( 27127),
        -INT16_C( 11362), -INT16_C(  1216), -INT16_C( 25590), -INT16_C( 27816),  INT16_C( 31311),  INT16_C( 11800),  INT16_C( 18152),  INT16_C( 13096) },
      {  INT16_C(  8932),  INT16_C(  8332),  INT16_C(  1982),  INT16_C(  4660),  INT16_C( 26442),  INT16_C(  2482),  INT16_C( 25461),  INT16_C( 21056),
         INT16_C( 27632),  INT16_C( 21814),  INT16_C( 23434),  INT16_C( 23643),  INT16_C( 11749),  INT16_C( 31710),  INT16_C(  3575), -INT16_C( 22809),
         INT16_C( 17589),  INT16_C(  7397), -INT16_C(  3665),  INT16_C( 32245), -INT16_C( 17660),  INT16_C(  4991),  INT16_C( 13222),  INT16_C( 15460),
        -INT16_C(  8896),  INT16_C(  1216), -INT16_C( 29384),  INT16_C( 27816), -INT16_C(  3398),  INT16_C( 11800),  INT16_C( 21503),  INT16_C( 13096) } },
    { {  INT16_C( 17153), -INT16_C( 14314),  INT16_C(  3218),  INT16_C( 31045), -INT16_C( 18353), -INT16_C(  2347), -INT16_C(  8468), -INT16_C( 30068),
        -INT16_C( 12878), -INT16_C( 17274), -INT16_C(  8599), -INT16_C( 18353),  INT16_C( 26456),  INT16_C( 16614),  INT16_C(  4014), -INT16_C( 20621),
        -INT16_C( 30126), -INT16_C(  6792), -INT16_C( 17002), -INT16_C(  6818),  INT16_C( 13430),  INT16_C( 25307),  INT16_C( 26642), -INT16_C( 15124),
         INT16_C( 29237), -INT16_C( 24960), -INT16_C( 12208), -INT16_C( 22186),  INT16_C( 15671), -INT16_C(  6679),  INT16_C( 23884), -INT16_C( 24939) },
      UINT32_C(2105740775),
      { -INT16_C(  7478),  INT16_C( 16482),  INT16_C( 15894),  INT16_C( 10402), -INT16_C( 28762), -INT16_C(  9235),  INT16_C( 27905),  INT16_C( 21113),
        -INT16_C( 12483),  INT16_C( 30203), -INT16_C(  7156),  INT16_C( 22618), -INT16_C(  4287),  INT16_C( 10487),  INT16_C( 31484), -INT16_C( 14427),
         INT16_C(  2140),  INT16_C( 29191), -INT16_C( 21946), -INT16_C(  4965), -INT16_C( 30663),  INT16_C( 15047),  INT16_C( 16629),  INT16_C( 13196),
        -INT16_C( 30961),  INT16_C(  7336),  INT16_C(   620), -INT16_C( 21132),  INT16_C( 27634), -INT16_C(  4394),  INT16_C( 31718),  INT16_C( 17077) },
      {  INT16_C(  7478),  INT16_C( 16482),  INT16_C( 15894),  INT16_C( 31045), -INT16_C( 18353),  INT16_C(  9235),  INT16_C( 27905),  INT16_C( 21113),
         INT16_C( 12483), -INT16_C( 17274),  INT16_C(  7156),  INT16_C( 22618),  INT16_C( 26456),  INT16_C( 16614),  INT16_C(  4014), -INT16_C( 20621),
         INT16_C(  2140),  INT16_C( 29191), -INT16_C( 17002), -INT16_C(  6818),  INT16_C( 13430),  INT16_C( 25307),  INT16_C( 26642),  INT16_C( 13196),
         INT16_C( 30961), -INT16_C( 24960),  INT16_C(   620),  INT16_C( 21132),  INT16_C( 27634),  INT16_C(  4394),  INT16_C( 31718), -INT16_C( 24939) } },
    { { -INT16_C( 17021), -INT16_C( 13899),  INT16_C( 20583), -INT16_C( 24395),  INT16_C( 31960), -INT16_C( 12838),  INT16_C( 26556), -INT16_C( 13312),
        -INT16_C( 22290),  INT16_C( 23272),  INT16_C( 23723), -INT16_C( 25336), -INT16_C(  8504), -INT16_C( 20853),  INT16_C( 16729), -INT16_C(  8720),
        -INT16_C( 23042),  INT16_C( 26022),  INT16_C( 23797), -INT16_C( 13051), -INT16_C(  8232), -INT16_C( 27237), -INT16_C( 25786),  INT16_C( 13665),
         INT16_C( 18756), -INT16_C(  4209), -INT16_C( 26715),  INT16_C( 28044),  INT16_C(  6005), -INT16_C( 12517),  INT16_C(  3160),  INT16_C( 22188) },
      UINT32_C(2814071473),
      { -INT16_C( 16210), -INT16_C( 30860),  INT16_C(  4000), -INT16_C(  6628),  INT16_C( 32171), -INT16_C(  4325), -INT16_C( 21562),  INT16_C( 27614),
         INT16_C( 27202), -INT16_C( 18215), -INT16_C(  2943), -INT16_C(  9593),  INT16_C( 13056), -INT16_C( 19920), -INT16_C(  4987),  INT16_C( 13401),
        -INT16_C( 12884),  INT16_C( 19643), -INT16_C( 10275), -INT16_C( 30669),  INT16_C( 20052),  INT16_C(  6775),  INT16_C( 22009),  INT16_C( 15493),
         INT16_C( 24255),  INT16_C( 16628),  INT16_C( 31571),  INT16_C( 21274),  INT16_C( 19374),  INT16_C( 13061),  INT16_C( 24119), -INT16_C(  7321) },
      {  INT16_C( 16210), -INT16_C( 13899),  INT16_C( 20583), -INT16_C( 24395),  INT16_C( 32171),  INT16_C(  4325),  INT16_C( 26556),  INT16_C( 27614),
        -INT16_C( 22290),  INT16_C( 18215),  INT16_C( 23723), -INT16_C( 25336),  INT16_C( 13056), -INT16_C( 20853),  INT16_C(  4987), -INT16_C(  8720),
         INT16_C( 12884),  INT16_C( 19643),  INT16_C( 23797),  INT16_C( 30669),  INT16_C( 20052),  INT16_C(  6775), -INT16_C( 25786),  INT16_C( 15493),
         INT16_C( 24255),  INT16_C( 16628),  INT16_C( 31571),  INT16_C( 28044),  INT16_C(  6005),  INT16_C( 13061),  INT16_C(  3160),  INT16_C(  7321) } },
    { {  INT16_C(  8748),  INT16_C(  2352),  INT16_C( 25593),  INT16_C( 19857),  INT16_C(  2225), -INT16_C( 21657), -INT16_C(  4771),  INT16_C(  7399),
        -INT16_C(  9397), -INT16_C( 24996),  INT16_C( 30550),  INT16_C(  1266), -INT16_C(  2110), -INT16_C(  1737), -INT16_C( 24746), -INT16_C( 32036),
         INT16_C(  3265), -INT16_C( 17525),  INT16_C(  7279),  INT16_C(  8456),  INT16_C( 28708), -INT16_C( 32308), -INT16_C( 19619), -INT16_C( 22371),
        -INT16_C(  1650), -INT16_C(  7097),  INT16_C( 14704),  INT16_C( 13032),  INT16_C(  7984), -INT16_C( 31189),  INT16_C(  2238), -INT16_C( 32760) },
      UINT32_C(2218496788),
      {  INT16_C( 17327), -INT16_C( 11355),  INT16_C( 29107),  INT16_C(  4180), -INT16_C(  3804), -INT16_C( 19783),  INT16_C(   235),  INT16_C( 23446),
         INT16_C( 32313),  INT16_C( 27022), -INT16_C( 18019),  INT16_C( 23792), -INT16_C(  1855), -INT16_C( 10532),  INT16_C(  6028),  INT16_C( 15194),
        -INT16_C(   166),  INT16_C(  3599),  INT16_C( 25456), -INT16_C( 27618), -INT16_C( 10411),  INT16_C( 16454), -INT16_C(  9001),  INT16_C(  4251),
         INT16_C( 10586), -INT16_C(  2182),  INT16_C( 27363), -INT16_C( 23469),  INT16_C( 12130), -INT16_C(  4486), -INT16_C( 11194), -INT16_C( 24278) },
      {  INT16_C(  8748),  INT16_C(  2352),  INT16_C( 29107),  INT16_C( 19857),  INT16_C(  3804), -INT16_C( 21657), -INT16_C(  4771),  INT16_C(  7399),
         INT16_C( 32313),  INT16_C( 27022),  INT16_C( 30550),  INT16_C(  1266),  INT16_C(  1855), -INT16_C(  1737), -INT16_C( 24746),  INT16_C( 15194),
         INT16_C(   166),  INT16_C(  3599),  INT16_C(  7279),  INT16_C( 27618),  INT16_C( 10411),  INT16_C( 16454), -INT16_C( 19619), -INT16_C( 22371),
        -INT16_C(  1650), -INT16_C(  7097),  INT16_C( 27363),  INT16_C( 13032),  INT16_C(  7984), -INT16_C( 31189),  INT16_C(  2238),  INT16_C( 24278) } },
    { {  INT16_C( 14803),  INT16_C( 17327), -INT16_C( 12900), -INT16_C(  3625),  INT16_C(  7589),  INT16_C( 31793), -INT16_C( 12807),  INT16_C( 21389),
         INT16_C(  2038), -INT16_C(  9909), -INT16_C( 24975), -INT16_C( 11394), -INT16_C(  1842),  INT16_C(  5314), -INT16_C(  4915), -INT16_C( 24395),
         INT16_C( 25637), -INT16_C( 15900), -INT16_C( 17614), -INT16_C( 10317), -INT16_C(  6951), -INT16_C( 11693), -INT16_C(  8015), -INT16_C( 22490),
         INT16_C( 29159),  INT16_C( 22657), -INT16_C(   241), -INT16_C(  8916), -INT16_C(  4360), -INT16_C( 14862), -INT16_C( 22566), -INT16_C(   155) },
      UINT32_C(1052789004),
      {  INT16_C( 29445), -INT16_C(  8683),  INT16_C( 26712),  INT16_C(  2480), -INT16_C( 10679),  INT16_C( 12465),  INT16_C( 13127),  INT16_C( 22409),
        -INT16_C( 19150),  INT16_C( 10804),  INT16_C(  9891),  INT16_C( 32239),  INT16_C( 21966), -INT16_C(  9604),  INT16_C( 15518), -INT16_C( 23784),
         INT16_C( 11696),  INT16_C(  2177),  INT16_C( 12949), -INT16_C(  8687), -INT16_C( 15608),  INT16_C( 20495), -INT16_C( 26378),  INT16_C( 10407),
        -INT16_C(  9395), -INT16_C(  4013),  INT16_C( 16898), -INT16_C( 12179), -INT16_C(  5737),  INT16_C( 13994), -INT16_C( 15835), -INT16_C( 10791) },
      {  INT16_C( 14803),  INT16_C( 17327),  INT16_C( 26712),  INT16_C(  2480),  INT16_C(  7589),  INT16_C( 31793), -INT16_C( 12807),  INT16_C( 21389),
         INT16_C( 19150), -INT16_C(  9909), -INT16_C( 24975),  INT16_C( 32239), -INT16_C(  1842),  INT16_C(  5314),  INT16_C( 15518), -INT16_C( 24395),
         INT16_C( 25637), -INT16_C( 15900), -INT16_C( 17614), -INT16_C( 10317), -INT16_C(  6951), -INT16_C( 11693),  INT16_C( 26378),  INT16_C( 10407),
         INT16_C( 29159),  INT16_C(  4013),  INT16_C( 16898),  INT16_C( 12179),  INT16_C(  5737),  INT16_C( 13994), -INT16_C( 22566), -INT16_C(   155) } },
    { {  INT16_C( 23535), -INT16_C( 31523), -INT16_C(  4211), -INT16_C( 27293),  INT16_C( 29362), -INT16_C( 22299), -INT16_C( 29686),  INT16_C( 22480),
         INT16_C(  9064),  INT16_C( 27207), -INT16_C( 19354), -INT16_C(   710), -INT16_C(  7011), -INT16_C( 15821),  INT16_C(  3494), -INT16_C( 27240),
         INT16_C( 30056), -INT16_C(  2791),  INT16_C( 31844),  INT16_C(  5770),  INT16_C( 28910), -INT16_C(  1858), -INT16_C( 28676),  INT16_C( 25679),
        -INT16_C( 26958),  INT16_C(  6350),  INT16_C(  2122), -INT16_C(  6378),  INT16_C( 18924), -INT16_C( 27990),  INT16_C( 16982), -INT16_C( 16857) },
      UINT32_C( 481509815),
      {  INT16_C( 16061), -INT16_C( 21454), -INT16_C(  3666), -INT16_C( 21852), -INT16_C(  2944),  INT16_C( 12815), -INT16_C(  8822), -INT16_C( 10933),
         INT16_C( 25062), -INT16_C( 11588),  INT16_C( 26282),  INT16_C(   357), -INT16_C( 29528),  INT16_C( 24767),  INT16_C( 29645), -INT16_C( 29828),
        -INT16_C( 20815),  INT16_C( 24375), -INT16_C(  9313),  INT16_C(  7945),  INT16_C(  6351),  INT16_C( 23122), -INT16_C( 25098), -INT16_C(  9169),
        -INT16_C(  5122), -INT16_C( 22354),  INT16_C(  4946), -INT16_C(  1367),  INT16_C( 27040),  INT16_C( 27994), -INT16_C( 10532), -INT16_C( 29192) },
      {  INT16_C( 16061),  INT16_C( 21454),  INT16_C(  3666), -INT16_C( 27293),  INT16_C(  2944),  INT16_C( 12815), -INT16_C( 29686),  INT16_C( 10933),
         INT16_C( 25062),  INT16_C( 27207), -INT16_C( 19354), -INT16_C(   710), -INT16_C(  7011), -INT16_C( 15821),  INT16_C( 29645), -INT16_C( 27240),
         INT16_C( 20815),  INT16_C( 24375),  INT16_C( 31844),  INT16_C(  5770),  INT16_C(  6351),  INT16_C( 23122), -INT16_C( 28676),  INT16_C(  9169),
        -INT16_C( 26958),  INT16_C(  6350),  INT16_C(  4946),  INT16_C(  1367),  INT16_C( 27040), -INT16_C( 27990),  INT16_C( 16982), -INT16_C( 16857) } },
    { {  INT16_C( 12165),  INT16_C(  9452), -INT16_C(  2805), -INT16_C(  9660), -INT16_C( 27122),  INT16_C(  1076),  INT16_C( 25395),  INT16_C( 12768),
        -INT16_C( 29105), -INT16_C( 24103), -INT16_C( 31838),  INT16_C( 17051), -INT16_C(  2324), -INT16_C( 14161), -INT16_C( 22324),  INT16_C( 20821),
         INT16_C( 16855), -INT16_C(  7562), -INT16_C( 17866),  INT16_C( 17597), -INT16_C(  3760), -INT16_C( 31928),  INT16_C( 10325), -INT16_C( 23372),
        -INT16_C( 29257),  INT16_C( 22853), -INT16_C(  8176), -INT16_C(   869),  INT16_C( 19158), -INT16_C( 23612),  INT16_C(  6642), -INT16_C( 13580) },
      UINT32_C(2443995738),
      {  INT16_C( 26916),  INT16_C( 29909),  INT16_C(  7771), -INT16_C( 20233), -INT16_C( 21690), -INT16_C(   684), -INT16_C( 26311),  INT16_C( 18774),
        -INT16_C(  3719),  INT16_C( 20550),  INT16_C(  2620),  INT16_C( 12019), -INT16_C(  6364),  INT16_C( 32504), -INT16_C( 23214),  INT16_C( 30223),
        -INT16_C(  6898),  INT16_C( 27115), -INT16_C(  7677),  INT16_C( 18713),  INT16_C( 28046), -INT16_C( 14521), -INT16_C( 25338), -INT16_C( 32752),
         INT16_C( 22159), -INT16_C( 13360), -INT16_C( 15519), -INT16_C( 31239), -INT16_C(  3414), -INT16_C(  1021),  INT16_C(  5015), -INT16_C( 23181) },
      {  INT16_C( 12165),  INT16_C( 29909), -INT16_C(  2805),  INT16_C( 20233),  INT16_C( 21690),  INT16_C(  1076),  INT16_C( 26311),  INT16_C( 12768),
        -INT16_C( 29105),  INT16_C( 20550), -INT16_C( 31838),  INT16_C( 12019), -INT16_C(  2324),  INT16_C( 32504),  INT16_C( 23214),  INT16_C( 20821),
         INT16_C( 16855), -INT16_C(  7562),  INT16_C(  7677),  INT16_C( 18713), -INT16_C(  3760),  INT16_C( 14521),  INT16_C( 10325),  INT16_C( 32752),
         INT16_C( 22159),  INT16_C( 22853), -INT16_C(  8176), -INT16_C(   869),  INT16_C(  3414), -INT16_C( 23612),  INT16_C(  6642),  INT16_C( 23181) } }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
    simde__m512i src = simde_mm512_loadu_epi16(test_vec[i].src);
    simde__m512i a = simde_mm512_loadu_epi16(test_vec[i].a);
    simde__m512i r = simde_mm512_mask_abs_epi16(src, test_vec[i].k, a);
    simde_test_x86_assert_equal_i16x32(r, simde_mm512_loadu_epi16(test_vec[i].r));
  }

  return 0;
}

static int
test_simde_mm512_maskz_abs_epi16 (SIMDE_MUNIT_TEST_ARGS) {
  static const struct {
    const simde__mmask32 k;
    const int16_t a[32];
    const int16_t r[32];
  } test_vec[] = {
    { UINT32_C( 426916685),
      {  INT16_C( 30267),  INT16_C( 27257), -INT16_C( 27872), -INT16_C( 31845), -INT16_C( 31872),  INT16_C( 14983), -INT16_C( 30143),  INT16_C(   666),
         INT16_C( 12540),  INT16_C(  6967), -INT16_C( 16243),  INT16_C(   692), -INT16_C(  5341),  INT16_C( 28883),  INT16_C( 17702),  INT16_C( 24969),
         INT16_C(   955), -INT16_C(  9013),  INT16_C( 26518),  INT16_C(  5727), -INT16_C(  6422),  INT16_C( 11089), -INT16_C(  5264),  INT16_C( 27693),
         INT16_C( 25627), -INT16_C( 22392),  INT16_C( 15396),  INT16_C( 18346),  INT16_C( 32295),  INT16_C( 19896),  INT16_C( 16835),  INT16_C( 32686) },
      {  INT16_C( 30267),  INT16_C(     0),  INT16_C( 27872),  INT16_C( 31845),  INT16_C(     0),  INT16_C(     0),  INT16_C( 30143),  INT16_C(     0),
         INT16_C( 12540),  INT16_C(  6967),  INT16_C(     0),  INT16_C(   692),  INT16_C(  5341),  INT16_C( 28883),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C(  9013),  INT16_C(     0),  INT16_C(     0),  INT16_C(  6422),  INT16_C( 11089),  INT16_C(  5264),  INT16_C(     0),
         INT16_C( 25627),  INT16_C(     0),  INT16_C(     0),  INT16_C( 18346),  INT16_C( 32295),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0) } },
    { UINT32_C(3680205380),
      { -INT16_C( 17695), -INT16_C( 13327),  INT16_C( 17057),  INT16_C(  4599),  INT16_C(  9261),  INT16_C( 18558),  INT16_C(  1673), -INT16_C( 21008),
        -INT16_C( 25790),  INT16_C( 27125), -INT16_C( 21223), -INT16_C(  9034),  INT16_C( 25838),  INT16_C( 13147), -INT16_C( 18722), -INT16_C( 16626),
        -INT16_C(   143),  INT16_C(  4747), -INT16_C( 32190),  INT16_C( 28451), -INT16_C( 24154),  INT16_C( 12216), -INT16_C( 22361), -INT16_C(  5667),
        -INT16_C( 11709),  INT16_C( 23634),  INT16_C(  2175),  INT16_C( 27961), -INT16_C( 27539),  INT16_C( 19360), -INT16_C( 20917), -INT16_C( 17397) },
      {  INT16_C(     0),  INT16_C(     0),  INT16_C( 17057),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(  1673),  INT16_C(     0),
         INT16_C(     0),  INT16_C( 27125),  INT16_C(     0),  INT16_C(  9034),  INT16_C( 25838),  INT16_C( 13147),  INT16_C( 18722),  INT16_C(     0),
         INT16_C(   143),  INT16_C(  4747),  INT16_C(     0),  INT16_C( 28451),  INT16_C( 24154),  INT16_C(     0),  INT16_C( 22361),  INT16_C(     0),
         INT16_C( 11709),  INT16_C( 23634),  INT16_C(     0),  INT16_C( 27961),  INT16_C( 27539),  INT16_C(     0),  INT16_C( 20917),  INT16_C( 17397) } },
    { UINT32_C(4040070830),
      { -INT16_C(  3816), -INT16_C( 16801),  INT16_C(  6035),  INT16_C( 15086), -INT16_C( 13376),  INT16_C(   804),  INT16_C( 30365),  INT16_C(  7264),
        -INT16_C( 26241), -INT16_C(  4983),  INT16_C( 10797),  INT16_C( 30775),  INT16_C( 17112), -INT16_C( 31180),  INT16_C(   728), -INT16_C(  3978),
        -INT16_C( 10508), -INT16_C( 30801), -INT16_C( 25107), -INT16_C( 21055), -INT16_C(  6808),  INT16_C(  1457),  INT16_C(  4444), -INT16_C(  9439),
        -INT16_C( 21846), -INT16_C( 10297), -INT16_C(   300), -INT16_C( 21168), -INT16_C( 31679),  INT16_C(  6451), -INT16_C( 21881),  INT16_C( 31498) },
      {  INT16_C(     0),  INT16_C( 16801),  INT16_C(  6035),  INT16_C( 15086),  INT16_C(     0),  INT16_C(   804),  INT16_C(     0),  INT16_C(  7264),
         INT16_C(     0),  INT16_C(  4983),  INT16_C( 10797),  INT16_C(     0),  INT16_C( 17112),  INT16_C(     0),  INT16_C(     0),  INT16_C(  3978),
         INT16_C(     0),  INT16_C( 30801),  INT16_C( 25107),  INT16_C( 21055),  INT16_C(     0),  INT16_C(     0),  INT16_C(  4444),  INT16_C(  9439),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C( 31679),  INT16_C(  6451),  INT16_C( 21881),  INT16_C( 31498) } },
    { UINT32_C(1828895104),
      { -INT16_C( 15530), -INT16_C( 16869), -INT16_C( 13143),  INT16_C(  1475), -INT16_C(  6947), -INT16_C( 30752), -INT16_C( 22642),  INT16_C( 25438),
        -INT16_C( 20827), -INT16_C(  6640),  INT16_C( 17203), -INT16_C( 17920),  INT16_C(  2797),  INT16_C( 27957),  INT16_C( 14275),  INT16_C(  6619),
        -INT16_C(  2310), -INT16_C( 23593), -INT16_C( 25918), -INT16_C( 24664), -INT16_C( 30594),  INT16_C(  3110), -INT16_C( 31697), -INT16_C( 10897),
         INT16_C( 32563),  INT16_C( 26299), -INT16_C( 17469), -INT16_C( 20448),  INT16_C( 21957), -INT16_C( 30690), -INT16_C(  1652), -INT16_C( 31071) },
      {  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C( 25438),
         INT16_C( 20827),  INT16_C(     0),  INT16_C(     0),  INT16_C( 17920),  INT16_C(  2797),  INT16_C( 27957),  INT16_C(     0),  INT16_C(  6619),
         INT16_C(     0),  INT16_C( 23593),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C( 32563),  INT16_C(     0),  INT16_C( 17469),  INT16_C( 20448),  INT16_C(     0),  INT16_C( 30690),  INT16_C(  1652),  INT16_C(     0) } },
    { UINT32_C(2972350703),
      { -INT16_C( 11758), -INT16_C( 28592),  INT16_C( 30299), -INT16_C( 30051),  INT16_C(  3322),  INT16_C( 11615),  INT16_C(  7052),  INT16_C( 20371),
        -INT16_C( 19498), -INT16_C( 25345),  INT16_C(  7432), -INT16_C( 27612), -INT16_C( 14826),  INT16_C(  1307),  INT16_C( 17726),  INT16_C( 20918),
         INT16_C(  1559),  INT16_C( 29409),  INT16_C( 32380),  INT16_C( 30717),  INT16_C( 23691),  INT16_C(  6052),  INT16_C( 14455),  INT16_C( 20070),
         INT16_C( 26091), -INT16_C(  2838),  INT16_C(  3715), -INT16_C( 26232), -INT16_C( 23596),  INT16_C(  5023),  INT16_C( 21992),  INT16_C(   100) },
      {  INT16_C( 11758),  INT16_C( 28592),  INT16_C( 30299),  INT16_C( 30051),  INT16_C(     0),  INT16_C( 11615),  INT16_C(  7052),  INT16_C( 20371),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C( 27612),  INT16_C( 14826),  INT16_C(  1307),  INT16_C( 17726),  INT16_C(     0),
         INT16_C(     0),  INT16_C( 29409),  INT16_C(     0),  INT16_C( 30717),  INT16_C(     0),  INT16_C(  6052),  INT16_C(     0),  INT16_C(     0),
         INT16_C( 26091),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C( 23596),  INT16_C(  5023),  INT16_C(     0),  INT16_C(   100) } },
    { UINT32_C(3631367516),
      {  INT16_C( 28612),  INT16_C( 20303), -INT16_C(  2868),  INT16_C( 17254), -INT16_C( 13268),  INT16_C(  6033),  INT16_C( 31537), -INT16_C( 19445),
        -INT16_C( 27510),  INT16_C( 24142), -INT16_C(  4809),  INT16_C(  8305), -INT16_C( 10942), -INT16_C( 25056), -INT16_C( 28133), -INT16_C(  8329),
        -INT16_C( 14846), -INT16_C( 12754), -INT16_C( 27462), -INT16_C(  6639), -INT16_C( 23712), -INT16_C( 28162),  INT16_C(  2334), -INT16_C( 22458),
        -INT16_C( 27491), -INT16_C( 11001),  INT16_C( 30849), -INT16_C( 15371),  INT16_C(  5454),  INT16_C( 26978), -INT16_C(  9817), -INT16_C( 22200) },
      {  INT16_C(     0),  INT16_C(     0),  INT16_C(  2868),  INT16_C( 17254),  INT16_C( 13268),  INT16_C(     0),  INT16_C( 31537),  INT16_C(     0),
         INT16_C( 27510),  INT16_C(     0),  INT16_C(  4809),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C( 28133),  INT16_C(     0),
         INT16_C(     0),  INT16_C( 12754),  INT16_C(     0),  INT16_C(     0),  INT16_C( 23712),  INT16_C( 28162),  INT16_C(  2334),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C( 15371),  INT16_C(  5454),  INT16_C(     0),  INT16_C(  9817),  INT16_C( 22200) } },
    { UINT32_C(1517778591),
      { -INT16_C( 30454),  INT16_C( 27200),  INT16_C( 15916),  INT16_C( 19195),  INT16_C( 16712), -INT16_C(  6669), -INT16_C(  1323),  INT16_C( 22202),
        -INT16_C( 20622), -INT16_C( 16358),  INT16_C( 31940),  INT16_C( 27689),  INT16_C( 29013), -INT16_C(  3051), -INT16_C( 29209), -INT16_C(  3762),
        -INT16_C( 28906),  INT16_C( 16987),  INT16_C( 22477),  INT16_C(  5516),  INT16_C( 32664),  INT16_C( 28411), -INT16_C( 19079), -INT16_C(  4924),
        -INT16_C(  8603),  INT16_C( 10668), -INT16_C( 10662), -INT16_C( 20587), -INT16_C( 21689),  INT16_C( 12196), -INT16_C(  3528),  INT16_C( 20000) },
      {  INT16_C( 30454),  INT16_C( 27200),  INT16_C( 15916),  INT16_C( 19195),  INT16_C( 16712),  INT16_C(     0),  INT16_C(     0),  INT16_C( 22202),
         INT16_C(     0),  INT16_C( 16358),  INT16_C( 31940),  INT16_C(     0),  INT16_C( 29013),  INT16_C(  3051),  INT16_C( 29209),  INT16_C(     0),
         INT16_C( 28906),  INT16_C( 16987),  INT16_C( 22477),  INT16_C(     0),  INT16_C( 32664),  INT16_C( 28411),  INT16_C( 19079),  INT16_C(     0),
         INT16_C(     0),  INT16_C( 10668),  INT16_C(     0),  INT16_C( 20587),  INT16_C( 21689),  INT16_C(     0),  INT16_C(  3528),  INT16_C(     0) } },
    { UINT32_C(1334869121),
      {  INT16_C(  7379),  INT16_C( 27492),  INT16_C( 24476),  INT16_C(  5593), -INT16_C( 25067),  INT16_C( 31233), -INT16_C( 20868), -INT16_C( 10333),
         INT16_C( 14724), -INT16_C( 13434),  INT16_C( 10980),  INT16_C(  7418),  INT16_C(  6941), -INT16_C( 24982), -INT16_C(  1385),  INT16_C( 27373),
         INT16_C( 21014), -INT16_C( 19755), -INT16_C( 20559), -INT16_C( 14648), -INT16_C( 14003), -INT16_C( 14016), -INT16_C(  7049), -INT16_C(  1120),
         INT16_C( 10013),  INT16_C(   455), -INT16_C( 16047),  INT16_C( 28189), -INT16_C( 30756),  INT16_C( 29453), -INT16_C(  1407), -INT16_C( 26659) },
      {  INT16_C(  7379),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C( 10333),
         INT16_C(     0),  INT16_C(     0),  INT16_C( 10980),  INT16_C(  7418),  INT16_C(  6941),  INT16_C( 24982),  INT16_C(  1385),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C( 14003),  INT16_C(     0),  INT16_C(     0),  INT16_C(  1120),
         INT16_C( 10013),  INT16_C(   455),  INT16_C( 16047),  INT16_C( 28189),  INT16_C(     0),  INT16_C(     0),  INT16_C(  1407),  INT16_C(     0) } }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
    simde__m512i a = simde_mm512_loadu_epi16(test_vec[i].a);
    simde__m512i r = simde_mm512_maskz_abs_epi16(test_vec[i].k, a);
    simde_test_x86_assert_equal_i16x32(r, simde_mm512_loadu_epi16(test_vec[i].r));
  }

  return 0;
}

static int
test_simde_mm512_add_epi8 (SIMDE_MUNIT_TEST_ARGS) {
  struct {
    const int8_t a[64];
    const int8_t b[64];
    const int8_t r[64];
  } test_vec[] = {
    { {  INT8_C(  16), -INT8_C(  23), -INT8_C(  42), -INT8_C( 110), -INT8_C(  66), -INT8_C(  42),  INT8_C(  81), -INT8_C( 107),
        -INT8_C(  64), -INT8_C(  89),  INT8_C( 109),  INT8_C(  69),  INT8_C(  32), -INT8_C(  26), -INT8_C(  52), -INT8_C( 121),
        -INT8_C(  91), -INT8_C( 119),  INT8_C(  20), -INT8_C( 127),  INT8_C(  41), -INT8_C(  19),  INT8_C(  18),  INT8_C(   3),
         INT8_C( 103),  INT8_C( 122),  INT8_C(  63), -INT8_C(  75),  INT8_C(  40), -INT8_C(  38), -INT8_C(  44),  INT8_C(  56),
        -INT8_C(  61), -INT8_C(  86), -INT8_C(  54), -INT8_C( 127),      INT8_MIN,  INT8_C(  27),  INT8_C(  22),  INT8_C(  64),
        -INT8_C(  61), -INT8_C( 125), -INT8_C( 122), -INT8_C(  29),  INT8_C( 105),  INT8_C(  82),  INT8_C( 106),  INT8_C(  14),
        -INT8_C(  37),  INT8_C( 126), -INT8_C( 113),  INT8_C(   5),  INT8_C( 107), -INT8_C(  95),  INT8_C(   8), -INT8_C(  46),
         INT8_C(  27),  INT8_C(  71), -INT8_C( 120),  INT8_C(  67),  INT8_C(  33),  INT8_C(  92),  INT8_C( 124), -INT8_C(  28) },
      {  INT8_C(   6),  INT8_C(  70),  INT8_C( 101), -INT8_C( 122),  INT8_C(  98),  INT8_C( 123), -INT8_C(  58),  INT8_C(  37),
        -INT8_C(   1),  INT8_C(  76),  INT8_C(   8),  INT8_C( 104), -INT8_C(  98),  INT8_C( 114),  INT8_C( 119),  INT8_C( 122),
        -INT8_C(  16),  INT8_C(   6),      INT8_MAX,  INT8_C(  91), -INT8_C(  88), -INT8_C( 121),  INT8_C(  45), -INT8_C(  61),
        -INT8_C(  50), -INT8_C(  75),  INT8_C(   7), -INT8_C(  17),  INT8_C(  17), -INT8_C( 125), -INT8_C(  45),  INT8_C(  23),
        -INT8_C(  55),  INT8_C(  56), -INT8_C(  99),  INT8_C(  43), -INT8_C(  77),  INT8_C( 100),  INT8_C(  80), -INT8_C(  78),
        -INT8_C(  80),  INT8_C(  88),  INT8_C(  27),  INT8_C(  79), -INT8_C(  54), -INT8_C( 110), -INT8_C(  55), -INT8_C(  70),
        -INT8_C( 104),  INT8_C(  72),  INT8_C(  21),  INT8_C(  64), -INT8_C(  49),  INT8_C(  67),  INT8_C(   4), -INT8_C(  99),
        -INT8_C(   8),  INT8_C(  11), -INT8_C( 116),  INT8_C(  10), -INT8_C( 114),  INT8_C(  95),  INT8_C(  33),  INT8_C(  87) },
      {  INT8_C(  22),  INT8_C(  47),  INT8_C(  59),  INT8_C(  24),  INT8_C(  32),  INT8_C(  81),  INT8_C(  23), -INT8_C(  70),
        -INT8_C(  65), -INT8_C(  13),  INT8_C( 117), -INT8_C(  83), -INT8_C(  66),  INT8_C(  88),  INT8_C(  67),  INT8_C(   1),
        -INT8_C( 107), -INT8_C( 113), -INT8_C( 109), -INT8_C(  36), -INT8_C(  47),  INT8_C( 116),  INT8_C(  63), -INT8_C(  58),
         INT8_C(  53),  INT8_C(  47),  INT8_C(  70), -INT8_C(  92),  INT8_C(  57),  INT8_C(  93), -INT8_C(  89),  INT8_C(  79),
        -INT8_C( 116), -INT8_C(  30),  INT8_C( 103), -INT8_C(  84),  INT8_C(  51),      INT8_MAX,  INT8_C( 102), -INT8_C(  14),
         INT8_C( 115), -INT8_C(  37), -INT8_C(  95),  INT8_C(  50),  INT8_C(  51), -INT8_C(  28),  INT8_C(  51), -INT8_C(  56),
         INT8_C( 115), -INT8_C(  58), -INT8_C(  92),  INT8_C(  69),  INT8_C(  58), -INT8_C(  28),  INT8_C(  12),  INT8_C( 111),
         INT8_C(  19),  INT8_C(  82),  INT8_C(  20),  INT8_C(  77), -INT8_C(  81), -INT8_C(  69), -INT8_C(  99),  INT8_C(  59) } },
    { { -INT8_C( 105), -INT8_C(  65), -INT8_C( 125),  INT8_C(  74),  INT8_C(  35), -INT8_C(  45), -INT8_C(   3), -INT8_C(  45),
         INT8_C(  44),  INT8_C(  24),  INT8_C(  34), -INT8_C(  10), -INT8_C(  86), -INT8_C(  21), -INT8_C(  79),  INT8_C(  66),
         INT8_C(  51), -INT8_C(  58), -INT8_C( 125),  INT8_C(   2),  INT8_C(   9), -INT8_C( 121), -INT8_C(  97),  INT8_C(   2),
        -INT8_C( 110),  INT8_C(  43),  INT8_C(  12),  INT8_C(  32), -INT8_C( 118),  INT8_C(  45),  INT8_C( 119),  INT8_C(  33),
        -INT8_C(  20), -INT8_C(   6),  INT8_C( 108),  INT8_C(  15), -INT8_C(  50),  INT8_C( 105), -INT8_C(  29), -INT8_C(   6),
        -INT8_C( 127),  INT8_C(   5), -INT8_C(  16),  INT8_C(  43), -INT8_C(  15), -INT8_C(  95),  INT8_C( 109),  INT8_C(  36),
         INT8_C( 104), -INT8_C(  16),  INT8_C(  39),  INT8_C( 113),  INT8_C( 119), -INT8_C(  58),  INT8_C( 115),  INT8_C(   9),
        -INT8_C(  14),      INT8_MAX,  INT8_C(  41),  INT8_C( 124), -INT8_C(  83), -INT8_C(  95), -INT8_C(  98), -INT8_C( 103) },
      { -INT8_C( 101),  INT8_C(  10), -INT8_C(  87),  INT8_C( 105),  INT8_C( 115), -INT8_C( 116),  INT8_C(  99), -INT8_C(  12),
        -INT8_C( 111),  INT8_C(  84),  INT8_C(  31), -INT8_C( 126), -INT8_C(  11), -INT8_C( 116), -INT8_C(  89),  INT8_C(  93),
         INT8_C( 125), -INT8_C(  50), -INT8_C(  49), -INT8_C(  12), -INT8_C( 108),  INT8_C(  66), -INT8_C(   2), -INT8_C( 122),
        -INT8_C(  62),  INT8_C(  39),  INT8_C(   3),  INT8_C( 111), -INT8_C(  56), -INT8_C(  95),  INT8_C(   8),  INT8_C( 100),
        -INT8_C(  85), -INT8_C(  79), -INT8_C(  51),  INT8_C(  30),  INT8_C(  61),  INT8_C(  49),  INT8_C(  18), -INT8_C(  49),
        -INT8_C( 123),  INT8_C(  49),  INT8_C(  81),  INT8_C( 122), -INT8_C(  67), -INT8_C(   8), -INT8_C(  40),  INT8_C(  58),
        -INT8_C(  58), -INT8_C(  89),  INT8_C(  47),  INT8_C(  91), -INT8_C(  23),  INT8_C(  45), -INT8_C(  31), -INT8_C(  85),
         INT8_C(  84), -INT8_C(  28),  INT8_C(  26),  INT8_C(  29), -INT8_C( 123),  INT8_C(  35), -INT8_C( 127),  INT8_C(  48) },
      {  INT8_C(  50), -INT8_C(  55),  INT8_C(  44), -INT8_C(  77), -INT8_C( 106),  INT8_C(  95),  INT8_C(  96), -INT8_C(  57),
        -INT8_C(  67),  INT8_C( 108),  INT8_C(  65),  INT8_C( 120), -INT8_C(  97),  INT8_C( 119),  INT8_C(  88), -INT8_C(  97),
        -INT8_C(  80), -INT8_C( 108),  INT8_C(  82), -INT8_C(  10), -INT8_C(  99), -INT8_C(  55), -INT8_C(  99), -INT8_C( 120),
         INT8_C(  84),  INT8_C(  82),  INT8_C(  15), -INT8_C( 113),  INT8_C(  82), -INT8_C(  50),      INT8_MAX, -INT8_C( 123),
        -INT8_C( 105), -INT8_C(  85),  INT8_C(  57),  INT8_C(  45),  INT8_C(  11), -INT8_C( 102), -INT8_C(  11), -INT8_C(  55),
         INT8_C(   6),  INT8_C(  54),  INT8_C(  65), -INT8_C(  91), -INT8_C(  82), -INT8_C( 103),  INT8_C(  69),  INT8_C(  94),
         INT8_C(  46), -INT8_C( 105),  INT8_C(  86), -INT8_C(  52),  INT8_C(  96), -INT8_C(  13),  INT8_C(  84), -INT8_C(  76),
         INT8_C(  70),  INT8_C(  99),  INT8_C(  67), -INT8_C( 103),  INT8_C(  50), -INT8_C(  60),  INT8_C(  31), -INT8_C(  55) } },
    { { -INT8_C(  44),  INT8_C(  78),  INT8_C(  78),  INT8_C(  18),      INT8_MAX,  INT8_C(  96), -INT8_C(  31),  INT8_C(   4),
        -INT8_C( 111),  INT8_C(  50),      INT8_MAX,  INT8_C(  79),  INT8_C(  43),  INT8_C(  87), -INT8_C( 119), -INT8_C(  15),
        -INT8_C(   2), -INT8_C(  72),  INT8_C(  76), -INT8_C(  25), -INT8_C(  27),  INT8_C(  46), -INT8_C( 109),  INT8_C(  58),
         INT8_C(  18), -INT8_C(  83),  INT8_C(  87), -INT8_C( 104), -INT8_C(  48), -INT8_C(  40), -INT8_C(  56), -INT8_C(  91),
         INT8_C(  38),  INT8_C(  23), -INT8_C(  73), -INT8_C(  90),  INT8_C( 119), -INT8_C( 104), -INT8_C(  86),  INT8_C(   9),
        -INT8_C(  54),  INT8_C(  41),  INT8_C(  88), -INT8_C(  11),      INT8_MIN, -INT8_C(  31), -INT8_C(  25),  INT8_C( 126),
        -INT8_C( 102),  INT8_C(  51),  INT8_C( 102),      INT8_MAX,  INT8_C(  97), -INT8_C(   7), -INT8_C(  71),  INT8_C( 116),
        -INT8_C(  90),  INT8_C(  16),  INT8_C(  12),  INT8_C( 119), -INT8_C(  24), -INT8_C(  44),  INT8_C(  28),  INT8_C(  15) },
      { -INT8_C(  21), -INT8_C(  45), -INT8_C(  75),  INT8_C(  99),  INT8_C( 107),  INT8_C(  95),  INT8_C( 108),  INT8_C(  53),
        -INT8_C( 119), -INT8_C(  60),  INT8_C(  43),  INT8_C(   9), -INT8_C(  91),  INT8_C(  18), -INT8_C( 120),  INT8_C(  63),
         INT8_C(  69), -INT8_C(  18), -INT8_C(  65), -INT8_C(  89), -INT8_C(  25),  INT8_C( 120),  INT8_C(  27), -INT8_C( 115),
        -INT8_C( 119),  INT8_C(  39),  INT8_C(   4),  INT8_C( 113), -INT8_C(   5),  INT8_C(  32),      INT8_MIN, -INT8_C(  25),
        -INT8_C(  13),  INT8_C(  53),  INT8_C(  74),  INT8_C(  94), -INT8_C( 107), -INT8_C(  74), -INT8_C( 108),  INT8_C(  30),
         INT8_C( 122), -INT8_C(  65),  INT8_C(  39),  INT8_C(  31), -INT8_C(  47), -INT8_C(  81),  INT8_C(  95),  INT8_C(  22),
        -INT8_C(  99),  INT8_C(  30), -INT8_C(  67), -INT8_C( 124), -INT8_C( 106), -INT8_C(  40),  INT8_C(  18),  INT8_C(  31),
        -INT8_C(   1),  INT8_C(  22), -INT8_C( 111), -INT8_C(   5),  INT8_C(  55),  INT8_C(  17), -INT8_C(  30),  INT8_C(  42) },
      { -INT8_C(  65),  INT8_C(  33),  INT8_C(   3),  INT8_C( 117), -INT8_C(  22), -INT8_C(  65),  INT8_C(  77),  INT8_C(  57),
         INT8_C(  26), -INT8_C(  10), -INT8_C(  86),  INT8_C(  88), -INT8_C(  48),  INT8_C( 105),  INT8_C(  17),  INT8_C(  48),
         INT8_C(  67), -INT8_C(  90),  INT8_C(  11), -INT8_C( 114), -INT8_C(  52), -INT8_C(  90), -INT8_C(  82), -INT8_C(  57),
        -INT8_C( 101), -INT8_C(  44),  INT8_C(  91),  INT8_C(   9), -INT8_C(  53), -INT8_C(   8),  INT8_C(  72), -INT8_C( 116),
         INT8_C(  25),  INT8_C(  76),  INT8_C(   1),  INT8_C(   4),  INT8_C(  12),  INT8_C(  78),  INT8_C(  62),  INT8_C(  39),
         INT8_C(  68), -INT8_C(  24),      INT8_MAX,  INT8_C(  20),  INT8_C(  81), -INT8_C( 112),  INT8_C(  70), -INT8_C( 108),
         INT8_C(  55),  INT8_C(  81),  INT8_C(  35),  INT8_C(   3), -INT8_C(   9), -INT8_C(  47), -INT8_C(  53), -INT8_C( 109),
        -INT8_C(  91),  INT8_C(  38), -INT8_C(  99),  INT8_C( 114),  INT8_C(  31), -INT8_C(  27), -INT8_C(   2),  INT8_C(  57) } },
    { {  INT8_C(  71),  INT8_C(  44), -INT8_C( 119), -INT8_C(  36), -INT8_C(  30),  INT8_C(  29), -INT8_C(   6),  INT8_C(  92),
        -INT8_C(  36),  INT8_C(  33),  INT8_C( 123), -INT8_C(  83), -INT8_C(  47), -INT8_C(  38), -INT8_C(  61),  INT8_C( 110),
        -INT8_C(   8), -INT8_C( 127), -INT8_C(  13), -INT8_C( 113),  INT8_C(  89),  INT8_C(   5), -INT8_C(  82),  INT8_C(  89),
         INT8_C(  27),  INT8_C(  63),  INT8_C(  84),  INT8_C(  82),  INT8_C(  81),  INT8_C(  54),  INT8_C( 125), -INT8_C( 104),
         INT8_C(  98),  INT8_C(   6),  INT8_C( 116),  INT8_C(  68),  INT8_C(  35),  INT8_C( 110), -INT8_C(  96), -INT8_C(   1),
        -INT8_C( 113),  INT8_C(  27), -INT8_C(  84),  INT8_C(  96), -INT8_C(  10),  INT8_C( 111), -INT8_C(  49), -INT8_C(  18),
        -INT8_C(  16), -INT8_C(  62),  INT8_C( 125),  INT8_C(  74), -INT8_C(  57),  INT8_C(  44), -INT8_C(  93), -INT8_C(  30),
         INT8_C( 107), -INT8_C(   9),  INT8_C(  53), -INT8_C(  68),  INT8_C(  45), -INT8_C(  78),  INT8_C(  84), -INT8_C( 113) },
      { -INT8_C(  72), -INT8_C(  56), -INT8_C(  45), -INT8_C(  37),  INT8_C(  54),  INT8_C( 115), -INT8_C(  38), -INT8_C(  58),
        -INT8_C( 114), -INT8_C( 122),  INT8_C(  38), -INT8_C( 124), -INT8_C(  11), -INT8_C(  11),  INT8_C( 115), -INT8_C(  26),
        -INT8_C(  73), -INT8_C(  16),  INT8_C(  48),  INT8_C( 126),  INT8_C(  28), -INT8_C(  45),  INT8_C(  97), -INT8_C( 120),
        -INT8_C(  54), -INT8_C( 106),  INT8_C(  68), -INT8_C(   9),  INT8_C(  72), -INT8_C( 103), -INT8_C( 122),  INT8_C(   0),
         INT8_C(  97),  INT8_C(  89), -INT8_C(  37), -INT8_C( 104), -INT8_C(  52), -INT8_C(  75),  INT8_C(  94),  INT8_C(  90),
         INT8_C(  59), -INT8_C( 124), -INT8_C(  33),  INT8_C(  48),  INT8_C( 122),  INT8_C(  82),  INT8_C(  22),  INT8_C(  49),
         INT8_C(  66),  INT8_C(  70), -INT8_C(  80),  INT8_C(  95),  INT8_C(  25),  INT8_C(  17), -INT8_C(  25), -INT8_C(  29),
        -INT8_C(  89),  INT8_C(  43), -INT8_C(  38), -INT8_C(  17), -INT8_C(  60),  INT8_C(  96), -INT8_C(  17),  INT8_C(  38) },
      { -INT8_C(   1), -INT8_C(  12),  INT8_C(  92), -INT8_C(  73),  INT8_C(  24), -INT8_C( 112), -INT8_C(  44),  INT8_C(  34),
         INT8_C( 106), -INT8_C(  89), -INT8_C(  95),  INT8_C(  49), -INT8_C(  58), -INT8_C(  49),  INT8_C(  54),  INT8_C(  84),
        -INT8_C(  81),  INT8_C( 113),  INT8_C(  35),  INT8_C(  13),  INT8_C( 117), -INT8_C(  40),  INT8_C(  15), -INT8_C(  31),
        -INT8_C(  27), -INT8_C(  43), -INT8_C( 104),  INT8_C(  73), -INT8_C( 103), -INT8_C(  49),  INT8_C(   3), -INT8_C( 104),
        -INT8_C(  61),  INT8_C(  95),  INT8_C(  79), -INT8_C(  36), -INT8_C(  17),  INT8_C(  35), -INT8_C(   2),  INT8_C(  89),
        -INT8_C(  54), -INT8_C(  97), -INT8_C( 117), -INT8_C( 112),  INT8_C( 112), -INT8_C(  63), -INT8_C(  27),  INT8_C(  31),
         INT8_C(  50),  INT8_C(   8),  INT8_C(  45), -INT8_C(  87), -INT8_C(  32),  INT8_C(  61), -INT8_C( 118), -INT8_C(  59),
         INT8_C(  18),  INT8_C(  34),  INT8_C(  15), -INT8_C(  85), -INT8_C(  15),  INT8_C(  18),  INT8_C(  67), -INT8_C(  75) } },
    { { -INT8_C(  71), -INT8_C(  54), -INT8_C(  66), -INT8_C( 123),      INT8_MAX,  INT8_C(  28), -INT8_C(  32), -INT8_C(  70),
        -INT8_C(  96), -INT8_C(  65), -INT8_C(  22),  INT8_C(  26),  INT8_C(  17),  INT8_C(   1),  INT8_C(  76),  INT8_C(  83),
         INT8_C(  71), -INT8_C(   4), -INT8_C(  78),  INT8_C(  97),  INT8_C(  13), -INT8_C( 103),  INT8_C(  68), -INT8_C(  76),
        -INT8_C(  59),  INT8_C(  31), -INT8_C(  93), -INT8_C( 119),      INT8_MAX, -INT8_C( 110), -INT8_C(  81),  INT8_C(  57),
         INT8_C(  92),  INT8_C( 109), -INT8_C(  66), -INT8_C(  37), -INT8_C( 119), -INT8_C(  98), -INT8_C( 107),  INT8_C(  42),
         INT8_C(  93),      INT8_MAX,  INT8_C(  68),  INT8_C( 110),      INT8_MIN, -INT8_C( 112), -INT8_C(  62), -INT8_C(  56),
        -INT8_C( 116),  INT8_C( 116),  INT8_C(  41), -INT8_C( 103),  INT8_C(  14),  INT8_C( 109),  INT8_C(  77), -INT8_C(  45),
        -INT8_C( 116), -INT8_C(  16),  INT8_C(  92),  INT8_C(  12), -INT8_C( 126),  INT8_C(  12),  INT8_C(  69), -INT8_C(  34) },
      {  INT8_C( 121),  INT8_C(   3), -INT8_C(  71),  INT8_C(   3), -INT8_C(  94),  INT8_C(  78),  INT8_C(  45), -INT8_C(   1),
        -INT8_C(  50),  INT8_C( 113),  INT8_C( 110),  INT8_C(  78),  INT8_C(   2),  INT8_C(  48),  INT8_C(  22), -INT8_C( 114),
        -INT8_C(  92),  INT8_C(  63),  INT8_C(  40), -INT8_C(  78), -INT8_C(  83),  INT8_C( 117), -INT8_C( 123),  INT8_C(  57),
         INT8_C( 102), -INT8_C(  30),  INT8_C(  69), -INT8_C(  24), -INT8_C(  18), -INT8_C( 118), -INT8_C(  57),  INT8_C( 103),
        -INT8_C( 114),      INT8_MIN,  INT8_C( 106),  INT8_C(  48), -INT8_C(  49), -INT8_C( 105),  INT8_C(  47), -INT8_C(  99),
         INT8_C(   9), -INT8_C(  99), -INT8_C(  21),  INT8_C(  11), -INT8_C(  51),  INT8_C(   2), -INT8_C( 103),  INT8_C( 114),
         INT8_C(  65), -INT8_C(  63),  INT8_C(  36), -INT8_C(  18),  INT8_C(  55), -INT8_C(  86),  INT8_C(  40), -INT8_C(  99),
        -INT8_C( 116),  INT8_C( 109), -INT8_C( 123),  INT8_C( 122), -INT8_C(   8),  INT8_C(  76), -INT8_C(  31), -INT8_C( 122) },
      {  INT8_C(  50), -INT8_C(  51),  INT8_C( 119), -INT8_C( 120),  INT8_C(  33),  INT8_C( 106),  INT8_C(  13), -INT8_C(  71),
         INT8_C( 110),  INT8_C(  48),  INT8_C(  88),  INT8_C( 104),  INT8_C(  19),  INT8_C(  49),  INT8_C(  98), -INT8_C(  31),
        -INT8_C(  21),  INT8_C(  59), -INT8_C(  38),  INT8_C(  19), -INT8_C(  70),  INT8_C(  14), -INT8_C(  55), -INT8_C(  19),
         INT8_C(  43),  INT8_C(   1), -INT8_C(  24),  INT8_C( 113),  INT8_C( 109),  INT8_C(  28),  INT8_C( 118), -INT8_C(  96),
        -INT8_C(  22), -INT8_C(  19),  INT8_C(  40),  INT8_C(  11),  INT8_C(  88),  INT8_C(  53), -INT8_C(  60), -INT8_C(  57),
         INT8_C( 102),  INT8_C(  28),  INT8_C(  47),  INT8_C( 121),  INT8_C(  77), -INT8_C( 110),  INT8_C(  91),  INT8_C(  58),
        -INT8_C(  51),  INT8_C(  53),  INT8_C(  77), -INT8_C( 121),  INT8_C(  69),  INT8_C(  23),  INT8_C( 117),  INT8_C( 112),
         INT8_C(  24),  INT8_C(  93), -INT8_C(  31), -INT8_C( 122),  INT8_C( 122),  INT8_C(  88),  INT8_C(  38),  INT8_C( 100) } },
    { { -INT8_C(  51),  INT8_C(  76), -INT8_C(  74), -INT8_C( 100), -INT8_C(  29), -INT8_C(  27),  INT8_C(  57), -INT8_C(  20),
        -INT8_C( 125),  INT8_C(  36), -INT8_C(   9),  INT8_C(  80),  INT8_C(  38), -INT8_C( 111), -INT8_C(  62),  INT8_C( 104),
         INT8_C(  82), -INT8_C(  25),  INT8_C(  86), -INT8_C( 119), -INT8_C( 111),  INT8_C( 126),  INT8_C(  38),  INT8_C(  29),
        -INT8_C(  20), -INT8_C(  84), -INT8_C( 105), -INT8_C(  28), -INT8_C(   8),  INT8_C( 120),  INT8_C( 106), -INT8_C(  59),
        -INT8_C(  60),  INT8_C(  32),  INT8_C(  97), -INT8_C(  88),  INT8_C(   5), -INT8_C( 102), -INT8_C( 108), -INT8_C( 120),
        -INT8_C(  65), -INT8_C( 116), -INT8_C(  39), -INT8_C(  27),  INT8_C(  29), -INT8_C( 101),  INT8_C(  77),  INT8_C( 111),
        -INT8_C( 126), -INT8_C(  92), -INT8_C(   7),  INT8_C(  19),  INT8_C(  34),  INT8_C(  31),  INT8_C(  48),  INT8_C(  14),
        -INT8_C(  53), -INT8_C(  57), -INT8_C(  14), -INT8_C(  60),  INT8_C(  64),  INT8_C(  92), -INT8_C( 119),  INT8_C(   4) },
      {  INT8_C( 124), -INT8_C(  21), -INT8_C(  84), -INT8_C( 126), -INT8_C( 123),  INT8_C(  65),  INT8_C(  10),  INT8_C(  68),
        -INT8_C(  51), -INT8_C(  29),  INT8_C(  42), -INT8_C(  22),      INT8_MAX,  INT8_C( 119),  INT8_C(  89),  INT8_C(   1),
         INT8_C(  27),  INT8_C(  82),  INT8_C(  21),  INT8_C(  62),  INT8_C( 114),  INT8_C(  69),  INT8_C(  76),  INT8_C(  61),
         INT8_C(  13),  INT8_C(  63),  INT8_C(   1),  INT8_C(  77), -INT8_C( 101), -INT8_C( 117),  INT8_C(  81),  INT8_C(  24),
         INT8_C( 118), -INT8_C(   2), -INT8_C( 102), -INT8_C(   5),  INT8_C(  63), -INT8_C(  92),  INT8_C(  64),  INT8_C(  12),
        -INT8_C( 120),  INT8_C( 106), -INT8_C(  10),  INT8_C(   7), -INT8_C(  31),  INT8_C(  79),  INT8_C(   8), -INT8_C(   3),
        -INT8_C(  94),  INT8_C(  29),  INT8_C(  59),  INT8_C(  20),  INT8_C(  99), -INT8_C( 121),  INT8_C(  81),  INT8_C( 112),
        -INT8_C(  58),  INT8_C(  83), -INT8_C(  67),  INT8_C(  98), -INT8_C(  34),  INT8_C(  14),  INT8_C( 122),  INT8_C(  84) },
      {  INT8_C(  73),  INT8_C(  55),  INT8_C(  98),  INT8_C(  30),  INT8_C( 104),  INT8_C(  38),  INT8_C(  67),  INT8_C(  48),
         INT8_C(  80),  INT8_C(   7),  INT8_C(  33),  INT8_C(  58), -INT8_C(  91),  INT8_C(   8),  INT8_C(  27),  INT8_C( 105),
         INT8_C( 109),  INT8_C(  57),  INT8_C( 107), -INT8_C(  57),  INT8_C(   3), -INT8_C(  61),  INT8_C( 114),  INT8_C(  90),
        -INT8_C(   7), -INT8_C(  21), -INT8_C( 104),  INT8_C(  49), -INT8_C( 109),  INT8_C(   3), -INT8_C(  69), -INT8_C(  35),
         INT8_C(  58),  INT8_C(  30), -INT8_C(   5), -INT8_C(  93),  INT8_C(  68),  INT8_C(  62), -INT8_C(  44), -INT8_C( 108),
         INT8_C(  71), -INT8_C(  10), -INT8_C(  49), -INT8_C(  20), -INT8_C(   2), -INT8_C(  22),  INT8_C(  85),  INT8_C( 108),
         INT8_C(  36), -INT8_C(  63),  INT8_C(  52),  INT8_C(  39), -INT8_C( 123), -INT8_C(  90), -INT8_C( 127),  INT8_C( 126),
        -INT8_C( 111),  INT8_C(  26), -INT8_C(  81),  INT8_C(  38),  INT8_C(  30),  INT8_C( 106),  INT8_C(   3),  INT8_C(  88) } },
    { {  INT8_C(  12),  INT8_C(  20),  INT8_C(  79),  INT8_C(  75), -INT8_C(  72), -INT8_C( 113),  INT8_C(  87),  INT8_C(  64),
        -INT8_C(   7),  INT8_C(  77),  INT8_C(  71), -INT8_C(  37), -INT8_C(  99),  INT8_C(  80), -INT8_C(  40),  INT8_C(  63),
         INT8_C( 109),  INT8_C(  19),  INT8_C(  83), -INT8_C(  48), -INT8_C( 102), -INT8_C(  92),  INT8_C(  64),  INT8_C(  97),
        -INT8_C(   9), -INT8_C(   3), -INT8_C(  61), -INT8_C(  43),  INT8_C(  12),  INT8_C(  61),  INT8_C(  41),  INT8_C(  24),
         INT8_C(  81),  INT8_C( 121),  INT8_C( 100),  INT8_C(   9),  INT8_C(   8), -INT8_C(  69),  INT8_C(  74),  INT8_C(   2),
         INT8_C(   9), -INT8_C( 111), -INT8_C(  35), -INT8_C(  90), -INT8_C(  31), -INT8_C(  75), -INT8_C(  27),  INT8_C(  79),
        -INT8_C(  56),  INT8_C(  56),  INT8_C(  31),  INT8_C(  98), -INT8_C(  36),  INT8_C(  96), -INT8_C(  61), -INT8_C(  44),
         INT8_C(  93), -INT8_C( 122), -INT8_C(  87),  INT8_C( 105), -INT8_C(  61), -INT8_C(  45), -INT8_C( 126),  INT8_C(  20) },
      {  INT8_C(  76), -INT8_C(  26),  INT8_C(  30),  INT8_C(  84), -INT8_C(  95),  INT8_C( 104),  INT8_C(  86), -INT8_C(  86),
        -INT8_C(   7),  INT8_C(  51),  INT8_C(  80), -INT8_C(  37), -INT8_C(  24),  INT8_C(  53),  INT8_C(  42), -INT8_C(  80),
         INT8_C( 109),  INT8_C(  73),  INT8_C(  19),  INT8_C(  74), -INT8_C(  87), -INT8_C(  42),  INT8_C(  30),  INT8_C(   7),
         INT8_C(  93), -INT8_C(  57),  INT8_C( 112),  INT8_C(  32), -INT8_C( 102), -INT8_C(  14),  INT8_C(  53), -INT8_C(  26),
        -INT8_C(  40),  INT8_C(  83),  INT8_C(  59),  INT8_C( 122), -INT8_C(  69), -INT8_C( 111),  INT8_C(  36), -INT8_C(  76),
        -INT8_C(  59),  INT8_C( 117), -INT8_C( 113), -INT8_C(  83), -INT8_C(  86), -INT8_C(  71),  INT8_C(  94),  INT8_C(  24),
         INT8_C(   3),  INT8_C( 113),  INT8_C(  98), -INT8_C(  84),  INT8_C(  71),      INT8_MIN, -INT8_C(  77), -INT8_C(  92),
         INT8_C(  71),  INT8_C(  36), -INT8_C(  59), -INT8_C(  30),  INT8_C(  22), -INT8_C(   6), -INT8_C(  56), -INT8_C(  17) },
      {  INT8_C(  88), -INT8_C(   6),  INT8_C( 109), -INT8_C(  97),  INT8_C(  89), -INT8_C(   9), -INT8_C(  83), -INT8_C(  22),
        -INT8_C(  14),      INT8_MIN, -INT8_C( 105), -INT8_C(  74), -INT8_C( 123), -INT8_C( 123),  INT8_C(   2), -INT8_C(  17),
        -INT8_C(  38),  INT8_C(  92),  INT8_C( 102),  INT8_C(  26),  INT8_C(  67),  INT8_C( 122),  INT8_C(  94),  INT8_C( 104),
         INT8_C(  84), -INT8_C(  60),  INT8_C(  51), -INT8_C(  11), -INT8_C(  90),  INT8_C(  47),  INT8_C(  94), -INT8_C(   2),
         INT8_C(  41), -INT8_C(  52), -INT8_C(  97), -INT8_C( 125), -INT8_C(  61),  INT8_C(  76),  INT8_C( 110), -INT8_C(  74),
        -INT8_C(  50),  INT8_C(   6),  INT8_C( 108),  INT8_C(  83), -INT8_C( 117),  INT8_C( 110),  INT8_C(  67),  INT8_C( 103),
        -INT8_C(  53), -INT8_C(  87), -INT8_C( 127),  INT8_C(  14),  INT8_C(  35), -INT8_C(  32),  INT8_C( 118),  INT8_C( 120),
        -INT8_C(  92), -INT8_C(  86),  INT8_C( 110),  INT8_C(  75), -INT8_C(  39), -INT8_C(  51),  INT8_C(  74),  INT8_C(   3) } },
    { {  INT8_C(  77),  INT8_C(   3),  INT8_C( 105),  INT8_C(   8), -INT8_C( 107), -INT8_C( 115), -INT8_C(  68),  INT8_C(  90),
         INT8_C(   2),  INT8_C(  76),  INT8_C(   7), -INT8_C(  83),  INT8_C(   5),  INT8_C( 101), -INT8_C(  59),  INT8_C(   8),
        -INT8_C(  42),  INT8_C(  39), -INT8_C(  75),  INT8_C(  30), -INT8_C(  89),  INT8_C( 104), -INT8_C(  62), -INT8_C(  18),
        -INT8_C( 116), -INT8_C( 121), -INT8_C(  48), -INT8_C(  93), -INT8_C( 127), -INT8_C( 103), -INT8_C( 110), -INT8_C(  50),
        -INT8_C( 100), -INT8_C(   5), -INT8_C(  42),  INT8_C(  49), -INT8_C( 120), -INT8_C( 109), -INT8_C( 117), -INT8_C( 117),
        -INT8_C(  33), -INT8_C( 109),  INT8_C(  56), -INT8_C(  28), -INT8_C(   8), -INT8_C(   3), -INT8_C(  19), -INT8_C(  49),
         INT8_C(  36), -INT8_C(  94), -INT8_C(  19), -INT8_C(  53),  INT8_C(  10), -INT8_C(  81), -INT8_C(  71), -INT8_C( 105),
         INT8_C(  55), -INT8_C( 118),  INT8_C(  58), -INT8_C(  72),  INT8_C(  35), -INT8_C(  52), -INT8_C( 121), -INT8_C(  65) },
      { -INT8_C(  57),  INT8_C(  93), -INT8_C(  15),  INT8_C(  79), -INT8_C(  16),  INT8_C( 124), -INT8_C(  38), -INT8_C(  49),
         INT8_C(  15),  INT8_C(  18), -INT8_C(  76),  INT8_C(   8),  INT8_C(  15), -INT8_C(  95), -INT8_C(  41),  INT8_C(  51),
         INT8_C(  67), -INT8_C(  60), -INT8_C(   2),  INT8_C(  77),  INT8_C( 115), -INT8_C(  72), -INT8_C(  28), -INT8_C(  86),
         INT8_C(  66),  INT8_C(  30),  INT8_C(  99),  INT8_C( 101), -INT8_C(  22), -INT8_C(  22),  INT8_C(  36), -INT8_C(  79),
         INT8_C(  71),  INT8_C(  21),  INT8_C(   1),  INT8_C(  56), -INT8_C( 110), -INT8_C(  37),  INT8_C(   7), -INT8_C(  95),
        -INT8_C(  18), -INT8_C(  69), -INT8_C(  87), -INT8_C(   3),  INT8_C(  92),      INT8_MIN,  INT8_C(  49), -INT8_C(  97),
         INT8_C(  68),  INT8_C(  47), -INT8_C(  19), -INT8_C(  72), -INT8_C(  25), -INT8_C(  47),  INT8_C(  98),  INT8_C(  41),
        -INT8_C(  16), -INT8_C(  59), -INT8_C( 114), -INT8_C(  38), -INT8_C(  81), -INT8_C(  77), -INT8_C( 116), -INT8_C(   9) },
      {  INT8_C(  20),  INT8_C(  96),  INT8_C(  90),  INT8_C(  87), -INT8_C( 123),  INT8_C(   9), -INT8_C( 106),  INT8_C(  41),
         INT8_C(  17),  INT8_C(  94), -INT8_C(  69), -INT8_C(  75),  INT8_C(  20),  INT8_C(   6), -INT8_C( 100),  INT8_C(  59),
         INT8_C(  25), -INT8_C(  21), -INT8_C(  77),  INT8_C( 107),  INT8_C(  26),  INT8_C(  32), -INT8_C(  90), -INT8_C( 104),
        -INT8_C(  50), -INT8_C(  91),  INT8_C(  51),  INT8_C(   8),  INT8_C( 107), -INT8_C( 125), -INT8_C(  74),      INT8_MAX,
        -INT8_C(  29),  INT8_C(  16), -INT8_C(  41),  INT8_C( 105),  INT8_C(  26),  INT8_C( 110), -INT8_C( 110),  INT8_C(  44),
        -INT8_C(  51),  INT8_C(  78), -INT8_C(  31), -INT8_C(  31),  INT8_C(  84),  INT8_C( 125),  INT8_C(  30),  INT8_C( 110),
         INT8_C( 104), -INT8_C(  47), -INT8_C(  38), -INT8_C( 125), -INT8_C(  15),      INT8_MIN,  INT8_C(  27), -INT8_C(  64),
         INT8_C(  39),  INT8_C(  79), -INT8_C(  56), -INT8_C( 110), -INT8_C(  46),      INT8_MAX,  INT8_C(  19), -INT8_C(  74) } }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
    simde__m512i a = simde_mm512_loadu_epi8(test_vec[i].a);
    simde__m512i b = simde_mm512_loadu_epi8(test_vec[i].b);
    simde__m512i r = simde_mm512_add_epi8(a, b);
    simde_test_x86_assert_equal_i8x64(r, simde_mm512_loadu_epi8(test_vec[i].r));
  }

  return 0;
}

static int
test_simde_mm512_mask_add_epi8 (SIMDE_MUNIT_TEST_ARGS) {
  static const struct {
    const int8_t src[64];
    const simde__mmask64 k;
    const int8_t a[64];
    const int8_t b[64];
    const int8_t r[64];
  } test_vec[] = {
    { {  INT8_C(  20), -INT8_C(  19),  INT8_C(  38),  INT8_C(  45), -INT8_C(  89), -INT8_C(  95),  INT8_C(  34), -INT8_C(   3),
        -INT8_C(  21),  INT8_C(  99), -INT8_C(  35),  INT8_C(  73),  INT8_C(   3), -INT8_C( 119),  INT8_C(   1), -INT8_C(   7),
        -INT8_C( 123), -INT8_C(  90),  INT8_C(  32),  INT8_C(  73), -INT8_C(  12), -INT8_C( 115), -INT8_C(  93),  INT8_C(  56),
         INT8_C( 116),  INT8_C(  96), -INT8_C(  89), -INT8_C( 108),  INT8_C(  46), -INT8_C(  17),  INT8_C(  92),  INT8_C(  67),
        -INT8_C(  35), -INT8_C( 125),  INT8_C( 112), -INT8_C( 124),  INT8_C(  36), -INT8_C( 110), -INT8_C( 127),  INT8_C(  15),
        -INT8_C(  11),  INT8_C(  95),  INT8_C(  88), -INT8_C(   8), -INT8_C(  24),  INT8_C(  89), -INT8_C(  14),  INT8_C( 109),
        -INT8_C(   1),  INT8_C(  18), -INT8_C(  73), -INT8_C(  13), -INT8_C(  97),  INT8_C(  90),  INT8_C(  43),  INT8_C(  19),
        -INT8_C(  69), -INT8_C(  45), -INT8_C(  88), -INT8_C(  23), -INT8_C(  62),  INT8_C(   4),  INT8_C(  44), -INT8_C(  97) },
      UINT64_C( 2646890825868614791),
      {  INT8_C(   4),  INT8_C(  19),  INT8_C(  28), -INT8_C(  20),  INT8_C( 109),  INT8_C(  14),  INT8_C(  90),  INT8_C( 108),
         INT8_C(  32),  INT8_C(  17),  INT8_C(  96), -INT8_C(  64),  INT8_C( 107), -INT8_C( 117), -INT8_C(  45),  INT8_C(  38),
         INT8_C(  94),  INT8_C( 123),  INT8_C(  16),  INT8_C(  33),      INT8_MIN,  INT8_C(  60), -INT8_C(  64),  INT8_C(   7),
        -INT8_C(  39), -INT8_C(  28), -INT8_C(  77),  INT8_C(   7), -INT8_C( 119),  INT8_C( 110),  INT8_C(  43), -INT8_C( 115),
        -INT8_C( 127),  INT8_C(  72),  INT8_C( 121), -INT8_C(  18),  INT8_C(  86), -INT8_C(  45),  INT8_C(  91),  INT8_C( 119),
        -INT8_C(  28), -INT8_C(  69),  INT8_C(  55),  INT8_C(  80),  INT8_C(  70),  INT8_C(  10),  INT8_C( 118), -INT8_C(  91),
        -INT8_C( 122), -INT8_C( 122), -INT8_C(  58),  INT8_C(   6), -INT8_C(  61), -INT8_C( 122),  INT8_C(  13), -INT8_C( 100),
         INT8_C( 106), -INT8_C(  64), -INT8_C(  93), -INT8_C(  13),  INT8_C(  46), -INT8_C(  49),      INT8_MIN, -INT8_C(  80) },
      {  INT8_C(  23), -INT8_C(   6), -INT8_C(  98),  INT8_C( 109), -INT8_C(  51), -INT8_C(   7), -INT8_C(  28), -INT8_C(  78),
        -INT8_C(  76),  INT8_C(  27),  INT8_C(   2), -INT8_C(   5),  INT8_C(  38),  INT8_C( 120), -INT8_C(  96), -INT8_C(  84),
        -INT8_C(   1),  INT8_C( 102), -INT8_C(  78), -INT8_C(  62), -INT8_C(  20), -INT8_C(  65),  INT8_C(  94),  INT8_C(  87),
             INT8_MIN,  INT8_C(   1),  INT8_C(  74), -INT8_C(  82), -INT8_C(  48), -INT8_C(  53),  INT8_C(  94), -INT8_C(  25),
        -INT8_C(  59), -INT8_C(   3),  INT8_C(  85), -INT8_C( 110), -INT8_C(  10),  INT8_C(  57),  INT8_C(  68), -INT8_C(  85),
         INT8_C(  85),  INT8_C(  70), -INT8_C(  90),  INT8_C( 123), -INT8_C(  65),  INT8_C(  70),  INT8_C(  39), -INT8_C(  66),
        -INT8_C(  84), -INT8_C(  39),      INT8_MIN, -INT8_C( 104), -INT8_C( 104), -INT8_C(  34), -INT8_C(  17),  INT8_C(  24),
        -INT8_C(  33),  INT8_C(  58), -INT8_C(  57), -INT8_C(  80),  INT8_C(   5),  INT8_C(  37), -INT8_C( 105), -INT8_C(  54) },
      {  INT8_C(  27),  INT8_C(  13), -INT8_C(  70),  INT8_C(  45), -INT8_C(  89), -INT8_C(  95),  INT8_C(  34),  INT8_C(  30),
        -INT8_C(  21),  INT8_C(  99),  INT8_C(  98), -INT8_C(  69), -INT8_C( 111), -INT8_C( 119),  INT8_C(   1), -INT8_C(  46),
         INT8_C(  93), -INT8_C(  31),  INT8_C(  32),  INT8_C(  73), -INT8_C(  12), -INT8_C(   5), -INT8_C(  93),  INT8_C(  56),
         INT8_C(  89), -INT8_C(  27), -INT8_C(  89), -INT8_C(  75),  INT8_C(  46),  INT8_C(  57),  INT8_C(  92),  INT8_C( 116),
        -INT8_C(  35),  INT8_C(  69), -INT8_C(  50),      INT8_MIN,  INT8_C(  36),  INT8_C(  12), -INT8_C( 127),  INT8_C(  15),
         INT8_C(  57),  INT8_C(  95), -INT8_C(  35), -INT8_C(   8), -INT8_C(  24),  INT8_C(  80), -INT8_C(  14),  INT8_C(  99),
         INT8_C(  50),  INT8_C(  95), -INT8_C(  73), -INT8_C(  98),  INT8_C(  91),  INT8_C( 100),  INT8_C(  43), -INT8_C(  76),
        -INT8_C(  69), -INT8_C(  45),  INT8_C( 106), -INT8_C(  23), -INT8_C(  62), -INT8_C(  12),  INT8_C(  44), -INT8_C(  97) } },
    { {  INT8_C(  34), -INT8_C(  20),  INT8_C(  92),  INT8_C(  25),  INT8_C(  38), -INT8_C(  95), -INT8_C(  60),  INT8_C( 123),
        -INT8_C(  25),  INT8_C( 106), -INT8_C(  10), -INT8_C(  90), -INT8_C(  80),  INT8_C(  29),  INT8_C( 100),  INT8_C(  92),
        -INT8_C(  10), -INT8_C(  28), -INT8_C(  12), -INT8_C( 114), -INT8_C(  62), -INT8_C(  28), -INT8_C(  89), -INT8_C(  94),
         INT8_C(  30),  INT8_C( 110),  INT8_C(  82),  INT8_C(  35), -INT8_C( 109), -INT8_C(  23), -INT8_C(  19), -INT8_C(  74),
        -INT8_C(  42),  INT8_C(  73), -INT8_C(  49), -INT8_C(   4), -INT8_C(  22), -INT8_C( 109),  INT8_C( 119), -INT8_C(  46),
        -INT8_C(   3),  INT8_C( 109),  INT8_C( 120), -INT8_C(  83), -INT8_C( 118), -INT8_C(  35),  INT8_C(   9),      INT8_MIN,
        -INT8_C(  63), -INT8_C(   3),  INT8_C(  14), -INT8_C( 124), -INT8_C(  31), -INT8_C(  75),  INT8_C(  38), -INT8_C(   1),
         INT8_C(  35),  INT8_C( 120),  INT8_C(  34), -INT8_C(  73),  INT8_C(  97),  INT8_C(  15),  INT8_C( 109),  INT8_C(  55) },
      UINT64_C(14705847965410606169),
      {  INT8_C(  23), -INT8_C( 114),  INT8_C( 121), -INT8_C(  95),  INT8_C( 107), -INT8_C( 126),  INT8_C(  33),  INT8_C(  44),
             INT8_MAX,  INT8_C(  48), -INT8_C(  80),  INT8_C(  97), -INT8_C(  27), -INT8_C(  42),  INT8_C(  96),  INT8_C(   9),
         INT8_C(  78), -INT8_C( 125), -INT8_C(  64), -INT8_C(  80), -INT8_C( 110),  INT8_C(  45), -INT8_C(  25), -INT8_C(  21),
         INT8_C( 105),  INT8_C(  27),  INT8_C(  47),  INT8_C(  56), -INT8_C(  59),  INT8_C(  68),  INT8_C(   4), -INT8_C(  35),
        -INT8_C(  46),  INT8_C( 125),  INT8_C( 126),  INT8_C(  61), -INT8_C(   1), -INT8_C(  96),  INT8_C( 106),  INT8_C( 126),
        -INT8_C(  48),  INT8_C(  26), -INT8_C(  33), -INT8_C(  75), -INT8_C(  15),  INT8_C(  64), -INT8_C(  66),  INT8_C(  63),
        -INT8_C(  61),  INT8_C( 126), -INT8_C(  17),  INT8_C(  85), -INT8_C(  85), -INT8_C(  41),  INT8_C(  65),  INT8_C(  20),
        -INT8_C(  14),  INT8_C( 112),  INT8_C(  76), -INT8_C(  73), -INT8_C(  76),  INT8_C(  80), -INT8_C( 108), -INT8_C( 121) },
      { -INT8_C(  51),  INT8_C(  19), -INT8_C(  60), -INT8_C(  52), -INT8_C(  77),  INT8_C(  46),  INT8_C(  75), -INT8_C( 125),
         INT8_C(  73),  INT8_C(  42),  INT8_C(  56),  INT8_C(  58),  INT8_C( 106), -INT8_C(   9),  INT8_C( 121),  INT8_C(  45),
         INT8_C( 117),  INT8_C( 105), -INT8_C( 125),  INT8_C(  33),  INT8_C(  64), -INT8_C(  60),  INT8_C(  53),  INT8_C(  50),
         INT8_C(  52), -INT8_C( 126), -INT8_C(  23), -INT8_C(  24), -INT8_C(  46),  INT8_C( 126),  INT8_C( 111), -INT8_C(  96),
        -INT8_C( 111),  INT8_C(  52),  INT8_C( 108),  INT8_C(  68),  INT8_C(  98), -INT8_C(  73), -INT8_C(  57), -INT8_C(  85),
        -INT8_C(  30), -INT8_C(   1), -INT8_C(  27),  INT8_C(  76), -INT8_C(  10),  INT8_C(  95),  INT8_C( 122),  INT8_C( 108),
        -INT8_C(  56), -INT8_C(   3), -INT8_C( 115),  INT8_C(   8), -INT8_C(  63), -INT8_C(  62),  INT8_C(  58), -INT8_C(  11),
         INT8_C(  68),  INT8_C(  35), -INT8_C(  35),  INT8_C(  23), -INT8_C(  95),  INT8_C(  77), -INT8_C(  73),  INT8_C(  50) },
      { -INT8_C(  28), -INT8_C(  20),  INT8_C(  92),  INT8_C( 109),  INT8_C(  30), -INT8_C(  95),  INT8_C( 108),  INT8_C( 123),
        -INT8_C(  25),  INT8_C( 106), -INT8_C(  24), -INT8_C( 101),  INT8_C(  79), -INT8_C(  51),  INT8_C( 100),  INT8_C(  92),
        -INT8_C(  61), -INT8_C(  20), -INT8_C(  12), -INT8_C( 114), -INT8_C(  46), -INT8_C(  15), -INT8_C(  89), -INT8_C(  94),
        -INT8_C(  99), -INT8_C(  99),  INT8_C(  82),  INT8_C(  35), -INT8_C( 109), -INT8_C(  23),  INT8_C( 115), -INT8_C(  74),
         INT8_C(  99), -INT8_C(  79), -INT8_C(  22), -INT8_C( 127), -INT8_C(  22), -INT8_C( 109),  INT8_C(  49),  INT8_C(  41),
        -INT8_C(   3),  INT8_C(  25),  INT8_C( 120),  INT8_C(   1), -INT8_C( 118), -INT8_C(  97),  INT8_C(   9), -INT8_C(  85),
        -INT8_C( 117), -INT8_C(   3),  INT8_C( 124), -INT8_C( 124),  INT8_C( 108), -INT8_C(  75),  INT8_C(  38), -INT8_C(   1),
         INT8_C(  35),  INT8_C( 120),  INT8_C(  41), -INT8_C(  50),  INT8_C(  97),  INT8_C(  15),  INT8_C(  75), -INT8_C(  71) } },
    { { -INT8_C( 127),  INT8_C(  35),  INT8_C( 118), -INT8_C(  29), -INT8_C(  37),  INT8_C(  61), -INT8_C( 113), -INT8_C(  67),
         INT8_C(  61),  INT8_C( 116),  INT8_C(   9),  INT8_C(  51), -INT8_C(  45), -INT8_C( 125), -INT8_C(  97), -INT8_C( 101),
             INT8_MIN,  INT8_C(  44), -INT8_C(  93),  INT8_C(  65), -INT8_C(  17), -INT8_C(  35),  INT8_C(  54),  INT8_C(  51),
         INT8_C(   1),  INT8_C(  20),  INT8_C(  74), -INT8_C(  94),  INT8_C(  97),  INT8_C(   1), -INT8_C(  43), -INT8_C(  30),
         INT8_C(  37),  INT8_C(  75), -INT8_C(  59),  INT8_C(   0), -INT8_C( 119),  INT8_C(  84), -INT8_C(  67), -INT8_C(  58),
        -INT8_C(  55), -INT8_C(  58), -INT8_C(   7), -INT8_C( 100),  INT8_C(  74), -INT8_C( 103),  INT8_C(  56), -INT8_C(  54),
        -INT8_C(  59), -INT8_C(  37),  INT8_C(  12), -INT8_C(  76), -INT8_C(  71),  INT8_C(  66), -INT8_C(  24), -INT8_C(  70),
         INT8_C(  86),  INT8_C(  50),  INT8_C(  92), -INT8_C(  73),  INT8_C(  52),  INT8_C(  49), -INT8_C( 103),  INT8_C(  89) },
      UINT64_C( 8992587514113515389),
      { -INT8_C(  36), -INT8_C(  59),  INT8_C(  25),  INT8_C(  38),  INT8_C(  94),  INT8_C(  81), -INT8_C(  15),  INT8_C(  36),
         INT8_C(  44), -INT8_C(   3), -INT8_C(  40), -INT8_C(  27),  INT8_C(  63), -INT8_C(  64), -INT8_C(  97), -INT8_C( 106),
        -INT8_C(  13), -INT8_C(   4),  INT8_C(  77),  INT8_C(  39),  INT8_C(  45), -INT8_C(  25),      INT8_MIN, -INT8_C(  86),
         INT8_C(  70), -INT8_C(  39), -INT8_C(  80), -INT8_C(   7), -INT8_C(  17),  INT8_C( 124),  INT8_C( 118), -INT8_C(  53),
         INT8_C(  66), -INT8_C( 113), -INT8_C(  14), -INT8_C(  96), -INT8_C(  32), -INT8_C(  29), -INT8_C(  60),  INT8_C(  12),
        -INT8_C(  32), -INT8_C(  99), -INT8_C(  14),  INT8_C(  31),  INT8_C(  93), -INT8_C( 111), -INT8_C(  75),  INT8_C(  80),
        -INT8_C( 115),  INT8_C(   3),  INT8_C( 119), -INT8_C(  69), -INT8_C(  22), -INT8_C(   9),  INT8_C( 101),  INT8_C(  48),
        -INT8_C(  48),  INT8_C(  22),  INT8_C(  41), -INT8_C(  65), -INT8_C( 110), -INT8_C(  97), -INT8_C( 117), -INT8_C(  44) },
      {  INT8_C(  46),  INT8_C( 125),  INT8_C( 117),  INT8_C(  14),  INT8_C(  96),  INT8_C(  57),  INT8_C(  27),  INT8_C(  64),
        -INT8_C(  42),  INT8_C(  13),  INT8_C(  95),  INT8_C(  52), -INT8_C(  98),  INT8_C(  21), -INT8_C( 124),  INT8_C(  44),
         INT8_C(  24), -INT8_C(   4), -INT8_C(  25),  INT8_C(   2), -INT8_C(  13),  INT8_C(  76),  INT8_C(  50), -INT8_C(  60),
         INT8_C(  98),  INT8_C(  91), -INT8_C( 125), -INT8_C(  11), -INT8_C(   5),  INT8_C(  14), -INT8_C(  55),  INT8_C(  41),
        -INT8_C( 117),  INT8_C(  62),  INT8_C(  56), -INT8_C(  21),  INT8_C( 120),  INT8_C(  83),  INT8_C(  43),  INT8_C(  78),
         INT8_C(  96), -INT8_C( 117), -INT8_C( 126), -INT8_C(   2), -INT8_C(  96),  INT8_C(   7),  INT8_C(  42), -INT8_C(  72),
         INT8_C(   3),  INT8_C(  17), -INT8_C(  70), -INT8_C(  10),  INT8_C(  94), -INT8_C(  20), -INT8_C(  70), -INT8_C(  64),
         INT8_C(  71),  INT8_C(  62), -INT8_C(  75),  INT8_C(  66),  INT8_C(  76),      INT8_MAX,  INT8_C( 108), -INT8_C(  40) },
      {  INT8_C(  10),  INT8_C(  35), -INT8_C( 114),  INT8_C(  52), -INT8_C(  66), -INT8_C( 118),  INT8_C(  12), -INT8_C(  67),
         INT8_C(   2),  INT8_C(  10),  INT8_C(  55),  INT8_C(  25), -INT8_C(  35), -INT8_C( 125),  INT8_C(  35), -INT8_C( 101),
         INT8_C(  11),  INT8_C(  44), -INT8_C(  93),  INT8_C(  41),  INT8_C(  32), -INT8_C(  35), -INT8_C(  78),  INT8_C(  51),
         INT8_C(   1),  INT8_C(  52),  INT8_C(  51), -INT8_C(  94),  INT8_C(  97),  INT8_C(   1), -INT8_C(  43), -INT8_C(  30),
        -INT8_C(  51), -INT8_C(  51), -INT8_C(  59),  INT8_C(   0),  INT8_C(  88),  INT8_C(  54), -INT8_C(  67),  INT8_C(  90),
        -INT8_C(  55),  INT8_C(  40),  INT8_C( 116), -INT8_C( 100), -INT8_C(   3), -INT8_C( 103),  INT8_C(  56), -INT8_C(  54),
        -INT8_C(  59), -INT8_C(  37),  INT8_C(  49), -INT8_C(  79), -INT8_C(  71),  INT8_C(  66),  INT8_C(  31), -INT8_C(  16),
         INT8_C(  86),  INT8_C(  50), -INT8_C(  34),  INT8_C(   1), -INT8_C(  34),  INT8_C(  30), -INT8_C(   9),  INT8_C(  89) } },
    { { -INT8_C(  67), -INT8_C(  92), -INT8_C(  61),  INT8_C(  53), -INT8_C(   9), -INT8_C(  17), -INT8_C( 124),  INT8_C(  87),
         INT8_C( 122),  INT8_C(   6),  INT8_C(  85),  INT8_C(  26),  INT8_C(  13),      INT8_MIN, -INT8_C(  46),  INT8_C(  16),
        -INT8_C( 111), -INT8_C( 116),  INT8_C(   7), -INT8_C(  17),  INT8_C( 120), -INT8_C(  63), -INT8_C(  80), -INT8_C(  65),
        -INT8_C(   1),  INT8_C( 101),  INT8_C(   2),  INT8_C(  76), -INT8_C(  28),  INT8_C( 110),  INT8_C(  36), -INT8_C(  94),
         INT8_C(  18), -INT8_C(  25), -INT8_C(  41),  INT8_C(   9), -INT8_C(  42),  INT8_C(  91),  INT8_C(  96),  INT8_C(  80),
         INT8_C(  98), -INT8_C(  75),  INT8_C( 106),  INT8_C( 111),  INT8_C(  53),  INT8_C(  60),      INT8_MIN, -INT8_C(  57),
        -INT8_C(  56), -INT8_C( 121), -INT8_C(  74),  INT8_C(  64),  INT8_C(  72),  INT8_C( 102),  INT8_C(   0),  INT8_C(  72),
        -INT8_C(  52),  INT8_C(   2), -INT8_C( 108), -INT8_C(  80),  INT8_C( 112), -INT8_C(  72),  INT8_C(  82), -INT8_C( 126) },
      UINT64_C(16701295226602072735),
      { -INT8_C(  96),  INT8_C(  49),  INT8_C(  87), -INT8_C(  42),  INT8_C( 109), -INT8_C(  41), -INT8_C(  99),  INT8_C(  54),
         INT8_C(  94),  INT8_C(  83),  INT8_C( 118), -INT8_C(  90), -INT8_C(  70),  INT8_C( 118), -INT8_C(  18), -INT8_C( 122),
         INT8_C( 120), -INT8_C( 126),  INT8_C(  54), -INT8_C(  24),  INT8_C(  58), -INT8_C( 119),  INT8_C( 106), -INT8_C(  38),
        -INT8_C(  77), -INT8_C(  11),  INT8_C(  80),  INT8_C(  56), -INT8_C(  32),  INT8_C(  22),  INT8_C(  32), -INT8_C( 127),
         INT8_C(  71),  INT8_C( 119),  INT8_C(  87), -INT8_C(  75),  INT8_C(  78), -INT8_C(  12), -INT8_C(  21), -INT8_C(  84),
         INT8_C(  71),  INT8_C(  97),  INT8_C(  82),  INT8_C(   1), -INT8_C(  40),  INT8_C(  65), -INT8_C( 121),  INT8_C(  80),
        -INT8_C(  61), -INT8_C(  66),  INT8_C(  57), -INT8_C(   2),  INT8_C(  71), -INT8_C(  93), -INT8_C(  40), -INT8_C(   6),
        -INT8_C( 103),  INT8_C(  40),  INT8_C(  50),  INT8_C( 121),  INT8_C(  62),  INT8_C(  82), -INT8_C(   6), -INT8_C( 122) },
      { -INT8_C(  55),  INT8_C(  81),  INT8_C(  59),  INT8_C(  23),  INT8_C(  69),  INT8_C(  38), -INT8_C(  61), -INT8_C( 115),
        -INT8_C( 121),  INT8_C(  22), -INT8_C( 114),  INT8_C(  95),  INT8_C(  87),  INT8_C(  22), -INT8_C(  80),  INT8_C(  26),
        -INT8_C(  44), -INT8_C(  23),  INT8_C(  24),  INT8_C(  27), -INT8_C( 116), -INT8_C(  16),  INT8_C(  21),  INT8_C(  37),
         INT8_C(  24),  INT8_C(  71), -INT8_C(  97),  INT8_C(  87), -INT8_C( 102), -INT8_C( 103), -INT8_C(  35),  INT8_C(  99),
        -INT8_C(  21),  INT8_C(  24),  INT8_C( 123),  INT8_C(  48),  INT8_C(  62),  INT8_C(  62), -INT8_C(  67), -INT8_C(  59),
         INT8_C(  84),  INT8_C(  76),  INT8_C(  37), -INT8_C(  85),  INT8_C(  98), -INT8_C(  43), -INT8_C(  58),  INT8_C(  54),
        -INT8_C(  66), -INT8_C(  34),  INT8_C(  81),  INT8_C(  74), -INT8_C(  49),  INT8_C( 102),  INT8_C( 112), -INT8_C(  25),
        -INT8_C(  83),  INT8_C(  15),  INT8_C(  62),  INT8_C(  71), -INT8_C(  88),  INT8_C(  27), -INT8_C(  85), -INT8_C( 109) },
      {  INT8_C( 105), -INT8_C( 126), -INT8_C( 110), -INT8_C(  19), -INT8_C(  78), -INT8_C(  17), -INT8_C( 124), -INT8_C(  61),
         INT8_C( 122),  INT8_C( 105),  INT8_C(  85),  INT8_C(   5),  INT8_C(  13), -INT8_C( 116), -INT8_C(  46),  INT8_C(  16),
         INT8_C(  76),  INT8_C( 107),  INT8_C(   7),  INT8_C(   3),  INT8_C( 120), -INT8_C(  63), -INT8_C(  80), -INT8_C(   1),
        -INT8_C(   1),  INT8_C(  60), -INT8_C(  17),  INT8_C(  76),  INT8_C( 122), -INT8_C(  81), -INT8_C(   3), -INT8_C(  94),
         INT8_C(  50), -INT8_C(  25), -INT8_C(  46),  INT8_C(   9), -INT8_C(  42),  INT8_C(  91),  INT8_C(  96),  INT8_C( 113),
        -INT8_C( 101), -INT8_C(  83),  INT8_C( 106), -INT8_C(  84),  INT8_C(  53),  INT8_C(  22),  INT8_C(  77), -INT8_C( 122),
        -INT8_C(  56), -INT8_C( 100), -INT8_C( 118),  INT8_C(  64),  INT8_C(  72),  INT8_C( 102),  INT8_C(  72), -INT8_C(  31),
         INT8_C(  70),  INT8_C(  55),  INT8_C( 112), -INT8_C(  80),  INT8_C( 112),  INT8_C( 109), -INT8_C(  91),  INT8_C(  25) } },
    { {  INT8_C(  51),  INT8_C(  38), -INT8_C(  60),  INT8_C( 113),  INT8_C( 100), -INT8_C( 127),  INT8_C(  55), -INT8_C(  71),
        -INT8_C(  51),  INT8_C(  92),  INT8_C( 100),  INT8_C(  47),  INT8_C(  49),  INT8_C(  42),  INT8_C( 101), -INT8_C(  17),
         INT8_C(   9), -INT8_C(  74),  INT8_C(  57), -INT8_C(  40),  INT8_C(  28), -INT8_C(  87), -INT8_C(  65), -INT8_C(  54),
        -INT8_C(  72), -INT8_C(   2),  INT8_C(  17),  INT8_C(  97),  INT8_C(  25), -INT8_C(  68), -INT8_C(  12),  INT8_C(  77),
        -INT8_C(  30), -INT8_C(  72), -INT8_C(  66),  INT8_C(  71),  INT8_C(  58), -INT8_C(  11),  INT8_C(   0),  INT8_C(   7),
         INT8_C(  81),  INT8_C( 100),  INT8_C(  55), -INT8_C( 126), -INT8_C( 113), -INT8_C( 100),  INT8_C( 113), -INT8_C( 104),
         INT8_C(  83), -INT8_C(  85),  INT8_C( 112),  INT8_C( 111),  INT8_C(  84),  INT8_C(  47),  INT8_C(  57),  INT8_C(  13),
         INT8_C(  45),  INT8_C(  75),  INT8_C( 110),  INT8_C(  71),  INT8_C(   7),  INT8_C(  98), -INT8_C( 108), -INT8_C(  22) },
      UINT64_C(11050761772397056539),
      { -INT8_C( 107), -INT8_C( 109),  INT8_C(  28),  INT8_C(  36),  INT8_C(  48), -INT8_C( 115), -INT8_C(  68), -INT8_C( 125),
         INT8_C(  56),  INT8_C(  44), -INT8_C(  14), -INT8_C( 115),  INT8_C(  92),  INT8_C(  44), -INT8_C( 102), -INT8_C( 119),
         INT8_C( 119),  INT8_C(   8), -INT8_C(  48),  INT8_C( 126),  INT8_C( 106),  INT8_C( 100),  INT8_C( 104), -INT8_C( 123),
        -INT8_C(  73), -INT8_C( 103), -INT8_C(  38), -INT8_C(   1), -INT8_C(  54),  INT8_C(  55), -INT8_C( 104),  INT8_C(  96),
        -INT8_C(  54), -INT8_C(  76), -INT8_C( 124), -INT8_C(   6),  INT8_C(  66),  INT8_C(  65),  INT8_C( 125),  INT8_C( 122),
         INT8_C( 109),  INT8_C( 112),  INT8_C(   7), -INT8_C(  55), -INT8_C( 100), -INT8_C(  95),  INT8_C(  83),  INT8_C(  19),
        -INT8_C(  87),  INT8_C(  35), -INT8_C( 111),  INT8_C(  20), -INT8_C( 120), -INT8_C(   6), -INT8_C( 103),  INT8_C(  63),
        -INT8_C( 109),  INT8_C( 116),  INT8_C(  62),  INT8_C(  94), -INT8_C(  85), -INT8_C(  42), -INT8_C(  66),  INT8_C( 117) },
      { -INT8_C( 117),  INT8_C(  66),  INT8_C( 112), -INT8_C(  51), -INT8_C( 125), -INT8_C(  19),  INT8_C(  71), -INT8_C(  15),
         INT8_C(  93),  INT8_C(  79), -INT8_C(  70), -INT8_C(   7), -INT8_C(  16),  INT8_C(  13),  INT8_C(  12), -INT8_C( 102),
         INT8_C(  49), -INT8_C(  98), -INT8_C(  82), -INT8_C(  71), -INT8_C( 104),  INT8_C(  71), -INT8_C(   8),  INT8_C(  43),
        -INT8_C(  69),  INT8_C(  54), -INT8_C( 119),  INT8_C( 102),  INT8_C(  12),  INT8_C(  71), -INT8_C(  36), -INT8_C( 105),
        -INT8_C( 118),  INT8_C(  76),  INT8_C( 100),  INT8_C(  13),  INT8_C(  57), -INT8_C(  84), -INT8_C(   2), -INT8_C( 105),
        -INT8_C(   5), -INT8_C(  71), -INT8_C( 112), -INT8_C(  21), -INT8_C(  58), -INT8_C(  99), -INT8_C( 123), -INT8_C(   9),
         INT8_C(  59),  INT8_C(  51), -INT8_C(  80), -INT8_C(  45),  INT8_C( 123), -INT8_C(  88), -INT8_C(   2),  INT8_C(  54),
        -INT8_C(  34), -INT8_C( 120), -INT8_C(  99), -INT8_C(  21), -INT8_C(  49),  INT8_C( 121), -INT8_C( 126),  INT8_C(  89) },
      {  INT8_C(  32), -INT8_C(  43), -INT8_C(  60), -INT8_C(  15), -INT8_C(  77), -INT8_C( 127),  INT8_C(  55), -INT8_C(  71),
        -INT8_C(  51),  INT8_C( 123),  INT8_C( 100),  INT8_C(  47),  INT8_C(  76),  INT8_C(  42), -INT8_C(  90), -INT8_C(  17),
        -INT8_C(  88), -INT8_C(  74),  INT8_C(  57), -INT8_C(  40),  INT8_C(   2), -INT8_C(  85), -INT8_C(  65), -INT8_C(  54),
         INT8_C( 114), -INT8_C(   2),  INT8_C(  99),  INT8_C(  97), -INT8_C(  42), -INT8_C(  68),  INT8_C( 116),  INT8_C(  77),
        -INT8_C(  30), -INT8_C(  72), -INT8_C(  66),  INT8_C(   7),  INT8_C(  58), -INT8_C(  11),  INT8_C( 123),  INT8_C(   7),
         INT8_C( 104),  INT8_C( 100),  INT8_C(  55), -INT8_C( 126),  INT8_C(  98),  INT8_C(  62),  INT8_C( 113), -INT8_C( 104),
         INT8_C(  83), -INT8_C(  85),  INT8_C(  65), -INT8_C(  25),  INT8_C(   3),  INT8_C(  47), -INT8_C( 105),  INT8_C(  13),
         INT8_C( 113),  INT8_C(  75),  INT8_C( 110),  INT8_C(  73),  INT8_C( 122),  INT8_C(  98), -INT8_C( 108), -INT8_C(  50) } },
    { { -INT8_C(  59), -INT8_C(  25),  INT8_C( 103), -INT8_C(   2), -INT8_C( 109),  INT8_C( 101), -INT8_C( 107), -INT8_C( 114),
         INT8_C(  30),  INT8_C(  38),  INT8_C( 121), -INT8_C(  27), -INT8_C(  61), -INT8_C(   1), -INT8_C(  36), -INT8_C(   2),
         INT8_C(  50), -INT8_C( 115), -INT8_C(  47), -INT8_C(  83),  INT8_C(  53), -INT8_C(  49), -INT8_C(  28),  INT8_C(  20),
         INT8_C(  87), -INT8_C( 127), -INT8_C(   1),  INT8_C(  39), -INT8_C(   6), -INT8_C( 127),      INT8_MIN, -INT8_C(  65),
         INT8_C( 104), -INT8_C(  25), -INT8_C(  67), -INT8_C(   5),  INT8_C(  77),  INT8_C(  83), -INT8_C( 119),  INT8_C( 107),
         INT8_C( 121),  INT8_C(   3),  INT8_C(  80),  INT8_C(  60),  INT8_C(   2),  INT8_C(  45),  INT8_C(  58),  INT8_C(  52),
        -INT8_C(  70),  INT8_C(  11), -INT8_C(  30), -INT8_C(  17), -INT8_C(  38), -INT8_C(  58),  INT8_C(   3),  INT8_C(  50),
         INT8_C(  71),  INT8_C(   2),  INT8_C(  89),  INT8_C(  65), -INT8_C( 124), -INT8_C(  39),  INT8_C(   0), -INT8_C(  20) },
      UINT64_C( 9906073169161665985),
      {  INT8_C( 116), -INT8_C(  54), -INT8_C(  59),  INT8_C( 118), -INT8_C(   9), -INT8_C(   1), -INT8_C(  85), -INT8_C(  79),
         INT8_C(  10), -INT8_C( 115), -INT8_C(  96), -INT8_C(  27),  INT8_C(  83), -INT8_C(  92),  INT8_C(  23), -INT8_C( 102),
        -INT8_C(  90),  INT8_C( 112), -INT8_C(  37),  INT8_C(  42),  INT8_C(  73), -INT8_C(  37),  INT8_C(  23),  INT8_C(  10),
        -INT8_C( 104), -INT8_C(   1),  INT8_C(  24), -INT8_C(  87),  INT8_C( 112), -INT8_C( 110),  INT8_C(  50), -INT8_C(  27),
         INT8_C(  92), -INT8_C(   8),  INT8_C(  91),  INT8_C(  83), -INT8_C(   9),  INT8_C(   6),  INT8_C(   4),  INT8_C(   2),
        -INT8_C( 109), -INT8_C(  92), -INT8_C(  25), -INT8_C(  26),  INT8_C(  72), -INT8_C(   2),      INT8_MIN, -INT8_C(  17),
         INT8_C( 110),  INT8_C(  91),  INT8_C(  25), -INT8_C(  73),  INT8_C(  54),  INT8_C(  48), -INT8_C(  62), -INT8_C(  49),
         INT8_C(  47), -INT8_C(  38),  INT8_C( 120), -INT8_C(  96),  INT8_C( 108), -INT8_C(  86), -INT8_C( 123), -INT8_C(  56) },
      { -INT8_C(  94), -INT8_C(  32),  INT8_C(  27), -INT8_C( 102), -INT8_C(  25),  INT8_C(  31), -INT8_C( 100),  INT8_C( 122),
        -INT8_C(  60), -INT8_C( 125),  INT8_C(  97),  INT8_C(  12), -INT8_C( 127), -INT8_C(  31), -INT8_C(   5), -INT8_C(  17),
         INT8_C(  61),  INT8_C(  21), -INT8_C(  90),  INT8_C( 115),  INT8_C(  69),  INT8_C( 104),  INT8_C(  66),  INT8_C( 117),
         INT8_C(  67), -INT8_C(  70),  INT8_C(  21), -INT8_C(  81),  INT8_C( 101), -INT8_C( 102),  INT8_C( 120),  INT8_C(   7),
         INT8_C( 122), -INT8_C( 109), -INT8_C(  95),  INT8_C(  97), -INT8_C(  77),  INT8_C(  61), -INT8_C(  36),  INT8_C( 119),
        -INT8_C(  64),  INT8_C(  61), -INT8_C( 125),  INT8_C(  65),  INT8_C(  30),      INT8_MAX,  INT8_C(  48),  INT8_C(  91),
        -INT8_C( 108), -INT8_C(  41), -INT8_C(  49), -INT8_C(  39),  INT8_C(  63),  INT8_C(  17),  INT8_C(  78), -INT8_C( 126),
        -INT8_C(  52),  INT8_C(  99),  INT8_C(  50),  INT8_C(  49), -INT8_C(   3), -INT8_C(  86),  INT8_C(  56),  INT8_C( 120) },
      {  INT8_C(  22), -INT8_C(  25),  INT8_C( 103), -INT8_C(   2), -INT8_C( 109),  INT8_C( 101),  INT8_C(  71),  INT8_C(  43),
        -INT8_C(  50),  INT8_C(  38),  INT8_C(   1), -INT8_C(  15), -INT8_C(  44), -INT8_C( 123), -INT8_C(  36), -INT8_C( 119),
         INT8_C(  50), -INT8_C( 115), -INT8_C(  47), -INT8_C(  99),  INT8_C(  53),  INT8_C(  67),  INT8_C(  89),      INT8_MAX,
         INT8_C(  87), -INT8_C(  71),  INT8_C(  45),  INT8_C(  88), -INT8_C(   6), -INT8_C( 127),      INT8_MIN, -INT8_C(  65),
         INT8_C( 104), -INT8_C(  25), -INT8_C(  67), -INT8_C(   5), -INT8_C(  86),  INT8_C(  83), -INT8_C( 119),  INT8_C( 107),
         INT8_C(  83),  INT8_C(   3),  INT8_C(  80),  INT8_C(  60),  INT8_C( 102),  INT8_C( 125), -INT8_C(  80),  INT8_C(  52),
         INT8_C(   2),  INT8_C(  11), -INT8_C(  30), -INT8_C( 112),  INT8_C( 117),  INT8_C(  65),  INT8_C(  16),  INT8_C(  50),
        -INT8_C(   5),  INT8_C(   2),  INT8_C(  89), -INT8_C(  47), -INT8_C( 124), -INT8_C(  39),  INT8_C(   0),  INT8_C(  64) } },
    { {  INT8_C(  61), -INT8_C(  38), -INT8_C(  39), -INT8_C(  16),  INT8_C(  23), -INT8_C(  75),  INT8_C( 103), -INT8_C(  40),
        -INT8_C(  14), -INT8_C(  21),  INT8_C(  25),  INT8_C(  17),  INT8_C( 106),  INT8_C(  74),  INT8_C( 108), -INT8_C(   2),
         INT8_C(  33),  INT8_C(  59), -INT8_C(  41),  INT8_C(  96),  INT8_C(  77),  INT8_C(  38), -INT8_C(  29),  INT8_C(  25),
        -INT8_C( 119),  INT8_C(  21),  INT8_C(  74), -INT8_C( 121), -INT8_C(  65), -INT8_C( 126), -INT8_C(   1), -INT8_C(   4),
         INT8_C(  92), -INT8_C(  40), -INT8_C(  19),  INT8_C( 116), -INT8_C( 114),  INT8_C(  84),  INT8_C(  76),      INT8_MIN,
         INT8_C(  63),  INT8_C( 101), -INT8_C( 111), -INT8_C(  87), -INT8_C(  81), -INT8_C(   2), -INT8_C(  89), -INT8_C(  48),
         INT8_C(  57),      INT8_MAX,  INT8_C(  49), -INT8_C( 122), -INT8_C(  91),  INT8_C(  20), -INT8_C(  97),  INT8_C(  46),
         INT8_C(  41), -INT8_C(  23), -INT8_C(  75), -INT8_C(  24),  INT8_C( 108), -INT8_C(  76), -INT8_C(  28), -INT8_C(  56) },
      UINT64_C( 7321595316467978637),
      { -INT8_C(  18),  INT8_C(  45),  INT8_C(  15), -INT8_C(  99),  INT8_C(  43), -INT8_C(  74),  INT8_C( 110),  INT8_C( 100),
         INT8_C(  53), -INT8_C(  97), -INT8_C(  21), -INT8_C(  38), -INT8_C(  77), -INT8_C( 118),  INT8_C(   9), -INT8_C(  36),
         INT8_C( 116), -INT8_C(  66), -INT8_C(  60), -INT8_C(  32),  INT8_C( 115), -INT8_C(  88), -INT8_C(  88),  INT8_C(   0),
         INT8_C( 122), -INT8_C(  27),  INT8_C(  27), -INT8_C(  96),  INT8_C( 109), -INT8_C(  74),  INT8_C(   5),  INT8_C(  91),
        -INT8_C(  29),  INT8_C(  20), -INT8_C(   7),  INT8_C(  14), -INT8_C(  53),  INT8_C( 103),  INT8_C( 115),  INT8_C(   0),
         INT8_C(   6),  INT8_C(  94), -INT8_C(  37), -INT8_C(  71), -INT8_C(  24), -INT8_C(  28), -INT8_C( 107),  INT8_C(  92),
        -INT8_C(  94),  INT8_C(  89),  INT8_C(  60),  INT8_C(  21),  INT8_C(   1), -INT8_C(  27),  INT8_C(  21),  INT8_C( 123),
        -INT8_C(  54),  INT8_C(  48),  INT8_C(  27),  INT8_C(  55), -INT8_C(  25),  INT8_C(  33), -INT8_C( 109), -INT8_C(  54) },
      {  INT8_C(  53), -INT8_C( 116), -INT8_C(  39),  INT8_C(   0), -INT8_C(  13),  INT8_C(  76),  INT8_C(   1), -INT8_C(   7),
        -INT8_C(  86), -INT8_C(  36), -INT8_C(  78), -INT8_C( 110), -INT8_C(  64),  INT8_C(  71), -INT8_C(  17),  INT8_C(  98),
        -INT8_C(  96),  INT8_C(  43),  INT8_C( 120), -INT8_C(  95),  INT8_C(  16), -INT8_C( 115),  INT8_C(  29), -INT8_C(  38),
        -INT8_C(  66),  INT8_C(  56),  INT8_C(  18), -INT8_C(  91),  INT8_C(  89), -INT8_C(  91),  INT8_C( 111), -INT8_C( 113),
         INT8_C(  49),  INT8_C(  72), -INT8_C( 113),  INT8_C(  36), -INT8_C( 108), -INT8_C( 112),  INT8_C(  29),  INT8_C(  62),
         INT8_C( 108), -INT8_C(  49), -INT8_C(  47),  INT8_C(  44),  INT8_C(  22), -INT8_C(  64), -INT8_C( 113), -INT8_C(  74),
        -INT8_C(  21),  INT8_C(   7),  INT8_C(  87), -INT8_C(   4), -INT8_C( 108),  INT8_C( 116), -INT8_C(  42),  INT8_C(  82),
        -INT8_C(  83), -INT8_C(  24), -INT8_C(   9),  INT8_C(   6), -INT8_C( 115),  INT8_C( 103), -INT8_C( 107), -INT8_C(  66) },
      {  INT8_C(  35), -INT8_C(  38), -INT8_C(  24), -INT8_C(  99),  INT8_C(  23), -INT8_C(  75),  INT8_C( 103),  INT8_C(  93),
        -INT8_C(  33), -INT8_C(  21),  INT8_C(  25),  INT8_C(  17),  INT8_C( 115),  INT8_C(  74), -INT8_C(   8),  INT8_C(  62),
         INT8_C(  33),  INT8_C(  59),  INT8_C(  60), -INT8_C( 127), -INT8_C( 125),  INT8_C(  53), -INT8_C(  29),  INT8_C(  25),
         INT8_C(  56),  INT8_C(  29),  INT8_C(  74),  INT8_C(  69), -INT8_C(  58), -INT8_C( 126), -INT8_C(   1), -INT8_C(   4),
         INT8_C(  92),  INT8_C(  92), -INT8_C( 120),  INT8_C( 116), -INT8_C( 114), -INT8_C(   9),  INT8_C(  76),      INT8_MIN,
         INT8_C(  63),  INT8_C( 101), -INT8_C( 111), -INT8_C(  27), -INT8_C(  81), -INT8_C(   2), -INT8_C(  89),  INT8_C(  18),
        -INT8_C( 115),  INT8_C(  96),  INT8_C(  49),  INT8_C(  17), -INT8_C( 107),  INT8_C(  20), -INT8_C(  97), -INT8_C(  51),
         INT8_C( 119), -INT8_C(  23),  INT8_C(  18), -INT8_C(  24),  INT8_C( 108), -INT8_C( 120),  INT8_C(  40), -INT8_C(  56) } },
    { { -INT8_C(  81),  INT8_C(  37), -INT8_C(  30),  INT8_C(  68), -INT8_C(  75), -INT8_C(   1), -INT8_C( 126),  INT8_C(  34),
        -INT8_C(  50),  INT8_C(  83),  INT8_C(  78), -INT8_C(  28),  INT8_C(  19), -INT8_C(  35), -INT8_C( 102), -INT8_C(   1),
        -INT8_C(  28), -INT8_C(  14), -INT8_C(   5),  INT8_C( 121),  INT8_C( 102), -INT8_C(  47), -INT8_C(  53),  INT8_C(  19),
        -INT8_C(  70), -INT8_C(  61),  INT8_C(  26),  INT8_C(  71),  INT8_C(  42), -INT8_C(  81),  INT8_C(   6), -INT8_C(  39),
        -INT8_C(  44), -INT8_C(  24),  INT8_C(  29), -INT8_C( 118), -INT8_C(  24), -INT8_C(  96), -INT8_C(  84), -INT8_C(  74),
        -INT8_C(  13), -INT8_C(   6), -INT8_C( 101),  INT8_C(   7), -INT8_C(  40),  INT8_C(  53),  INT8_C(   6), -INT8_C(  68),
         INT8_C(  39),  INT8_C(   1),  INT8_C(  53), -INT8_C( 114), -INT8_C(  46),  INT8_C(   1), -INT8_C(  95), -INT8_C( 116),
        -INT8_C(  60), -INT8_C(  69), -INT8_C(  44), -INT8_C(  18),  INT8_C( 107), -INT8_C(  38), -INT8_C(  57),  INT8_C(  63) },
      UINT64_C( 8674343574248744386),
      {  INT8_C( 112), -INT8_C(   4),      INT8_MAX,  INT8_C(  72),  INT8_C(  49), -INT8_C( 123),  INT8_C(   4),  INT8_C(  89),
        -INT8_C( 122),  INT8_C(  58), -INT8_C(  25),  INT8_C(  89),  INT8_C(  59), -INT8_C( 120), -INT8_C(  27), -INT8_C(   1),
         INT8_C(  68), -INT8_C(  71), -INT8_C(  19), -INT8_C(  81), -INT8_C( 109), -INT8_C(  76), -INT8_C(  18),  INT8_C(  86),
        -INT8_C( 103), -INT8_C(  72),  INT8_C(   0),  INT8_C(  30),  INT8_C(  45),  INT8_C(  97), -INT8_C( 105), -INT8_C(  99),
         INT8_C(  93),  INT8_C(  22), -INT8_C(  27), -INT8_C( 113), -INT8_C( 100), -INT8_C(  22), -INT8_C(  24),  INT8_C(  34),
         INT8_C(  36), -INT8_C(  49),  INT8_C( 123),  INT8_C(  95),  INT8_C(  87),  INT8_C(  97),  INT8_C(  94), -INT8_C( 101),
         INT8_C(  26),  INT8_C(  75),  INT8_C(  74), -INT8_C(  82), -INT8_C(   1),  INT8_C(  57),  INT8_C(   4), -INT8_C( 103),
        -INT8_C(  15),  INT8_C(   4), -INT8_C(  73),  INT8_C(  30),  INT8_C( 102),  INT8_C(  78), -INT8_C(  68), -INT8_C(  61) },
      {  INT8_C( 101), -INT8_C(  95),  INT8_C(  82),  INT8_C(   1), -INT8_C( 117),  INT8_C(  58),  INT8_C(  35), -INT8_C(  81),
         INT8_C(   9), -INT8_C(  97),  INT8_C(  14),  INT8_C(  97),  INT8_C(   0),  INT8_C( 108), -INT8_C(   4),  INT8_C(  26),
        -INT8_C(  73),  INT8_C(  71), -INT8_C(  56), -INT8_C(  73),      INT8_MIN, -INT8_C(  52),  INT8_C(  80),  INT8_C( 113),
        -INT8_C(  47),  INT8_C(   7), -INT8_C( 113),  INT8_C(  55),  INT8_C(  86),  INT8_C(  75), -INT8_C(   6), -INT8_C(  69),
        -INT8_C(  19),  INT8_C(  77), -INT8_C(  68),  INT8_C( 120), -INT8_C( 121), -INT8_C(  33),  INT8_C(  40), -INT8_C( 111),
         INT8_C( 126),  INT8_C(  54), -INT8_C(  14),  INT8_C( 126), -INT8_C(  93), -INT8_C(  18), -INT8_C( 103),  INT8_C(  90),
         INT8_C(  53),  INT8_C(  97),  INT8_C(  17), -INT8_C(  75),  INT8_C(  46),  INT8_C(  97),  INT8_C(  38), -INT8_C(   1),
         INT8_C( 105), -INT8_C(  74),  INT8_C(  54), -INT8_C(  65),  INT8_C(   1),  INT8_C(  48),  INT8_C( 122), -INT8_C(  18) },
      { -INT8_C(  81), -INT8_C(  99), -INT8_C(  30),  INT8_C(  68), -INT8_C(  75), -INT8_C(   1),  INT8_C(  39),  INT8_C(   8),
        -INT8_C( 113),  INT8_C(  83), -INT8_C(  11), -INT8_C(  28),  INT8_C(  19), -INT8_C(  12), -INT8_C(  31),  INT8_C(  25),
        -INT8_C(   5), -INT8_C(  14), -INT8_C(   5),  INT8_C( 102),  INT8_C( 102), -INT8_C(  47),  INT8_C(  62), -INT8_C(  57),
        -INT8_C(  70), -INT8_C(  65),  INT8_C(  26),  INT8_C(  85),  INT8_C(  42), -INT8_C(  84),  INT8_C(   6),  INT8_C(  88),
         INT8_C(  74), -INT8_C(  24), -INT8_C(  95), -INT8_C( 118), -INT8_C(  24), -INT8_C(  96), -INT8_C(  84), -INT8_C(  77),
        -INT8_C(  94), -INT8_C(   6),  INT8_C( 109),  INT8_C(   7), -INT8_C(   6),  INT8_C(  79), -INT8_C(   9), -INT8_C(  68),
         INT8_C(  79),  INT8_C(   1),  INT8_C(  53), -INT8_C( 114), -INT8_C(  46), -INT8_C( 102),  INT8_C(  42), -INT8_C( 116),
        -INT8_C(  60), -INT8_C(  69), -INT8_C(  44), -INT8_C(  35),  INT8_C( 103),  INT8_C( 126),  INT8_C(  54),  INT8_C(  63) } }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
    simde__m512i src = simde_mm512_loadu_epi8(test_vec[i].src);
    simde__m512i a = simde_mm512_loadu_epi8(test_vec[i].a);
    simde__m512i b = simde_mm512_loadu_epi8(test_vec[i].b);
    simde__m512i r = simde_mm512_mask_add_epi8(src, test_vec[i].k, a, b);
    simde_test_x86_assert_equal_i8x64(r, simde_mm512_loadu_epi8(test_vec[i].r));
  }

  return 0;
}

static int
test_simde_mm512_maskz_add_epi8 (SIMDE_MUNIT_TEST_ARGS) {
  static const struct {
    const simde__mmask64 k;
    const int8_t a[64];
    const int8_t b[64];
    const int8_t r[64];
  } test_vec[] = {
    { UINT64_C( 9122680976650596708),
      {  INT8_C(  68), -INT8_C(  57),  INT8_C(  11), -INT8_C( 119), -INT8_C( 113),  INT8_C( 124),  INT8_C(  91),  INT8_C(   1),
         INT8_C( 112), -INT8_C( 126),  INT8_C(  44), -INT8_C(  65),  INT8_C(  76), -INT8_C(  60), -INT8_C(  30),  INT8_C(  88),
        -INT8_C(   8),  INT8_C(  72), -INT8_C(  34), -INT8_C( 108),  INT8_C(   2),  INT8_C(  65), -INT8_C(  12),  INT8_C( 102),
         INT8_C(  50),  INT8_C( 109),  INT8_C(  10),  INT8_C(  54), -INT8_C(  77), -INT8_C(  91), -INT8_C(  76), -INT8_C(   9),
         INT8_C( 108), -INT8_C(  65),      INT8_MIN, -INT8_C(   5),  INT8_C(  60), -INT8_C(  36), -INT8_C(   4), -INT8_C(  84),
         INT8_C(  94),  INT8_C(  40),  INT8_C( 108), -INT8_C(  86), -INT8_C(  20),  INT8_C(  78),  INT8_C(   2), -INT8_C(  27),
        -INT8_C( 106), -INT8_C(  32),  INT8_C( 121), -INT8_C( 104),  INT8_C(  34),  INT8_C( 110), -INT8_C(   2),  INT8_C(  84),
        -INT8_C(  37),  INT8_C(   8), -INT8_C( 118), -INT8_C( 114), -INT8_C(  83),  INT8_C(  63), -INT8_C( 122),  INT8_C(  25) },
      { -INT8_C(   2),  INT8_C(   6),  INT8_C(  20),  INT8_C(  58), -INT8_C(  30),  INT8_C(  16), -INT8_C(  25),  INT8_C(  65),
         INT8_C(  56),  INT8_C(  83), -INT8_C(  21),  INT8_C(  37), -INT8_C(  95), -INT8_C(  18),  INT8_C(  10),  INT8_C(  55),
        -INT8_C(  50), -INT8_C( 125), -INT8_C(  49), -INT8_C(  16), -INT8_C(  15), -INT8_C(  51),  INT8_C(  69), -INT8_C(  52),
        -INT8_C(  43), -INT8_C(  49),  INT8_C(  91), -INT8_C( 125),  INT8_C(  14), -INT8_C(  31), -INT8_C( 100),  INT8_C(  13),
        -INT8_C(  25), -INT8_C(  79),  INT8_C(  71), -INT8_C(  54), -INT8_C(  63),  INT8_C(  46),  INT8_C(  11), -INT8_C(   6),
        -INT8_C( 127), -INT8_C(  10),  INT8_C(  31),  INT8_C(  34), -INT8_C(  28),  INT8_C(  41),  INT8_C(  89), -INT8_C(  77),
        -INT8_C(  84),  INT8_C(  40), -INT8_C(  93), -INT8_C(  98), -INT8_C(  11), -INT8_C(  24),  INT8_C( 106), -INT8_C(  53),
        -INT8_C(  72), -INT8_C(  59),  INT8_C(  78), -INT8_C(  58), -INT8_C(  90), -INT8_C(  22), -INT8_C(  45), -INT8_C( 114) },
      {  INT8_C(   0),  INT8_C(   0),  INT8_C(  31),  INT8_C(   0),  INT8_C(   0), -INT8_C( 116),  INT8_C(  66),  INT8_C(   0),
        -INT8_C(  88),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0), -INT8_C(  19), -INT8_C(  78), -INT8_C(  20), -INT8_C( 113),
         INT8_C(   0),  INT8_C(   0),  INT8_C(   0), -INT8_C( 124), -INT8_C(  13),  INT8_C(  14),  INT8_C(  57),  INT8_C(   0),
         INT8_C(   0),  INT8_C(   0),  INT8_C( 101),  INT8_C(   0),  INT8_C(   0), -INT8_C( 122),  INT8_C(   0),  INT8_C(   4),
         INT8_C(  83),  INT8_C( 112),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),
         INT8_C(   0),  INT8_C(  30), -INT8_C( 117),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(  91),  INT8_C(   0),
         INT8_C(   0),  INT8_C(   8),  INT8_C(   0),  INT8_C(  54),  INT8_C(  23),  INT8_C(   0),  INT8_C(   0),  INT8_C(  31),
         INT8_C(   0), -INT8_C(  51), -INT8_C(  40),  INT8_C(  84),  INT8_C(  83),  INT8_C(  41),  INT8_C(  89),  INT8_C(   0) } },
    { UINT64_C(14652289079423015835),
      {  INT8_C(  89),  INT8_C( 118), -INT8_C(  19),  INT8_C(  62), -INT8_C(  97),  INT8_C(  71), -INT8_C(  15),  INT8_C(  75),
         INT8_C( 111), -INT8_C( 108), -INT8_C(  23),  INT8_C( 101),  INT8_C( 125),  INT8_C(  84),  INT8_C(  48),  INT8_C(  53),
         INT8_C(  25),  INT8_C( 126), -INT8_C(   5), -INT8_C(  64),  INT8_C( 104), -INT8_C(  49),  INT8_C(  78),  INT8_C(   4),
        -INT8_C(  22), -INT8_C(  90),  INT8_C(  97),  INT8_C(  51),  INT8_C(   9), -INT8_C(  72), -INT8_C(   2),  INT8_C(  98),
         INT8_C(  46), -INT8_C(  20), -INT8_C(  96), -INT8_C(  51),  INT8_C(  51), -INT8_C( 111),  INT8_C(  24), -INT8_C(  94),
         INT8_C(  38),  INT8_C(   2),  INT8_C(   7), -INT8_C(  93),  INT8_C(  86),  INT8_C(  55), -INT8_C(  40),  INT8_C( 111),
        -INT8_C(  75), -INT8_C(  45),  INT8_C(  47),  INT8_C(  30), -INT8_C(  94),  INT8_C( 125),  INT8_C(  34), -INT8_C( 116),
         INT8_C(  35), -INT8_C( 125), -INT8_C(  64),  INT8_C(  44),  INT8_C(  59), -INT8_C(  66), -INT8_C( 113),  INT8_C( 105) },
      { -INT8_C(  86),  INT8_C(  47),  INT8_C(  54), -INT8_C(  35), -INT8_C(  63),  INT8_C(  78),      INT8_MIN, -INT8_C(  25),
         INT8_C(  80), -INT8_C( 121), -INT8_C( 118), -INT8_C(  90), -INT8_C(  65),  INT8_C(  98),  INT8_C(  22),  INT8_C( 116),
         INT8_C(  53),  INT8_C(  69), -INT8_C( 110), -INT8_C(  40), -INT8_C(  61), -INT8_C(  76),  INT8_C( 100), -INT8_C(  26),
         INT8_C(  55),  INT8_C(  36),  INT8_C(  19),  INT8_C( 114), -INT8_C(  29), -INT8_C(  94), -INT8_C(  37), -INT8_C( 115),
        -INT8_C(  47),  INT8_C(  17),  INT8_C( 107), -INT8_C( 110),  INT8_C(  96), -INT8_C(  21),  INT8_C( 121), -INT8_C(  80),
         INT8_C( 114),  INT8_C(   3),  INT8_C(  87),  INT8_C(  49),  INT8_C( 101),  INT8_C( 109), -INT8_C(  90), -INT8_C( 101),
        -INT8_C(  78),  INT8_C(  56),  INT8_C( 115),  INT8_C( 117), -INT8_C(  19), -INT8_C(  41),  INT8_C(  92),  INT8_C(  36),
        -INT8_C(   4),  INT8_C( 111), -INT8_C( 105), -INT8_C(  33),  INT8_C(  17),  INT8_C( 114),  INT8_C( 108), -INT8_C(  30) },
      {  INT8_C(   3), -INT8_C(  91),  INT8_C(   0),  INT8_C(  27),  INT8_C(  96),  INT8_C(   0),  INT8_C(   0),  INT8_C(  50),
        -INT8_C(  65),  INT8_C(  27),  INT8_C(   0),  INT8_C(  11),  INT8_C(  60),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),
         INT8_C(   0),  INT8_C(   0),  INT8_C(   0), -INT8_C( 104),  INT8_C(  43),  INT8_C(   0), -INT8_C(  78),  INT8_C(   0),
         INT8_C(  33),  INT8_C(   0),  INT8_C( 116), -INT8_C(  91), -INT8_C(  20),  INT8_C(   0), -INT8_C(  39),  INT8_C(   0),
        -INT8_C(   1),  INT8_C(   0),  INT8_C(   0),  INT8_C(  95),  INT8_C(   0),  INT8_C(   0), -INT8_C( 111),  INT8_C(   0),
        -INT8_C( 104),  INT8_C(   5),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0), -INT8_C(  92),  INT8_C( 126),  INT8_C(   0),
         INT8_C( 103),  INT8_C(  11), -INT8_C(  94),  INT8_C(   0), -INT8_C( 113),  INT8_C(   0),  INT8_C( 126),  INT8_C(   0),
         INT8_C(  31), -INT8_C(  14),  INT8_C(   0),  INT8_C(  11),  INT8_C(   0),  INT8_C(   0), -INT8_C(   5),  INT8_C(  75) } },
    { UINT64_C( 3860973301387351940),
      { -INT8_C(  14), -INT8_C(  21),  INT8_C( 102),  INT8_C(  87),  INT8_C(  88),  INT8_C(  12), -INT8_C(  14),  INT8_C(  11),
         INT8_C(  69),  INT8_C( 101),      INT8_MIN,  INT8_C(  50),  INT8_C(  61), -INT8_C(  36),  INT8_C(  86),  INT8_C(  57),
         INT8_C(  75), -INT8_C(  19),  INT8_C(  24),  INT8_C(  92),  INT8_C(  96), -INT8_C( 124),  INT8_C(  63), -INT8_C(  28),
         INT8_C(  92), -INT8_C(  76), -INT8_C(  56),  INT8_C(  30), -INT8_C(  94),  INT8_C(  92),  INT8_C(  83), -INT8_C( 108),
         INT8_C(  72), -INT8_C(  70), -INT8_C(  20), -INT8_C(  96), -INT8_C(  58), -INT8_C(  34), -INT8_C(  85),  INT8_C(  11),
         INT8_C(  68),  INT8_C(  44),  INT8_C(  61), -INT8_C( 127),  INT8_C(   8), -INT8_C( 108), -INT8_C(  70),  INT8_C(  84),
        -INT8_C( 127), -INT8_C(  46), -INT8_C(  80), -INT8_C(  31),  INT8_C(  86), -INT8_C(  17), -INT8_C(  59), -INT8_C(  78),
        -INT8_C(  93), -INT8_C( 115), -INT8_C(  47),  INT8_C(  70), -INT8_C(  22),  INT8_C(  36), -INT8_C(  38),  INT8_C(  50) },
      { -INT8_C(  34), -INT8_C(  58), -INT8_C(  46), -INT8_C(  91), -INT8_C(  91),  INT8_C( 126), -INT8_C(  80), -INT8_C(  23),
        -INT8_C(  86), -INT8_C(  18),  INT8_C( 106), -INT8_C(  78), -INT8_C( 126),  INT8_C(  36),  INT8_C(   6),  INT8_C(   3),
        -INT8_C(  10), -INT8_C(  73), -INT8_C(  27),  INT8_C(  76), -INT8_C(  90), -INT8_C(  86), -INT8_C(   1),  INT8_C(  74),
         INT8_C(  56), -INT8_C(  48), -INT8_C( 112),  INT8_C(  34), -INT8_C(  12),  INT8_C( 106),  INT8_C(  84), -INT8_C(  45),
         INT8_C(  49),  INT8_C(  38),  INT8_C( 120), -INT8_C(  42), -INT8_C(  92),  INT8_C(  40), -INT8_C(  65),  INT8_C(  78),
         INT8_C(  22),  INT8_C(  41),  INT8_C(   1), -INT8_C( 104),  INT8_C(  77),  INT8_C(   7), -INT8_C( 100),  INT8_C(  67),
        -INT8_C(  66), -INT8_C( 127), -INT8_C( 113),  INT8_C( 101),  INT8_C(  43), -INT8_C( 114), -INT8_C(  81),  INT8_C(  99),
         INT8_C(  94),  INT8_C(  63), -INT8_C( 123),  INT8_C(  83), -INT8_C(  87), -INT8_C(  39),  INT8_C(  38), -INT8_C(  38) },
      {  INT8_C(   0),  INT8_C(   0),  INT8_C(  56),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0), -INT8_C(  12),
        -INT8_C(  17),  INT8_C(  83), -INT8_C(  22),  INT8_C(   0), -INT8_C(  65),  INT8_C(   0),  INT8_C(  92),  INT8_C(  60),
         INT8_C(  65),  INT8_C(   0), -INT8_C(   3),  INT8_C(   0),  INT8_C(   6),  INT8_C(  46),  INT8_C(  62),  INT8_C(   0),
         INT8_C(   0),  INT8_C(   0),  INT8_C(  88),  INT8_C(   0),  INT8_C(   0), -INT8_C(  58), -INT8_C(  89),  INT8_C( 103),
         INT8_C(   0), -INT8_C(  32),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C( 106),  INT8_C(  89),
         INT8_C(   0),  INT8_C(  85),  INT8_C(  62),  INT8_C(  25),  INT8_C(   0), -INT8_C( 101),  INT8_C(  86), -INT8_C( 105),
         INT8_C(   0),  INT8_C(   0),  INT8_C(  63),  INT8_C(   0), -INT8_C( 127),  INT8_C(   0),  INT8_C(   0),  INT8_C(  21),
         INT8_C(   1),  INT8_C(   0),  INT8_C(  86),  INT8_C(   0), -INT8_C( 109), -INT8_C(   3),  INT8_C(   0),  INT8_C(   0) } },
    { UINT64_C(15993249600680009216),
      { -INT8_C( 104), -INT8_C(  12),  INT8_C( 117), -INT8_C(  27), -INT8_C(   5),  INT8_C(  17),  INT8_C(  40), -INT8_C(  70),
        -INT8_C( 110), -INT8_C(  72),  INT8_C(  31), -INT8_C(  66),  INT8_C(  70), -INT8_C(  50),  INT8_C(  33), -INT8_C(  91),
         INT8_C(  13), -INT8_C(  89), -INT8_C(   8), -INT8_C(  74),      INT8_MIN,  INT8_C(  30), -INT8_C( 111),      INT8_MIN,
        -INT8_C(  68),  INT8_C(  65),  INT8_C(  37), -INT8_C( 126), -INT8_C(  79),  INT8_C(  24),  INT8_C(  95),  INT8_C(  73),
         INT8_C(  12), -INT8_C(  43),  INT8_C(  47),  INT8_C(   7), -INT8_C(  26),  INT8_C(  87), -INT8_C(  63),  INT8_C( 121),
         INT8_C(  15), -INT8_C(  32),  INT8_C(  55),  INT8_C(  86), -INT8_C(  82),  INT8_C(  88), -INT8_C(   5), -INT8_C(  69),
        -INT8_C(   1), -INT8_C(  13),  INT8_C( 114),      INT8_MIN,  INT8_C(  17),  INT8_C(   3),  INT8_C(   0), -INT8_C(  51),
         INT8_C(  68),  INT8_C(  37),  INT8_C(  79), -INT8_C(  11),  INT8_C(  61), -INT8_C(  81),  INT8_C(  63),  INT8_C(  73) },
      { -INT8_C( 124),  INT8_C( 110),  INT8_C(  81),  INT8_C( 106), -INT8_C(  59),  INT8_C(  18), -INT8_C(  29), -INT8_C(  43),
        -INT8_C(  13),  INT8_C(  26),  INT8_C(  43), -INT8_C(  95),  INT8_C( 115),  INT8_C(  38),  INT8_C(  93),  INT8_C( 114),
         INT8_C(  25), -INT8_C(  49), -INT8_C(  14),  INT8_C(  42), -INT8_C(  46), -INT8_C(  13), -INT8_C(   9),  INT8_C(  22),
         INT8_C(  24),  INT8_C(  70),  INT8_C(  12),  INT8_C(  86), -INT8_C(  11),  INT8_C(  75), -INT8_C(  97),  INT8_C( 121),
        -INT8_C(  71), -INT8_C(  16), -INT8_C(  28),  INT8_C( 126),  INT8_C(   3), -INT8_C(  57),  INT8_C(  83), -INT8_C(  10),
        -INT8_C(  30),  INT8_C( 126), -INT8_C( 105),  INT8_C(  85), -INT8_C(  92), -INT8_C(  12), -INT8_C(  57), -INT8_C(  67),
        -INT8_C(  61), -INT8_C(  70), -INT8_C(  25), -INT8_C( 107), -INT8_C(  83), -INT8_C(  34), -INT8_C(  84), -INT8_C(  59),
         INT8_C(  37), -INT8_C(  72),  INT8_C(  27),  INT8_C(  26),  INT8_C(   3), -INT8_C(  69), -INT8_C( 108), -INT8_C(  68) },
      {  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),
         INT8_C(   0), -INT8_C(  46),  INT8_C(  74),  INT8_C(  95), -INT8_C(  71),  INT8_C(   0),  INT8_C(   0),  INT8_C(  23),
         INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(  82),  INT8_C(  17),  INT8_C(   0), -INT8_C( 106),
         INT8_C(   0),  INT8_C(   0),  INT8_C(  49),  INT8_C(   0),  INT8_C(   0),  INT8_C(  99),  INT8_C(   0), -INT8_C(  62),
         INT8_C(   0), -INT8_C(  59),  INT8_C(  19),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(  20),  INT8_C( 111),
        -INT8_C(  15),  INT8_C(  94), -INT8_C(  50), -INT8_C(  85),  INT8_C(   0),  INT8_C(  76), -INT8_C(  62),  INT8_C(   0),
        -INT8_C(  62), -INT8_C(  83),  INT8_C(   0),  INT8_C(   0), -INT8_C(  66), -INT8_C(  31), -INT8_C(  84), -INT8_C( 110),
         INT8_C( 105),  INT8_C(   0),  INT8_C( 106),  INT8_C(  15),  INT8_C(  64),  INT8_C(   0), -INT8_C(  45),  INT8_C(   5) } },
    { UINT64_C( 2424218903589320875),
      {  INT8_C(  12),  INT8_C(  60),  INT8_C( 118), -INT8_C(  79),  INT8_C(  48),  INT8_C(  62),  INT8_C( 110), -INT8_C(  12),
        -INT8_C(   8),  INT8_C(  86), -INT8_C( 119), -INT8_C(  91),  INT8_C(  52),  INT8_C(  53),  INT8_C( 106),  INT8_C(  89),
        -INT8_C(  19), -INT8_C( 122),  INT8_C( 116), -INT8_C(  16),  INT8_C(  65),  INT8_C(   8), -INT8_C(  84), -INT8_C(  20),
             INT8_MIN, -INT8_C(  25), -INT8_C( 101), -INT8_C(  65),  INT8_C( 117),  INT8_C(  63), -INT8_C(  31), -INT8_C( 127),
         INT8_C( 123),  INT8_C(  87),  INT8_C(  50), -INT8_C(  84), -INT8_C( 107), -INT8_C(  95), -INT8_C(  96), -INT8_C( 115),
        -INT8_C(   9),  INT8_C(  41),  INT8_C(  50),  INT8_C(  43),  INT8_C(  95), -INT8_C(  99), -INT8_C( 123),  INT8_C(  76),
         INT8_C(  35), -INT8_C(   7),  INT8_C(  61),  INT8_C( 100),  INT8_C(   1), -INT8_C(  23),  INT8_C(  80), -INT8_C( 127),
        -INT8_C(  48), -INT8_C(  21),  INT8_C(  64),  INT8_C(  69),  INT8_C(  43),  INT8_C(  33), -INT8_C(  57), -INT8_C(  90) },
      {  INT8_C( 121), -INT8_C(   7),  INT8_C(  82),  INT8_C(  14), -INT8_C( 102), -INT8_C(  14), -INT8_C( 100), -INT8_C( 111),
         INT8_C(  28), -INT8_C(  50), -INT8_C(  67),  INT8_C( 123),  INT8_C( 107),  INT8_C(  66), -INT8_C(  57), -INT8_C( 114),
         INT8_C(  59),  INT8_C(   4), -INT8_C(  14),  INT8_C(  60), -INT8_C(  18),  INT8_C(  67), -INT8_C(  67), -INT8_C(  66),
         INT8_C(  46), -INT8_C(   3),  INT8_C(   4),  INT8_C(  89),  INT8_C(  31), -INT8_C(  53),  INT8_C(   0), -INT8_C( 104),
        -INT8_C(  60),  INT8_C(  82), -INT8_C(  90),  INT8_C(  95),  INT8_C(  69),  INT8_C(  66), -INT8_C(  16),  INT8_C(  97),
         INT8_C(  17), -INT8_C(  83), -INT8_C(  36),  INT8_C( 124), -INT8_C(  17), -INT8_C(  93),  INT8_C(  11),  INT8_C(  42),
        -INT8_C(  88), -INT8_C(   3),  INT8_C( 102), -INT8_C( 106),  INT8_C(  64),  INT8_C(  35),  INT8_C(  84),  INT8_C( 111),
         INT8_C(  33),  INT8_C(  88), -INT8_C(  56),  INT8_C(  64),  INT8_C(  35), -INT8_C(  56), -INT8_C(  40), -INT8_C(  24) },
      { -INT8_C( 123),  INT8_C(  53),  INT8_C(   0), -INT8_C(  65),  INT8_C(   0),  INT8_C(  48),  INT8_C(   0), -INT8_C( 123),
         INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(  32), -INT8_C(  97),  INT8_C( 119),  INT8_C(  49),  INT8_C(   0),
         INT8_C(   0), -INT8_C( 118),  INT8_C(   0),  INT8_C(  44),  INT8_C(  47),  INT8_C(  75),  INT8_C(   0),  INT8_C(   0),
         INT8_C(   0), -INT8_C(  28), -INT8_C(  97),  INT8_C(  24),  INT8_C(   0),  INT8_C(  10),  INT8_C(   0),  INT8_C(  25),
         INT8_C(  63), -INT8_C(  87), -INT8_C(  40),  INT8_C(  11), -INT8_C(  38), -INT8_C(  29),  INT8_C(   0),  INT8_C(   0),
         INT8_C(   0), -INT8_C(  42),  INT8_C(  14), -INT8_C(  89),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C( 118),
         INT8_C(   0),  INT8_C(   0), -INT8_C(  93),  INT8_C(   0),  INT8_C(   0),  INT8_C(  12),  INT8_C(   0), -INT8_C(  16),
        -INT8_C(  15),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0), -INT8_C(  23),  INT8_C(   0),  INT8_C(   0) } },
    { UINT64_C(15186480722153537051),
      { -INT8_C(  27), -INT8_C(  99),  INT8_C(  78), -INT8_C(  44),  INT8_C(  64),  INT8_C(  89), -INT8_C(   1), -INT8_C(  24),
         INT8_C(  87),  INT8_C( 101),  INT8_C( 126), -INT8_C( 105), -INT8_C( 119), -INT8_C(  45),  INT8_C(   6), -INT8_C(  86),
         INT8_C(  43), -INT8_C(  49), -INT8_C(  22),  INT8_C(  79), -INT8_C( 105), -INT8_C(  62),  INT8_C(  55), -INT8_C(  78),
         INT8_C(  64),  INT8_C( 126),  INT8_C(  18),  INT8_C(   1), -INT8_C(  75), -INT8_C(  45), -INT8_C(  45), -INT8_C( 102),
         INT8_C( 112),  INT8_C(  34),  INT8_C( 111), -INT8_C(  79),  INT8_C( 123),  INT8_C( 110), -INT8_C( 103), -INT8_C(  46),
        -INT8_C(  45),  INT8_C(  24),  INT8_C( 106),  INT8_C(  92), -INT8_C(  21),  INT8_C( 112),  INT8_C(   6),  INT8_C(  22),
         INT8_C(  63), -INT8_C(  16),  INT8_C( 101), -INT8_C(  41), -INT8_C(  78), -INT8_C( 100), -INT8_C( 119), -INT8_C(  13),
         INT8_C(  26), -INT8_C( 100), -INT8_C(  12), -INT8_C(  48),  INT8_C( 111), -INT8_C(  56),  INT8_C( 106), -INT8_C(  32) },
      { -INT8_C(  22), -INT8_C(  39), -INT8_C( 111),  INT8_C( 101),  INT8_C(  71),  INT8_C(  42),  INT8_C(  56),  INT8_C(  27),
         INT8_C(  66), -INT8_C(  94),  INT8_C( 119),  INT8_C(  45),  INT8_C(  18),  INT8_C( 126),  INT8_C(  68),  INT8_C(  82),
         INT8_C( 110), -INT8_C(  87),  INT8_C(  41),  INT8_C(  33),  INT8_C(  70), -INT8_C(  78),  INT8_C(  20),  INT8_C(  96),
         INT8_C(  78),  INT8_C(   8),  INT8_C(  48), -INT8_C(  66), -INT8_C(  48), -INT8_C( 101), -INT8_C(  98), -INT8_C(  70),
         INT8_C( 116),  INT8_C(  47),  INT8_C(  32), -INT8_C(  68),  INT8_C(  89),  INT8_C(  88), -INT8_C(  41), -INT8_C( 100),
        -INT8_C(   6),  INT8_C(  78), -INT8_C(  55),  INT8_C(  12), -INT8_C(  52),  INT8_C(  13),  INT8_C(  94),  INT8_C(  59),
        -INT8_C(  73), -INT8_C( 121),  INT8_C(  92), -INT8_C(   3),  INT8_C(  58),  INT8_C( 112),  INT8_C(  93), -INT8_C( 120),
         INT8_C( 120), -INT8_C( 114),  INT8_C(  70),  INT8_C(  73),  INT8_C(  41), -INT8_C(  28),  INT8_C(   3), -INT8_C(  99) },
      { -INT8_C(  49),  INT8_C( 118),  INT8_C(   0),  INT8_C(  57), -INT8_C( 121),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),
         INT8_C(   0),  INT8_C(   7), -INT8_C(  11), -INT8_C(  60), -INT8_C( 101),  INT8_C(  81),  INT8_C(  74),  INT8_C(   0),
        -INT8_C( 103),  INT8_C( 120),  INT8_C(  19),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(  75),  INT8_C(   0),
         INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C( 110),  INT8_C( 113),  INT8_C(   0),
        -INT8_C(  28),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C( 112),  INT8_C( 110),
        -INT8_C(  51),  INT8_C( 102),  INT8_C(  51),  INT8_C(   0), -INT8_C(  73),  INT8_C( 125),  INT8_C(   0),  INT8_C(   0),
        -INT8_C(  10),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0), -INT8_C(  26),  INT8_C( 123),
         INT8_C(   0),  INT8_C(  42),  INT8_C(   0),  INT8_C(   0), -INT8_C( 104),  INT8_C(   0),  INT8_C( 109),  INT8_C( 125) } },
    { UINT64_C( 8433325083901633299),
      {      INT8_MAX, -INT8_C(  46), -INT8_C( 126),  INT8_C(  75), -INT8_C(  32), -INT8_C(  32), -INT8_C( 122), -INT8_C( 105),
         INT8_C( 104), -INT8_C(  30), -INT8_C( 108), -INT8_C(  94),  INT8_C(  82), -INT8_C(  15),  INT8_C(  42), -INT8_C(  53),
             INT8_MAX,  INT8_C( 113),  INT8_C(  20), -INT8_C(  88),  INT8_C(  85),  INT8_C(  23),  INT8_C(  70),  INT8_C( 105),
         INT8_C(  59), -INT8_C(  97), -INT8_C(  42), -INT8_C(  74), -INT8_C(  48), -INT8_C(  33),  INT8_C(  44),  INT8_C(  79),
        -INT8_C(  79), -INT8_C(  82), -INT8_C( 102), -INT8_C( 111), -INT8_C( 114),  INT8_C(  33),  INT8_C(  40), -INT8_C(  10),
         INT8_C(   3), -INT8_C(  68), -INT8_C( 104),  INT8_C(  86), -INT8_C(  82), -INT8_C(  61),  INT8_C(  33),  INT8_C(  45),
         INT8_C(  52),  INT8_C(  53), -INT8_C(  42), -INT8_C( 119),  INT8_C(  76),  INT8_C(  28), -INT8_C(  14), -INT8_C( 121),
        -INT8_C(  69), -INT8_C(  56),  INT8_C(  62), -INT8_C( 117), -INT8_C(  89),  INT8_C( 106), -INT8_C(  38),  INT8_C(  89) },
      {  INT8_C(  24),  INT8_C( 117), -INT8_C(  22), -INT8_C(  90), -INT8_C( 106),  INT8_C(  19), -INT8_C(  99), -INT8_C( 103),
        -INT8_C(  49),  INT8_C(  53), -INT8_C(  17),  INT8_C( 125), -INT8_C(   8),  INT8_C(  16), -INT8_C(  85),  INT8_C(  44),
         INT8_C(  69), -INT8_C( 127), -INT8_C(  74), -INT8_C( 110), -INT8_C(  99), -INT8_C(  88),  INT8_C(  25),  INT8_C(  88),
         INT8_C( 113),  INT8_C(  87), -INT8_C(  28),  INT8_C(  24), -INT8_C(  63), -INT8_C(  66),  INT8_C( 113), -INT8_C(  39),
         INT8_C(  51),  INT8_C(  92),      INT8_MIN, -INT8_C(  55),  INT8_C( 111),  INT8_C(  29),  INT8_C(  99),  INT8_C(  62),
         INT8_C(  82),  INT8_C(  82), -INT8_C(  68),  INT8_C(  75),  INT8_C(  99),  INT8_C( 103),  INT8_C( 119), -INT8_C(  88),
        -INT8_C(  24),  INT8_C(  45),  INT8_C(  58), -INT8_C( 123), -INT8_C(  42),  INT8_C(  84), -INT8_C(  35),  INT8_C(  71),
        -INT8_C(  85), -INT8_C(  63),  INT8_C(  95),  INT8_C( 109),      INT8_MIN, -INT8_C(  47),  INT8_C(  70), -INT8_C(  77) },
      { -INT8_C( 105),  INT8_C(  71),  INT8_C(   0),  INT8_C(   0),  INT8_C( 118),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),
         INT8_C(  55),  INT8_C(  23),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   1),  INT8_C(   0),  INT8_C(   0),
        -INT8_C(  60),  INT8_C(   0),  INT8_C(   0),  INT8_C(  58), -INT8_C(  14),  INT8_C(   0),  INT8_C(  95),  INT8_C(   0),
        -INT8_C(  84),  INT8_C(   0), -INT8_C(  70), -INT8_C(  50),  INT8_C(   0), -INT8_C(  99), -INT8_C(  99),  INT8_C(   0),
        -INT8_C(  28),  INT8_C(  10),  INT8_C(   0),  INT8_C(  90), -INT8_C(   3),  INT8_C(  62), -INT8_C( 117),  INT8_C(   0),
         INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(  17),  INT8_C(  42),  INT8_C(   0),  INT8_C(   0),
         INT8_C(  28),  INT8_C(   0),  INT8_C(   0),  INT8_C(  14),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),
         INT8_C( 102),  INT8_C(   0), -INT8_C(  99),  INT8_C(   0),  INT8_C(  39),  INT8_C(  59),  INT8_C(  32),  INT8_C(   0) } },
    { UINT64_C( 3952718891158717997),
      {  INT8_C(  50), -INT8_C( 106), -INT8_C( 127), -INT8_C( 107), -INT8_C(   3), -INT8_C(   8),  INT8_C(  62), -INT8_C(  27),
         INT8_C(  38),  INT8_C( 120),  INT8_C( 106), -INT8_C(   4), -INT8_C(  52),  INT8_C(  72),  INT8_C(  67),  INT8_C( 120),
         INT8_C(   9), -INT8_C(  94), -INT8_C(  27), -INT8_C( 119),  INT8_C( 115),  INT8_C(  43),  INT8_C(  61), -INT8_C(  96),
        -INT8_C(  14), -INT8_C(  70),  INT8_C(  60), -INT8_C(  43), -INT8_C( 102),  INT8_C(  23),  INT8_C(  11), -INT8_C(  52),
        -INT8_C(  83), -INT8_C( 116),  INT8_C(  98), -INT8_C(  85), -INT8_C( 123), -INT8_C(  96), -INT8_C( 112), -INT8_C(  85),
         INT8_C(  24), -INT8_C(   5), -INT8_C(  89), -INT8_C(  27),  INT8_C(  67), -INT8_C(  22),  INT8_C(  93),  INT8_C(  76),
        -INT8_C( 116),  INT8_C(  66), -INT8_C(  42),  INT8_C(   0),  INT8_C( 109),  INT8_C(  19), -INT8_C(  96),  INT8_C(  95),
        -INT8_C(  51), -INT8_C(  35),  INT8_C(  53),  INT8_C( 103), -INT8_C(  12),  INT8_C(  64),  INT8_C(  51), -INT8_C(  95) },
      { -INT8_C(  51), -INT8_C( 107),  INT8_C(  76),  INT8_C(  82),  INT8_C(  53), -INT8_C(  35), -INT8_C(   3),  INT8_C(  78),
        -INT8_C(  40), -INT8_C(  92),  INT8_C(  51),  INT8_C(  27), -INT8_C( 114), -INT8_C( 112),  INT8_C( 103),  INT8_C(  26),
        -INT8_C(  46),  INT8_C(  61),  INT8_C(  26),  INT8_C(  63),  INT8_C(  80), -INT8_C(  69), -INT8_C(  97),  INT8_C(  29),
        -INT8_C( 104), -INT8_C(  44), -INT8_C( 124), -INT8_C( 116),  INT8_C(  20), -INT8_C(  72),  INT8_C(  45), -INT8_C(  31),
         INT8_C(  77),  INT8_C( 122),  INT8_C(  51), -INT8_C( 125),  INT8_C(  87),  INT8_C(  48), -INT8_C(  47),  INT8_C(  47),
        -INT8_C(  44),  INT8_C(   4),  INT8_C(  74),  INT8_C(  98), -INT8_C( 108), -INT8_C(  79),  INT8_C( 125),  INT8_C( 102),
        -INT8_C(  17), -INT8_C( 105), -INT8_C(  91),  INT8_C(  63),  INT8_C(  82),  INT8_C(  68),  INT8_C(  93), -INT8_C(  22),
         INT8_C(  24), -INT8_C(  31),  INT8_C( 118),  INT8_C(  45), -INT8_C( 103), -INT8_C(  92),  INT8_C(  14), -INT8_C(  25) },
      { -INT8_C(   1),  INT8_C(   0), -INT8_C(  51), -INT8_C(  25),  INT8_C(   0), -INT8_C(  43),  INT8_C(   0),  INT8_C(   0),
         INT8_C(   0),  INT8_C(  28), -INT8_C(  99),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0), -INT8_C(  86), -INT8_C( 110),
        -INT8_C(  37),  INT8_C(   0), -INT8_C(   1), -INT8_C(  56), -INT8_C(  61), -INT8_C(  26), -INT8_C(  36),  INT8_C(   0),
         INT8_C(   0),  INT8_C(   0), -INT8_C(  64),  INT8_C(  97), -INT8_C(  82),  INT8_C(   0),  INT8_C(   0), -INT8_C(  83),
        -INT8_C(   6),  INT8_C(   6),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0), -INT8_C(  48),  INT8_C(  97), -INT8_C(  38),
         INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0), -INT8_C( 101), -INT8_C(  38), -INT8_C(  78),
         INT8_C(   0), -INT8_C(  39),  INT8_C(   0),  INT8_C(  63), -INT8_C(  65),  INT8_C(   0), -INT8_C(   3),  INT8_C(  73),
         INT8_C(   0), -INT8_C(  66), -INT8_C(  85),  INT8_C(   0), -INT8_C( 115), -INT8_C(  28),  INT8_C(   0),  INT8_C(   0) } }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
    simde__m512i a = simde_mm512_loadu_epi8(test_vec[i].a);
    simde__m512i b = simde_mm512_loadu_epi8(test_vec[i].b);
    simde__m512i r = simde_mm512_maskz_add_epi8(test_vec[i].k, a, b);
    simde_test_x86_assert_equal_i8x64(r, simde_mm512_loadu_epi8(test_vec[i].r));
  }

  return 0;
}

static int
test_simde_mm512_add_epi16 (SIMDE_MUNIT_TEST_ARGS) {
  struct {
    const int16_t a[32];
    const int16_t b[32];
    const int16_t r[32];
  } test_vec[] = {
    { {  INT16_C( 11452),  INT16_C( 18562),  INT16_C(  2675), -INT16_C( 17089),  INT16_C( 30550), -INT16_C( 14832), -INT16_C( 11694), -INT16_C( 20057),
         INT16_C( 31125),  INT16_C(  7807), -INT16_C( 11481),  INT16_C( 12519), -INT16_C(   410), -INT16_C( 11992),  INT16_C( 27537),  INT16_C( 19885),
         INT16_C( 12440),  INT16_C(  2965), -INT16_C( 11206), -INT16_C( 28472), -INT16_C( 10164), -INT16_C( 25001), -INT16_C(   342),  INT16_C( 16463),
        -INT16_C( 12424), -INT16_C( 24738),  INT16_C( 17826),  INT16_C(  2255), -INT16_C(  1981), -INT16_C( 11047), -INT16_C( 30877), -INT16_C(  1246) },
      { -INT16_C( 18505), -INT16_C(  3833), -INT16_C( 12404), -INT16_C( 10111), -INT16_C( 10072),  INT16_C( 21110), -INT16_C( 14633),  INT16_C( 20370),
        -INT16_C(  3947),  INT16_C( 14318), -INT16_C( 17098),  INT16_C( 31040),  INT16_C(  6581),  INT16_C(  6478),  INT16_C( 28832),  INT16_C( 22292),
         INT16_C(  6951), -INT16_C( 19640), -INT16_C( 13589), -INT16_C( 27765),  INT16_C(   674),  INT16_C( 31205),  INT16_C( 30920),  INT16_C( 24008),
        -INT16_C( 18840), -INT16_C( 24940), -INT16_C( 11148),  INT16_C( 10520),  INT16_C( 26350), -INT16_C( 29118),  INT16_C( 22486), -INT16_C(   538) },
      { -INT16_C(  7053),  INT16_C( 14729), -INT16_C(  9729), -INT16_C( 27200),  INT16_C( 20478),  INT16_C(  6278), -INT16_C( 26327),  INT16_C(   313),
         INT16_C( 27178),  INT16_C( 22125), -INT16_C( 28579), -INT16_C( 21977),  INT16_C(  6171), -INT16_C(  5514), -INT16_C(  9167), -INT16_C( 23359),
         INT16_C( 19391), -INT16_C( 16675), -INT16_C( 24795),  INT16_C(  9299), -INT16_C(  9490),  INT16_C(  6204),  INT16_C( 30578), -INT16_C( 25065),
        -INT16_C( 31264),  INT16_C( 15858),  INT16_C(  6678),  INT16_C( 12775),  INT16_C( 24369),  INT16_C( 25371), -INT16_C(  8391), -INT16_C(  1784) } },
    { {  INT16_C( 11890),  INT16_C( 23985),  INT16_C( 15608), -INT16_C( 25616), -INT16_C( 10690),  INT16_C(  1556), -INT16_C(  8882), -INT16_C( 18845),
        -INT16_C(  1901),  INT16_C(  1877),  INT16_C( 28108), -INT16_C( 17871),  INT16_C( 29651), -INT16_C( 22199),  INT16_C( 12234),  INT16_C( 15782),
         INT16_C( 22365),  INT16_C( 22170), -INT16_C( 29804), -INT16_C( 11535),  INT16_C(  1377), -INT16_C( 20519),  INT16_C( 15586),  INT16_C( 30309),
        -INT16_C( 17868),  INT16_C(   381), -INT16_C( 20953), -INT16_C(  1349),  INT16_C(  1058), -INT16_C(  4957),  INT16_C( 18995), -INT16_C( 28375) },
      { -INT16_C( 15199),  INT16_C( 13799), -INT16_C( 10161), -INT16_C( 20472), -INT16_C(  7715), -INT16_C( 16289), -INT16_C( 15331),  INT16_C( 21046),
        -INT16_C( 19585), -INT16_C( 22957),  INT16_C(  3682), -INT16_C( 31583),  INT16_C( 17427),  INT16_C( 18032), -INT16_C( 25970),  INT16_C( 12503),
        -INT16_C( 16802), -INT16_C( 21147),  INT16_C( 28054),  INT16_C( 29789), -INT16_C( 17330),  INT16_C( 27700),  INT16_C( 27264), -INT16_C(    66),
         INT16_C(  4381),  INT16_C( 32678),  INT16_C( 18207),  INT16_C( 12803),  INT16_C( 29835),  INT16_C(  6777),  INT16_C( 20494),  INT16_C( 27722) },
      { -INT16_C(  3309), -INT16_C( 27752),  INT16_C(  5447),  INT16_C( 19448), -INT16_C( 18405), -INT16_C( 14733), -INT16_C( 24213),  INT16_C(  2201),
        -INT16_C( 21486), -INT16_C( 21080),  INT16_C( 31790),  INT16_C( 16082), -INT16_C( 18458), -INT16_C(  4167), -INT16_C( 13736),  INT16_C( 28285),
         INT16_C(  5563),  INT16_C(  1023), -INT16_C(  1750),  INT16_C( 18254), -INT16_C( 15953),  INT16_C(  7181), -INT16_C( 22686),  INT16_C( 30243),
        -INT16_C( 13487), -INT16_C( 32477), -INT16_C(  2746),  INT16_C( 11454),  INT16_C( 30893),  INT16_C(  1820), -INT16_C( 26047), -INT16_C(   653) } },
    { { -INT16_C( 20721), -INT16_C( 23271),  INT16_C( 30237),  INT16_C( 27417),  INT16_C( 19762), -INT16_C( 19753), -INT16_C( 27209), -INT16_C( 10830),
         INT16_C( 22694), -INT16_C( 14764),  INT16_C( 22687),  INT16_C( 11000),  INT16_C( 29132), -INT16_C(  9660), -INT16_C( 28990), -INT16_C( 11962),
         INT16_C( 24382),  INT16_C( 23414), -INT16_C( 28459),  INT16_C(  1990), -INT16_C( 24867), -INT16_C( 27207),  INT16_C( 27443), -INT16_C(  9622),
        -INT16_C( 16701),  INT16_C( 25248), -INT16_C( 26602), -INT16_C(  7539), -INT16_C( 12022), -INT16_C( 13124),  INT16_C(   608), -INT16_C( 24931) },
      {  INT16_C(  4961),  INT16_C( 14073), -INT16_C( 16477), -INT16_C( 32451), -INT16_C(  2211), -INT16_C( 28394), -INT16_C( 32670),  INT16_C(  9835),
         INT16_C(  2878),  INT16_C( 21896),  INT16_C(  5539), -INT16_C( 21193), -INT16_C(  2841),  INT16_C( 18297),  INT16_C(  5878),  INT16_C( 22757),
        -INT16_C(  8662), -INT16_C( 12914), -INT16_C( 13155), -INT16_C(  1202),  INT16_C( 25795),  INT16_C(  9612), -INT16_C(  2076),  INT16_C(  9035),
        -INT16_C( 11262), -INT16_C( 23176), -INT16_C( 20503), -INT16_C( 12205), -INT16_C( 13149), -INT16_C( 26089), -INT16_C(   797),  INT16_C(  3570) },
      { -INT16_C( 15760), -INT16_C(  9198),  INT16_C( 13760), -INT16_C(  5034),  INT16_C( 17551),  INT16_C( 17389),  INT16_C(  5657), -INT16_C(   995),
         INT16_C( 25572),  INT16_C(  7132),  INT16_C( 28226), -INT16_C( 10193),  INT16_C( 26291),  INT16_C(  8637), -INT16_C( 23112),  INT16_C( 10795),
         INT16_C( 15720),  INT16_C( 10500),  INT16_C( 23922),  INT16_C(   788),  INT16_C(   928), -INT16_C( 17595),  INT16_C( 25367), -INT16_C(   587),
        -INT16_C( 27963),  INT16_C(  2072),  INT16_C( 18431), -INT16_C( 19744), -INT16_C( 25171),  INT16_C( 26323), -INT16_C(   189), -INT16_C( 21361) } },
    { { -INT16_C( 32550),  INT16_C( 30938),  INT16_C( 10572),  INT16_C(  3955), -INT16_C(   115),  INT16_C( 29237), -INT16_C( 32522), -INT16_C(  1899),
         INT16_C(  3412),  INT16_C( 16029), -INT16_C(  3908),  INT16_C( 24590),  INT16_C(  9917), -INT16_C( 24326), -INT16_C(  5086), -INT16_C(   595),
        -INT16_C( 30868), -INT16_C( 18059), -INT16_C(  5968),  INT16_C( 16072), -INT16_C(   537), -INT16_C(  8784),  INT16_C( 17790), -INT16_C( 11563),
         INT16_C( 29266),  INT16_C(  3600),  INT16_C(  8035),  INT16_C(  8302),  INT16_C( 26693),  INT16_C( 26560),  INT16_C( 27988), -INT16_C( 16028) },
      { -INT16_C(  9740), -INT16_C( 23174),  INT16_C( 17089), -INT16_C( 22301), -INT16_C( 27840), -INT16_C( 16763),  INT16_C( 23256),  INT16_C( 10896),
        -INT16_C( 24115),  INT16_C( 12344), -INT16_C( 22592),  INT16_C(  1360),  INT16_C(  4111),  INT16_C( 25708), -INT16_C( 11907),  INT16_C( 28965),
        -INT16_C( 24662),  INT16_C( 27670), -INT16_C(  1567),  INT16_C(  8468), -INT16_C( 25972),  INT16_C( 25823),  INT16_C( 28916), -INT16_C( 15986),
        -INT16_C( 14575), -INT16_C( 11791),  INT16_C( 16750),  INT16_C( 32214),  INT16_C( 16977), -INT16_C( 12575),  INT16_C(  1555), -INT16_C( 16832) },
      {  INT16_C( 23246),  INT16_C(  7764),  INT16_C( 27661), -INT16_C( 18346), -INT16_C( 27955),  INT16_C( 12474), -INT16_C(  9266),  INT16_C(  8997),
        -INT16_C( 20703),  INT16_C( 28373), -INT16_C( 26500),  INT16_C( 25950),  INT16_C( 14028),  INT16_C(  1382), -INT16_C( 16993),  INT16_C( 28370),
         INT16_C( 10006),  INT16_C(  9611), -INT16_C(  7535),  INT16_C( 24540), -INT16_C( 26509),  INT16_C( 17039), -INT16_C( 18830), -INT16_C( 27549),
         INT16_C( 14691), -INT16_C(  8191),  INT16_C( 24785), -INT16_C( 25020), -INT16_C( 21866),  INT16_C( 13985),  INT16_C( 29543),  INT16_C( 32676) } },
    { {  INT16_C( 22181), -INT16_C( 30934),  INT16_C( 15952), -INT16_C(  9048), -INT16_C( 30504), -INT16_C( 12991), -INT16_C( 12296),  INT16_C(  2446),
        -INT16_C( 32618),  INT16_C(  1242), -INT16_C( 20287),  INT16_C(  4994),  INT16_C( 25586),  INT16_C(  1761),  INT16_C(  8554),  INT16_C(  4036),
        -INT16_C(  4488), -INT16_C( 14186),  INT16_C( 16172),  INT16_C(  1444), -INT16_C(  6713), -INT16_C( 16430),  INT16_C( 24757),  INT16_C( 19400),
        -INT16_C( 23840), -INT16_C( 23984), -INT16_C( 11694),  INT16_C( 17589), -INT16_C( 27083), -INT16_C( 24758),  INT16_C(  3768),  INT16_C( 12463) },
      {  INT16_C( 17916),  INT16_C( 10744), -INT16_C( 25468),  INT16_C( 19246),  INT16_C(   130),  INT16_C( 14090), -INT16_C( 11680),  INT16_C( 16770),
        -INT16_C( 11660), -INT16_C( 14621), -INT16_C( 26460), -INT16_C(  9717),  INT16_C( 21806), -INT16_C(  6535),  INT16_C( 10340),  INT16_C( 24598),
         INT16_C(  3694), -INT16_C(  3447), -INT16_C( 18517),  INT16_C( 11582),  INT16_C( 18615),  INT16_C(  6244), -INT16_C(  6629), -INT16_C( 28839),
         INT16_C( 15545),  INT16_C( 23894),  INT16_C( 25044),  INT16_C(   567), -INT16_C( 20042),  INT16_C(  6889), -INT16_C(    39),  INT16_C( 18299) },
      { -INT16_C( 25439), -INT16_C( 20190), -INT16_C(  9516),  INT16_C( 10198), -INT16_C( 30374),  INT16_C(  1099), -INT16_C( 23976),  INT16_C( 19216),
         INT16_C( 21258), -INT16_C( 13379),  INT16_C( 18789), -INT16_C(  4723), -INT16_C( 18144), -INT16_C(  4774),  INT16_C( 18894),  INT16_C( 28634),
        -INT16_C(   794), -INT16_C( 17633), -INT16_C(  2345),  INT16_C( 13026),  INT16_C( 11902), -INT16_C( 10186),  INT16_C( 18128), -INT16_C(  9439),
        -INT16_C(  8295), -INT16_C(    90),  INT16_C( 13350),  INT16_C( 18156),  INT16_C( 18411), -INT16_C( 17869),  INT16_C(  3729),  INT16_C( 30762) } },
    { {  INT16_C(  1038), -INT16_C( 18118),  INT16_C( 30908),  INT16_C( 29670),  INT16_C( 19136), -INT16_C(  9333), -INT16_C(  7120), -INT16_C(  5781),
        -INT16_C( 16096), -INT16_C(  3001),  INT16_C( 32290), -INT16_C(  9993), -INT16_C(  8145),  INT16_C(  2547),  INT16_C( 28383), -INT16_C(  4784),
        -INT16_C( 30094),  INT16_C( 11942), -INT16_C( 29694), -INT16_C( 15454),  INT16_C( 11734),  INT16_C(  1950),  INT16_C(  2322),  INT16_C( 13040),
         INT16_C( 14282), -INT16_C(  5081),  INT16_C(  7862), -INT16_C(  6715), -INT16_C( 18178), -INT16_C(  8722),  INT16_C( 16166), -INT16_C( 26421) },
      {  INT16_C( 29129), -INT16_C( 13113),  INT16_C( 27134), -INT16_C( 11121),  INT16_C( 11670), -INT16_C( 22309), -INT16_C( 13257),  INT16_C(   475),
         INT16_C(   515), -INT16_C( 17938), -INT16_C( 19680),  INT16_C(  7839), -INT16_C( 29333), -INT16_C( 28165), -INT16_C( 14644), -INT16_C( 27095),
        -INT16_C(  4040),  INT16_C( 13922), -INT16_C(  3751), -INT16_C(  4086), -INT16_C(  6626),  INT16_C( 21912),  INT16_C( 29618), -INT16_C( 19113),
         INT16_C( 17781), -INT16_C( 27281),  INT16_C(  3832),  INT16_C( 25523), -INT16_C( 20581),  INT16_C( 26868),  INT16_C(  7541), -INT16_C( 20994) },
      {  INT16_C( 30167), -INT16_C( 31231), -INT16_C(  7494),  INT16_C( 18549),  INT16_C( 30806), -INT16_C( 31642), -INT16_C( 20377), -INT16_C(  5306),
        -INT16_C( 15581), -INT16_C( 20939),  INT16_C( 12610), -INT16_C(  2154),  INT16_C( 28058), -INT16_C( 25618),  INT16_C( 13739), -INT16_C( 31879),
         INT16_C( 31402),  INT16_C( 25864),  INT16_C( 32091), -INT16_C( 19540),  INT16_C(  5108),  INT16_C( 23862),  INT16_C( 31940), -INT16_C(  6073),
         INT16_C( 32063), -INT16_C( 32362),  INT16_C( 11694),  INT16_C( 18808),  INT16_C( 26777),  INT16_C( 18146),  INT16_C( 23707),  INT16_C( 18121) } },
    { {  INT16_C( 24590),  INT16_C( 26595), -INT16_C(  4527),  INT16_C( 28503), -INT16_C(  3884), -INT16_C( 31035),  INT16_C(  7267), -INT16_C(  9925),
        -INT16_C( 21919),  INT16_C( 22894),  INT16_C(  8888),  INT16_C( 21692), -INT16_C( 20271),  INT16_C( 18108), -INT16_C( 17715), -INT16_C(  9228),
        -INT16_C( 10470),  INT16_C( 27459), -INT16_C( 25915), -INT16_C( 26150), -INT16_C( 24694), -INT16_C(  4577),  INT16_C( 23483),  INT16_C(  7367),
         INT16_C( 13573), -INT16_C( 16779),  INT16_C( 12631),  INT16_C( 10258), -INT16_C( 12575), -INT16_C( 20625),  INT16_C( 25480), -INT16_C( 23926) },
      { -INT16_C( 12998),  INT16_C(    13), -INT16_C(  6296), -INT16_C(  3431), -INT16_C( 18041),  INT16_C( 17120), -INT16_C( 22764),  INT16_C(  6495),
        -INT16_C( 11043),  INT16_C( 13527), -INT16_C(  5882), -INT16_C(  6307), -INT16_C( 13129),  INT16_C( 16278),  INT16_C(  8495),  INT16_C( 27105),
        -INT16_C(  4370),  INT16_C( 22121),  INT16_C(   982),  INT16_C( 23881),  INT16_C( 10684), -INT16_C( 12129), -INT16_C(   303), -INT16_C( 20759),
        -INT16_C( 15917), -INT16_C(  9758),  INT16_C( 16298),  INT16_C( 25280),  INT16_C( 22283),  INT16_C( 15009), -INT16_C( 31880),  INT16_C( 26276) },
      {  INT16_C( 11592),  INT16_C( 26608), -INT16_C( 10823),  INT16_C( 25072), -INT16_C( 21925), -INT16_C( 13915), -INT16_C( 15497), -INT16_C(  3430),
         INT16_C( 32574), -INT16_C( 29115),  INT16_C(  3006),  INT16_C( 15385),  INT16_C( 32136), -INT16_C( 31150), -INT16_C(  9220),  INT16_C( 17877),
        -INT16_C( 14840), -INT16_C( 15956), -INT16_C( 24933), -INT16_C(  2269), -INT16_C( 14010), -INT16_C( 16706),  INT16_C( 23180), -INT16_C( 13392),
        -INT16_C(  2344), -INT16_C( 26537),  INT16_C( 28929), -INT16_C( 29998),  INT16_C(  9708), -INT16_C(  5616), -INT16_C(  6400),  INT16_C(  2350) } },
    { {  INT16_C(  3441),  INT16_C( 18365),  INT16_C(  1552), -INT16_C( 13148),  INT16_C( 17455),  INT16_C(   156), -INT16_C( 31166),  INT16_C(  5550),
        -INT16_C( 28345), -INT16_C(  3602), -INT16_C( 20528), -INT16_C(  9133), -INT16_C(  2810),  INT16_C( 32278), -INT16_C( 17800), -INT16_C(  5660),
        -INT16_C( 24120), -INT16_C( 10191), -INT16_C( 10841), -INT16_C( 10331),  INT16_C( 16665),  INT16_C( 23767), -INT16_C( 31033),  INT16_C(  3697),
         INT16_C( 24599), -INT16_C(  6400),  INT16_C( 21263),  INT16_C(  5571), -INT16_C(  9656), -INT16_C( 16237),  INT16_C( 30612),  INT16_C( 23722) },
      { -INT16_C(  9447), -INT16_C( 16331), -INT16_C(  9552), -INT16_C( 13673),  INT16_C( 28443), -INT16_C(  7386), -INT16_C( 26635),  INT16_C(  3313),
        -INT16_C(  3593),  INT16_C(  1779), -INT16_C( 18619), -INT16_C( 29413), -INT16_C( 20847),  INT16_C(  9550), -INT16_C(  2010),  INT16_C( 16258),
        -INT16_C( 18477), -INT16_C( 31745), -INT16_C( 26735), -INT16_C( 21427),  INT16_C( 29446), -INT16_C(  1137), -INT16_C( 32501),  INT16_C(   519),
        -INT16_C(  1422), -INT16_C( 18679),  INT16_C(  9393),  INT16_C( 16965), -INT16_C( 27693), -INT16_C(  1688), -INT16_C(  5493),  INT16_C( 24120) },
      { -INT16_C(  6006),  INT16_C(  2034), -INT16_C(  8000), -INT16_C( 26821), -INT16_C( 19638), -INT16_C(  7230),  INT16_C(  7735),  INT16_C(  8863),
        -INT16_C( 31938), -INT16_C(  1823),  INT16_C( 26389),  INT16_C( 26990), -INT16_C( 23657), -INT16_C( 23708), -INT16_C( 19810),  INT16_C( 10598),
         INT16_C( 22939),  INT16_C( 23600),  INT16_C( 27960), -INT16_C( 31758), -INT16_C( 19425),  INT16_C( 22630),  INT16_C(  2002),  INT16_C(  4216),
         INT16_C( 23177), -INT16_C( 25079),  INT16_C( 30656),  INT16_C( 22536),  INT16_C( 28187), -INT16_C( 17925),  INT16_C( 25119), -INT16_C( 17694) } }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
    simde__m512i a = simde_mm512_loadu_epi16(test_vec[i].a);
    simde__m512i b = simde_mm512_loadu_epi16(test_vec[i].b);
    simde__m512i r = simde_mm512_add_epi16(a, b);
    simde_test_x86_assert_equal_i16x32(r, simde_mm512_loadu_epi16(test_vec[i].r));
  }

  return 0;
}

static int
test_simde_mm512_mask_add_epi16 (SIMDE_MUNIT_TEST_ARGS) {
  static const struct {
    const int16_t src[32];
    const simde__mmask32 k;
    const int16_t a[32];
    const int16_t b[32];
    const int16_t r[32];
  } test_vec[] = {
    { {  INT16_C( 19989),  INT16_C( 17201), -INT16_C(   484), -INT16_C(  4807), -INT16_C( 18583),  INT16_C(  7804),  INT16_C( 26728),  INT16_C( 16294),
        -INT16_C( 31636),  INT16_C( 28135), -INT16_C( 32158),  INT16_C( 20064), -INT16_C( 16695),  INT16_C(  3157),  INT16_C( 32300),  INT16_C( 16873),
         INT16_C(  6860), -INT16_C(  5755), -INT16_C( 16872), -INT16_C( 32042),  INT16_C( 21110), -INT16_C(  8544),  INT16_C( 18106),  INT16_C(  9757),
         INT16_C(  1482),  INT16_C( 11668), -INT16_C(  2937),  INT16_C( 20859), -INT16_C( 12110), -INT16_C(  8611),  INT16_C( 17999),  INT16_C(  6944) },
      UINT32_C(2030347617),
      { -INT16_C( 25811), -INT16_C(  6217), -INT16_C( 10782), -INT16_C( 21490), -INT16_C( 23846),  INT16_C( 25049),  INT16_C( 21910),  INT16_C( 18610),
         INT16_C(  4133),  INT16_C( 29734),  INT16_C( 18006), -INT16_C( 18544), -INT16_C( 27413),  INT16_C( 20273),  INT16_C( 11375), -INT16_C( 25560),
        -INT16_C(  7992), -INT16_C( 21885), -INT16_C( 28235), -INT16_C( 28842),  INT16_C( 12339), -INT16_C( 13840), -INT16_C( 23675), -INT16_C( 21999),
         INT16_C( 14515),  INT16_C(  2335), -INT16_C( 20610),  INT16_C( 27329), -INT16_C(  3517), -INT16_C( 19783), -INT16_C(  7906), -INT16_C(  6578) },
      { -INT16_C( 11583),  INT16_C( 30352), -INT16_C(  6301), -INT16_C( 26875), -INT16_C(  2537), -INT16_C( 25504),  INT16_C( 29337),  INT16_C( 19526),
         INT16_C( 26026),  INT16_C( 10325),  INT16_C(  5652),  INT16_C( 22674),  INT16_C( 19208),  INT16_C(  9994),  INT16_C( 22829), -INT16_C(  4595),
        -INT16_C( 25045), -INT16_C( 29083),  INT16_C( 27269), -INT16_C( 25563), -INT16_C( 31136), -INT16_C(  1736),  INT16_C( 32504), -INT16_C( 23995),
        -INT16_C( 25628), -INT16_C(  1846),  INT16_C( 23985), -INT16_C( 17840),  INT16_C( 23464), -INT16_C( 10783), -INT16_C(  4428), -INT16_C(  8252) },
      {  INT16_C( 28142),  INT16_C( 17201), -INT16_C(   484), -INT16_C(  4807), -INT16_C( 18583), -INT16_C(   455), -INT16_C( 14289),  INT16_C( 16294),
         INT16_C( 30159),  INT16_C( 28135),  INT16_C( 23658),  INT16_C( 20064), -INT16_C( 16695),  INT16_C( 30267),  INT16_C( 32300), -INT16_C( 30155),
         INT16_C(  6860), -INT16_C(  5755), -INT16_C(   966), -INT16_C( 32042),  INT16_C( 21110), -INT16_C(  8544),  INT16_C( 18106),  INT16_C(  9757),
        -INT16_C( 11113),  INT16_C( 11668), -INT16_C(  2937),  INT16_C(  9489),  INT16_C( 19947), -INT16_C( 30566), -INT16_C( 12334),  INT16_C(  6944) } },
    { {  INT16_C( 10636),  INT16_C(  4461), -INT16_C( 27757), -INT16_C(  2899), -INT16_C(  6887),  INT16_C(  4589),  INT16_C( 13156),  INT16_C( 18611),
         INT16_C( 32206),  INT16_C( 32576), -INT16_C( 28198), -INT16_C( 31943),  INT16_C(  6892), -INT16_C( 24488),  INT16_C(  7177), -INT16_C( 27265),
        -INT16_C(  5051), -INT16_C(  9817),  INT16_C( 21631), -INT16_C( 26419), -INT16_C( 17862), -INT16_C( 24919),  INT16_C( 23789), -INT16_C( 17434),
         INT16_C(  9946), -INT16_C( 19397),  INT16_C( 29879), -INT16_C( 23753), -INT16_C( 28529), -INT16_C( 26557), -INT16_C( 15700), -INT16_C(  3539) },
      UINT32_C( 785110191),
      {  INT16_C( 28754),  INT16_C( 16385), -INT16_C(  6195), -INT16_C( 22533),  INT16_C( 13837), -INT16_C( 15013), -INT16_C( 27733),  INT16_C( 14952),
        -INT16_C( 21469), -INT16_C( 12334), -INT16_C(   146),  INT16_C(  7617), -INT16_C( 29484), -INT16_C(   692),  INT16_C(  4900),  INT16_C( 30560),
         INT16_C( 24963),  INT16_C( 20663), -INT16_C( 19896),  INT16_C( 22007),  INT16_C( 21481), -INT16_C( 27622), -INT16_C( 31770),  INT16_C(  2510),
        -INT16_C( 24529), -INT16_C( 25128), -INT16_C( 25953),  INT16_C( 29627),  INT16_C(  1830),  INT16_C( 19312), -INT16_C( 12262), -INT16_C( 25150) },
      {  INT16_C( 31025),  INT16_C( 31214), -INT16_C(  6869),  INT16_C(  5327), -INT16_C(  5832),  INT16_C(  7848),  INT16_C( 30316), -INT16_C( 25817),
         INT16_C(    22), -INT16_C( 18887), -INT16_C(  2918), -INT16_C( 16343), -INT16_C( 25861),  INT16_C(  5387), -INT16_C( 12950), -INT16_C( 25422),
        -INT16_C( 24506),  INT16_C( 29205), -INT16_C(  7034), -INT16_C( 16762),  INT16_C( 12238),  INT16_C( 15069),  INT16_C(  1189), -INT16_C( 17194),
         INT16_C(  3844), -INT16_C( 24974), -INT16_C( 25853), -INT16_C(   417),  INT16_C( 27189), -INT16_C( 24557), -INT16_C( 15048),  INT16_C( 32316) },
      { -INT16_C(  5757), -INT16_C( 17937), -INT16_C( 13064), -INT16_C( 17206), -INT16_C(  6887), -INT16_C(  7165),  INT16_C( 13156), -INT16_C( 10865),
         INT16_C( 32206),  INT16_C( 32576), -INT16_C(  3064), -INT16_C( 31943),  INT16_C( 10191), -INT16_C( 24488), -INT16_C(  8050),  INT16_C(  5138),
         INT16_C(   457), -INT16_C( 15668),  INT16_C( 21631),  INT16_C(  5245), -INT16_C( 17862), -INT16_C( 24919), -INT16_C( 30581), -INT16_C( 14684),
         INT16_C(  9946),  INT16_C( 15434),  INT16_C( 13730),  INT16_C( 29210), -INT16_C( 28529), -INT16_C(  5245), -INT16_C( 15700), -INT16_C(  3539) } },
    { {  INT16_C( 20838), -INT16_C(  4880),  INT16_C( 30518),  INT16_C(  1194), -INT16_C( 30810),  INT16_C( 19262),  INT16_C(  5260), -INT16_C( 28665),
         INT16_C( 31011),  INT16_C(  9775), -INT16_C( 29163),  INT16_C( 18980),  INT16_C( 14328),  INT16_C( 12522),  INT16_C(  9981),  INT16_C( 25519),
        -INT16_C( 24712), -INT16_C( 20913), -INT16_C(  1770), -INT16_C( 17230), -INT16_C(  3967),  INT16_C(  3336),  INT16_C(  3845),  INT16_C( 10397),
        -INT16_C( 13175), -INT16_C( 25009),  INT16_C( 29530),  INT16_C( 21480), -INT16_C( 11349), -INT16_C( 22397),  INT16_C( 13049),  INT16_C( 28939) },
      UINT32_C(3894368978),
      { -INT16_C( 21054), -INT16_C( 14367),  INT16_C( 32700),  INT16_C( 17903),  INT16_C( 15947), -INT16_C( 22813), -INT16_C( 13134),  INT16_C( 24057),
         INT16_C( 31903), -INT16_C( 26619),  INT16_C(  4271), -INT16_C( 32502),  INT16_C( 10602), -INT16_C( 17047),  INT16_C(  3835), -INT16_C( 17006),
         INT16_C( 29627),  INT16_C( 30852),  INT16_C( 29682),  INT16_C( 16061), -INT16_C( 24142),  INT16_C( 25828), -INT16_C(  8851),  INT16_C(  3265),
        -INT16_C( 14759),  INT16_C(  2212), -INT16_C( 20778),  INT16_C( 16521), -INT16_C(  3112), -INT16_C( 11267), -INT16_C( 28927), -INT16_C( 17008) },
      {  INT16_C(  5123), -INT16_C(  2763), -INT16_C(  3449),  INT16_C( 14643),  INT16_C(  6035),  INT16_C(   157),  INT16_C( 24308),  INT16_C( 19980),
        -INT16_C( 20188), -INT16_C(  1450), -INT16_C(  8097),  INT16_C( 14138),  INT16_C( 14547), -INT16_C( 11254), -INT16_C( 25913), -INT16_C( 13679),
        -INT16_C( 14674),  INT16_C( 14016), -INT16_C(  3143),  INT16_C( 19567),  INT16_C(  3339), -INT16_C(   179),  INT16_C( 22891), -INT16_C( 28595),
        -INT16_C( 23542),  INT16_C( 27274), -INT16_C( 14972),  INT16_C( 22433), -INT16_C( 21251), -INT16_C( 15317), -INT16_C( 17082), -INT16_C(  2673) },
      {  INT16_C( 20838), -INT16_C( 17130),  INT16_C( 30518),  INT16_C(  1194),  INT16_C( 21982),  INT16_C( 19262),  INT16_C( 11174), -INT16_C( 21499),
         INT16_C( 31011), -INT16_C( 28069), -INT16_C( 29163), -INT16_C( 18364),  INT16_C( 25149),  INT16_C( 12522), -INT16_C( 22078),  INT16_C( 25519),
         INT16_C( 14953), -INT16_C( 20668),  INT16_C( 26539), -INT16_C( 29908), -INT16_C( 20803),  INT16_C(  3336),  INT16_C(  3845),  INT16_C( 10397),
        -INT16_C( 13175), -INT16_C( 25009),  INT16_C( 29530), -INT16_C( 26582), -INT16_C( 11349), -INT16_C( 26584),  INT16_C( 19527), -INT16_C( 19681) } },
    { {  INT16_C( 20355),  INT16_C( 15403), -INT16_C( 26046),  INT16_C( 19849), -INT16_C( 10585),  INT16_C(  4941), -INT16_C( 26065),  INT16_C( 15011),
         INT16_C( 11582), -INT16_C( 15708),  INT16_C( 17906), -INT16_C(  4327),  INT16_C( 17905),  INT16_C( 14516),  INT16_C( 17154), -INT16_C( 31443),
         INT16_C( 22674), -INT16_C( 11070),  INT16_C( 19442), -INT16_C( 26078),  INT16_C( 28449),  INT16_C( 20653),  INT16_C( 20489),  INT16_C( 18570),
         INT16_C( 11901),  INT16_C( 28682),  INT16_C(  9332),  INT16_C( 25951),  INT16_C(  4969),  INT16_C( 27549), -INT16_C( 13738), -INT16_C(  5904) },
      UINT32_C( 364753442),
      {  INT16_C( 23630),  INT16_C( 22383), -INT16_C(  1620),  INT16_C( 10655), -INT16_C( 21976), -INT16_C( 25447), -INT16_C(  1586),  INT16_C( 14081),
        -INT16_C( 24820),  INT16_C( 25506), -INT16_C( 28055), -INT16_C( 29621),  INT16_C(  2117),  INT16_C( 17057),  INT16_C( 20711),  INT16_C( 13665),
        -INT16_C( 12116),  INT16_C( 22669),  INT16_C( 11465), -INT16_C(  3711),  INT16_C(  7126), -INT16_C( 23411), -INT16_C( 28908),  INT16_C(  8411),
         INT16_C( 32046), -INT16_C( 26749), -INT16_C( 12528),  INT16_C( 21795), -INT16_C( 15145), -INT16_C( 16489), -INT16_C(  2028), -INT16_C( 16140) },
      { -INT16_C( 32312), -INT16_C( 28136), -INT16_C( 25938), -INT16_C( 31613),  INT16_C(  4533), -INT16_C( 14039),  INT16_C(  1184), -INT16_C( 12567),
         INT16_C( 28034), -INT16_C( 28059), -INT16_C( 30404),  INT16_C(  5095),  INT16_C( 32333),  INT16_C( 25298), -INT16_C( 14473),  INT16_C( 16162),
         INT16_C( 15176), -INT16_C(  2351),  INT16_C( 21973), -INT16_C( 30085), -INT16_C( 23450),  INT16_C(  1619),  INT16_C( 15528),  INT16_C( 10964),
         INT16_C( 14761), -INT16_C(  6724), -INT16_C( 23614),  INT16_C(  4345), -INT16_C( 13534), -INT16_C( 26254), -INT16_C( 27502), -INT16_C(  9256) },
      {  INT16_C( 20355), -INT16_C(  5753), -INT16_C( 26046),  INT16_C( 19849), -INT16_C( 10585),  INT16_C( 26050), -INT16_C( 26065),  INT16_C( 15011),
         INT16_C( 11582), -INT16_C(  2553),  INT16_C( 17906), -INT16_C(  4327), -INT16_C( 31086), -INT16_C( 23181),  INT16_C( 17154),  INT16_C( 29827),
         INT16_C(  3060), -INT16_C( 11070), -INT16_C( 32098),  INT16_C( 31740), -INT16_C( 16324), -INT16_C( 21792),  INT16_C( 20489),  INT16_C( 19375),
        -INT16_C( 18729),  INT16_C( 28682),  INT16_C( 29394),  INT16_C( 25951), -INT16_C( 28679),  INT16_C( 27549), -INT16_C( 13738), -INT16_C(  5904) } },
    { { -INT16_C( 21809), -INT16_C( 23343),  INT16_C( 19711),  INT16_C( 25902), -INT16_C( 32272), -INT16_C( 26261),  INT16_C( 16318),  INT16_C( 26563),
        -INT16_C( 32648),  INT16_C( 15181),  INT16_C( 17955),  INT16_C( 17739), -INT16_C( 17135), -INT16_C( 23330), -INT16_C( 18607),  INT16_C(  8575),
         INT16_C( 20577),  INT16_C( 24773), -INT16_C(  2915), -INT16_C( 29243),  INT16_C( 12405),  INT16_C( 13094), -INT16_C(  5521), -INT16_C(  6245),
        -INT16_C(  6038), -INT16_C( 29406),  INT16_C( 27950),  INT16_C( 16339), -INT16_C( 20182),  INT16_C( 31971),  INT16_C( 25192), -INT16_C( 13923) },
      UINT32_C(1344889523),
      {  INT16_C(  1054), -INT16_C( 29185), -INT16_C( 25874),  INT16_C( 22645), -INT16_C( 26750), -INT16_C( 20251), -INT16_C( 18427),  INT16_C( 12272),
        -INT16_C( 11414), -INT16_C( 11605),  INT16_C( 18486), -INT16_C(  5732), -INT16_C( 14933),  INT16_C(   313),  INT16_C(  5812), -INT16_C( 11571),
        -INT16_C( 13030),  INT16_C(  2144), -INT16_C( 10905), -INT16_C(  5536),  INT16_C( 18028),  INT16_C( 29082), -INT16_C( 29954),  INT16_C( 26785),
         INT16_C( 19550), -INT16_C( 27589), -INT16_C( 10347),  INT16_C( 16509), -INT16_C( 18788),  INT16_C( 20545),  INT16_C(  4044), -INT16_C(  6365) },
      { -INT16_C( 31780),  INT16_C( 17391),  INT16_C( 20568), -INT16_C( 15315), -INT16_C( 14186), -INT16_C( 27594), -INT16_C( 10414), -INT16_C( 20227),
         INT16_C( 14371), -INT16_C( 18364), -INT16_C( 16113), -INT16_C( 21512),  INT16_C( 14967),  INT16_C( 17660),  INT16_C(  8009),  INT16_C(  9515),
         INT16_C(  6818), -INT16_C(  1432), -INT16_C( 27030),  INT16_C(   190), -INT16_C(  2978), -INT16_C( 20331), -INT16_C( 27957), -INT16_C(  4255),
        -INT16_C( 23094), -INT16_C(  9817), -INT16_C( 24473), -INT16_C(  8572), -INT16_C( 32550),  INT16_C(  8994),  INT16_C( 19871),  INT16_C( 16712) },
      { -INT16_C( 30726), -INT16_C( 11794),  INT16_C( 19711),  INT16_C( 25902),  INT16_C( 24600),  INT16_C( 17691),  INT16_C( 16318), -INT16_C(  7955),
        -INT16_C( 32648), -INT16_C( 29969),  INT16_C( 17955),  INT16_C( 17739), -INT16_C( 17135),  INT16_C( 17973),  INT16_C( 13821),  INT16_C(  8575),
        -INT16_C(  6212),  INT16_C( 24773), -INT16_C(  2915), -INT16_C(  5346),  INT16_C( 12405),  INT16_C(  8751), -INT16_C(  5521), -INT16_C(  6245),
        -INT16_C(  6038), -INT16_C( 29406),  INT16_C( 27950),  INT16_C( 16339),  INT16_C( 14198),  INT16_C( 31971),  INT16_C( 23915), -INT16_C( 13923) } },
    { { -INT16_C( 20376), -INT16_C( 11717), -INT16_C(  1466), -INT16_C( 23341),  INT16_C( 26862), -INT16_C( 17835), -INT16_C( 18694), -INT16_C( 15191),
         INT16_C( 20571), -INT16_C( 15715),  INT16_C(  8688), -INT16_C( 13663), -INT16_C( 15454),  INT16_C( 16877),  INT16_C( 13585),  INT16_C( 31107),
        -INT16_C( 16666),  INT16_C( 11339),  INT16_C(  7864), -INT16_C( 22575),  INT16_C(  9862), -INT16_C( 32671),  INT16_C(  2780),  INT16_C( 14148),
        -INT16_C(  7846),  INT16_C( 19450), -INT16_C( 25853), -INT16_C( 23275),  INT16_C(   862),  INT16_C( 28646),  INT16_C( 26936),  INT16_C(  7912) },
      UINT32_C(3763024936),
      { -INT16_C(  6078),  INT16_C(  7769), -INT16_C( 24846),  INT16_C( 19797),  INT16_C( 20351), -INT16_C( 32104), -INT16_C( 21014),  INT16_C( 18727),
         INT16_C(  3760), -INT16_C(  5704), -INT16_C( 24201), -INT16_C( 24825),  INT16_C( 21205),  INT16_C( 10112),  INT16_C(  1902), -INT16_C( 20480),
         INT16_C( 23280), -INT16_C(  7474),  INT16_C(  9464),  INT16_C( 30511), -INT16_C( 14477),  INT16_C( 24314),  INT16_C(  8565),  INT16_C(  9639),
         INT16_C( 24367), -INT16_C( 22770),  INT16_C(  5632), -INT16_C( 10938), -INT16_C( 14744), -INT16_C( 10243), -INT16_C(   562), -INT16_C( 16761) },
      {  INT16_C( 22103),  INT16_C( 20384), -INT16_C( 12166), -INT16_C(  4665), -INT16_C( 15977),  INT16_C(  3147), -INT16_C(  3358),  INT16_C(  4658),
         INT16_C( 16466),  INT16_C( 21177), -INT16_C(   170), -INT16_C( 16600),  INT16_C(  9670), -INT16_C( 27498),  INT16_C(  7458),  INT16_C( 31314),
        -INT16_C(  3469), -INT16_C(  4663), -INT16_C( 28478),  INT16_C( 23259),  INT16_C(  9809),  INT16_C( 13414), -INT16_C( 26599),  INT16_C( 27462),
        -INT16_C(    39),  INT16_C( 12221), -INT16_C(  6658), -INT16_C( 15122), -INT16_C( 31734),  INT16_C( 11608), -INT16_C( 21854),  INT16_C(  5543) },
      { -INT16_C( 20376), -INT16_C( 11717), -INT16_C(  1466),  INT16_C( 15132),  INT16_C( 26862), -INT16_C( 28957), -INT16_C( 18694), -INT16_C( 15191),
         INT16_C( 20571), -INT16_C( 15715), -INT16_C( 24371), -INT16_C( 13663),  INT16_C( 30875), -INT16_C( 17386),  INT16_C( 13585),  INT16_C( 31107),
         INT16_C( 19811), -INT16_C( 12137),  INT16_C(  7864), -INT16_C( 11766),  INT16_C(  9862), -INT16_C( 32671), -INT16_C( 18034),  INT16_C( 14148),
        -INT16_C(  7846),  INT16_C( 19450), -INT16_C( 25853), -INT16_C( 23275),  INT16_C(   862),  INT16_C(  1365), -INT16_C( 22416), -INT16_C( 11218) } },
    { {  INT16_C( 28829),  INT16_C( 24323), -INT16_C(  8703),  INT16_C( 21177),  INT16_C(  8196),  INT16_C(  7558), -INT16_C( 13128), -INT16_C( 28280),
         INT16_C( 18123), -INT16_C( 13631), -INT16_C( 20693),  INT16_C( 13966), -INT16_C(  6348), -INT16_C( 10653),  INT16_C(  2705),  INT16_C( 12011),
        -INT16_C(  4486),  INT16_C( 31630),  INT16_C( 18380), -INT16_C( 11826),  INT16_C( 21607),  INT16_C(  8430),  INT16_C( 30497), -INT16_C(  4943),
         INT16_C( 29373), -INT16_C(  5962),  INT16_C( 17698),  INT16_C( 22046), -INT16_C( 32468), -INT16_C( 17108),  INT16_C(  6027),  INT16_C(  1772) },
      UINT32_C(3531700742),
      { -INT16_C( 27996), -INT16_C( 15031), -INT16_C(  1527), -INT16_C( 14671),  INT16_C( 26733), -INT16_C( 28754), -INT16_C( 12883), -INT16_C(  9755),
         INT16_C(  4430), -INT16_C(  9578), -INT16_C( 32216),  INT16_C( 12000),  INT16_C( 25084), -INT16_C( 16895), -INT16_C( 23375),  INT16_C( 21991),
         INT16_C( 12342),  INT16_C( 16154), -INT16_C( 13526), -INT16_C( 26875), -INT16_C( 19405), -INT16_C(  8154),  INT16_C(  2945), -INT16_C( 12359),
         INT16_C( 20508),  INT16_C( 17833), -INT16_C( 30254), -INT16_C( 12429),  INT16_C( 29931), -INT16_C( 25459),  INT16_C( 29721),  INT16_C( 20465) },
      {  INT16_C(  2980), -INT16_C( 12657), -INT16_C( 27434),  INT16_C(  2662), -INT16_C( 29624), -INT16_C( 13846), -INT16_C( 23400), -INT16_C( 19303),
         INT16_C( 17140), -INT16_C( 14599),  INT16_C( 28108), -INT16_C( 18539),  INT16_C(  8929), -INT16_C(  1453),  INT16_C( 17558),  INT16_C( 14922),
        -INT16_C(  9905),  INT16_C(  9481),  INT16_C( 28525), -INT16_C( 18897),  INT16_C(  6907), -INT16_C( 27777),  INT16_C(  6334), -INT16_C( 19896),
         INT16_C( 16731),  INT16_C( 10104),  INT16_C(  3758), -INT16_C( 28450),  INT16_C( 12592), -INT16_C( 14454), -INT16_C( 11147), -INT16_C( 15359) },
      {  INT16_C( 28829), -INT16_C( 27688), -INT16_C( 28961),  INT16_C( 21177),  INT16_C(  8196),  INT16_C(  7558), -INT16_C( 13128), -INT16_C( 28280),
         INT16_C( 18123), -INT16_C( 24177), -INT16_C( 20693), -INT16_C(  6539), -INT16_C( 31523), -INT16_C( 18348), -INT16_C(  5817),  INT16_C( 12011),
         INT16_C(  2437),  INT16_C( 31630),  INT16_C( 18380), -INT16_C( 11826),  INT16_C( 21607),  INT16_C(  8430),  INT16_C( 30497), -INT16_C( 32255),
         INT16_C( 29373),  INT16_C( 27937),  INT16_C( 17698),  INT16_C( 22046), -INT16_C( 23013), -INT16_C( 17108),  INT16_C( 18574),  INT16_C(  5106) } },
    { {  INT16_C(  2733),  INT16_C(  7145),  INT16_C(  6521),  INT16_C( 30161),  INT16_C( 20531), -INT16_C(  3832),  INT16_C( 20585), -INT16_C( 15197),
         INT16_C(  7058),  INT16_C( 16619), -INT16_C( 14039),  INT16_C( 23248),  INT16_C( 23546),  INT16_C( 28449),  INT16_C(  8751), -INT16_C(  8909),
         INT16_C(  7213), -INT16_C( 22792), -INT16_C( 14027),  INT16_C( 26651),  INT16_C(  9241), -INT16_C( 32167), -INT16_C(   908),  INT16_C(  1606),
         INT16_C( 12568),  INT16_C( 16711),  INT16_C(  6138), -INT16_C(  2917), -INT16_C( 17294), -INT16_C( 23965), -INT16_C( 26913),  INT16_C(  3199) },
      UINT32_C(3904010163),
      { -INT16_C( 21774),  INT16_C( 26332),  INT16_C(  8871), -INT16_C( 16531), -INT16_C( 19372),  INT16_C( 19968), -INT16_C( 25397),  INT16_C( 15939),
        -INT16_C( 22952),  INT16_C( 14304),  INT16_C( 24381), -INT16_C(  4029), -INT16_C(  2346),  INT16_C(  5848),  INT16_C( 10692), -INT16_C( 18833),
         INT16_C( 19412),  INT16_C( 31516), -INT16_C( 30354), -INT16_C( 15814),  INT16_C( 14909),  INT16_C(  2320),  INT16_C( 21462),  INT16_C( 12103),
         INT16_C( 10234),  INT16_C( 14182), -INT16_C( 21882),  INT16_C( 23591), -INT16_C(    96),  INT16_C( 25714), -INT16_C(  7895), -INT16_C(   742) },
      {  INT16_C( 13869), -INT16_C( 25736), -INT16_C( 19776), -INT16_C(   675),  INT16_C( 28140), -INT16_C( 15610),  INT16_C( 19905), -INT16_C( 17422),
         INT16_C( 22644), -INT16_C(  1294),  INT16_C(  6402), -INT16_C( 23978), -INT16_C( 14312),  INT16_C( 16646),  INT16_C(  8362), -INT16_C( 10434),
        -INT16_C( 18857),  INT16_C(  6002), -INT16_C( 12440),  INT16_C( 21780),  INT16_C(  6972), -INT16_C(   744),  INT16_C(  2664), -INT16_C(  8776),
        -INT16_C( 21918),  INT16_C( 26071),  INT16_C( 11971), -INT16_C(  9209),  INT16_C(  3830), -INT16_C( 24547),  INT16_C( 23598), -INT16_C( 31369) },
      { -INT16_C(  7905),  INT16_C(   596),  INT16_C(  6521),  INT16_C( 30161),  INT16_C(  8768),  INT16_C(  4358),  INT16_C( 20585), -INT16_C(  1483),
        -INT16_C(   308),  INT16_C( 13010),  INT16_C( 30783),  INT16_C( 23248), -INT16_C( 16658),  INT16_C( 22494),  INT16_C( 19054), -INT16_C(  8909),
         INT16_C(  7213), -INT16_C( 28018), -INT16_C( 14027),  INT16_C( 26651),  INT16_C( 21881),  INT16_C(  1576), -INT16_C(   908),  INT16_C(  3327),
         INT16_C( 12568),  INT16_C( 16711),  INT16_C(  6138),  INT16_C( 14382), -INT16_C( 17294),  INT16_C(  1167),  INT16_C( 15703), -INT16_C( 32111) } }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
    simde__m512i src = simde_mm512_loadu_epi16(test_vec[i].src);
    simde__m512i a = simde_mm512_loadu_epi16(test_vec[i].a);
    simde__m512i b = simde_mm512_loadu_epi16(test_vec[i].b);
    simde__m512i r = simde_mm512_mask_add_epi16(src, test_vec[i].k, a, b);
    simde_test_x86_assert_equal_i16x32(r, simde_mm512_loadu_epi16(test_vec[i].r));
  }

  return 0;
}

static int
test_simde_mm512_maskz_add_epi16 (SIMDE_MUNIT_TEST_ARGS) {
  static const struct {
    const simde__mmask32 k;
    const int16_t a[32];
    const int16_t b[32];
    const int16_t r[32];
  } test_vec[] = {
    { UINT32_C(1970569674),
      { -INT16_C(  4224), -INT16_C( 11503), -INT16_C( 18041),  INT16_C(  6436), -INT16_C(  9270), -INT16_C( 15814), -INT16_C( 27569),  INT16_C( 13042),
        -INT16_C( 23737), -INT16_C( 13044),  INT16_C(  7220), -INT16_C(   316),  INT16_C( 14494), -INT16_C(   908),  INT16_C( 27220), -INT16_C( 11118),
        -INT16_C( 23719), -INT16_C(  8025), -INT16_C( 13476),  INT16_C(  9977),  INT16_C( 13479), -INT16_C(  2328), -INT16_C(  9528),  INT16_C(  3881),
         INT16_C( 13693), -INT16_C( 19747), -INT16_C( 24239), -INT16_C(  4176),  INT16_C(  9433),  INT16_C( 11756),  INT16_C( 32398), -INT16_C(  6143) },
      { -INT16_C( 22239),  INT16_C( 32200), -INT16_C( 15756),  INT16_C(  7075), -INT16_C( 29450), -INT16_C( 16878),  INT16_C( 15206), -INT16_C(  6962),
        -INT16_C( 21648), -INT16_C( 15978),  INT16_C( 17996),  INT16_C(  9649), -INT16_C( 25237), -INT16_C(  1709),  INT16_C( 21531),  INT16_C( 15585),
        -INT16_C( 21763),  INT16_C( 29369),  INT16_C( 23660),  INT16_C( 25229), -INT16_C( 24600),  INT16_C( 20256), -INT16_C(  4390),  INT16_C( 18995),
        -INT16_C( 13927), -INT16_C(  6900), -INT16_C( 17137),  INT16_C( 31243),  INT16_C( 24154),  INT16_C( 30068),  INT16_C( 21938), -INT16_C( 20303) },
      {  INT16_C(     0),  INT16_C( 20697),  INT16_C(     0),  INT16_C( 13511),  INT16_C(     0),  INT16_C(     0), -INT16_C( 12363),  INT16_C(  6080),
         INT16_C( 20151),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(  4467),
         INT16_C(     0),  INT16_C(     0),  INT16_C( 10184),  INT16_C(     0), -INT16_C( 11121),  INT16_C( 17928), -INT16_C( 13918),  INT16_C(     0),
        -INT16_C(   234),  INT16_C(     0),  INT16_C( 24160),  INT16_C(     0), -INT16_C( 31949), -INT16_C( 23712), -INT16_C( 11200),  INT16_C(     0) } },
    { UINT32_C(1797417727),
      { -INT16_C(  4529),  INT16_C( 10750),  INT16_C( 12764),  INT16_C( 30324), -INT16_C( 32518),  INT16_C(  2395),  INT16_C( 26173), -INT16_C( 26748),
        -INT16_C(  1852),  INT16_C( 30476), -INT16_C( 17075),  INT16_C( 19751),  INT16_C( 18727), -INT16_C(  4680), -INT16_C( 30984),  INT16_C( 18332),
        -INT16_C( 25996),  INT16_C( 20593), -INT16_C(  6709), -INT16_C( 14906),  INT16_C(  8805), -INT16_C( 23857),  INT16_C( 21384),  INT16_C( 19769),
         INT16_C( 17739), -INT16_C( 26428), -INT16_C(  5374),  INT16_C( 10725), -INT16_C( 25036),  INT16_C( 11286), -INT16_C( 19676), -INT16_C( 26508) },
      { -INT16_C(  6835),  INT16_C(  6632), -INT16_C( 20534),  INT16_C( 12254), -INT16_C( 21039),  INT16_C( 22993),  INT16_C(  2560),  INT16_C( 19366),
         INT16_C( 27215),  INT16_C( 20964), -INT16_C( 13995), -INT16_C( 30342), -INT16_C( 28569), -INT16_C( 29770),  INT16_C( 10819), -INT16_C( 28381),
         INT16_C(  3087), -INT16_C(  9814), -INT16_C( 30533), -INT16_C( 29688), -INT16_C(  9930),  INT16_C( 14053), -INT16_C( 29469),  INT16_C( 12930),
         INT16_C( 26358),  INT16_C( 19587), -INT16_C(   721), -INT16_C( 26667), -INT16_C( 29811), -INT16_C( 11998),  INT16_C( 18101), -INT16_C( 15262) },
      { -INT16_C( 11364),  INT16_C( 17382), -INT16_C(  7770), -INT16_C( 22958),  INT16_C( 11979),  INT16_C( 25388),  INT16_C( 28733), -INT16_C(  7382),
         INT16_C(     0), -INT16_C( 14096),  INT16_C(     0), -INT16_C( 10591),  INT16_C(     0),  INT16_C( 31086), -INT16_C( 20165),  INT16_C(     0),
         INT16_C(     0),  INT16_C( 10779),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0), -INT16_C(  9804),  INT16_C(     0),  INT16_C(     0),
        -INT16_C( 21439), -INT16_C(  6841),  INT16_C(     0), -INT16_C( 15942),  INT16_C(     0), -INT16_C(   712), -INT16_C(  1575),  INT16_C(     0) } },
    { UINT32_C( 228396114),
      {  INT16_C( 32382),  INT16_C( 24833), -INT16_C( 31990),  INT16_C(   403),  INT16_C(  5865),  INT16_C(  6221),  INT16_C(  8723), -INT16_C( 24145),
        -INT16_C( 11602),  INT16_C( 25458), -INT16_C( 11240),  INT16_C( 27176), -INT16_C( 14880),  INT16_C( 29815),  INT16_C(  4203), -INT16_C(  5825),
         INT16_C( 16526), -INT16_C( 26293), -INT16_C(  8509), -INT16_C( 21350), -INT16_C(  6155),  INT16_C(  2244),  INT16_C( 29705), -INT16_C( 18519),
         INT16_C(  6982),  INT16_C( 24091),  INT16_C( 17391), -INT16_C( 12344),  INT16_C( 16136),  INT16_C( 29508), -INT16_C( 31921), -INT16_C(  8867) },
      { -INT16_C( 22333), -INT16_C( 31114),  INT16_C(  4230),  INT16_C( 31538), -INT16_C(  2313),  INT16_C(   388),  INT16_C( 11626), -INT16_C( 20296),
        -INT16_C( 11447),  INT16_C( 14350), -INT16_C( 10730),  INT16_C(  7944),  INT16_C( 19477),  INT16_C( 25746), -INT16_C(  4145), -INT16_C( 28094),
        -INT16_C( 18281),  INT16_C(  7704),  INT16_C( 19145), -INT16_C( 16231),  INT16_C(  7488), -INT16_C( 21567),  INT16_C( 31307), -INT16_C( 27557),
         INT16_C( 27213),  INT16_C( 25804), -INT16_C( 11200),  INT16_C( 22147),  INT16_C(  5408), -INT16_C(  4166), -INT16_C(  1019), -INT16_C( 25471) },
      {  INT16_C(     0), -INT16_C(  6281),  INT16_C(     0),  INT16_C(     0),  INT16_C(  3552),  INT16_C(     0),  INT16_C( 20349),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0), -INT16_C( 21970), -INT16_C( 30416),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
        -INT16_C(  1755),  INT16_C(     0),  INT16_C( 10636),  INT16_C( 27955),  INT16_C(  1333),  INT16_C(     0),  INT16_C(     0),  INT16_C( 19460),
        -INT16_C( 31341),  INT16_C(     0),  INT16_C(  6191),  INT16_C(  9803),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0) } },
    { UINT32_C(2126158261),
      {  INT16_C(   113), -INT16_C( 17201),  INT16_C( 10874), -INT16_C( 14512),  INT16_C(  7572), -INT16_C( 10965), -INT16_C( 20751),  INT16_C(  4651),
        -INT16_C(  6716), -INT16_C( 14079), -INT16_C( 31774), -INT16_C( 26779),  INT16_C(  8220),  INT16_C(    21),  INT16_C( 21364), -INT16_C(  6876),
        -INT16_C(  3245), -INT16_C( 12894), -INT16_C(  3555), -INT16_C( 19819), -INT16_C( 16369),  INT16_C(   391), -INT16_C( 19857),  INT16_C( 13075),
         INT16_C(  5271),  INT16_C( 31228),  INT16_C( 24983), -INT16_C( 19440),  INT16_C(  9601), -INT16_C(  2636), -INT16_C( 10119), -INT16_C( 13093) },
      {  INT16_C( 32203), -INT16_C(  5990),  INT16_C( 12143),  INT16_C( 32666),  INT16_C(  8687),  INT16_C( 24192), -INT16_C( 27693),  INT16_C( 27537),
        -INT16_C( 29273),  INT16_C( 16356), -INT16_C(  2577),  INT16_C( 28915), -INT16_C( 22758), -INT16_C( 27802),  INT16_C( 16767),  INT16_C( 19040),
        -INT16_C(  1346),  INT16_C( 11570), -INT16_C( 13015),  INT16_C(  6316),  INT16_C( 11502), -INT16_C( 15753),  INT16_C(  2239),  INT16_C( 26413),
         INT16_C(  4502), -INT16_C( 31322), -INT16_C( 26362),  INT16_C(  8693),  INT16_C( 23360), -INT16_C( 16460),  INT16_C(  5276),  INT16_C( 23049) },
      {  INT16_C( 32316),  INT16_C(     0),  INT16_C( 23017),  INT16_C(     0),  INT16_C( 16259),  INT16_C( 13227),  INT16_C(     0),  INT16_C( 32188),
         INT16_C( 29547),  INT16_C(     0),  INT16_C(     0),  INT16_C(  2136), -INT16_C( 14538),  INT16_C(     0),  INT16_C(     0),  INT16_C( 12164),
         INT16_C(     0), -INT16_C(  1324),  INT16_C(     0), -INT16_C( 13503), -INT16_C(  4867), -INT16_C( 15362),  INT16_C(     0), -INT16_C( 26048),
         INT16_C(     0), -INT16_C(    94), -INT16_C(  1379), -INT16_C( 10747), -INT16_C( 32575), -INT16_C( 19096), -INT16_C(  4843),  INT16_C(     0) } },
    { UINT32_C( 931674894),
      { -INT16_C( 14495),  INT16_C(  8377), -INT16_C(  6449),  INT16_C( 25991),  INT16_C( 11767), -INT16_C(   278), -INT16_C(  7994),  INT16_C(  1567),
        -INT16_C( 11461), -INT16_C( 10043), -INT16_C( 12568), -INT16_C(  2510), -INT16_C( 17910),  INT16_C(  4654),  INT16_C( 32495),  INT16_C( 20489),
        -INT16_C( 15803),  INT16_C(  5232), -INT16_C(  1880), -INT16_C( 24454),  INT16_C( 25637), -INT16_C(  4962), -INT16_C( 17084), -INT16_C( 32526),
        -INT16_C( 18288),  INT16_C( 30808), -INT16_C( 30074), -INT16_C( 28561), -INT16_C( 25275),  INT16_C( 13475), -INT16_C( 21477),  INT16_C( 24708) },
      { -INT16_C(  2961),  INT16_C(  6004), -INT16_C(  4372),  INT16_C(  4791),  INT16_C( 21843), -INT16_C( 26626), -INT16_C(  4078), -INT16_C( 23785),
         INT16_C( 28584),  INT16_C( 12059), -INT16_C( 29958),  INT16_C( 16319),  INT16_C( 25127),  INT16_C( 17011), -INT16_C(  2289),  INT16_C( 32418),
         INT16_C(  6123), -INT16_C( 10091),  INT16_C( 19717),  INT16_C( 22762), -INT16_C(  5982), -INT16_C( 18960),  INT16_C(  2008), -INT16_C( 32424),
         INT16_C( 29559),  INT16_C( 29104),  INT16_C( 28670),  INT16_C(  9648),  INT16_C(  9170), -INT16_C(  7832),  INT16_C(  2586),  INT16_C(  1375) },
      {  INT16_C(     0),  INT16_C( 14381), -INT16_C( 10821),  INT16_C( 30782),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C( 17123),  INT16_C(  2016),  INT16_C(     0),  INT16_C( 13809),  INT16_C(  7217),  INT16_C( 21665),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0), -INT16_C(  1692),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(   586),
         INT16_C( 11271), -INT16_C(  5624), -INT16_C(  1404),  INT16_C(     0), -INT16_C( 16105),  INT16_C(  5643),  INT16_C(     0),  INT16_C(     0) } },
    { UINT32_C( 668857377),
      {  INT16_C( 28591), -INT16_C( 30567), -INT16_C(  3721), -INT16_C(  4599), -INT16_C( 18076),  INT16_C( 25183),  INT16_C(  3880), -INT16_C(  1400),
        -INT16_C(  4046),  INT16_C( 19675),  INT16_C( 15098),  INT16_C(  7249),  INT16_C( 12079),  INT16_C( 28739), -INT16_C( 15626), -INT16_C( 22956),
        -INT16_C(  4814), -INT16_C( 22226),  INT16_C( 14302),  INT16_C( 17303), -INT16_C(  2320),  INT16_C(  6309),  INT16_C( 11525),  INT16_C( 14099),
        -INT16_C(  4579),  INT16_C(  6275), -INT16_C( 11223),  INT16_C( 22580),  INT16_C( 30467), -INT16_C(  1336),  INT16_C(  7481),  INT16_C( 27552) },
      { -INT16_C( 12790), -INT16_C(  5868), -INT16_C( 21755), -INT16_C(  2772), -INT16_C( 11871), -INT16_C( 23027),  INT16_C(  8447),  INT16_C(  7389),
         INT16_C( 24591),  INT16_C( 14388),  INT16_C( 26677),  INT16_C( 14480),  INT16_C( 22751),  INT16_C(  6450), -INT16_C( 11659), -INT16_C( 32636),
        -INT16_C( 26208), -INT16_C( 23191), -INT16_C( 27324), -INT16_C(  6502), -INT16_C( 22426),  INT16_C( 25996),  INT16_C( 27336), -INT16_C( 10366),
        -INT16_C( 18742), -INT16_C(   241), -INT16_C( 24801), -INT16_C(   456),  INT16_C( 27384),  INT16_C( 27927), -INT16_C( 25539), -INT16_C(  8723) },
      {  INT16_C( 15801),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(  2156),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0), -INT16_C( 23761),  INT16_C(     0), -INT16_C( 30706), -INT16_C( 30347), -INT16_C( 27285),  INT16_C(  9944),
        -INT16_C( 31022),  INT16_C(     0), -INT16_C( 13022),  INT16_C( 10801), -INT16_C( 24746),  INT16_C(     0), -INT16_C( 26675),  INT16_C(  3733),
        -INT16_C( 23321),  INT16_C(  6034),  INT16_C( 29512),  INT16_C(     0),  INT16_C(     0),  INT16_C( 26591),  INT16_C(     0),  INT16_C(     0) } },
    { UINT32_C(2038650421),
      { -INT16_C(  4923), -INT16_C( 29001),  INT16_C( 14678),  INT16_C(  8293),  INT16_C( 30192),  INT16_C(  3872),  INT16_C( 22548),  INT16_C(  3085),
         INT16_C(  9666), -INT16_C(   134),  INT16_C( 26561), -INT16_C(  2339),  INT16_C( 24766), -INT16_C( 22161), -INT16_C( 12419),  INT16_C( 17403),
        -INT16_C( 19525),  INT16_C(  4561),  INT16_C( 14060), -INT16_C(  9167),  INT16_C( 20907), -INT16_C( 16149), -INT16_C(  1623),  INT16_C( 27852),
         INT16_C( 17950), -INT16_C(  8341),  INT16_C( 18606),  INT16_C( 27861),  INT16_C( 17576),  INT16_C(  9749),  INT16_C(  4371), -INT16_C( 12695) },
      {  INT16_C( 15044), -INT16_C( 20257),  INT16_C(  4464),  INT16_C(  7309),  INT16_C( 30818),  INT16_C(  3292), -INT16_C( 22415), -INT16_C( 28808),
        -INT16_C(  7185), -INT16_C( 25234),  INT16_C( 17196), -INT16_C( 11255),  INT16_C(  7816), -INT16_C( 25606),  INT16_C( 25391), -INT16_C(  3222),
         INT16_C( 18845),  INT16_C(  3748),  INT16_C( 12634), -INT16_C( 17110),  INT16_C(  1705),  INT16_C(  7113),  INT16_C( 16814), -INT16_C( 25174),
         INT16_C(  6436),  INT16_C( 20538),  INT16_C( 17244), -INT16_C(  7131),  INT16_C(  8034), -INT16_C( 28288), -INT16_C(  5501),  INT16_C(  8325) },
      {  INT16_C( 10121),  INT16_C(     0),  INT16_C( 19142),  INT16_C(     0), -INT16_C(  4526),  INT16_C(  7164),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0), -INT16_C( 25368), -INT16_C( 21779),  INT16_C(     0),  INT16_C( 32582),  INT16_C(     0),  INT16_C( 12972),  INT16_C(     0),
        -INT16_C(   680),  INT16_C(  8309),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(  2678),
         INT16_C( 24386),  INT16_C(     0),  INT16_C(     0),  INT16_C( 20730),  INT16_C( 25610), -INT16_C( 18539), -INT16_C(  1130),  INT16_C(     0) } },
    { UINT32_C(2385389875),
      {  INT16_C(  5214),  INT16_C(  3358), -INT16_C( 13995),  INT16_C( 31146), -INT16_C(  6686),  INT16_C( 16074), -INT16_C(  4312), -INT16_C( 30173),
        -INT16_C( 23794), -INT16_C( 28388), -INT16_C( 24179), -INT16_C( 16206), -INT16_C(  7990),  INT16_C(  9294), -INT16_C( 26311), -INT16_C( 26841),
         INT16_C( 18093),  INT16_C(   676),  INT16_C( 20239), -INT16_C(  3716),  INT16_C( 17972),  INT16_C( 23599),  INT16_C( 21045),  INT16_C( 17383),
         INT16_C(  1013), -INT16_C( 32043), -INT16_C( 30812),  INT16_C( 28227), -INT16_C( 28313), -INT16_C( 24430), -INT16_C( 18133), -INT16_C( 10184) },
      { -INT16_C(  8961),  INT16_C(  3803),  INT16_C( 22315),  INT16_C( 24575),  INT16_C( 12189), -INT16_C( 11588), -INT16_C( 23679),  INT16_C( 30485),
        -INT16_C(  5466),  INT16_C( 19193),  INT16_C( 15473), -INT16_C(  9800),  INT16_C( 19150), -INT16_C(  1671), -INT16_C( 20221),  INT16_C(   977),
        -INT16_C( 21362), -INT16_C( 18159),  INT16_C(  4355), -INT16_C( 24551), -INT16_C( 10944), -INT16_C( 16014), -INT16_C( 30600),  INT16_C(  7736),
         INT16_C( 12914), -INT16_C(  7064),  INT16_C(  8302),  INT16_C( 15549),  INT16_C( 13930),  INT16_C( 27957),  INT16_C(  2024),  INT16_C( 30320) },
      { -INT16_C(  3747),  INT16_C(  7161),  INT16_C(     0),  INT16_C(     0),  INT16_C(  5503),  INT16_C(  4486),  INT16_C(     0),  INT16_C(     0),
        -INT16_C( 29260),  INT16_C(     0),  INT16_C(     0), -INT16_C( 26006),  INT16_C(     0),  INT16_C(  7623),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0), -INT16_C( 17483),  INT16_C( 24594), -INT16_C( 28267),  INT16_C(     0),  INT16_C(  7585),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C( 26429), -INT16_C( 22510), -INT16_C( 21760),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C( 20136) } }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
    simde__m512i a = simde_mm512_loadu_epi16(test_vec[i].a);
    simde__m512i b = simde_mm512_loadu_epi16(test_vec[i].b);
    simde__m512i r = simde_mm512_maskz_add_epi16(test_vec[i].k, a, b);
    simde_test_x86_assert_equal_i16x32(r, simde_mm512_loadu_epi16(test_vec[i].r));
  }

  return 0;
}

static int
test_simde_mm512_adds_epi8(SIMDE_MUNIT_TEST_ARGS) {
  const struct {
    simde__m512i a;
    simde__m512i b;
    simde__m512i r;
  } test_vec[8] = {
    { simde_mm512_set_epi8(INT8_C( -30), INT8_C( -16), INT8_C( -64), INT8_C( 113),
                           INT8_C(  51), INT8_C(-115), INT8_C(  19), INT8_C( -80),
                           INT8_C(-110), INT8_C( -62), INT8_C( -91), INT8_C(   8),
                           INT8_C(  11), INT8_C( -49), INT8_C( -43), INT8_C(-101),
                           INT8_C(  16), INT8_C(  61), INT8_C(  -2), INT8_C(-100),
                           INT8_C(   1), INT8_C( -80), INT8_C( 127), INT8_C(-105),
                           INT8_C( -74), INT8_C(-126), INT8_C( 122), INT8_C(  30),
                           INT8_C( -73), INT8_C(  48), INT8_C( -33), INT8_C(   2),
                           INT8_C( -82), INT8_C( -10), INT8_C(  33), INT8_C(  20),
                           INT8_C(-120), INT8_C(-120), INT8_C( -46), INT8_C( -54),
                           INT8_C( -43), INT8_C(  63), INT8_C(  81), INT8_C( 103),
                           INT8_C( 118), INT8_C( -84), INT8_C(  76), INT8_C(  47),
                           INT8_C( 101), INT8_C( -83), INT8_C(  15), INT8_C(  23),
                           INT8_C(  36), INT8_C(-116), INT8_C( -88), INT8_C( -45),
                           INT8_C(  -6), INT8_C(  86), INT8_C(  20), INT8_C(  39),
                           INT8_C( 117), INT8_C(  80), INT8_C(  97), INT8_C(  41)),
      simde_mm512_set_epi8(INT8_C( 122), INT8_C(  43), INT8_C(  38), INT8_C(  97),
                           INT8_C(  38), INT8_C(  68), INT8_C(  88), INT8_C(  56),
                           INT8_C( -39), INT8_C(  61), INT8_C( -57), INT8_C( -66),
                           INT8_C(-121), INT8_C(  29), INT8_C( 110), INT8_C( 127),
                           INT8_C(-115), INT8_C(  16), INT8_C( -46), INT8_C(  65),
                           INT8_C( -36), INT8_C(  26), INT8_C(  12), INT8_C( -79),
                           INT8_C( -66), INT8_C( -28), INT8_C( -67), INT8_C( -79),
                           INT8_C( -60), INT8_C( -13), INT8_C(  74), INT8_C(  25),
                           INT8_C(  46), INT8_C(   8), INT8_C(  70), INT8_C( 106),
                           INT8_C(-119), INT8_C(   0), INT8_C( -96), INT8_C( -51),
                           INT8_C( -50), INT8_C(  93), INT8_C(  92), INT8_C(  65),
                           INT8_C( -96), INT8_C(-126), INT8_C(   4), INT8_C(   9),
                           INT8_C(  26), INT8_C(-119), INT8_C(  93), INT8_C(  15),
                           INT8_C(-115), INT8_C(  77), INT8_C( 125), INT8_C( -62),
                           INT8_C(  77), INT8_C( -22), INT8_C( 101), INT8_C(  83),
                           INT8_C(  45), INT8_C( -68), INT8_C(  97), INT8_C( -19)),
      simde_mm512_set_epi8(INT8_C(  92), INT8_C(  27), INT8_C( -26), INT8_C( 127),
                           INT8_C(  89), INT8_C( -47), INT8_C( 107), INT8_C( -24),
                           INT8_C(-128), INT8_C(  -1), INT8_C(-128), INT8_C( -58),
                           INT8_C(-110), INT8_C( -20), INT8_C(  67), INT8_C(  26),
                           INT8_C( -99), INT8_C(  77), INT8_C( -48), INT8_C( -35),
                           INT8_C( -35), INT8_C( -54), INT8_C( 127), INT8_C(-128),
                           INT8_C(-128), INT8_C(-128), INT8_C(  55), INT8_C( -49),
                           INT8_C(-128), INT8_C(  35), INT8_C(  41), INT8_C(  27),
                           INT8_C( -36), INT8_C(  -2), INT8_C( 103), INT8_C( 126),
                           INT8_C(-128), INT8_C(-120), INT8_C(-128), INT8_C(-105),
                           INT8_C( -93), INT8_C( 127), INT8_C( 127), INT8_C( 127),
                           INT8_C(  22), INT8_C(-128), INT8_C(  80), INT8_C(  56),
                           INT8_C( 127), INT8_C(-128), INT8_C( 108), INT8_C(  38),
                           INT8_C( -79), INT8_C( -39), INT8_C(  37), INT8_C(-107),
                           INT8_C(  71), INT8_C(  64), INT8_C( 121), INT8_C( 122),
                           INT8_C( 127), INT8_C(  12), INT8_C( 127), INT8_C(  22)) },
    { simde_mm512_set_epi8(INT8_C(  60), INT8_C(  96), INT8_C(-106), INT8_C(-115),
                           INT8_C(  31), INT8_C(-108), INT8_C(  15), INT8_C(  63),
                           INT8_C( -77), INT8_C( 125), INT8_C(  41), INT8_C( -80),
                           INT8_C(  36), INT8_C(-118), INT8_C(-116), INT8_C( -63),
                           INT8_C( -44), INT8_C(  70), INT8_C(  99), INT8_C(  48),
                           INT8_C(  67), INT8_C(  43), INT8_C(  83), INT8_C(  53),
                           INT8_C(  60), INT8_C(  57), INT8_C(-118), INT8_C(  55),
                           INT8_C( -62), INT8_C( -42), INT8_C(  19), INT8_C(  52),
                           INT8_C( -37), INT8_C( -32), INT8_C(  33), INT8_C(-114),
                           INT8_C( -96), INT8_C(  53), INT8_C(  18), INT8_C( -37),
                           INT8_C(   6), INT8_C( -87), INT8_C( -11), INT8_C( -10),
                           INT8_C(  -4), INT8_C(  84), INT8_C( 104), INT8_C(  55),
                           INT8_C(  92), INT8_C( 117), INT8_C(  16), INT8_C( 115),
                           INT8_C(  83), INT8_C(  80), INT8_C(-125), INT8_C(  64),
                           INT8_C(  74), INT8_C(  -9), INT8_C( -62), INT8_C(  67),
                           INT8_C( 102), INT8_C(  66), INT8_C( -86), INT8_C(-112)),
      simde_mm512_set_epi8(INT8_C( -97), INT8_C(  52), INT8_C( -91), INT8_C(   7),
                           INT8_C(  -1), INT8_C( -19), INT8_C(  38), INT8_C(  15),
                           INT8_C(  76), INT8_C(  63), INT8_C(  10), INT8_C(  18),
                           INT8_C(  54), INT8_C(  73), INT8_C(  15), INT8_C( -54),
                           INT8_C(-114), INT8_C(  63), INT8_C(  44), INT8_C(   4),
                           INT8_C(  41), INT8_C(  90), INT8_C( -78), INT8_C( -67),
                           INT8_C(  95), INT8_C( -14), INT8_C( -10), INT8_C( -44),
                           INT8_C(  53), INT8_C( 102), INT8_C( 127), INT8_C( 120),
                           INT8_C( -89), INT8_C(  10), INT8_C( -36), INT8_C( -50),
                           INT8_C( 118), INT8_C(-106), INT8_C( -52), INT8_C(  76),
                           INT8_C(  66), INT8_C( -36), INT8_C( -79), INT8_C(  91),
                           INT8_C(  14), INT8_C( 103), INT8_C( -73), INT8_C(-123),
                           INT8_C(  68), INT8_C( -54), INT8_C(-103), INT8_C(  38),
                           INT8_C(  58), INT8_C(   0), INT8_C( -62), INT8_C( -76),
                           INT8_C(  93), INT8_C( 119), INT8_C(  14), INT8_C(  84),
                           INT8_C( -83), INT8_C(  76), INT8_C( -47), INT8_C( -53)),
      simde_mm512_set_epi8(INT8_C( -37), INT8_C( 127), INT8_C(-128), INT8_C(-108),
                           INT8_C(  30), INT8_C(-127), INT8_C(  53), INT8_C(  78),
                           INT8_C(  -1), INT8_C( 127), INT8_C(  51), INT8_C( -62),
                           INT8_C(  90), INT8_C( -45), INT8_C(-101), INT8_C(-117),
                           INT8_C(-128), INT8_C( 127), INT8_C( 127), INT8_C(  52),
                           INT8_C( 108), INT8_C( 127), INT8_C(   5), INT8_C( -14),
                           INT8_C( 127), INT8_C(  43), INT8_C(-128), INT8_C(  11),
                           INT8_C(  -9), INT8_C(  60), INT8_C( 127), INT8_C( 127),
                           INT8_C(-126), INT8_C( -22), INT8_C(  -3), INT8_C(-128),
                           INT8_C(  22), INT8_C( -53), INT8_C( -34), INT8_C(  39),
                           INT8_C(  72), INT8_C(-123), INT8_C( -90), INT8_C(  81),
                           INT8_C(  10), INT8_C( 127), INT8_C(  31), INT8_C( -68),
                           INT8_C( 127), INT8_C(  63), INT8_C( -87), INT8_C( 127),
                           INT8_C( 127), INT8_C(  80), INT8_C(-128), INT8_C( -12),
                           INT8_C( 127), INT8_C( 110), INT8_C( -48), INT8_C( 127),
                           INT8_C(  19), INT8_C( 127), INT8_C(-128), INT8_C(-128)) },
    { simde_mm512_set_epi8(INT8_C( -80), INT8_C( 122), INT8_C(-100), INT8_C( 123),
                           INT8_C(  82), INT8_C(-107), INT8_C(  95), INT8_C( -80),
                           INT8_C(-115), INT8_C(-109), INT8_C(  60), INT8_C(  72),
                           INT8_C(  57), INT8_C(  99), INT8_C( -30), INT8_C(-115),
                           INT8_C(  69), INT8_C(  18), INT8_C(  -5), INT8_C(  -6),
                           INT8_C( -90), INT8_C( -20), INT8_C(  17), INT8_C( 121),
                           INT8_C(-100), INT8_C( -55), INT8_C(  90), INT8_C( -42),
                           INT8_C(-113), INT8_C( 119), INT8_C(  44), INT8_C(-123),
                           INT8_C( -39), INT8_C( 114), INT8_C(  37), INT8_C( -84),
                           INT8_C( -88), INT8_C(  15), INT8_C(  23), INT8_C( 114),
                           INT8_C(  63), INT8_C( -61), INT8_C(  22), INT8_C(   8),
                           INT8_C(  54), INT8_C(  19), INT8_C( -34), INT8_C(  18),
                           INT8_C( -36), INT8_C( 104), INT8_C(   1), INT8_C(   5),
                           INT8_C(-116), INT8_C(  79), INT8_C( -20), INT8_C(  -4),
                           INT8_C(  95), INT8_C( 103), INT8_C(   3), INT8_C(  64),
                           INT8_C(  34), INT8_C( -49), INT8_C( -27), INT8_C(  41)),
      simde_mm512_set_epi8(INT8_C(  97), INT8_C(-116), INT8_C( -44), INT8_C( -44),
                           INT8_C(  67), INT8_C( -66), INT8_C(  77), INT8_C(  60),
                           INT8_C(  74), INT8_C( -19), INT8_C(-123), INT8_C( -81),
                           INT8_C( -74), INT8_C( -21), INT8_C( -32), INT8_C(-122),
                           INT8_C(-110), INT8_C( 116), INT8_C( 115), INT8_C(  99),
                           INT8_C(  29), INT8_C(  50), INT8_C(-119), INT8_C(-126),
                           INT8_C( -53), INT8_C(  68), INT8_C( -37), INT8_C(  84),
                           INT8_C(  23), INT8_C( -10), INT8_C(  15), INT8_C(  37),
                           INT8_C( -93), INT8_C(  57), INT8_C(  28), INT8_C(-116),
                           INT8_C(  56), INT8_C(-124), INT8_C( -93), INT8_C( -67),
                           INT8_C(  27), INT8_C(  -1), INT8_C( -70), INT8_C( -30),
                           INT8_C( -39), INT8_C(  59), INT8_C(  76), INT8_C( 108),
                           INT8_C(  13), INT8_C( -29), INT8_C(  60), INT8_C( 106),
                           INT8_C( 106), INT8_C( -77), INT8_C(-102), INT8_C(   3),
                           INT8_C( -18), INT8_C(  23), INT8_C( 113), INT8_C( -97),
                           INT8_C( 109), INT8_C(  81), INT8_C(  42), INT8_C(  93)),
      simde_mm512_set_epi8(INT8_C(  17), INT8_C(   6), INT8_C(-128), INT8_C(  79),
                           INT8_C( 127), INT8_C(-128), INT8_C( 127), INT8_C( -20),
                           INT8_C( -41), INT8_C(-128), INT8_C( -63), INT8_C(  -9),
                           INT8_C( -17), INT8_C(  78), INT8_C( -62), INT8_C(-128),
                           INT8_C( -41), INT8_C( 127), INT8_C( 110), INT8_C(  93),
                           INT8_C( -61), INT8_C(  30), INT8_C(-102), INT8_C(  -5),
                           INT8_C(-128), INT8_C(  13), INT8_C(  53), INT8_C(  42),
                           INT8_C( -90), INT8_C( 109), INT8_C(  59), INT8_C( -86),
                           INT8_C(-128), INT8_C( 127), INT8_C(  65), INT8_C(-128),
                           INT8_C( -32), INT8_C(-109), INT8_C( -70), INT8_C(  47),
                           INT8_C(  90), INT8_C( -62), INT8_C( -48), INT8_C( -22),
                           INT8_C(  15), INT8_C(  78), INT8_C(  42), INT8_C( 126),
                           INT8_C( -23), INT8_C(  75), INT8_C(  61), INT8_C( 111),
                           INT8_C( -10), INT8_C(   2), INT8_C(-122), INT8_C(  -1),
                           INT8_C(  77), INT8_C( 126), INT8_C( 116), INT8_C( -33),
                           INT8_C( 127), INT8_C(  32), INT8_C(  15), INT8_C( 127)) },
    { simde_mm512_set_epi8(INT8_C( -94), INT8_C(  96), INT8_C( -77), INT8_C( -55),
                           INT8_C(  18), INT8_C(  12), INT8_C(  78), INT8_C( -17),
                           INT8_C( -94), INT8_C(  83), INT8_C( -20), INT8_C(-101),
                           INT8_C( -62), INT8_C( -62), INT8_C( -77), INT8_C(  21),
                           INT8_C(  21), INT8_C( -49), INT8_C(-127), INT8_C( -47),
                           INT8_C( -26), INT8_C(  62), INT8_C( -51), INT8_C( -34),
                           INT8_C(   9), INT8_C( -56), INT8_C(  63), INT8_C(   4),
                           INT8_C(  64), INT8_C(  46), INT8_C(  68), INT8_C( -18),
                           INT8_C(-110), INT8_C( 103), INT8_C(-101), INT8_C(  45),
                           INT8_C( -81), INT8_C( 125), INT8_C(   8), INT8_C(  72),
                           INT8_C( -48), INT8_C( -28), INT8_C( 102), INT8_C( -90),
                           INT8_C(-101), INT8_C( -40), INT8_C( -94), INT8_C(-127),
                           INT8_C( -36), INT8_C( -32), INT8_C(  34), INT8_C( -39),
                           INT8_C( -64), INT8_C( 111), INT8_C(  36), INT8_C(  91),
                           INT8_C(  90), INT8_C( -10), INT8_C(  88), INT8_C(-117),
                           INT8_C( 117), INT8_C(-111), INT8_C(-128), INT8_C( -35)),
      simde_mm512_set_epi8(INT8_C(  65), INT8_C(  -2), INT8_C(   4), INT8_C( -77),
                           INT8_C(  33), INT8_C(-119), INT8_C( -36), INT8_C(  95),
                           INT8_C( -54), INT8_C(  57), INT8_C( -15), INT8_C(  20),
                           INT8_C( 119), INT8_C( -56), INT8_C( -57), INT8_C(  22),
                           INT8_C( -23), INT8_C( -56), INT8_C( -77), INT8_C( 114),
                           INT8_C( -25), INT8_C(  85), INT8_C(  65), INT8_C( 124),
                           INT8_C(  80), INT8_C(  94), INT8_C(  -6), INT8_C(-128),
                           INT8_C(  25), INT8_C( -80), INT8_C(  31), INT8_C( -23),
                           INT8_C( 123), INT8_C(-123), INT8_C( -56), INT8_C(  34),
                           INT8_C(  72), INT8_C( -39), INT8_C( -17), INT8_C(  39),
                           INT8_C(  29), INT8_C( -88), INT8_C(  65), INT8_C(  81),
                           INT8_C(-120), INT8_C(  80), INT8_C( -76), INT8_C( -59),
                           INT8_C(  48), INT8_C( -90), INT8_C( -85), INT8_C(  82),
                           INT8_C( 115), INT8_C(-114), INT8_C(  84), INT8_C( -40),
                           INT8_C( -69), INT8_C( -11), INT8_C(-118), INT8_C(  39),
                           INT8_C( -17), INT8_C( -23), INT8_C(   4), INT8_C( -37)),
      simde_mm512_set_epi8(INT8_C( -29), INT8_C(  94), INT8_C( -73), INT8_C(-128),
                           INT8_C(  51), INT8_C(-107), INT8_C(  42), INT8_C(  78),
                           INT8_C(-128), INT8_C( 127), INT8_C( -35), INT8_C( -81),
                           INT8_C(  57), INT8_C(-118), INT8_C(-128), INT8_C(  43),
                           INT8_C(  -2), INT8_C(-105), INT8_C(-128), INT8_C(  67),
                           INT8_C( -51), INT8_C( 127), INT8_C(  14), INT8_C(  90),
                           INT8_C(  89), INT8_C(  38), INT8_C(  57), INT8_C(-124),
                           INT8_C(  89), INT8_C( -34), INT8_C(  99), INT8_C( -41),
                           INT8_C(  13), INT8_C( -20), INT8_C(-128), INT8_C(  79),
                           INT8_C(  -9), INT8_C(  86), INT8_C(  -9), INT8_C( 111),
                           INT8_C( -19), INT8_C(-116), INT8_C( 127), INT8_C(  -9),
                           INT8_C(-128), INT8_C(  40), INT8_C(-128), INT8_C(-128),
                           INT8_C(  12), INT8_C(-122), INT8_C( -51), INT8_C(  43),
                           INT8_C(  51), INT8_C(  -3), INT8_C( 120), INT8_C(  51),
                           INT8_C(  21), INT8_C( -21), INT8_C( -30), INT8_C( -78),
                           INT8_C( 100), INT8_C(-128), INT8_C(-124), INT8_C( -72)) },
    { simde_mm512_set_epi8(INT8_C(  31), INT8_C( -81), INT8_C( 115), INT8_C(  18),
                           INT8_C(  20), INT8_C( -33), INT8_C(-125), INT8_C( -45),
                           INT8_C(  54), INT8_C(  82), INT8_C(  61), INT8_C(  81),
                           INT8_C( 123), INT8_C(  18), INT8_C(  89), INT8_C(  34),
                           INT8_C(  10), INT8_C( -54), INT8_C( -24), INT8_C(  54),
                           INT8_C(  49), INT8_C( -70), INT8_C(   7), INT8_C( -12),
                           INT8_C( 110), INT8_C( -16), INT8_C( -10), INT8_C(   4),
                           INT8_C(   3), INT8_C( -17), INT8_C( -46), INT8_C( -29),
                           INT8_C(  26), INT8_C( -38), INT8_C(-107), INT8_C( -25),
                           INT8_C(  61), INT8_C(  -4), INT8_C( -21), INT8_C( -11),
                           INT8_C( -29), INT8_C(  62), INT8_C( 120), INT8_C(  84),
                           INT8_C( -48), INT8_C( -42), INT8_C( -15), INT8_C( -64),
                           INT8_C( -90), INT8_C( 111), INT8_C(-123), INT8_C(  61),
                           INT8_C(  22), INT8_C( -48), INT8_C(-107), INT8_C( 122),
                           INT8_C(  27), INT8_C( 119), INT8_C( -63), INT8_C( -61),
                           INT8_C( -69), INT8_C(  46), INT8_C(  34), INT8_C(-101)),
      simde_mm512_set_epi8(INT8_C(  44), INT8_C( 101), INT8_C( -48), INT8_C( -49),
                           INT8_C(  63), INT8_C(  93), INT8_C( -48), INT8_C(-122),
                           INT8_C( -67), INT8_C(  27), INT8_C(   1), INT8_C( -55),
                           INT8_C( -79), INT8_C( -44), INT8_C(-115), INT8_C(-126),
                           INT8_C( -42), INT8_C(  29), INT8_C(  66), INT8_C( -83),
                           INT8_C( 108), INT8_C(  -1), INT8_C( -47), INT8_C(-104),
                           INT8_C(  62), INT8_C(  29), INT8_C(   4), INT8_C( -47),
                           INT8_C(  98), INT8_C(-109), INT8_C( -23), INT8_C(  69),
                           INT8_C(-110), INT8_C( -47), INT8_C(  48), INT8_C(-101),
                           INT8_C( -80), INT8_C(-110), INT8_C( -55), INT8_C(  25),
                           INT8_C(  39), INT8_C(  58), INT8_C(   4), INT8_C(-108),
                           INT8_C( -23), INT8_C( -79), INT8_C( 124), INT8_C(  36),
                           INT8_C( 113), INT8_C( 110), INT8_C( 105), INT8_C( 113),
                           INT8_C( -54), INT8_C( -63), INT8_C(  50), INT8_C( -99),
                           INT8_C(  -8), INT8_C( -76), INT8_C( 102), INT8_C(  51),
                           INT8_C(  58), INT8_C(  16), INT8_C( -94), INT8_C( -93)),
      simde_mm512_set_epi8(INT8_C(  75), INT8_C(  20), INT8_C(  67), INT8_C( -31),
                           INT8_C(  83), INT8_C(  60), INT8_C(-128), INT8_C(-128),
                           INT8_C( -13), INT8_C( 109), INT8_C(  62), INT8_C(  26),
                           INT8_C(  44), INT8_C( -26), INT8_C( -26), INT8_C( -92),
                           INT8_C( -32), INT8_C( -25), INT8_C(  42), INT8_C( -29),
                           INT8_C( 127), INT8_C( -71), INT8_C( -40), INT8_C(-116),
                           INT8_C( 127), INT8_C(  13), INT8_C(  -6), INT8_C( -43),
                           INT8_C( 101), INT8_C(-126), INT8_C( -69), INT8_C(  40),
                           INT8_C( -84), INT8_C( -85), INT8_C( -59), INT8_C(-126),
                           INT8_C( -19), INT8_C(-114), INT8_C( -76), INT8_C(  14),
                           INT8_C(  10), INT8_C( 120), INT8_C( 124), INT8_C( -24),
                           INT8_C( -71), INT8_C(-121), INT8_C( 109), INT8_C( -28),
                           INT8_C(  23), INT8_C( 127), INT8_C( -18), INT8_C( 127),
                           INT8_C( -32), INT8_C(-111), INT8_C( -57), INT8_C(  23),
                           INT8_C(  19), INT8_C(  43), INT8_C(  39), INT8_C( -10),
                           INT8_C( -11), INT8_C(  62), INT8_C( -60), INT8_C(-128)) },
    { simde_mm512_set_epi8(INT8_C(  64), INT8_C(  55), INT8_C(  97), INT8_C( -61),
                           INT8_C(  89), INT8_C( 120), INT8_C(  49), INT8_C( 124),
                           INT8_C(  16), INT8_C( 113), INT8_C(  48), INT8_C(  70),
                           INT8_C(  60), INT8_C( -11), INT8_C(  98), INT8_C(  70),
                           INT8_C( 111), INT8_C(  55), INT8_C( -50), INT8_C( -21),
                           INT8_C(-102), INT8_C(   3), INT8_C(  75), INT8_C(  -9),
                           INT8_C(  34), INT8_C(  96), INT8_C(-104), INT8_C(  37),
                           INT8_C(  74), INT8_C(  22), INT8_C(  13), INT8_C(  82),
                           INT8_C(-108), INT8_C(-112), INT8_C(  49), INT8_C( -58),
                           INT8_C( 116), INT8_C(  58), INT8_C( -29), INT8_C(  60),
                           INT8_C( 125), INT8_C( 105), INT8_C( -20), INT8_C(  -4),
                           INT8_C(-106), INT8_C(-111), INT8_C( -29), INT8_C( -32),
                           INT8_C( -43), INT8_C(-103), INT8_C(  84), INT8_C(  40),
                           INT8_C(  63), INT8_C(  88), INT8_C( -74), INT8_C( -49),
                           INT8_C(  10), INT8_C(  50), INT8_C(  38), INT8_C( 108),
                           INT8_C(  42), INT8_C( -40), INT8_C( -81), INT8_C(  31)),
      simde_mm512_set_epi8(INT8_C(-107), INT8_C( 105), INT8_C( -15), INT8_C( -49),
                           INT8_C(  74), INT8_C( -31), INT8_C( -49), INT8_C( 112),
                           INT8_C(-103), INT8_C(  69), INT8_C( -55), INT8_C(-115),
                           INT8_C( -48), INT8_C(  96), INT8_C(  -8), INT8_C( -35),
                           INT8_C( -24), INT8_C( 101), INT8_C(  70), INT8_C( -69),
                           INT8_C(-105), INT8_C( -28), INT8_C( -38), INT8_C( -85),
                           INT8_C( -94), INT8_C(-122), INT8_C( -80), INT8_C(  95),
                           INT8_C(  -1), INT8_C(  87), INT8_C(  21), INT8_C(   6),
                           INT8_C(-103), INT8_C(  38), INT8_C(  15), INT8_C( -98),
                           INT8_C( -27), INT8_C(  57), INT8_C( -76), INT8_C(-112),
                           INT8_C(  77), INT8_C(  -3), INT8_C(  57), INT8_C(   3),
                           INT8_C( 123), INT8_C( -18), INT8_C( -90), INT8_C(-119),
                           INT8_C( 112), INT8_C(  61), INT8_C( -48), INT8_C( -16),
                           INT8_C( -36), INT8_C(-125), INT8_C( -10), INT8_C(  77),
                           INT8_C( 106), INT8_C(  72), INT8_C(  62), INT8_C( -24),
                           INT8_C( -65), INT8_C( 102), INT8_C(-122), INT8_C(  19)),
      simde_mm512_set_epi8(INT8_C( -43), INT8_C( 127), INT8_C(  82), INT8_C(-110),
                           INT8_C( 127), INT8_C(  89), INT8_C(   0), INT8_C( 127),
                           INT8_C( -87), INT8_C( 127), INT8_C(  -7), INT8_C( -45),
                           INT8_C(  12), INT8_C(  85), INT8_C(  90), INT8_C(  35),
                           INT8_C(  87), INT8_C( 127), INT8_C(  20), INT8_C( -90),
                           INT8_C(-128), INT8_C( -25), INT8_C(  37), INT8_C( -94),
                           INT8_C( -60), INT8_C( -26), INT8_C(-128), INT8_C( 127),
                           INT8_C(  73), INT8_C( 109), INT8_C(  34), INT8_C(  88),
                           INT8_C(-128), INT8_C( -74), INT8_C(  64), INT8_C(-128),
                           INT8_C(  89), INT8_C( 115), INT8_C(-105), INT8_C( -52),
                           INT8_C( 127), INT8_C( 102), INT8_C(  37), INT8_C(  -1),
                           INT8_C(  17), INT8_C(-128), INT8_C(-119), INT8_C(-128),
                           INT8_C(  69), INT8_C( -42), INT8_C(  36), INT8_C(  24),
                           INT8_C(  27), INT8_C( -37), INT8_C( -84), INT8_C(  28),
                           INT8_C( 116), INT8_C( 122), INT8_C( 100), INT8_C(  84),
                           INT8_C( -23), INT8_C(  62), INT8_C(-128), INT8_C(  50)) },
    { simde_mm512_set_epi8(INT8_C(  90), INT8_C(-125), INT8_C(  -5), INT8_C( -69),
                           INT8_C( 103), INT8_C( -40), INT8_C(  35), INT8_C( -38),
                           INT8_C( 107), INT8_C(-117), INT8_C( -80), INT8_C( 123),
                           INT8_C(  57), INT8_C( -70), INT8_C( -34), INT8_C(  38),
                           INT8_C( 114), INT8_C(-126), INT8_C(  20), INT8_C( -93),
                           INT8_C(  17), INT8_C(-128), INT8_C(   2), INT8_C(  15),
                           INT8_C(-122), INT8_C( -10), INT8_C(  -2), INT8_C(  84),
                           INT8_C(  93), INT8_C(  89), INT8_C(  57), INT8_C( -50),
                           INT8_C(   4), INT8_C( -63), INT8_C( 118), INT8_C(  19),
                           INT8_C( -68), INT8_C( -29), INT8_C( -16), INT8_C( -30),
                           INT8_C( -76), INT8_C(-110), INT8_C( 121), INT8_C(  87),
                           INT8_C(-117), INT8_C(-113), INT8_C( -94), INT8_C(  61),
                           INT8_C( -29), INT8_C(  43), INT8_C( -69), INT8_C( 123),
                           INT8_C(  79), INT8_C(-101), INT8_C(  40), INT8_C(  64),
                           INT8_C(  34), INT8_C(-102), INT8_C(  77), INT8_C( 114),
                           INT8_C( -49), INT8_C( -31), INT8_C( 103), INT8_C(  81)),
      simde_mm512_set_epi8(INT8_C(  34), INT8_C(-125), INT8_C( -96), INT8_C(-111),
                           INT8_C(  23), INT8_C(  58), INT8_C(  -5), INT8_C( -22),
                           INT8_C( -80), INT8_C( -90), INT8_C( -33), INT8_C( -65),
                           INT8_C( -34), INT8_C( 100), INT8_C( -10), INT8_C( -57),
                           INT8_C(  37), INT8_C(  -9), INT8_C( -29), INT8_C(-114),
                           INT8_C(-102), INT8_C(  53), INT8_C( 107), INT8_C( 124),
                           INT8_C( -12), INT8_C( -57), INT8_C( -57), INT8_C( -37),
                           INT8_C(  50), INT8_C(  22), INT8_C( -71), INT8_C(  -2),
                           INT8_C( -31), INT8_C(  60), INT8_C(  62), INT8_C(  19),
                           INT8_C( 117), INT8_C(   1), INT8_C( -26), INT8_C(-100),
                           INT8_C(  29), INT8_C(  -6), INT8_C(   7), INT8_C(-100),
                           INT8_C(-120), INT8_C( -33), INT8_C(  17), INT8_C(-103),
                           INT8_C(  10), INT8_C( -45), INT8_C( -76), INT8_C(  10),
                           INT8_C( -10), INT8_C(  15), INT8_C(  36), INT8_C(   2),
                           INT8_C(  74), INT8_C(  44), INT8_C( -16), INT8_C( 122),
                           INT8_C(  -4), INT8_C(  15), INT8_C( -27), INT8_C( -15)),
      simde_mm512_set_epi8(INT8_C( 124), INT8_C(-128), INT8_C(-101), INT8_C(-128),
                           INT8_C( 126), INT8_C(  18), INT8_C(  30), INT8_C( -60),
                           INT8_C(  27), INT8_C(-128), INT8_C(-113), INT8_C(  58),
                           INT8_C(  23), INT8_C(  30), INT8_C( -44), INT8_C( -19),
                           INT8_C( 127), INT8_C(-128), INT8_C(  -9), INT8_C(-128),
                           INT8_C( -85), INT8_C( -75), INT8_C( 109), INT8_C( 127),
                           INT8_C(-128), INT8_C( -67), INT8_C( -59), INT8_C(  47),
                           INT8_C( 127), INT8_C( 111), INT8_C( -14), INT8_C( -52),
                           INT8_C( -27), INT8_C(  -3), INT8_C( 127), INT8_C(  38),
                           INT8_C(  49), INT8_C( -28), INT8_C( -42), INT8_C(-128),
                           INT8_C( -47), INT8_C(-116), INT8_C( 127), INT8_C( -13),
                           INT8_C(-128), INT8_C(-128), INT8_C( -77), INT8_C( -42),
                           INT8_C( -19), INT8_C(  -2), INT8_C(-128), INT8_C( 127),
                           INT8_C(  69), INT8_C( -86), INT8_C(  76), INT8_C(  66),
                           INT8_C( 108), INT8_C( -58), INT8_C(  61), INT8_C( 127),
                           INT8_C( -53), INT8_C( -16), INT8_C(  76), INT8_C(  66)) },
    { simde_mm512_set_epi8(INT8_C( -52), INT8_C(-111), INT8_C(  67), INT8_C( -14),
                           INT8_C(  11), INT8_C( -63), INT8_C( -35), INT8_C( -86),
                           INT8_C(-114), INT8_C( -97), INT8_C( 124), INT8_C( -30),
                           INT8_C(  -1), INT8_C(  55), INT8_C(  84), INT8_C(  12),
                           INT8_C(  86), INT8_C( -43), INT8_C(  81), INT8_C( -30),
                           INT8_C( -25), INT8_C(  74), INT8_C(-105), INT8_C(  11),
                           INT8_C( -97), INT8_C(   0), INT8_C(  98), INT8_C( 106),
                           INT8_C( -83), INT8_C( -89), INT8_C(  16), INT8_C( -42),
                           INT8_C(  81), INT8_C(  35), INT8_C(-127), INT8_C(-127),
                           INT8_C( -38), INT8_C(  51), INT8_C( -75), INT8_C(  24),
                           INT8_C(  86), INT8_C( -37), INT8_C(  97), INT8_C( -82),
                           INT8_C( 109), INT8_C(  21), INT8_C( 127), INT8_C(  16),
                           INT8_C( 101), INT8_C( -69), INT8_C(  95), INT8_C(-121),
                           INT8_C( -66), INT8_C(  39), INT8_C( 104), INT8_C(-109),
                           INT8_C(  -1), INT8_C(  35), INT8_C(  68), INT8_C(  93),
                           INT8_C( -25), INT8_C( 120), INT8_C( -19), INT8_C(  84)),
      simde_mm512_set_epi8(INT8_C(-111), INT8_C(-108), INT8_C( 102), INT8_C( -40),
                           INT8_C(-124), INT8_C( -61), INT8_C(  80), INT8_C( 102),
                           INT8_C( -35), INT8_C(   3), INT8_C( -76), INT8_C(  98),
                           INT8_C(   9), INT8_C( -39), INT8_C( -24), INT8_C( -92),
                           INT8_C( -73), INT8_C( -19), INT8_C(-103), INT8_C( -41),
                           INT8_C( -32), INT8_C(  -8), INT8_C( 126), INT8_C(  75),
                           INT8_C( -64), INT8_C( -26), INT8_C( -15), INT8_C( -35),
                           INT8_C( -20), INT8_C(  -6), INT8_C(  86), INT8_C( -56),
                           INT8_C( -56), INT8_C(  67), INT8_C(  59), INT8_C( -73),
                           INT8_C(  35), INT8_C( -67), INT8_C(  92), INT8_C(  34),
                           INT8_C(  16), INT8_C( -12), INT8_C(  44), INT8_C( -59),
                           INT8_C( -82), INT8_C(-102), INT8_C(  93), INT8_C( -43),
                           INT8_C(  79), INT8_C( -19), INT8_C( -45), INT8_C( -87),
                           INT8_C( -50), INT8_C( -23), INT8_C( -17), INT8_C( 110),
                           INT8_C( 102), INT8_C( -59), INT8_C(-117), INT8_C(  84),
                           INT8_C( -75), INT8_C(  87), INT8_C(  69), INT8_C(  -6)),
      simde_mm512_set_epi8(INT8_C(-128), INT8_C(-128), INT8_C( 127), INT8_C( -54),
                           INT8_C(-113), INT8_C(-124), INT8_C(  45), INT8_C(  16),
                           INT8_C(-128), INT8_C( -94), INT8_C(  48), INT8_C(  68),
                           INT8_C(   8), INT8_C(  16), INT8_C(  60), INT8_C( -80),
                           INT8_C(  13), INT8_C( -62), INT8_C( -22), INT8_C( -71),
                           INT8_C( -57), INT8_C(  66), INT8_C(  21), INT8_C(  86),
                           INT8_C(-128), INT8_C( -26), INT8_C(  83), INT8_C(  71),
                           INT8_C(-103), INT8_C( -95), INT8_C( 102), INT8_C( -98),
                           INT8_C(  25), INT8_C( 102), INT8_C( -68), INT8_C(-128),
                           INT8_C(  -3), INT8_C( -16), INT8_C(  17), INT8_C(  58),
                           INT8_C( 102), INT8_C( -49), INT8_C( 127), INT8_C(-128),
                           INT8_C(  27), INT8_C( -81), INT8_C( 127), INT8_C( -27),
                           INT8_C( 127), INT8_C( -88), INT8_C(  50), INT8_C(-128),
                           INT8_C(-116), INT8_C(  16), INT8_C(  87), INT8_C(   1),
                           INT8_C( 101), INT8_C( -24), INT8_C( -49), INT8_C( 127),
                           INT8_C(-100), INT8_C( 127), INT8_C(  50), INT8_C(  78)) }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])); i++) {
    simde__m512i r = simde_mm512_adds_epi8(test_vec[i].a, test_vec[i].b);
    simde_assert_m512i_i8(r, ==, test_vec[i].r);
  }

  return 0;
}

static int
test_simde_mm512_mask_adds_epi8(SIMDE_MUNIT_TEST_ARGS) {
  const struct {
    simde__m512i src;
    simde__mmask64 k;
    simde__m512i a;
    simde__m512i b;
    simde__m512i r;
  } test_vec[8] = {
    { simde_mm512_set_epi8(INT8_C(  92), INT8_C( 116), INT8_C( -78), INT8_C( -19),
                           INT8_C( -73), INT8_C(  22), INT8_C( -66), INT8_C( -29),
                           INT8_C(  55), INT8_C(  78), INT8_C( -45), INT8_C(-119),
                           INT8_C(  30), INT8_C( -29), INT8_C( -23), INT8_C(  89),
                           INT8_C(  15), INT8_C( 119), INT8_C( -88), INT8_C( 109),
                           INT8_C( -16), INT8_C( -10), INT8_C(   0), INT8_C( -18),
                           INT8_C(   1), INT8_C( 116), INT8_C(  62), INT8_C( -73),
                           INT8_C(-122), INT8_C(   0), INT8_C( 111), INT8_C(  95),
                           INT8_C( -20), INT8_C(   3), INT8_C( 122), INT8_C(-121),
                           INT8_C(  13), INT8_C(  25), INT8_C( -35), INT8_C(-127),
                           INT8_C(  82), INT8_C(  90), INT8_C(  53), INT8_C( 123),
                           INT8_C(  73), INT8_C( 108), INT8_C( -18), INT8_C(  15),
                           INT8_C(  81), INT8_C( -27), INT8_C( 102), INT8_C( 118),
                           INT8_C(  39), INT8_C( -77), INT8_C(  45), INT8_C(  81),
                           INT8_C( -17), INT8_C( -28), INT8_C(  67), INT8_C(-118),
                           INT8_C(  79), INT8_C(-113), INT8_C(-122), INT8_C( 124)),
      UINT64_C(10224647434006242820),
      simde_mm512_set_epi8(INT8_C(  68), INT8_C(-108), INT8_C(-121), INT8_C(-115),
                           INT8_C( -59), INT8_C( -78), INT8_C(-111), INT8_C(  56),
                           INT8_C(   9), INT8_C(-121), INT8_C( 120), INT8_C( -36),
                           INT8_C(  36), INT8_C(-103), INT8_C(-104), INT8_C(  25),
                           INT8_C(-111), INT8_C( -63), INT8_C( -35), INT8_C(-120),
                           INT8_C(  28), INT8_C( -44), INT8_C( -26), INT8_C( -86),
                           INT8_C( -13), INT8_C(  53), INT8_C( -88), INT8_C(-107),
                           INT8_C(  68), INT8_C(  42), INT8_C(-118), INT8_C( 111),
                           INT8_C(  54), INT8_C( -58), INT8_C( -13), INT8_C(  27),
                           INT8_C(  23), INT8_C(  41), INT8_C(-119), INT8_C(  44),
                           INT8_C(   7), INT8_C(-120), INT8_C(  32), INT8_C( -43),
                           INT8_C( 114), INT8_C( -72), INT8_C(  73), INT8_C( -96),
                           INT8_C(  96), INT8_C( 110), INT8_C( -81), INT8_C( -76),
                           INT8_C( 103), INT8_C(-100), INT8_C( -22), INT8_C(  18),
                           INT8_C( 115), INT8_C(  54), INT8_C( -40), INT8_C( 125),
                           INT8_C( 110), INT8_C(  31), INT8_C(  51), INT8_C(-104)),
      simde_mm512_set_epi8(INT8_C( -14), INT8_C(  85), INT8_C( -80), INT8_C(  80),
                           INT8_C(  48), INT8_C(  93), INT8_C(  79), INT8_C( 127),
                           INT8_C(  16), INT8_C(  41), INT8_C(  54), INT8_C(-116),
                           INT8_C(  17), INT8_C(  42), INT8_C( -86), INT8_C(  38),
                           INT8_C(-118), INT8_C( -56), INT8_C(  60), INT8_C(  19),
                           INT8_C(-100), INT8_C(-107), INT8_C( 105), INT8_C( -76),
                           INT8_C(  10), INT8_C(  -9), INT8_C( -12), INT8_C( -56),
                           INT8_C( -71), INT8_C(  96), INT8_C(   6), INT8_C(  24),
                           INT8_C(  69), INT8_C(  73), INT8_C( -27), INT8_C(   3),
                           INT8_C( -95), INT8_C(  50), INT8_C( -67), INT8_C( -39),
                           INT8_C(  97), INT8_C(  62), INT8_C( 101), INT8_C(  56),
                           INT8_C( -79), INT8_C(  83), INT8_C( -99), INT8_C( -56),
                           INT8_C( -17), INT8_C( -56), INT8_C(  -8), INT8_C( -16),
                           INT8_C(  84), INT8_C( -95), INT8_C( -73), INT8_C(  54),
                           INT8_C( 125), INT8_C(  85), INT8_C(  78), INT8_C( -65),
                           INT8_C(   4), INT8_C( 113), INT8_C( -16), INT8_C( -53)),
      simde_mm512_set_epi8(INT8_C(  54), INT8_C( 116), INT8_C( -78), INT8_C( -19),
                           INT8_C( -11), INT8_C(  15), INT8_C( -66), INT8_C( 127),
                           INT8_C(  25), INT8_C( -80), INT8_C( 127), INT8_C(-119),
                           INT8_C(  30), INT8_C( -61), INT8_C( -23), INT8_C(  63),
                           INT8_C(  15), INT8_C( 119), INT8_C(  25), INT8_C(-101),
                           INT8_C( -72), INT8_C(-128), INT8_C(  79), INT8_C( -18),
                           INT8_C(  -3), INT8_C( 116), INT8_C(-100), INT8_C( -73),
                           INT8_C(  -3), INT8_C(   0), INT8_C(-112), INT8_C( 127),
                           INT8_C( -20), INT8_C(   3), INT8_C( -40), INT8_C(  30),
                           INT8_C(  13), INT8_C(  25), INT8_C( -35), INT8_C(   5),
                           INT8_C( 104), INT8_C(  90), INT8_C(  53), INT8_C( 123),
                           INT8_C(  35), INT8_C(  11), INT8_C( -18), INT8_C(-128),
                           INT8_C(  81), INT8_C( -27), INT8_C( -89), INT8_C( 118),
                           INT8_C(  39), INT8_C(-128), INT8_C( -95), INT8_C(  81),
                           INT8_C( -17), INT8_C( -28), INT8_C(  67), INT8_C(-118),
                           INT8_C(  79), INT8_C( 127), INT8_C(-122), INT8_C( 124)) },
    { simde_mm512_set_epi8(INT8_C(-123), INT8_C(-100), INT8_C( -39), INT8_C( -44),
                           INT8_C(  22), INT8_C( 112), INT8_C(  16), INT8_C(  15),
                           INT8_C(-104), INT8_C(-102), INT8_C( 102), INT8_C( -95),
                           INT8_C(  69), INT8_C(  13), INT8_C( -21), INT8_C(  45),
                           INT8_C(  62), INT8_C(-120), INT8_C(-111), INT8_C(  32),
                           INT8_C(-107), INT8_C( -30), INT8_C(  99), INT8_C( -64),
                           INT8_C(   8), INT8_C( -42), INT8_C(  81), INT8_C( -34),
                           INT8_C( -46), INT8_C(  26), INT8_C(  31), INT8_C(  -2),
                           INT8_C(  68), INT8_C(  -7), INT8_C( -71), INT8_C(  46),
                           INT8_C( -21), INT8_C( -73), INT8_C(  21), INT8_C(  83),
                           INT8_C(-108), INT8_C( -97), INT8_C( -69), INT8_C(  73),
                           INT8_C(  57), INT8_C( -37), INT8_C(  21), INT8_C(  82),
                           INT8_C(-119), INT8_C(-126), INT8_C( 126), INT8_C(  91),
                           INT8_C( 115), INT8_C(  31), INT8_C( -79), INT8_C(  28),
                           INT8_C(-106), INT8_C( -18), INT8_C(  65), INT8_C(-104),
                           INT8_C(  81), INT8_C(  38), INT8_C( -84), INT8_C(  -2)),
      UINT64_C( 4597426592773770833),
      simde_mm512_set_epi8(INT8_C(  74), INT8_C(  72), INT8_C(  -4), INT8_C(  28),
                           INT8_C(-115), INT8_C(  93), INT8_C( 102), INT8_C(  44),
                           INT8_C(-103), INT8_C( -29), INT8_C( -50), INT8_C(  48),
                           INT8_C( -96), INT8_C( -50), INT8_C(  46), INT8_C( -65),
                           INT8_C(   4), INT8_C(  43), INT8_C( -75), INT8_C(  97),
                           INT8_C( -26), INT8_C(-103), INT8_C(  71), INT8_C(-107),
                           INT8_C(  91), INT8_C(  45), INT8_C( -11), INT8_C(  47),
                           INT8_C(  29), INT8_C(  25), INT8_C(  26), INT8_C(  -9),
                           INT8_C(  10), INT8_C(  36), INT8_C( -79), INT8_C( -53),
                           INT8_C(  41), INT8_C(   1), INT8_C( -23), INT8_C( -63),
                           INT8_C(-127), INT8_C(  68), INT8_C(  48), INT8_C(  36),
                           INT8_C(  89), INT8_C(-112), INT8_C( -31), INT8_C( 120),
                           INT8_C(  35), INT8_C(  62), INT8_C( -21), INT8_C(-114),
                           INT8_C(-104), INT8_C(  57), INT8_C(  42), INT8_C(-111),
                           INT8_C(  94), INT8_C( -63), INT8_C(  -9), INT8_C(  64),
                           INT8_C( -65), INT8_C(  -2), INT8_C( 110), INT8_C(  -8)),
      simde_mm512_set_epi8(INT8_C(  44), INT8_C( -92), INT8_C( -31), INT8_C(  26),
                           INT8_C( -99), INT8_C( -53), INT8_C( 117), INT8_C(  18),
                           INT8_C( -63), INT8_C(  45), INT8_C(  12), INT8_C(  24),
                           INT8_C(-108), INT8_C(  18), INT8_C( -60), INT8_C(  28),
                           INT8_C(  50), INT8_C( -11), INT8_C( -68), INT8_C( -31),
                           INT8_C( 105), INT8_C(-106), INT8_C(  98), INT8_C(  51),
                           INT8_C(  58), INT8_C( 103), INT8_C( 111), INT8_C(-127),
                           INT8_C(  68), INT8_C( -56), INT8_C( 124), INT8_C(-119),
                           INT8_C(  74), INT8_C( -62), INT8_C(-116), INT8_C(  37),
                           INT8_C( -12), INT8_C( 114), INT8_C(   0), INT8_C(  61),
                           INT8_C( 103), INT8_C(  -4), INT8_C(-105), INT8_C( -68),
                           INT8_C(  39), INT8_C(-100), INT8_C( -93), INT8_C(  11),
                           INT8_C( -80), INT8_C( -19), INT8_C( -22), INT8_C( -39),
                           INT8_C( 127), INT8_C( -38), INT8_C(-125), INT8_C(-111),
                           INT8_C(  84), INT8_C( -96), INT8_C(  87), INT8_C( -22),
                           INT8_C(  -5), INT8_C(  -3), INT8_C(-127), INT8_C(  41)),
      simde_mm512_set_epi8(INT8_C(-123), INT8_C(-100), INT8_C( -35), INT8_C(  54),
                           INT8_C(-128), INT8_C(  40), INT8_C( 127), INT8_C(  62),
                           INT8_C(-128), INT8_C(  16), INT8_C( 102), INT8_C( -95),
                           INT8_C(-128), INT8_C( -32), INT8_C( -21), INT8_C( -37),
                           INT8_C(  62), INT8_C(  32), INT8_C(-111), INT8_C(  66),
                           INT8_C(-107), INT8_C(-128), INT8_C( 127), INT8_C( -56),
                           INT8_C(   8), INT8_C( -42), INT8_C( 100), INT8_C( -34),
                           INT8_C( -46), INT8_C(  26), INT8_C(  31), INT8_C(  -2),
                           INT8_C(  84), INT8_C(  -7), INT8_C(-128), INT8_C( -16),
                           INT8_C(  29), INT8_C( 115), INT8_C( -23), INT8_C(  -2),
                           INT8_C(-108), INT8_C( -97), INT8_C( -57), INT8_C( -32),
                           INT8_C(  57), INT8_C(-128), INT8_C(-124), INT8_C( 127),
                           INT8_C(-119), INT8_C(-126), INT8_C( 126), INT8_C(  91),
                           INT8_C(  23), INT8_C(  19), INT8_C( -83), INT8_C(  28),
                           INT8_C(-106), INT8_C(-128), INT8_C(  65), INT8_C(  42),
                           INT8_C(  81), INT8_C(  38), INT8_C( -84), INT8_C(  33)) },
    { simde_mm512_set_epi8(INT8_C( -30), INT8_C( -37), INT8_C(  51), INT8_C( -36),
                           INT8_C(   8), INT8_C(  52), INT8_C(  97), INT8_C( 123),
                           INT8_C( -49), INT8_C(-124), INT8_C(  95), INT8_C( -83),
                           INT8_C(  70), INT8_C( -50), INT8_C( -61), INT8_C(  25),
                           INT8_C( -97), INT8_C(  28), INT8_C( -58), INT8_C(  11),
                           INT8_C( -14), INT8_C( 126), INT8_C(  81), INT8_C(  45),
                           INT8_C( -23), INT8_C( 120), INT8_C( -83), INT8_C( -16),
                           INT8_C(   7), INT8_C(  51), INT8_C( -57), INT8_C( -50),
                           INT8_C( -21), INT8_C(  98), INT8_C(  88), INT8_C(   0),
                           INT8_C( -66), INT8_C(   3), INT8_C( 124), INT8_C(-113),
                           INT8_C(  50), INT8_C(  88), INT8_C( -85), INT8_C( -93),
                           INT8_C( -44), INT8_C( -13), INT8_C( -94), INT8_C(  17),
                           INT8_C(  -2), INT8_C(  79), INT8_C(-116), INT8_C(  43),
                           INT8_C( -77), INT8_C(-125), INT8_C( -23), INT8_C(-120),
                           INT8_C(  96), INT8_C( -64), INT8_C( -23), INT8_C( -46),
                           INT8_C( -29), INT8_C( -71), INT8_C(  71), INT8_C(  90)),
      UINT64_C(12627002542648829104),
      simde_mm512_set_epi8(INT8_C(  56), INT8_C( -45), INT8_C(-108), INT8_C( -19),
                           INT8_C(-124), INT8_C( -27), INT8_C(  22), INT8_C( 126),
                           INT8_C(-106), INT8_C( -68), INT8_C( -60), INT8_C(   8),
                           INT8_C(  60), INT8_C(  93), INT8_C( -33), INT8_C( -27),
                           INT8_C(  -7), INT8_C(  27), INT8_C(-122), INT8_C( -38),
                           INT8_C(  23), INT8_C(   6), INT8_C(  45), INT8_C( -21),
                           INT8_C( -23), INT8_C(-101), INT8_C( 116), INT8_C( 127),
                           INT8_C(  96), INT8_C(  40), INT8_C( -97), INT8_C(  40),
                           INT8_C(  86), INT8_C( -44), INT8_C(  70), INT8_C( -71),
                           INT8_C(  62), INT8_C( -21), INT8_C(  66), INT8_C(  68),
                           INT8_C( -87), INT8_C( -61), INT8_C(  48), INT8_C( -70),
                           INT8_C(  18), INT8_C( -78), INT8_C( -98), INT8_C( 117),
                           INT8_C(  74), INT8_C(  32), INT8_C(  93), INT8_C( 125),
                           INT8_C( -47), INT8_C( -60), INT8_C( -86), INT8_C( 117),
                           INT8_C( 122), INT8_C( -54), INT8_C(  50), INT8_C( 123),
                           INT8_C( -31), INT8_C( -74), INT8_C( -64), INT8_C(  54)),
      simde_mm512_set_epi8(INT8_C( 115), INT8_C(  51), INT8_C( -91), INT8_C(  56),
                           INT8_C(  64), INT8_C( -39), INT8_C(-119), INT8_C( -28),
                           INT8_C( -54), INT8_C(  28), INT8_C(  54), INT8_C(  -8),
                           INT8_C( -54), INT8_C(-128), INT8_C( -28), INT8_C( -71),
                           INT8_C( 107), INT8_C( -66), INT8_C(-114), INT8_C( -88),
                           INT8_C(  34), INT8_C( -83), INT8_C( -21), INT8_C( -64),
                           INT8_C( 121), INT8_C( -20), INT8_C( -89), INT8_C( -94),
                           INT8_C( 112), INT8_C( -27), INT8_C(  81), INT8_C( -54),
                           INT8_C( -64), INT8_C(-114), INT8_C(  48), INT8_C( -89),
                           INT8_C( -61), INT8_C(  26), INT8_C(  43), INT8_C(  29),
                           INT8_C(   0), INT8_C(  64), INT8_C( 123), INT8_C( -67),
                           INT8_C(  15), INT8_C( 120), INT8_C(  36), INT8_C(  40),
                           INT8_C( 106), INT8_C(-118), INT8_C(-108), INT8_C( -58),
                           INT8_C(  26), INT8_C(-111), INT8_C(  63), INT8_C( -98),
                           INT8_C( -13), INT8_C( -12), INT8_C(-124), INT8_C(  96),
                           INT8_C( -13), INT8_C( -98), INT8_C(  99), INT8_C( -13)),
      simde_mm512_set_epi8(INT8_C( 127), INT8_C( -37), INT8_C(-128), INT8_C( -36),
                           INT8_C( -60), INT8_C( -66), INT8_C( -97), INT8_C(  98),
                           INT8_C( -49), INT8_C(-124), INT8_C(  -6), INT8_C(   0),
                           INT8_C(   6), INT8_C( -35), INT8_C( -61), INT8_C(  25),
                           INT8_C( -97), INT8_C(  28), INT8_C( -58), INT8_C(-126),
                           INT8_C(  57), INT8_C( -77), INT8_C(  24), INT8_C( -85),
                           INT8_C(  98), INT8_C(-121), INT8_C(  27), INT8_C( -16),
                           INT8_C( 127), INT8_C(  51), INT8_C( -57), INT8_C( -14),
                           INT8_C( -21), INT8_C(-128), INT8_C( 118), INT8_C(   0),
                           INT8_C(   1), INT8_C(   5), INT8_C( 124), INT8_C(-113),
                           INT8_C( -87), INT8_C(  88), INT8_C( -85), INT8_C( -93),
                           INT8_C(  33), INT8_C( -13), INT8_C( -94), INT8_C( 127),
                           INT8_C( 127), INT8_C(  79), INT8_C( -15), INT8_C(  43),
                           INT8_C( -77), INT8_C(-128), INT8_C( -23), INT8_C(-120),
                           INT8_C( 109), INT8_C( -64), INT8_C( -74), INT8_C( 127),
                           INT8_C( -29), INT8_C( -71), INT8_C(  71), INT8_C(  90)) },
    { simde_mm512_set_epi8(INT8_C(  72), INT8_C(  45), INT8_C( 120), INT8_C(  -5),
                           INT8_C(-109), INT8_C(  62), INT8_C(  17), INT8_C(  31),
                           INT8_C( -30), INT8_C( -58), INT8_C(  56), INT8_C(  21),
                           INT8_C(  72), INT8_C( -74), INT8_C( -40), INT8_C( 120),
                           INT8_C(  95), INT8_C( 108), INT8_C(  32), INT8_C(  64),
                           INT8_C(-128), INT8_C( 102), INT8_C( -21), INT8_C(  28),
                           INT8_C( 105), INT8_C(  52), INT8_C(  85), INT8_C(-104),
                           INT8_C(  57), INT8_C( -31), INT8_C( -38), INT8_C(-124),
                           INT8_C(-107), INT8_C(  -2), INT8_C(  55), INT8_C(  46),
                           INT8_C( -71), INT8_C(  77), INT8_C(  18), INT8_C(  70),
                           INT8_C(  89), INT8_C( 125), INT8_C( -42), INT8_C(-125),
                           INT8_C( 121), INT8_C( -11), INT8_C( -69), INT8_C( -59),
                           INT8_C( -53), INT8_C(  34), INT8_C(   9), INT8_C(  64),
                           INT8_C( -61), INT8_C( -25), INT8_C(-115), INT8_C( 100),
                           INT8_C(  65), INT8_C(   8), INT8_C(  69), INT8_C(  -8),
                           INT8_C( -15), INT8_C( -51), INT8_C(   1), INT8_C(  90)),
      UINT64_C(14515151237088493607),
      simde_mm512_set_epi8(INT8_C( -26), INT8_C(  -9), INT8_C(  66), INT8_C(   1),
                           INT8_C( -13), INT8_C(  60), INT8_C(-119), INT8_C( -83),
                           INT8_C(-122), INT8_C( -64), INT8_C( -83), INT8_C( -74),
                           INT8_C( 119), INT8_C(  -8), INT8_C(  12), INT8_C( 113),
                           INT8_C( -12), INT8_C( -84), INT8_C(   6), INT8_C(  69),
                           INT8_C(   2), INT8_C( -75), INT8_C( -34), INT8_C(-126),
                           INT8_C(   3), INT8_C(-128), INT8_C(  -9), INT8_C(  24),
                           INT8_C(  11), INT8_C( -94), INT8_C( -32), INT8_C( 110),
                           INT8_C(  33), INT8_C( -24), INT8_C( 125), INT8_C(  35),
                           INT8_C(-103), INT8_C( -48), INT8_C( -22), INT8_C(  38),
                           INT8_C( -81), INT8_C(   9), INT8_C( -11), INT8_C(-124),
                           INT8_C(  71), INT8_C(  31), INT8_C( -42), INT8_C(  93),
                           INT8_C(  67), INT8_C(  45), INT8_C(  51), INT8_C( -92),
                           INT8_C( 126), INT8_C( 108), INT8_C(-123), INT8_C( -71),
                           INT8_C( 113), INT8_C(  32), INT8_C(  71), INT8_C(  55),
                           INT8_C( -26), INT8_C(  82), INT8_C( -81), INT8_C( -20)),
      simde_mm512_set_epi8(INT8_C(-125), INT8_C( 121), INT8_C(-128), INT8_C( 103),
                           INT8_C(   0), INT8_C( 101), INT8_C( -41), INT8_C(  89),
                           INT8_C( -83), INT8_C( -65), INT8_C(   9), INT8_C(  -7),
                           INT8_C( -63), INT8_C(  13), INT8_C( 105), INT8_C(  92),
                           INT8_C( -18), INT8_C( -21), INT8_C(-102), INT8_C(-114),
                           INT8_C(  74), INT8_C( 121), INT8_C( -45), INT8_C(  52),
                           INT8_C( -63), INT8_C( -93), INT8_C(  98), INT8_C( 106),
                           INT8_C(-109), INT8_C( -47), INT8_C(  37), INT8_C(  70),
                           INT8_C( 100), INT8_C( 121), INT8_C(  18), INT8_C(  28),
                           INT8_C(-117), INT8_C( 107), INT8_C(   3), INT8_C( -62),
                           INT8_C(  42), INT8_C(  72), INT8_C(  91), INT8_C(  86),
                           INT8_C( -72), INT8_C(   9), INT8_C( -80), INT8_C( 118),
                           INT8_C( 122), INT8_C(-108), INT8_C( -70), INT8_C( -63),
                           INT8_C(  56), INT8_C(  71), INT8_C( -14), INT8_C(  49),
                           INT8_C( -73), INT8_C(  53), INT8_C( -29), INT8_C(   3),
                           INT8_C( -73), INT8_C(  43), INT8_C( -22), INT8_C(  85)),
      simde_mm512_set_epi8(INT8_C(-128), INT8_C( 112), INT8_C( 120), INT8_C(  -5),
                           INT8_C( -13), INT8_C(  62), INT8_C(  17), INT8_C(   6),
                           INT8_C( -30), INT8_C(-128), INT8_C( -74), INT8_C( -81),
                           INT8_C(  72), INT8_C( -74), INT8_C( -40), INT8_C( 120),
                           INT8_C(  95), INT8_C( 108), INT8_C( -96), INT8_C(  64),
                           INT8_C(  76), INT8_C(  46), INT8_C( -21), INT8_C( -74),
                           INT8_C( 105), INT8_C(  52), INT8_C(  89), INT8_C(-104),
                           INT8_C(  57), INT8_C(-128), INT8_C( -38), INT8_C( 127),
                           INT8_C(-107), INT8_C(  97), INT8_C(  55), INT8_C(  46),
                           INT8_C( -71), INT8_C(  77), INT8_C( -19), INT8_C( -24),
                           INT8_C( -39), INT8_C( 125), INT8_C(  80), INT8_C( -38),
                           INT8_C(  -1), INT8_C( -11), INT8_C(-122), INT8_C( 127),
                           INT8_C( -53), INT8_C( -63), INT8_C(   9), INT8_C(  64),
                           INT8_C( -61), INT8_C( -25), INT8_C(-115), INT8_C( 100),
                           INT8_C(  65), INT8_C(   8), INT8_C(  42), INT8_C(  -8),
                           INT8_C( -15), INT8_C( 125), INT8_C(-103), INT8_C(  65)) },
    { simde_mm512_set_epi8(INT8_C( -47), INT8_C(  84), INT8_C(-126), INT8_C( -64),
                           INT8_C(  14), INT8_C(  11), INT8_C(  37), INT8_C( -23),
                           INT8_C(  67), INT8_C( 124), INT8_C(  58), INT8_C( -94),
                           INT8_C(  30), INT8_C( -33), INT8_C(  70), INT8_C( -24),
                           INT8_C(  38), INT8_C( -97), INT8_C( -56), INT8_C( -60),
                           INT8_C( -59), INT8_C(  65), INT8_C( -74), INT8_C(  45),
                           INT8_C( -11), INT8_C(  55), INT8_C( -82), INT8_C(  12),
                           INT8_C( 106), INT8_C(  22), INT8_C(-124), INT8_C(  -4),
                           INT8_C(   2), INT8_C( -81), INT8_C(  14), INT8_C(  90),
                           INT8_C(-100), INT8_C(-122), INT8_C( -35), INT8_C(  81),
                           INT8_C( -14), INT8_C( -42), INT8_C( 125), INT8_C(-125),
                           INT8_C( -57), INT8_C(  90), INT8_C(  -9), INT8_C(  63),
                           INT8_C(  53), INT8_C(  77), INT8_C(  63), INT8_C( -84),
                           INT8_C(  27), INT8_C(  22), INT8_C(   3), INT8_C( -37),
                           INT8_C(  65), INT8_C( 118), INT8_C(-126), INT8_C(  97),
                           INT8_C( 109), INT8_C(   7), INT8_C(-114), INT8_C( -75)),
      UINT64_C( 8707623543556880126),
      simde_mm512_set_epi8(INT8_C(  84), INT8_C( -71), INT8_C(   8), INT8_C(  12),
                           INT8_C( -11), INT8_C( -76), INT8_C(  62), INT8_C(  93),
                           INT8_C( -75), INT8_C( -77), INT8_C( -84), INT8_C(-108),
                           INT8_C( -35), INT8_C(  14), INT8_C( -60), INT8_C(  18),
                           INT8_C(  23), INT8_C( -60), INT8_C( -63), INT8_C(-114),
                           INT8_C( -55), INT8_C(  75), INT8_C( -99), INT8_C( -55),
                           INT8_C(  58), INT8_C(  76), INT8_C(-102), INT8_C(-118),
                           INT8_C( -30), INT8_C(  39), INT8_C( 119), INT8_C(  85),
                           INT8_C(  -8), INT8_C( -72), INT8_C( -60), INT8_C( -94),
                           INT8_C(-112), INT8_C( 119), INT8_C( 124), INT8_C(  76),
                           INT8_C( -42), INT8_C(-124), INT8_C(  54), INT8_C(  74),
                           INT8_C( -92), INT8_C(  99), INT8_C(  79), INT8_C(  -3),
                           INT8_C(  61), INT8_C( -89), INT8_C(  84), INT8_C( -94),
                           INT8_C(  31), INT8_C(-116), INT8_C( -67), INT8_C(-102),
                           INT8_C( -72), INT8_C( -91), INT8_C(-105), INT8_C(-108),
                           INT8_C( -44), INT8_C(  74), INT8_C( -28), INT8_C( 124)),
      simde_mm512_set_epi8(INT8_C(   1), INT8_C(  75), INT8_C(  21), INT8_C( -36),
                           INT8_C(-126), INT8_C( 122), INT8_C(  71), INT8_C(  76),
                           INT8_C(  28), INT8_C( -56), INT8_C(  32), INT8_C( 101),
                           INT8_C(-107), INT8_C(-111), INT8_C( -88), INT8_C( -19),
                           INT8_C( -77), INT8_C(  19), INT8_C( -21), INT8_C(-111),
                           INT8_C( -68), INT8_C(  82), INT8_C(-118), INT8_C( -76),
                           INT8_C(  47), INT8_C( 127), INT8_C(  62), INT8_C( -16),
                           INT8_C(  10), INT8_C( -14), INT8_C(-100), INT8_C(  86),
                           INT8_C(  29), INT8_C( 107), INT8_C(  56), INT8_C(  21),
                           INT8_C(  24), INT8_C(  68), INT8_C( -96), INT8_C(  64),
                           INT8_C(  48), INT8_C(  13), INT8_C( -83), INT8_C(   4),
                           INT8_C(  -3), INT8_C( -64), INT8_C(  17), INT8_C(-115),
                           INT8_C(  21), INT8_C( 108), INT8_C( 125), INT8_C( -60),
                           INT8_C( -72), INT8_C(  74), INT8_C(  -5), INT8_C( -58),
                           INT8_C( -41), INT8_C(  22), INT8_C(-115), INT8_C( 102),
                           INT8_C(  59), INT8_C( -80), INT8_C( -15), INT8_C( -63)),
      simde_mm512_set_epi8(INT8_C( -47), INT8_C(   4), INT8_C(  29), INT8_C( -24),
                           INT8_C(-128), INT8_C(  11), INT8_C(  37), INT8_C( -23),
                           INT8_C( -47), INT8_C(-128), INT8_C(  58), INT8_C(  -7),
                           INT8_C(  30), INT8_C( -97), INT8_C(-128), INT8_C(  -1),
                           INT8_C( -54), INT8_C( -97), INT8_C( -84), INT8_C(-128),
                           INT8_C( -59), INT8_C(  65), INT8_C( -74), INT8_C(-128),
                           INT8_C( -11), INT8_C( 127), INT8_C( -40), INT8_C(-128),
                           INT8_C( -20), INT8_C(  22), INT8_C(  19), INT8_C(  -4),
                           INT8_C(   2), INT8_C(  35), INT8_C(  14), INT8_C( -73),
                           INT8_C(-100), INT8_C( 127), INT8_C(  28), INT8_C( 127),
                           INT8_C(   6), INT8_C( -42), INT8_C( 125), INT8_C(-125),
                           INT8_C( -95), INT8_C(  90), INT8_C(  -9), INT8_C(-118),
                           INT8_C(  53), INT8_C(  77), INT8_C( 127), INT8_C(-128),
                           INT8_C(  27), INT8_C( -42), INT8_C( -72), INT8_C( -37),
                           INT8_C(-113), INT8_C( -69), INT8_C(-128), INT8_C(  -6),
                           INT8_C(  15), INT8_C(  -6), INT8_C( -43), INT8_C( -75)) },
    { simde_mm512_set_epi8(INT8_C( -64), INT8_C( -53), INT8_C( -42), INT8_C( 126),
                           INT8_C(  67), INT8_C(  50), INT8_C( -18), INT8_C(  76),
                           INT8_C( -19), INT8_C( 123), INT8_C( -87), INT8_C( 106),
                           INT8_C( -74), INT8_C(  44), INT8_C( 117), INT8_C( 103),
                           INT8_C(  81), INT8_C( 122), INT8_C(  56), INT8_C( -10),
                           INT8_C(  67), INT8_C(  79), INT8_C(  83), INT8_C( -38),
                           INT8_C( -13), INT8_C(  43), INT8_C(  27), INT8_C( -97),
                           INT8_C( 102), INT8_C( 126), INT8_C(  38), INT8_C( -62),
                           INT8_C( -24), INT8_C( 117), INT8_C( -38), INT8_C( -93),
                           INT8_C( -58), INT8_C(-124), INT8_C( -75), INT8_C(  10),
                           INT8_C(  18), INT8_C( -74), INT8_C(  14), INT8_C(  36),
                           INT8_C(  -7), INT8_C( 113), INT8_C(  40), INT8_C(  48),
                           INT8_C(-107), INT8_C( -34), INT8_C( -75), INT8_C(  85),
                           INT8_C( -35), INT8_C(-116), INT8_C(  65), INT8_C( -21),
                           INT8_C(  15), INT8_C(   3), INT8_C(  45), INT8_C(  21),
                           INT8_C(  72), INT8_C(  93), INT8_C( 108), INT8_C( 125)),
      UINT64_C(12576710173448868104),
      simde_mm512_set_epi8(INT8_C(  90), INT8_C( -38), INT8_C( -98), INT8_C( -70),
                           INT8_C(-108), INT8_C(  20), INT8_C(  43), INT8_C(-128),
                           INT8_C(  77), INT8_C( 108), INT8_C(  53), INT8_C(  82),
                           INT8_C( -50), INT8_C(  52), INT8_C(  56), INT8_C(  58),
                           INT8_C(-120), INT8_C( -43), INT8_C( 114), INT8_C(  93),
                           INT8_C( -44), INT8_C( -15), INT8_C(  38), INT8_C( -17),
                           INT8_C(-110), INT8_C(-123), INT8_C( -39), INT8_C( 114),
                           INT8_C(  51), INT8_C(-115), INT8_C( -74), INT8_C(  43),
                           INT8_C(  41), INT8_C( -36), INT8_C(  19), INT8_C(  69),
                           INT8_C(  60), INT8_C( -53), INT8_C( 112), INT8_C( 108),
                           INT8_C(   8), INT8_C(  46), INT8_C( -35), INT8_C(  26),
                           INT8_C(  11), INT8_C(  42), INT8_C(  47), INT8_C(  59),
                           INT8_C( -57), INT8_C(  94), INT8_C(-125), INT8_C(-124),
                           INT8_C(  36), INT8_C(  57), INT8_C(  68), INT8_C( -52),
                           INT8_C(  39), INT8_C(  50), INT8_C( -48), INT8_C(  94),
                           INT8_C(  53), INT8_C(  11), INT8_C(  29), INT8_C(  65)),
      simde_mm512_set_epi8(INT8_C(-107), INT8_C( 120), INT8_C( -58), INT8_C( 107),
                           INT8_C( -32), INT8_C( -32), INT8_C(  88), INT8_C( -43),
                           INT8_C(  31), INT8_C( -32), INT8_C( -64), INT8_C(  27),
                           INT8_C(  82), INT8_C( -90), INT8_C( -54), INT8_C( -84),
                           INT8_C( -30), INT8_C(  63), INT8_C(  24), INT8_C(  81),
                           INT8_C(  -8), INT8_C(   9), INT8_C( -35), INT8_C(-101),
                           INT8_C(  83), INT8_C( 107), INT8_C( -47), INT8_C( -56),
                           INT8_C(  57), INT8_C( -88), INT8_C(-115), INT8_C( -20),
                           INT8_C(  58), INT8_C(  75), INT8_C(  56), INT8_C(  93),
                           INT8_C(  49), INT8_C(  43), INT8_C( 108), INT8_C( 118),
                           INT8_C( -79), INT8_C( 112), INT8_C(  44), INT8_C(-112),
                           INT8_C( -52), INT8_C(  10), INT8_C(  28), INT8_C( -86),
                           INT8_C(  65), INT8_C(  62), INT8_C(  86), INT8_C(-107),
                           INT8_C(  24), INT8_C( -55), INT8_C(  54), INT8_C(-110),
                           INT8_C( -33), INT8_C( 110), INT8_C(-116), INT8_C( -39),
                           INT8_C(  39), INT8_C(-112), INT8_C(  64), INT8_C(  43)),
      simde_mm512_set_epi8(INT8_C( -17), INT8_C( -53), INT8_C(-128), INT8_C( 126),
                           INT8_C(-128), INT8_C( -12), INT8_C( 127), INT8_C(  76),
                           INT8_C( 108), INT8_C( 123), INT8_C( -87), INT8_C( 106),
                           INT8_C(  32), INT8_C(  44), INT8_C( 117), INT8_C( -26),
                           INT8_C(  81), INT8_C(  20), INT8_C( 127), INT8_C( 127),
                           INT8_C(  67), INT8_C(  79), INT8_C(   3), INT8_C(-118),
                           INT8_C( -13), INT8_C( -16), INT8_C(  27), INT8_C( -97),
                           INT8_C( 102), INT8_C(-128), INT8_C(  38), INT8_C( -62),
                           INT8_C(  99), INT8_C( 117), INT8_C(  75), INT8_C( 127),
                           INT8_C( 109), INT8_C(-124), INT8_C( 127), INT8_C( 127),
                           INT8_C(  18), INT8_C( 127), INT8_C(   9), INT8_C( -86),
                           INT8_C(  -7), INT8_C(  52), INT8_C(  75), INT8_C(  48),
                           INT8_C(-107), INT8_C( -34), INT8_C( -75), INT8_C(-128),
                           INT8_C( -35), INT8_C(-116), INT8_C(  65), INT8_C(-128),
                           INT8_C(  15), INT8_C(   3), INT8_C(  45), INT8_C(  21),
                           INT8_C(  92), INT8_C(  93), INT8_C( 108), INT8_C( 125)) },
    { simde_mm512_set_epi8(INT8_C(-103), INT8_C(-124), INT8_C(  13), INT8_C( -80),
                           INT8_C( -32), INT8_C( 123), INT8_C( 115), INT8_C( -49),
                           INT8_C( 113), INT8_C( -51), INT8_C( 119), INT8_C( -67),
                           INT8_C( -21), INT8_C(  19), INT8_C( -12), INT8_C(  29),
                           INT8_C(  91), INT8_C( -64), INT8_C(  88), INT8_C(-105),
                           INT8_C(  24), INT8_C(  31), INT8_C(  77), INT8_C(  92),
                           INT8_C( -85), INT8_C(  48), INT8_C(-113), INT8_C(-114),
                           INT8_C(  16), INT8_C(  18), INT8_C( -44), INT8_C( -66),
                           INT8_C(  25), INT8_C(-105), INT8_C(-100), INT8_C( -91),
                           INT8_C(  26), INT8_C(-123), INT8_C( -33), INT8_C( -37),
                           INT8_C(  63), INT8_C(  13), INT8_C(-124), INT8_C(  41),
                           INT8_C(-104), INT8_C( -59), INT8_C(  -2), INT8_C( -54),
                           INT8_C(  73), INT8_C(   3), INT8_C( -18), INT8_C(  10),
                           INT8_C(  19), INT8_C(  58), INT8_C( -12), INT8_C( -75),
                           INT8_C( -88), INT8_C(  59), INT8_C( 104), INT8_C( -40),
                           INT8_C( -82), INT8_C(  42), INT8_C( -73), INT8_C( -94)),
      UINT64_C( 2633789449456316803),
      simde_mm512_set_epi8(INT8_C( 118), INT8_C(  44), INT8_C( -14), INT8_C(  84),
                           INT8_C( -69), INT8_C( -48), INT8_C(  40), INT8_C(  86),
                           INT8_C(  -1), INT8_C( 121), INT8_C( -40), INT8_C(  44),
                           INT8_C(  -1), INT8_C(  38), INT8_C( -44), INT8_C(  38),
                           INT8_C(  93), INT8_C(-107), INT8_C(  -4), INT8_C( -61),
                           INT8_C( -52), INT8_C(  22), INT8_C( -54), INT8_C(-125),
                           INT8_C( -29), INT8_C(  25), INT8_C( -77), INT8_C( -68),
                           INT8_C(   9), INT8_C( -35), INT8_C( -11), INT8_C(  53),
                           INT8_C(  28), INT8_C(  61), INT8_C( -35), INT8_C(-106),
                           INT8_C( -46), INT8_C( 121), INT8_C(-102), INT8_C( 121),
                           INT8_C( -54), INT8_C( -60), INT8_C(   7), INT8_C(   2),
                           INT8_C(-119), INT8_C( 111), INT8_C( -20), INT8_C( -58),
                           INT8_C( -98), INT8_C(  83), INT8_C(  32), INT8_C( -49),
                           INT8_C( -11), INT8_C(  48), INT8_C(  92), INT8_C(  47),
                           INT8_C( -38), INT8_C(  11), INT8_C(  26), INT8_C(  90),
                           INT8_C(  -5), INT8_C(  73), INT8_C(  45), INT8_C(  -2)),
      simde_mm512_set_epi8(INT8_C( -31), INT8_C( 126), INT8_C(-118), INT8_C( -57),
                           INT8_C(-126), INT8_C(  29), INT8_C( 101), INT8_C( -15),
                           INT8_C( -61), INT8_C( 118), INT8_C( 102), INT8_C(  12),
                           INT8_C( -59), INT8_C( -41), INT8_C( -60), INT8_C(  46),
                           INT8_C(  63), INT8_C(  78), INT8_C(  87), INT8_C(  18),
                           INT8_C(  18), INT8_C(  32), INT8_C( -26), INT8_C(  -6),
                           INT8_C( -20), INT8_C(-123), INT8_C(  99), INT8_C(  65),
                           INT8_C(  13), INT8_C(  25), INT8_C( 108), INT8_C(-121),
                           INT8_C(  42), INT8_C(   0), INT8_C( 104), INT8_C( -17),
                           INT8_C( 111), INT8_C(-110), INT8_C( -39), INT8_C( 125),
                           INT8_C( -50), INT8_C( -47), INT8_C(  30), INT8_C(  92),
                           INT8_C(  19), INT8_C(  -8), INT8_C(-120), INT8_C( 127),
                           INT8_C( -49), INT8_C(  23), INT8_C(  16), INT8_C( -64),
                           INT8_C( -79), INT8_C( 116), INT8_C(  -5), INT8_C( -50),
                           INT8_C(  32), INT8_C(  22), INT8_C( -42), INT8_C(  -3),
                           INT8_C(  30), INT8_C(  64), INT8_C(  96), INT8_C( -66)),
      simde_mm512_set_epi8(INT8_C(-103), INT8_C(-124), INT8_C(-128), INT8_C( -80),
                           INT8_C( -32), INT8_C( -19), INT8_C( 115), INT8_C( -49),
                           INT8_C( -62), INT8_C( -51), INT8_C( 119), INT8_C( -67),
                           INT8_C( -60), INT8_C(  -3), INT8_C( -12), INT8_C(  84),
                           INT8_C(  91), INT8_C( -64), INT8_C(  88), INT8_C( -43),
                           INT8_C( -34), INT8_C(  31), INT8_C(  77), INT8_C(-128),
                           INT8_C( -49), INT8_C(  48), INT8_C(-113), INT8_C(-114),
                           INT8_C(  22), INT8_C( -10), INT8_C( -44), INT8_C( -66),
                           INT8_C(  70), INT8_C(  61), INT8_C(-100), INT8_C( -91),
                           INT8_C(  26), INT8_C(  11), INT8_C( -33), INT8_C( -37),
                           INT8_C(  63), INT8_C(  13), INT8_C(-124), INT8_C(  41),
                           INT8_C(-104), INT8_C( -59), INT8_C(-128), INT8_C(  69),
                           INT8_C(-128), INT8_C( 106), INT8_C(  48), INT8_C(-113),
                           INT8_C(  19), INT8_C(  58), INT8_C( -12), INT8_C(  -3),
                           INT8_C(  -6), INT8_C(  59), INT8_C( 104), INT8_C( -40),
                           INT8_C( -82), INT8_C(  42), INT8_C( 127), INT8_C( -68)) },
    { simde_mm512_set_epi8(INT8_C( 117), INT8_C(  69), INT8_C( 121), INT8_C( -45),
                           INT8_C(  30), INT8_C( -73), INT8_C(   2), INT8_C( -40),
                           INT8_C(  95), INT8_C(  -3), INT8_C(  16), INT8_C( -78),
                           INT8_C(-128), INT8_C( -41), INT8_C( -66), INT8_C(  66),
                           INT8_C(  93), INT8_C( -32), INT8_C( -50), INT8_C(  -2),
                           INT8_C( -61), INT8_C(  29), INT8_C( -88), INT8_C(-118),
                           INT8_C( -27), INT8_C(  42), INT8_C(  78), INT8_C( -46),
                           INT8_C( -79), INT8_C(  38), INT8_C( -75), INT8_C(  14),
                           INT8_C(-118), INT8_C(-114), INT8_C(-120), INT8_C(  42),
                           INT8_C(   4), INT8_C(  79), INT8_C( -84), INT8_C(-110),
                           INT8_C(   0), INT8_C(  85), INT8_C( -20), INT8_C(  61),
                           INT8_C(  40), INT8_C( -75), INT8_C(  69), INT8_C( -99),
                           INT8_C(  73), INT8_C( -34), INT8_C( -14), INT8_C(  72),
                           INT8_C( 101), INT8_C(  96), INT8_C(-114), INT8_C(-124),
                           INT8_C( -87), INT8_C(  43), INT8_C(-118), INT8_C( 114),
                           INT8_C( -88), INT8_C(   8), INT8_C( -52), INT8_C(  75)),
      UINT64_C(14890918166471265655),
      simde_mm512_set_epi8(INT8_C( -56), INT8_C( -70), INT8_C(  66), INT8_C(-111),
                           INT8_C( -69), INT8_C(  15), INT8_C( -82), INT8_C( -12),
                           INT8_C( -89), INT8_C(  37), INT8_C(  80), INT8_C( 120),
                           INT8_C( -83), INT8_C(-120), INT8_C(  95), INT8_C(  21),
                           INT8_C(  91), INT8_C( -97), INT8_C( -72), INT8_C(  42),
                           INT8_C(  22), INT8_C( -70), INT8_C(  71), INT8_C( -78),
                           INT8_C(  -5), INT8_C(  52), INT8_C( -22), INT8_C( -34),
                           INT8_C(  16), INT8_C(  92), INT8_C(  91), INT8_C( -72),
                           INT8_C(   3), INT8_C( -31), INT8_C( -95), INT8_C( -56),
                           INT8_C( -50), INT8_C(  68), INT8_C( -24), INT8_C( -50),
                           INT8_C(  94), INT8_C(  67), INT8_C( 108), INT8_C(-118),
                           INT8_C( -65), INT8_C(  31), INT8_C(  70), INT8_C( 108),
                           INT8_C( -66), INT8_C( 107), INT8_C( -85), INT8_C(  38),
                           INT8_C(   2), INT8_C(  32), INT8_C(  56), INT8_C(  66),
                           INT8_C(  -2), INT8_C( -74), INT8_C( 112), INT8_C(  10),
                           INT8_C(  64), INT8_C( 100), INT8_C( -55), INT8_C(  83)),
      simde_mm512_set_epi8(INT8_C( -69), INT8_C( -45), INT8_C(  23), INT8_C(  70),
                           INT8_C(  22), INT8_C( 113), INT8_C(  75), INT8_C(-117),
                           INT8_C(  69), INT8_C( -74), INT8_C(  40), INT8_C( -39),
                           INT8_C( -51), INT8_C( -91), INT8_C(  25), INT8_C(  -4),
                           INT8_C( -12), INT8_C( -13), INT8_C( -77), INT8_C(  75),
                           INT8_C(-116), INT8_C( -36), INT8_C(  38), INT8_C( -52),
                           INT8_C(  13), INT8_C( -52), INT8_C(-100), INT8_C( -46),
                           INT8_C(  13), INT8_C(  83), INT8_C( -94), INT8_C( 102),
                           INT8_C( 116), INT8_C( -60), INT8_C(  44), INT8_C(  -7),
                           INT8_C( 104), INT8_C( -50), INT8_C( -30), INT8_C(  17),
                           INT8_C(  13), INT8_C(-107), INT8_C( 111), INT8_C( -13),
                           INT8_C(  17), INT8_C( -45), INT8_C( -31), INT8_C(  76),
                           INT8_C(-102), INT8_C( -71), INT8_C( 116), INT8_C(  72),
                           INT8_C( -11), INT8_C( -97), INT8_C(  93), INT8_C(  48),
                           INT8_C( -75), INT8_C( -90), INT8_C( -10), INT8_C( -78),
                           INT8_C(  -8), INT8_C( -10), INT8_C(  48), INT8_C( -11)),
      simde_mm512_set_epi8(INT8_C(-125), INT8_C(-115), INT8_C( 121), INT8_C( -45),
                           INT8_C( -47), INT8_C( 127), INT8_C(  -7), INT8_C( -40),
                           INT8_C( -20), INT8_C(  -3), INT8_C( 120), INT8_C( -78),
                           INT8_C(-128), INT8_C(-128), INT8_C( 120), INT8_C(  17),
                           INT8_C(  93), INT8_C( -32), INT8_C(-128), INT8_C(  -2),
                           INT8_C( -94), INT8_C(  29), INT8_C( 109), INT8_C(-128),
                           INT8_C( -27), INT8_C(  42), INT8_C(-122), INT8_C( -46),
                           INT8_C(  29), INT8_C( 127), INT8_C( -75), INT8_C(  30),
                           INT8_C(-118), INT8_C( -91), INT8_C(-120), INT8_C(  42),
                           INT8_C(  54), INT8_C(  79), INT8_C( -54), INT8_C( -33),
                           INT8_C( 107), INT8_C( -40), INT8_C( 127), INT8_C(  61),
                           INT8_C( -48), INT8_C( -14), INT8_C(  39), INT8_C( -99),
                           INT8_C(  73), INT8_C(  36), INT8_C( -14), INT8_C(  72),
                           INT8_C(  -9), INT8_C( -65), INT8_C(-114), INT8_C( 114),
                           INT8_C( -87), INT8_C(-128), INT8_C( 102), INT8_C( -68),
                           INT8_C( -88), INT8_C(  90), INT8_C(  -7), INT8_C(  72)) },
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])); i++) {
    simde__m512i r = simde_mm512_mask_adds_epi8(test_vec[i].src, test_vec[i].k, test_vec[i].a, test_vec[i].b);
    simde_assert_m512i_i8(r, ==, test_vec[i].r);
  }

  return 0;
}

static int
test_simde_mm512_maskz_adds_epi8(SIMDE_MUNIT_TEST_ARGS) {
  const struct {
    simde__mmask64 k;
    simde__m512i a;
    simde__m512i b;
    simde__m512i r;
  } test_vec[8] = {
    { UINT64_C(17286015531074160252),
      simde_mm512_set_epi8(INT8_C(-115), INT8_C( -27), INT8_C(  62), INT8_C( -85),
                           INT8_C(  49), INT8_C(-115), INT8_C(  38), INT8_C(   4),
                           INT8_C(  92), INT8_C( 116), INT8_C( -78), INT8_C( -19),
                           INT8_C( -73), INT8_C(  22), INT8_C( -66), INT8_C( -29),
                           INT8_C(  55), INT8_C(  78), INT8_C( -45), INT8_C(-119),
                           INT8_C(  30), INT8_C( -29), INT8_C( -23), INT8_C(  89),
                           INT8_C(  15), INT8_C( 119), INT8_C( -88), INT8_C( 109),
                           INT8_C( -16), INT8_C( -10), INT8_C(   0), INT8_C( -18),
                           INT8_C(   1), INT8_C( 116), INT8_C(  62), INT8_C( -73),
                           INT8_C(-122), INT8_C(   0), INT8_C( 111), INT8_C(  95),
                           INT8_C( -20), INT8_C(   3), INT8_C( 122), INT8_C(-121),
                           INT8_C(  13), INT8_C(  25), INT8_C( -35), INT8_C(-127),
                           INT8_C(  82), INT8_C(  90), INT8_C(  53), INT8_C( 123),
                           INT8_C(  73), INT8_C( 108), INT8_C( -18), INT8_C(  15),
                           INT8_C(  81), INT8_C( -27), INT8_C( 102), INT8_C( 118),
                           INT8_C(  39), INT8_C( -77), INT8_C(  45), INT8_C(  81)),
      simde_mm512_set_epi8(INT8_C(  68), INT8_C(-108), INT8_C(-121), INT8_C(-115),
                           INT8_C( -59), INT8_C( -78), INT8_C(-111), INT8_C(  56),
                           INT8_C(   9), INT8_C(-121), INT8_C( 120), INT8_C( -36),
                           INT8_C(  36), INT8_C(-103), INT8_C(-104), INT8_C(  25),
                           INT8_C(-111), INT8_C( -63), INT8_C( -35), INT8_C(-120),
                           INT8_C(  28), INT8_C( -44), INT8_C( -26), INT8_C( -86),
                           INT8_C( -13), INT8_C(  53), INT8_C( -88), INT8_C(-107),
                           INT8_C(  68), INT8_C(  42), INT8_C(-118), INT8_C( 111),
                           INT8_C(  54), INT8_C( -58), INT8_C( -13), INT8_C(  27),
                           INT8_C(  23), INT8_C(  41), INT8_C(-119), INT8_C(  44),
                           INT8_C(   7), INT8_C(-120), INT8_C(  32), INT8_C( -43),
                           INT8_C( 114), INT8_C( -72), INT8_C(  73), INT8_C( -96),
                           INT8_C(  96), INT8_C( 110), INT8_C( -81), INT8_C( -76),
                           INT8_C( 103), INT8_C(-100), INT8_C( -22), INT8_C(  18),
                           INT8_C( 115), INT8_C(  54), INT8_C( -40), INT8_C( 125),
                           INT8_C( 110), INT8_C(  31), INT8_C(  51), INT8_C(-104)),
      simde_mm512_set_epi8(INT8_C( -47), INT8_C(-128), INT8_C( -59), INT8_C(   0),
                           INT8_C( -10), INT8_C(-128), INT8_C( -73), INT8_C(  60),
                           INT8_C( 101), INT8_C(  -5), INT8_C(  42), INT8_C(   0),
                           INT8_C(   0), INT8_C( -81), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(  15), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C( -49), INT8_C(   3),
                           INT8_C(   2), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(  52), INT8_C(   0), INT8_C(-118), INT8_C(   0),
                           INT8_C(   0), INT8_C(  58), INT8_C(   0), INT8_C(   0),
                           INT8_C( -99), INT8_C(  41), INT8_C(  -8), INT8_C( 127),
                           INT8_C( -13), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C( 127), INT8_C( -47), INT8_C(  38), INT8_C(-128),
                           INT8_C( 127), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   8), INT8_C( -40), INT8_C(   0),
                           INT8_C(   0), INT8_C(  27), INT8_C(  62), INT8_C( 127),
                           INT8_C( 127), INT8_C( -46), INT8_C(   0), INT8_C(   0)) },
    { UINT64_C( 9031211210081693899),
      simde_mm512_set_epi8(INT8_C(-106), INT8_C( -18), INT8_C(  65), INT8_C(-104),
                           INT8_C(  81), INT8_C(  38), INT8_C( -84), INT8_C(  -2),
                           INT8_C( -14), INT8_C(  85), INT8_C( -80), INT8_C(  80),
                           INT8_C(  48), INT8_C(  93), INT8_C(  79), INT8_C( 127),
                           INT8_C(  16), INT8_C(  41), INT8_C(  54), INT8_C(-116),
                           INT8_C(  17), INT8_C(  42), INT8_C( -86), INT8_C(  38),
                           INT8_C(-118), INT8_C( -56), INT8_C(  60), INT8_C(  19),
                           INT8_C(-100), INT8_C(-107), INT8_C( 105), INT8_C( -76),
                           INT8_C(  10), INT8_C(  -9), INT8_C( -12), INT8_C( -56),
                           INT8_C( -71), INT8_C(  96), INT8_C(   6), INT8_C(  24),
                           INT8_C(  69), INT8_C(  73), INT8_C( -27), INT8_C(   3),
                           INT8_C( -95), INT8_C(  50), INT8_C( -67), INT8_C( -39),
                           INT8_C(  97), INT8_C(  62), INT8_C( 101), INT8_C(  56),
                           INT8_C( -79), INT8_C(  83), INT8_C( -99), INT8_C( -56),
                           INT8_C( -17), INT8_C( -56), INT8_C(  -8), INT8_C( -16),
                           INT8_C(  84), INT8_C( -95), INT8_C( -73), INT8_C(  54)),
      simde_mm512_set_epi8(INT8_C(  63), INT8_C( -51), INT8_C(  87), INT8_C(  32),
                           INT8_C( -65), INT8_C(  55), INT8_C(  14), INT8_C(  81),
                           INT8_C(-123), INT8_C(-100), INT8_C( -39), INT8_C( -44),
                           INT8_C(  22), INT8_C( 112), INT8_C(  16), INT8_C(  15),
                           INT8_C(-104), INT8_C(-102), INT8_C( 102), INT8_C( -95),
                           INT8_C(  69), INT8_C(  13), INT8_C( -21), INT8_C(  45),
                           INT8_C(  62), INT8_C(-120), INT8_C(-111), INT8_C(  32),
                           INT8_C(-107), INT8_C( -30), INT8_C(  99), INT8_C( -64),
                           INT8_C(   8), INT8_C( -42), INT8_C(  81), INT8_C( -34),
                           INT8_C( -46), INT8_C(  26), INT8_C(  31), INT8_C(  -2),
                           INT8_C(  68), INT8_C(  -7), INT8_C( -71), INT8_C(  46),
                           INT8_C( -21), INT8_C( -73), INT8_C(  21), INT8_C(  83),
                           INT8_C(-108), INT8_C( -97), INT8_C( -69), INT8_C(  73),
                           INT8_C(  57), INT8_C( -37), INT8_C(  21), INT8_C(  82),
                           INT8_C(-119), INT8_C(-126), INT8_C( 126), INT8_C(  91),
                           INT8_C( 115), INT8_C(  31), INT8_C( -79), INT8_C(  28)),
      simde_mm512_set_epi8(INT8_C(   0), INT8_C( -69), INT8_C( 127), INT8_C( -72),
                           INT8_C(  16), INT8_C(  93), INT8_C(   0), INT8_C(  79),
                           INT8_C(   0), INT8_C( -15), INT8_C(   0), INT8_C(  36),
                           INT8_C(   0), INT8_C( 127), INT8_C(   0), INT8_C( 127),
                           INT8_C(   0), INT8_C( -61), INT8_C(   0), INT8_C(   0),
                           INT8_C(  86), INT8_C(  55), INT8_C(-107), INT8_C(   0),
                           INT8_C( -56), INT8_C(   0), INT8_C( -51), INT8_C(  51),
                           INT8_C(-128), INT8_C(-128), INT8_C( 127), INT8_C(-128),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C( 122), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(  66), INT8_C( -98), INT8_C(  49),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(  44),
                           INT8_C( -11), INT8_C( -35), INT8_C(  32), INT8_C( 127),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(-128), INT8_C(-128), INT8_C(   0), INT8_C(   0),
                           INT8_C( 127), INT8_C(   0), INT8_C(-128), INT8_C(  82)) },
    { UINT64_C( 6828010367541473016),
      simde_mm512_set_epi8(INT8_C(  84), INT8_C( -96), INT8_C(  87), INT8_C( -22),
                           INT8_C(  -5), INT8_C(  -3), INT8_C(-127), INT8_C(  41),
                           INT8_C(  74), INT8_C(  72), INT8_C(  -4), INT8_C(  28),
                           INT8_C(-115), INT8_C(  93), INT8_C( 102), INT8_C(  44),
                           INT8_C(-103), INT8_C( -29), INT8_C( -50), INT8_C(  48),
                           INT8_C( -96), INT8_C( -50), INT8_C(  46), INT8_C( -65),
                           INT8_C(   4), INT8_C(  43), INT8_C( -75), INT8_C(  97),
                           INT8_C( -26), INT8_C(-103), INT8_C(  71), INT8_C(-107),
                           INT8_C(  91), INT8_C(  45), INT8_C( -11), INT8_C(  47),
                           INT8_C(  29), INT8_C(  25), INT8_C(  26), INT8_C(  -9),
                           INT8_C(  10), INT8_C(  36), INT8_C( -79), INT8_C( -53),
                           INT8_C(  41), INT8_C(   1), INT8_C( -23), INT8_C( -63),
                           INT8_C(-127), INT8_C(  68), INT8_C(  48), INT8_C(  36),
                           INT8_C(  89), INT8_C(-112), INT8_C( -31), INT8_C( 120),
                           INT8_C(  35), INT8_C(  62), INT8_C( -21), INT8_C(-114),
                           INT8_C(-104), INT8_C(  57), INT8_C(  42), INT8_C(-111)),
      simde_mm512_set_epi8(INT8_C(  96), INT8_C( -64), INT8_C( -23), INT8_C( -46),
                           INT8_C( -29), INT8_C( -71), INT8_C(  71), INT8_C(  90),
                           INT8_C(  44), INT8_C( -92), INT8_C( -31), INT8_C(  26),
                           INT8_C( -99), INT8_C( -53), INT8_C( 117), INT8_C(  18),
                           INT8_C( -63), INT8_C(  45), INT8_C(  12), INT8_C(  24),
                           INT8_C(-108), INT8_C(  18), INT8_C( -60), INT8_C(  28),
                           INT8_C(  50), INT8_C( -11), INT8_C( -68), INT8_C( -31),
                           INT8_C( 105), INT8_C(-106), INT8_C(  98), INT8_C(  51),
                           INT8_C(  58), INT8_C( 103), INT8_C( 111), INT8_C(-127),
                           INT8_C(  68), INT8_C( -56), INT8_C( 124), INT8_C(-119),
                           INT8_C(  74), INT8_C( -62), INT8_C(-116), INT8_C(  37),
                           INT8_C( -12), INT8_C( 114), INT8_C(   0), INT8_C(  61),
                           INT8_C( 103), INT8_C(  -4), INT8_C(-105), INT8_C( -68),
                           INT8_C(  39), INT8_C(-100), INT8_C( -93), INT8_C(  11),
                           INT8_C( -80), INT8_C( -19), INT8_C( -22), INT8_C( -39),
                           INT8_C( 127), INT8_C( -38), INT8_C(-125), INT8_C(-111)),
      simde_mm512_set_epi8(INT8_C(   0), INT8_C(-128), INT8_C(   0), INT8_C( -68),
                           INT8_C( -34), INT8_C( -74), INT8_C( -56), INT8_C(   0),
                           INT8_C( 118), INT8_C( -20), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(  62),
                           INT8_C(-128), INT8_C(  16), INT8_C( -38), INT8_C(  72),
                           INT8_C(   0), INT8_C( -32), INT8_C( -14), INT8_C( -37),
                           INT8_C(   0), INT8_C(  32), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C( 127), INT8_C(   0), INT8_C( 100), INT8_C( -80),
                           INT8_C(  97), INT8_C( -31), INT8_C( 127), INT8_C(-128),
                           INT8_C(  84), INT8_C( -26), INT8_C(-128), INT8_C( -16),
                           INT8_C(  29), INT8_C( 115), INT8_C( -23), INT8_C(   0),
                           INT8_C(   0), INT8_C(  64), INT8_C( -57), INT8_C(   0),
                           INT8_C( 127), INT8_C(-128), INT8_C(-124), INT8_C(   0),
                           INT8_C( -45), INT8_C(  43), INT8_C( -43), INT8_C(-128),
                           INT8_C(  23), INT8_C(   0), INT8_C(   0), INT8_C(   0)) },
    { UINT64_C(18325019528117086600),
      simde_mm512_set_epi8(INT8_C( 122), INT8_C( -54), INT8_C(  50), INT8_C( 123),
                           INT8_C( -31), INT8_C( -74), INT8_C( -64), INT8_C(  54),
                           INT8_C( -81), INT8_C(  60), INT8_C(  31), INT8_C( -23),
                           INT8_C( 108), INT8_C(-119), INT8_C( -92), INT8_C( -80),
                           INT8_C( -30), INT8_C( -37), INT8_C(  51), INT8_C( -36),
                           INT8_C(   8), INT8_C(  52), INT8_C(  97), INT8_C( 123),
                           INT8_C( -49), INT8_C(-124), INT8_C(  95), INT8_C( -83),
                           INT8_C(  70), INT8_C( -50), INT8_C( -61), INT8_C(  25),
                           INT8_C( -97), INT8_C(  28), INT8_C( -58), INT8_C(  11),
                           INT8_C( -14), INT8_C( 126), INT8_C(  81), INT8_C(  45),
                           INT8_C( -23), INT8_C( 120), INT8_C( -83), INT8_C( -16),
                           INT8_C(   7), INT8_C(  51), INT8_C( -57), INT8_C( -50),
                           INT8_C( -21), INT8_C(  98), INT8_C(  88), INT8_C(   0),
                           INT8_C( -66), INT8_C(   3), INT8_C( 124), INT8_C(-113),
                           INT8_C(  50), INT8_C(  88), INT8_C( -85), INT8_C( -93),
                           INT8_C( -44), INT8_C( -13), INT8_C( -94), INT8_C(  17)),
      simde_mm512_set_epi8(INT8_C( -13), INT8_C( -12), INT8_C(-124), INT8_C(  96),
                           INT8_C( -13), INT8_C( -98), INT8_C(  99), INT8_C( -13),
                           INT8_C(  56), INT8_C( -45), INT8_C(-108), INT8_C( -19),
                           INT8_C(-124), INT8_C( -27), INT8_C(  22), INT8_C( 126),
                           INT8_C(-106), INT8_C( -68), INT8_C( -60), INT8_C(   8),
                           INT8_C(  60), INT8_C(  93), INT8_C( -33), INT8_C( -27),
                           INT8_C(  -7), INT8_C(  27), INT8_C(-122), INT8_C( -38),
                           INT8_C(  23), INT8_C(   6), INT8_C(  45), INT8_C( -21),
                           INT8_C( -23), INT8_C(-101), INT8_C( 116), INT8_C( 127),
                           INT8_C(  96), INT8_C(  40), INT8_C( -97), INT8_C(  40),
                           INT8_C(  86), INT8_C( -44), INT8_C(  70), INT8_C( -71),
                           INT8_C(  62), INT8_C( -21), INT8_C(  66), INT8_C(  68),
                           INT8_C( -87), INT8_C( -61), INT8_C(  48), INT8_C( -70),
                           INT8_C(  18), INT8_C( -78), INT8_C( -98), INT8_C( 117),
                           INT8_C(  74), INT8_C(  32), INT8_C(  93), INT8_C( 125),
                           INT8_C( -47), INT8_C( -60), INT8_C( -86), INT8_C( 117)),
      simde_mm512_set_epi8(INT8_C( 109), INT8_C( -66), INT8_C( -74), INT8_C( 127),
                           INT8_C( -44), INT8_C(-128), INT8_C(  35), INT8_C(   0),
                           INT8_C(   0), INT8_C(  15), INT8_C(   0), INT8_C(   0),
                           INT8_C( -16), INT8_C(-128), INT8_C( -70), INT8_C(  46),
                           INT8_C(-128), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(  68), INT8_C( 127), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C( -27), INT8_C(   0),
                           INT8_C(  93), INT8_C(   0), INT8_C( -16), INT8_C(   4),
                           INT8_C(-120), INT8_C(   0), INT8_C(  58), INT8_C( 127),
                           INT8_C(   0), INT8_C(   0), INT8_C( -16), INT8_C(  85),
                           INT8_C(  63), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   9), INT8_C(  18),
                           INT8_C(-108), INT8_C(  37), INT8_C( 127), INT8_C(   0),
                           INT8_C( -48), INT8_C(   0), INT8_C(   0), INT8_C(   4),
                           INT8_C( 124), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C( -91), INT8_C(   0), INT8_C(   0), INT8_C(   0)) },
    { UINT64_C( 7677112093376593822),
      simde_mm512_set_epi8(INT8_C( -53), INT8_C(  34), INT8_C(   9), INT8_C(  64),
                           INT8_C( -61), INT8_C( -25), INT8_C(-115), INT8_C( 100),
                           INT8_C(  65), INT8_C(   8), INT8_C(  69), INT8_C(  -8),
                           INT8_C( -15), INT8_C( -51), INT8_C(   1), INT8_C(  90),
                           INT8_C( 115), INT8_C(  51), INT8_C( -91), INT8_C(  56),
                           INT8_C(  64), INT8_C( -39), INT8_C(-119), INT8_C( -28),
                           INT8_C( -54), INT8_C(  28), INT8_C(  54), INT8_C(  -8),
                           INT8_C( -54), INT8_C(-128), INT8_C( -28), INT8_C( -71),
                           INT8_C( 107), INT8_C( -66), INT8_C(-114), INT8_C( -88),
                           INT8_C(  34), INT8_C( -83), INT8_C( -21), INT8_C( -64),
                           INT8_C( 121), INT8_C( -20), INT8_C( -89), INT8_C( -94),
                           INT8_C( 112), INT8_C( -27), INT8_C(  81), INT8_C( -54),
                           INT8_C( -64), INT8_C(-114), INT8_C(  48), INT8_C( -89),
                           INT8_C( -61), INT8_C(  26), INT8_C(  43), INT8_C(  29),
                           INT8_C(   0), INT8_C(  64), INT8_C( 123), INT8_C( -67),
                           INT8_C(  15), INT8_C( 120), INT8_C(  36), INT8_C(  40)),
      simde_mm512_set_epi8(INT8_C( 113), INT8_C(  32), INT8_C(  71), INT8_C(  55),
                           INT8_C( -26), INT8_C(  82), INT8_C( -81), INT8_C( -20),
                           INT8_C( -55), INT8_C( 112), INT8_C(  45), INT8_C(  37),
                           INT8_C(  67), INT8_C( -69), INT8_C(  64), INT8_C(  39),
                           INT8_C(  72), INT8_C(  45), INT8_C( 120), INT8_C(  -5),
                           INT8_C(-109), INT8_C(  62), INT8_C(  17), INT8_C(  31),
                           INT8_C( -30), INT8_C( -58), INT8_C(  56), INT8_C(  21),
                           INT8_C(  72), INT8_C( -74), INT8_C( -40), INT8_C( 120),
                           INT8_C(  95), INT8_C( 108), INT8_C(  32), INT8_C(  64),
                           INT8_C(-128), INT8_C( 102), INT8_C( -21), INT8_C(  28),
                           INT8_C( 105), INT8_C(  52), INT8_C(  85), INT8_C(-104),
                           INT8_C(  57), INT8_C( -31), INT8_C( -38), INT8_C(-124),
                           INT8_C(-107), INT8_C(  -2), INT8_C(  55), INT8_C(  46),
                           INT8_C( -71), INT8_C(  77), INT8_C(  18), INT8_C(  70),
                           INT8_C(  89), INT8_C( 125), INT8_C( -42), INT8_C(-125),
                           INT8_C( 121), INT8_C( -11), INT8_C( -69), INT8_C( -59)),
      simde_mm512_set_epi8(INT8_C(   0), INT8_C(  66), INT8_C(  80), INT8_C(   0),
                           INT8_C( -87), INT8_C(   0), INT8_C(-128), INT8_C(   0),
                           INT8_C(  10), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(  52), INT8_C(   0), INT8_C(  65), INT8_C(   0),
                           INT8_C( 127), INT8_C(   0), INT8_C(   0), INT8_C(  51),
                           INT8_C(   0), INT8_C(  23), INT8_C(   0), INT8_C(   0),
                           INT8_C( -84), INT8_C( -30), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(-128), INT8_C( -68), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C( -24),
                           INT8_C( -94), INT8_C(   0), INT8_C( -42), INT8_C(   0),
                           INT8_C( 127), INT8_C(   0), INT8_C(   0), INT8_C(-128),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(-128),
                           INT8_C(   0), INT8_C(   0), INT8_C( 103), INT8_C( -43),
                           INT8_C(-128), INT8_C( 103), INT8_C(  61), INT8_C(  99),
                           INT8_C(  89), INT8_C(   0), INT8_C(   0), INT8_C(-128),
                           INT8_C( 127), INT8_C( 109), INT8_C( -33), INT8_C(   0)) },
    { UINT64_C( 4840581956081845689),
      simde_mm512_set_epi8(INT8_C( 122), INT8_C(-108), INT8_C( -70), INT8_C( -63),
                           INT8_C(  56), INT8_C(  71), INT8_C( -14), INT8_C(  49),
                           INT8_C( -73), INT8_C(  53), INT8_C( -29), INT8_C(   3),
                           INT8_C( -73), INT8_C(  43), INT8_C( -22), INT8_C(  85),
                           INT8_C( -26), INT8_C(  -9), INT8_C(  66), INT8_C(   1),
                           INT8_C( -13), INT8_C(  60), INT8_C(-119), INT8_C( -83),
                           INT8_C(-122), INT8_C( -64), INT8_C( -83), INT8_C( -74),
                           INT8_C( 119), INT8_C(  -8), INT8_C(  12), INT8_C( 113),
                           INT8_C( -12), INT8_C( -84), INT8_C(   6), INT8_C(  69),
                           INT8_C(   2), INT8_C( -75), INT8_C( -34), INT8_C(-126),
                           INT8_C(   3), INT8_C(-128), INT8_C(  -9), INT8_C(  24),
                           INT8_C(  11), INT8_C( -94), INT8_C( -32), INT8_C( 110),
                           INT8_C(  33), INT8_C( -24), INT8_C( 125), INT8_C(  35),
                           INT8_C(-103), INT8_C( -48), INT8_C( -22), INT8_C(  38),
                           INT8_C( -81), INT8_C(   9), INT8_C( -11), INT8_C(-124),
                           INT8_C(  71), INT8_C(  31), INT8_C( -42), INT8_C(  93)),
      simde_mm512_set_epi8(INT8_C(  53), INT8_C(  77), INT8_C(  63), INT8_C( -84),
                           INT8_C(  27), INT8_C(  22), INT8_C(   3), INT8_C( -37),
                           INT8_C(  65), INT8_C( 118), INT8_C(-126), INT8_C(  97),
                           INT8_C( 109), INT8_C(   7), INT8_C(-114), INT8_C( -75),
                           INT8_C(-125), INT8_C( 121), INT8_C(-128), INT8_C( 103),
                           INT8_C(   0), INT8_C( 101), INT8_C( -41), INT8_C(  89),
                           INT8_C( -83), INT8_C( -65), INT8_C(   9), INT8_C(  -7),
                           INT8_C( -63), INT8_C(  13), INT8_C( 105), INT8_C(  92),
                           INT8_C( -18), INT8_C( -21), INT8_C(-102), INT8_C(-114),
                           INT8_C(  74), INT8_C( 121), INT8_C( -45), INT8_C(  52),
                           INT8_C( -63), INT8_C( -93), INT8_C(  98), INT8_C( 106),
                           INT8_C(-109), INT8_C( -47), INT8_C(  37), INT8_C(  70),
                           INT8_C( 100), INT8_C( 121), INT8_C(  18), INT8_C(  28),
                           INT8_C(-117), INT8_C( 107), INT8_C(   3), INT8_C( -62),
                           INT8_C(  42), INT8_C(  72), INT8_C(  91), INT8_C(  86),
                           INT8_C( -72), INT8_C(   9), INT8_C( -80), INT8_C( 118)),
      simde_mm512_set_epi8(INT8_C(   0), INT8_C( -31), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C( -11), INT8_C(  12),
                           INT8_C(   0), INT8_C(   0), INT8_C(-128), INT8_C(   0),
                           INT8_C(  36), INT8_C(  50), INT8_C(   0), INT8_C(  10),
                           INT8_C(   0), INT8_C(   0), INT8_C( -62), INT8_C( 104),
                           INT8_C(   0), INT8_C(   0), INT8_C(-128), INT8_C(   6),
                           INT8_C(-128), INT8_C(   0), INT8_C( -74), INT8_C(   0),
                           INT8_C(   0), INT8_C(   5), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(-105), INT8_C( -96), INT8_C( -45),
                           INT8_C(  76), INT8_C(  46), INT8_C( -79), INT8_C(   0),
                           INT8_C(   0), INT8_C(-128), INT8_C(  89), INT8_C(   0),
                           INT8_C( -98), INT8_C(-128), INT8_C(   0), INT8_C(   0),
                           INT8_C( 127), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(  59), INT8_C(   0), INT8_C( -24),
                           INT8_C( -39), INT8_C(   0), INT8_C(  80), INT8_C( -38),
                           INT8_C(  -1), INT8_C(   0), INT8_C(   0), INT8_C( 127)) },
    { UINT64_C(17498311407133456191),
      simde_mm512_set_epi8(INT8_C(  61), INT8_C( -89), INT8_C(  84), INT8_C( -94),
                           INT8_C(  31), INT8_C(-116), INT8_C( -67), INT8_C(-102),
                           INT8_C( -72), INT8_C( -91), INT8_C(-105), INT8_C(-108),
                           INT8_C( -44), INT8_C(  74), INT8_C( -28), INT8_C( 124),
                           INT8_C( 120), INT8_C( -41), INT8_C( -79), INT8_C( 122),
                           INT8_C(  87), INT8_C(-119), INT8_C(  54), INT8_C(  -2),
                           INT8_C( -47), INT8_C(  84), INT8_C(-126), INT8_C( -64),
                           INT8_C(  14), INT8_C(  11), INT8_C(  37), INT8_C( -23),
                           INT8_C(  67), INT8_C( 124), INT8_C(  58), INT8_C( -94),
                           INT8_C(  30), INT8_C( -33), INT8_C(  70), INT8_C( -24),
                           INT8_C(  38), INT8_C( -97), INT8_C( -56), INT8_C( -60),
                           INT8_C( -59), INT8_C(  65), INT8_C( -74), INT8_C(  45),
                           INT8_C( -11), INT8_C(  55), INT8_C( -82), INT8_C(  12),
                           INT8_C( 106), INT8_C(  22), INT8_C(-124), INT8_C(  -4),
                           INT8_C(   2), INT8_C( -81), INT8_C(  14), INT8_C(  90),
                           INT8_C(-100), INT8_C(-122), INT8_C( -35), INT8_C(  81)),
      simde_mm512_set_epi8(INT8_C(  21), INT8_C( 108), INT8_C( 125), INT8_C( -60),
                           INT8_C( -72), INT8_C(  74), INT8_C(  -5), INT8_C( -58),
                           INT8_C( -41), INT8_C(  22), INT8_C(-115), INT8_C( 102),
                           INT8_C(  59), INT8_C( -80), INT8_C( -15), INT8_C( -63),
                           INT8_C(  84), INT8_C( -71), INT8_C(   8), INT8_C(  12),
                           INT8_C( -11), INT8_C( -76), INT8_C(  62), INT8_C(  93),
                           INT8_C( -75), INT8_C( -77), INT8_C( -84), INT8_C(-108),
                           INT8_C( -35), INT8_C(  14), INT8_C( -60), INT8_C(  18),
                           INT8_C(  23), INT8_C( -60), INT8_C( -63), INT8_C(-114),
                           INT8_C( -55), INT8_C(  75), INT8_C( -99), INT8_C( -55),
                           INT8_C(  58), INT8_C(  76), INT8_C(-102), INT8_C(-118),
                           INT8_C( -30), INT8_C(  39), INT8_C( 119), INT8_C(  85),
                           INT8_C(  -8), INT8_C( -72), INT8_C( -60), INT8_C( -94),
                           INT8_C(-112), INT8_C( 119), INT8_C( 124), INT8_C(  76),
                           INT8_C( -42), INT8_C(-124), INT8_C(  54), INT8_C(  74),
                           INT8_C( -92), INT8_C(  99), INT8_C(  79), INT8_C(  -3)),
      simde_mm512_set_epi8(INT8_C(  82), INT8_C(  19), INT8_C( 127), INT8_C(-128),
                           INT8_C(   0), INT8_C(   0), INT8_C( -72), INT8_C(   0),
                           INT8_C(-113), INT8_C( -69), INT8_C(   0), INT8_C(  -6),
                           INT8_C(   0), INT8_C(  -6), INT8_C( -43), INT8_C(   0),
                           INT8_C(   0), INT8_C(-112), INT8_C( -71), INT8_C( 127),
                           INT8_C(  76), INT8_C(-128), INT8_C(   0), INT8_C(  91),
                           INT8_C(-122), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C( -23), INT8_C(  -5),
                           INT8_C(  90), INT8_C(  64), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(  42), INT8_C( -29), INT8_C( -79),
                           INT8_C(   0), INT8_C( -21), INT8_C(   0), INT8_C(-128),
                           INT8_C( -89), INT8_C(   0), INT8_C(  45), INT8_C(   0),
                           INT8_C( -19), INT8_C( -17), INT8_C(-128), INT8_C( -82),
                           INT8_C(   0), INT8_C( 127), INT8_C(   0), INT8_C(  72),
                           INT8_C(   0), INT8_C(   0), INT8_C(  68), INT8_C( 127),
                           INT8_C(-128), INT8_C( -23), INT8_C(  44), INT8_C(  78)) },
    { UINT64_C( 3462613925466476941),
      simde_mm512_set_epi8(INT8_C(  18), INT8_C( -74), INT8_C(  14), INT8_C(  36),
                           INT8_C(  -7), INT8_C( 113), INT8_C(  40), INT8_C(  48),
                           INT8_C(-107), INT8_C( -34), INT8_C( -75), INT8_C(  85),
                           INT8_C( -35), INT8_C(-116), INT8_C(  65), INT8_C( -21),
                           INT8_C(  15), INT8_C(   3), INT8_C(  45), INT8_C(  21),
                           INT8_C(  72), INT8_C(  93), INT8_C( 108), INT8_C( 125),
                           INT8_C(   1), INT8_C(  75), INT8_C(  21), INT8_C( -36),
                           INT8_C(-126), INT8_C( 122), INT8_C(  71), INT8_C(  76),
                           INT8_C(  28), INT8_C( -56), INT8_C(  32), INT8_C( 101),
                           INT8_C(-107), INT8_C(-111), INT8_C( -88), INT8_C( -19),
                           INT8_C( -77), INT8_C(  19), INT8_C( -21), INT8_C(-111),
                           INT8_C( -68), INT8_C(  82), INT8_C(-118), INT8_C( -76),
                           INT8_C(  47), INT8_C( 127), INT8_C(  62), INT8_C( -16),
                           INT8_C(  10), INT8_C( -14), INT8_C(-100), INT8_C(  86),
                           INT8_C(  29), INT8_C( 107), INT8_C(  56), INT8_C(  21),
                           INT8_C(  24), INT8_C(  68), INT8_C( -96), INT8_C(  64)),
      simde_mm512_set_epi8(INT8_C( -57), INT8_C(  94), INT8_C(-125), INT8_C(-124),
                           INT8_C(  36), INT8_C(  57), INT8_C(  68), INT8_C( -52),
                           INT8_C(  39), INT8_C(  50), INT8_C( -48), INT8_C(  94),
                           INT8_C(  53), INT8_C(  11), INT8_C(  29), INT8_C(  65),
                           INT8_C( -82), INT8_C(-119), INT8_C( 115), INT8_C(  68),
                           INT8_C( -69), INT8_C( 118), INT8_C(  17), INT8_C(   8),
                           INT8_C( -64), INT8_C( -53), INT8_C( -42), INT8_C( 126),
                           INT8_C(  67), INT8_C(  50), INT8_C( -18), INT8_C(  76),
                           INT8_C( -19), INT8_C( 123), INT8_C( -87), INT8_C( 106),
                           INT8_C( -74), INT8_C(  44), INT8_C( 117), INT8_C( 103),
                           INT8_C(  81), INT8_C( 122), INT8_C(  56), INT8_C( -10),
                           INT8_C(  67), INT8_C(  79), INT8_C(  83), INT8_C( -38),
                           INT8_C( -13), INT8_C(  43), INT8_C(  27), INT8_C( -97),
                           INT8_C( 102), INT8_C( 126), INT8_C(  38), INT8_C( -62),
                           INT8_C( -24), INT8_C( 117), INT8_C( -38), INT8_C( -93),
                           INT8_C( -58), INT8_C(-124), INT8_C( -75), INT8_C(  10)),
      simde_mm512_set_epi8(INT8_C(   0), INT8_C(   0), INT8_C(-111), INT8_C( -88),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(  18), INT8_C(-105), INT8_C(   0), INT8_C(  44),
                           INT8_C( -67), INT8_C(   0), INT8_C( 127), INT8_C(   0),
                           INT8_C(   3), INT8_C( 127), INT8_C(   0), INT8_C( 127),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C( 127), INT8_C(   0), INT8_C(   0),
                           INT8_C(   9), INT8_C(  67), INT8_C( -55), INT8_C( 127),
                           INT8_C(-128), INT8_C( -67), INT8_C(   0), INT8_C(  84),
                           INT8_C(   4), INT8_C( 127), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(-113),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(  24),
                           INT8_C(   5), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C( -34), INT8_C( -56), INT8_C(   0), INT8_C(  74)) },
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])); i++) {
    simde__m512i r = simde_mm512_maskz_adds_epi8(test_vec[i].k, test_vec[i].a, test_vec[i].b);
    simde_assert_m512i_i8(r, ==, test_vec[i].r);
  }

  return 0;
}

static int
test_simde_mm512_adds_epi16(SIMDE_MUNIT_TEST_ARGS) {
  const struct {
    simde__m512i a;
    simde__m512i b;
    simde__m512i r;
  } test_vec[8] = {
    { simde_mm512_set_epi16(INT16_C(  5952), INT16_C(-21138), INT16_C( 23605), INT16_C( -3799),
                            INT16_C(  1987), INT16_C( 29254), INT16_C( -4184), INT16_C( 13346),
                            INT16_C( 26203), INT16_C(-24373), INT16_C( 15487), INT16_C( 15569),
                            INT16_C( 13821), INT16_C( -3315), INT16_C( 30667), INT16_C(  9811),
                            INT16_C( 22769), INT16_C( 21964), INT16_C(  -315), INT16_C(-15723),
                            INT16_C( -9658), INT16_C(-27088), INT16_C( 18289), INT16_C( 13213),
                            INT16_C(-12712), INT16_C( 23293), INT16_C( 12497), INT16_C( 16576),
                            INT16_C(-19358), INT16_C(-11263), INT16_C( -3745), INT16_C(  7925)),
      simde_mm512_set_epi16(INT16_C(-22600), INT16_C(  9825), INT16_C( 27347), INT16_C( -4649),
                            INT16_C(  4812), INT16_C( 27489), INT16_C( 14729), INT16_C(-20872),
                            INT16_C(-24487), INT16_C( 23053), INT16_C( 28966), INT16_C(-23890),
                            INT16_C( -9737), INT16_C(-24021), INT16_C( 12009), INT16_C(-16892),
                            INT16_C(-11018), INT16_C( -7664), INT16_C( 22598), INT16_C(  9112),
                            INT16_C(  -468), INT16_C(-16246), INT16_C( 11633), INT16_C(  3402),
                            INT16_C( 12940), INT16_C(-18453), INT16_C(-10463), INT16_C(-24372),
                            INT16_C(  9722), INT16_C(  4912), INT16_C( 14086), INT16_C( -2976)),
      simde_mm512_set_epi16(INT16_C(-16648), INT16_C(-11313), INT16_C( 32767), INT16_C( -8448),
                            INT16_C(  6799), INT16_C( 32767), INT16_C( 10545), INT16_C( -7526),
                            INT16_C(  1716), INT16_C( -1320), INT16_C( 32767), INT16_C( -8321),
                            INT16_C(  4084), INT16_C(-27336), INT16_C( 32767), INT16_C( -7081),
                            INT16_C( 11751), INT16_C( 14300), INT16_C( 22283), INT16_C( -6611),
                            INT16_C(-10126), INT16_C(-32768), INT16_C( 29922), INT16_C( 16615),
                            INT16_C(   228), INT16_C(  4840), INT16_C(  2034), INT16_C( -7796),
                            INT16_C( -9636), INT16_C( -6351), INT16_C( 10341), INT16_C(  4949)) },
    { simde_mm512_set_epi16(INT16_C(-21870), INT16_C( -1966), INT16_C(-26101), INT16_C(  8905),
                            INT16_C(-13069), INT16_C( 13555), INT16_C(-23554), INT16_C(-12947),
                            INT16_C( 31779), INT16_C( 21013), INT16_C( 32688), INT16_C( 12512),
                            INT16_C(-26721), INT16_C(  7598), INT16_C( 21566), INT16_C(-11203),
                            INT16_C( 27021), INT16_C( -8539), INT16_C(  -532), INT16_C(-17200),
                            INT16_C(-18609), INT16_C(-30604), INT16_C(  6829), INT16_C(-13538),
                            INT16_C( 21529), INT16_C( 29340), INT16_C( 23176), INT16_C( 10860),
                            INT16_C( 31408), INT16_C(  3656), INT16_C(-30572), INT16_C( -4393)),
      simde_mm512_set_epi16(INT16_C( 29137), INT16_C( 29112), INT16_C(-21893), INT16_C( 14830),
                            INT16_C( 28350), INT16_C( 21222), INT16_C( 26922), INT16_C( 26197),
                            INT16_C(-25881), INT16_C( 28163), INT16_C(-19268), INT16_C( 10158),
                            INT16_C(-29245), INT16_C( 16103), INT16_C(-23323), INT16_C( 12478),
                            INT16_C( -6515), INT16_C( 24007), INT16_C(-28366), INT16_C(-32677),
                            INT16_C(-27350), INT16_C(-26916), INT16_C(-11979), INT16_C( 13820),
                            INT16_C(-22393), INT16_C(-20903), INT16_C( -9892), INT16_C(-22447),
                            INT16_C(-14286), INT16_C(  3532), INT16_C( 19664), INT16_C(-26842)),
      simde_mm512_set_epi16(INT16_C(  7267), INT16_C( 27146), INT16_C(-32768), INT16_C( 23735),
                            INT16_C( 15281), INT16_C( 32767), INT16_C(  3368), INT16_C( 13250),
                            INT16_C(  5898), INT16_C( 32767), INT16_C( 13420), INT16_C( 22670),
                            INT16_C(-32768), INT16_C( 23701), INT16_C( -1757), INT16_C(  1275),
                            INT16_C( 20506), INT16_C( 15468), INT16_C(-28898), INT16_C(-32768),
                            INT16_C(-32768), INT16_C(-32768), INT16_C( -5150), INT16_C(   282),
                            INT16_C(  -864), INT16_C(  8437), INT16_C( 13284), INT16_C(-11587),
                            INT16_C( 17122), INT16_C(  7188), INT16_C(-10908), INT16_C(-31235)) },
    { simde_mm512_set_epi16(INT16_C(-22689), INT16_C( 25207), INT16_C( -9300), INT16_C( 28977),
                            INT16_C(  2270), INT16_C(-32394), INT16_C( 26182), INT16_C( 23367),
                            INT16_C( 31661), INT16_C(  9636), INT16_C(-18580), INT16_C(-28875),
                            INT16_C(-25943), INT16_C( 14067), INT16_C( 10599), INT16_C( 30831),
                            INT16_C(-23557), INT16_C( 11377), INT16_C( -4608), INT16_C( 14955),
                            INT16_C( 11781), INT16_C(-12602), INT16_C( -3223), INT16_C( 11440),
                            INT16_C( -2896), INT16_C(-24304), INT16_C( 29156), INT16_C( -4347),
                            INT16_C( -2421), INT16_C( 31033), INT16_C( -3132), INT16_C(-19324)),
      simde_mm512_set_epi16(INT16_C( -2724), INT16_C(  4704), INT16_C( 23772), INT16_C(-20368),
                            INT16_C(-30374), INT16_C( 15838), INT16_C( 19402), INT16_C( 16976),
                            INT16_C(-28476), INT16_C( -2715), INT16_C(-27679), INT16_C( -8608),
                            INT16_C(-20120), INT16_C( 29206), INT16_C( -1643), INT16_C(-29856),
                            INT16_C( 18656), INT16_C( -9660), INT16_C( -4660), INT16_C(-30272),
                            INT16_C(   610), INT16_C( -3787), INT16_C( 22038), INT16_C(-29446),
                            INT16_C(-26504), INT16_C(-28984), INT16_C(-21830), INT16_C(-27507),
                            INT16_C( 24148), INT16_C(-12945), INT16_C( 24529), INT16_C(  7913)),
      simde_mm512_set_epi16(INT16_C(-25413), INT16_C( 29911), INT16_C( 14472), INT16_C(  8609),
                            INT16_C(-28104), INT16_C(-16556), INT16_C( 32767), INT16_C( 32767),
                            INT16_C(  3185), INT16_C(  6921), INT16_C(-32768), INT16_C(-32768),
                            INT16_C(-32768), INT16_C( 32767), INT16_C(  8956), INT16_C(   975),
                            INT16_C( -4901), INT16_C(  1717), INT16_C( -9268), INT16_C(-15317),
                            INT16_C( 12391), INT16_C(-16389), INT16_C( 18815), INT16_C(-18006),
                            INT16_C(-29400), INT16_C(-32768), INT16_C(  7326), INT16_C(-31854),
                            INT16_C( 21727), INT16_C( 18088), INT16_C( 21397), INT16_C(-11411)) },
    { simde_mm512_set_epi16(INT16_C(-18069), INT16_C( 21685), INT16_C( -5808), INT16_C( 24672),
                            INT16_C( -8190), INT16_C( -2830), INT16_C(-23214), INT16_C(  1083),
                            INT16_C(  6699), INT16_C(   871), INT16_C(-14072), INT16_C( -2337),
                            INT16_C( 13356), INT16_C(  7260), INT16_C(-23788), INT16_C(-19723),
                            INT16_C( 13480), INT16_C(-15429), INT16_C(-20153), INT16_C( 18680),
                            INT16_C(-26180), INT16_C( 27923), INT16_C(-14099), INT16_C( 25829),
                            INT16_C(-27481), INT16_C( 21639), INT16_C( 16654), INT16_C( 19972),
                            INT16_C( 15776), INT16_C( 23126), INT16_C( 30799), INT16_C(-14043)),
      simde_mm512_set_epi16(INT16_C( 16111), INT16_C(-26103), INT16_C( -8800), INT16_C(-24747),
                            INT16_C( 27941), INT16_C(   603), INT16_C( -8112), INT16_C(-28325),
                            INT16_C( -6110), INT16_C(-15530), INT16_C(  -938), INT16_C(-26515),
                            INT16_C( -2492), INT16_C( 16124), INT16_C(-27181), INT16_C( -3573),
                            INT16_C( 11652), INT16_C( 11646), INT16_C(  6964), INT16_C( 27675),
                            INT16_C( 13103), INT16_C( -2742), INT16_C( 27906), INT16_C( -1077),
                            INT16_C(-30636), INT16_C(-23050), INT16_C(  8363), INT16_C( 31350),
                            INT16_C( -4750), INT16_C(  -220), INT16_C( -8954), INT16_C( 15617)),
      simde_mm512_set_epi16(INT16_C( -1958), INT16_C( -4418), INT16_C(-14608), INT16_C(   -75),
                            INT16_C( 19751), INT16_C( -2227), INT16_C(-31326), INT16_C(-27242),
                            INT16_C(   589), INT16_C(-14659), INT16_C(-15010), INT16_C(-28852),
                            INT16_C( 10864), INT16_C( 23384), INT16_C(-32768), INT16_C(-23296),
                            INT16_C( 25132), INT16_C( -3783), INT16_C(-13189), INT16_C( 32767),
                            INT16_C(-13077), INT16_C( 25181), INT16_C( 13807), INT16_C( 24752),
                            INT16_C(-32768), INT16_C( -1411), INT16_C( 25017), INT16_C( 32767),
                            INT16_C( 11026), INT16_C( 22906), INT16_C( 21845), INT16_C(  1574)) },
    { simde_mm512_set_epi16(INT16_C( 25180), INT16_C(-32332), INT16_C(-18604), INT16_C(-25763),
                            INT16_C( 28237), INT16_C(-22027), INT16_C( 18301), INT16_C( 27599),
                            INT16_C( 11815), INT16_C(-14839), INT16_C(-13552), INT16_C( -6300),
                            INT16_C(-30211), INT16_C(-25552), INT16_C(  7375), INT16_C(  5267),
                            INT16_C(-14761), INT16_C(-28375), INT16_C(-32756), INT16_C( 13128),
                            INT16_C( 17683), INT16_C( -4430), INT16_C( -1805), INT16_C(-17763),
                            INT16_C(   206), INT16_C( 15851), INT16_C(  1078), INT16_C( 27402),
                            INT16_C(-15177), INT16_C(  5068), INT16_C(-15079), INT16_C(-13584)),
      simde_mm512_set_epi16(INT16_C( -3533), INT16_C( -3885), INT16_C(   789), INT16_C( -3755),
                            INT16_C(  3668), INT16_C( 19955), INT16_C(-22356), INT16_C(  8403),
                            INT16_C(-16920), INT16_C( 15195), INT16_C( -1853), INT16_C(-12121),
                            INT16_C(  5095), INT16_C( -9909), INT16_C(   574), INT16_C( 31911),
                            INT16_C( -1319), INT16_C( -2880), INT16_C(-31000), INT16_C(-30829),
                            INT16_C(-12917), INT16_C( 21541), INT16_C( 27413), INT16_C(-28040),
                            INT16_C(-19236), INT16_C(-24178), INT16_C(-29369), INT16_C( -3607),
                            INT16_C( -2666), INT16_C(-13470), INT16_C(  4416), INT16_C( 23850)),
      simde_mm512_set_epi16(INT16_C( 21647), INT16_C(-32768), INT16_C(-17815), INT16_C(-29518),
                            INT16_C( 31905), INT16_C( -2072), INT16_C( -4055), INT16_C( 32767),
                            INT16_C( -5105), INT16_C(   356), INT16_C(-15405), INT16_C(-18421),
                            INT16_C(-25116), INT16_C(-32768), INT16_C(  7949), INT16_C( 32767),
                            INT16_C(-16080), INT16_C(-31255), INT16_C(-32768), INT16_C(-17701),
                            INT16_C(  4766), INT16_C( 17111), INT16_C( 25608), INT16_C(-32768),
                            INT16_C(-19030), INT16_C( -8327), INT16_C(-28291), INT16_C( 23795),
                            INT16_C(-17843), INT16_C( -8402), INT16_C(-10663), INT16_C( 10266)) },
    { simde_mm512_set_epi16(INT16_C( 11424), INT16_C( 29699), INT16_C( 29618), INT16_C(-29898),
                            INT16_C(-23079), INT16_C( -6822), INT16_C( -7340), INT16_C(-12296),
                            INT16_C( 17833), INT16_C( -2043), INT16_C(-29766), INT16_C( 30776),
                            INT16_C(-18161), INT16_C(-32768), INT16_C(-31882), INT16_C(  3163),
                            INT16_C( 20808), INT16_C(-24577), INT16_C(  7685), INT16_C(  6279),
                            INT16_C(-27880), INT16_C( 27718), INT16_C(-18275), INT16_C( 24470),
                            INT16_C(  8834), INT16_C( 20594), INT16_C( 23052), INT16_C(-18860),
                            INT16_C(  7784), INT16_C(-16668), INT16_C(-30440), INT16_C(  6387)),
      simde_mm512_set_epi16(INT16_C( 15054), INT16_C(-23448), INT16_C(   866), INT16_C(-23509),
                            INT16_C(    -2), INT16_C(  6267), INT16_C(-15891), INT16_C(-24685),
                            INT16_C( 17511), INT16_C(  7218), INT16_C(-13659), INT16_C(-27162),
                            INT16_C( 10378), INT16_C(-16488), INT16_C(-11578), INT16_C(-27832),
                            INT16_C(-17566), INT16_C(-29377), INT16_C( -2221), INT16_C( 18656),
                            INT16_C(  7516), INT16_C(-30776), INT16_C(-19010), INT16_C( 26269),
                            INT16_C(-18451), INT16_C( 31467), INT16_C(-22066), INT16_C( 30155),
                            INT16_C( -3394), INT16_C( -6131), INT16_C( 13533), INT16_C( 21770)),
      simde_mm512_set_epi16(INT16_C( 26478), INT16_C(  6251), INT16_C( 30484), INT16_C(-32768),
                            INT16_C(-23081), INT16_C(  -555), INT16_C(-23231), INT16_C(-32768),
                            INT16_C( 32767), INT16_C(  5175), INT16_C(-32768), INT16_C(  3614),
                            INT16_C( -7783), INT16_C(-32768), INT16_C(-32768), INT16_C(-24669),
                            INT16_C(  3242), INT16_C(-32768), INT16_C(  5464), INT16_C( 24935),
                            INT16_C(-20364), INT16_C( -3058), INT16_C(-32768), INT16_C( 32767),
                            INT16_C( -9617), INT16_C( 32767), INT16_C(   986), INT16_C( 11295),
                            INT16_C(  4390), INT16_C(-22799), INT16_C(-16907), INT16_C( 28157)) },
    { simde_mm512_set_epi16(INT16_C( 11108), INT16_C(  5360), INT16_C(  8246), INT16_C(  2034),
                            INT16_C(  1485), INT16_C( 28421), INT16_C( 17428), INT16_C(-13900),
                            INT16_C(  4889), INT16_C( 17148), INT16_C( 13806), INT16_C(-26968),
                            INT16_C( -7783), INT16_C( 11345), INT16_C( 17472), INT16_C( 26483),
                            INT16_C(-10340), INT16_C( -7816), INT16_C( 22407), INT16_C( 32028),
                            INT16_C( 18301), INT16_C(-30148), INT16_C( -4736), INT16_C(-10574),
                            INT16_C( 10686), INT16_C( -5463), INT16_C( 19858), INT16_C( -4320),
                            INT16_C(-28154), INT16_C(  8984), INT16_C( 32741), INT16_C( 29052)),
      simde_mm512_set_epi16(INT16_C(-22772), INT16_C(-14596), INT16_C( -9458), INT16_C(  2054),
                            INT16_C(-24090), INT16_C(  1808), INT16_C(  9897), INT16_C( 20003),
                            INT16_C( 21444), INT16_C(  8548), INT16_C( -1773), INT16_C(  8905),
                            INT16_C( 14811), INT16_C(  5752), INT16_C(-17876), INT16_C( -7032),
                            INT16_C(-19669), INT16_C(-30631), INT16_C(-19220), INT16_C( 18906),
                            INT16_C( 15935), INT16_C(  2767), INT16_C(-30937), INT16_C( 13780),
                            INT16_C( 28270), INT16_C( 29263), INT16_C( 11106), INT16_C( 19546),
                            INT16_C( 16947), INT16_C(-29470), INT16_C( -1882), INT16_C(-19990)),
      simde_mm512_set_epi16(INT16_C(-11664), INT16_C( -9236), INT16_C( -1212), INT16_C(  4088),
                            INT16_C(-22605), INT16_C( 30229), INT16_C( 27325), INT16_C(  6103),
                            INT16_C( 26333), INT16_C( 25696), INT16_C( 12033), INT16_C(-18063),
                            INT16_C(  7028), INT16_C( 17097), INT16_C(  -404), INT16_C( 19451),
                            INT16_C(-30009), INT16_C(-32768), INT16_C(  3187), INT16_C( 32767),
                            INT16_C( 32767), INT16_C(-27381), INT16_C(-32768), INT16_C(  3206),
                            INT16_C( 32767), INT16_C( 23800), INT16_C( 30964), INT16_C( 15226),
                            INT16_C(-11207), INT16_C(-20486), INT16_C( 30859), INT16_C(  9062)) },
    { simde_mm512_set_epi16(INT16_C(-30561), INT16_C( -5745), INT16_C( 32288), INT16_C( 11324),
                            INT16_C(-18220), INT16_C(-24874), INT16_C(-10154), INT16_C( 15837),
                            INT16_C( 22748), INT16_C(  6197), INT16_C( 23429), INT16_C(-23495),
                            INT16_C( -9809), INT16_C(-19367), INT16_C(-10631), INT16_C( -3845),
                            INT16_C( -5637), INT16_C(-22436), INT16_C(  6126), INT16_C( 16975),
                            INT16_C(  5830), INT16_C( 26963), INT16_C(-12238), INT16_C( 18631),
                            INT16_C(-23641), INT16_C(-17151), INT16_C(-13103), INT16_C(  5981),
                            INT16_C( 25710), INT16_C( 32081), INT16_C(-26911), INT16_C(-20494)),
      simde_mm512_set_epi16(INT16_C( 30869), INT16_C(-18069), INT16_C(  6380), INT16_C(-23760),
                            INT16_C( -6614), INT16_C( 32014), INT16_C( -2152), INT16_C( 25253),
                            INT16_C( -8172), INT16_C(-22416), INT16_C(  2949), INT16_C(  5712),
                            INT16_C( 30074), INT16_C( 20521), INT16_C( 28471), INT16_C( -3867),
                            INT16_C( -3892), INT16_C( 21304), INT16_C(  2611), INT16_C(  5827),
                            INT16_C(-30009), INT16_C( 31479), INT16_C(-19390), INT16_C(  1047),
                            INT16_C(-19967), INT16_C( 11404), INT16_C( 25909), INT16_C(  6741),
                            INT16_C(  1933), INT16_C(-26599), INT16_C(-25469), INT16_C(-30351)),
      simde_mm512_set_epi16(INT16_C(   308), INT16_C(-23814), INT16_C( 32767), INT16_C(-12436),
                            INT16_C(-24834), INT16_C(  7140), INT16_C(-12306), INT16_C( 32767),
                            INT16_C( 14576), INT16_C(-16219), INT16_C( 26378), INT16_C(-17783),
                            INT16_C( 20265), INT16_C(  1154), INT16_C( 17840), INT16_C( -7712),
                            INT16_C( -9529), INT16_C( -1132), INT16_C(  8737), INT16_C( 22802),
                            INT16_C(-24179), INT16_C( 32767), INT16_C(-31628), INT16_C( 19678),
                            INT16_C(-32768), INT16_C( -5747), INT16_C( 12806), INT16_C( 12722),
                            INT16_C( 27643), INT16_C(  5482), INT16_C(-32768), INT16_C(-32768)) }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])); i++) {
    simde__m512i r = simde_mm512_adds_epi16(test_vec[i].a, test_vec[i].b);
    simde_assert_m512i_i16(r, ==, test_vec[i].r);
  }

  return 0;
}

static int
test_simde_mm512_mask_adds_epi16 (SIMDE_MUNIT_TEST_ARGS) {
  static const struct {
    const int16_t src[32];
    const simde__mmask32 k;
    const int16_t a[32];
    const int16_t b[32];
    const int16_t r[32];
  } test_vec[] = {
    { {  INT16_C(    72), -INT16_C(  5287), -INT16_C(  4542),  INT16_C(  2288), -INT16_C(  8745),  INT16_C( 27056), -INT16_C( 11265), -INT16_C( 27298),
        -INT16_C( 32448), -INT16_C( 11055), -INT16_C( 28733),  INT16_C(  7301),  INT16_C( 28274), -INT16_C( 27095), -INT16_C(  1294),  INT16_C( 15311),
         INT16_C( 10490),  INT16_C( 15398),  INT16_C(  5654), -INT16_C(  4795), -INT16_C(  2572), -INT16_C(  3241), -INT16_C( 19000),  INT16_C(  2185),
         INT16_C( 23095), -INT16_C(  1315),  INT16_C( 25321),  INT16_C( 23574),  INT16_C( 16336), -INT16_C( 15374), -INT16_C( 16071),  INT16_C( 13566) },
      UINT32_C(   7349481),
      { -INT16_C( 19142),  INT16_C( 12013),  INT16_C( 17579),  INT16_C( 29474), -INT16_C( 21510),  INT16_C( 12668),  INT16_C( 22789), -INT16_C(  4565),
         INT16_C( 17083), -INT16_C( 29878),  INT16_C( 15489), -INT16_C( 17586),  INT16_C( 19709), -INT16_C(  6161),  INT16_C( 24432), -INT16_C( 21529),
        -INT16_C( 11243), -INT16_C( 16167), -INT16_C(  1255),  INT16_C(  4915), -INT16_C( 20570), -INT16_C( 21692),  INT16_C( 28424), -INT16_C( 15462),
        -INT16_C(  6991),  INT16_C( 13135), -INT16_C( 25311),  INT16_C(  7918), -INT16_C(  8726),  INT16_C( 23045), -INT16_C(  5060),  INT16_C( 20741) },
      { -INT16_C(  8255), -INT16_C(  9711),  INT16_C( 17882), -INT16_C( 32275),  INT16_C( 12788), -INT16_C(   724), -INT16_C( 14688),  INT16_C( 21184),
         INT16_C(  4011), -INT16_C( 13179),  INT16_C( 29613), -INT16_C( 26646), -INT16_C(  4016), -INT16_C( 29455), -INT16_C(  2084), -INT16_C( 25122),
        -INT16_C(  4138), -INT16_C( 20361),  INT16_C( 25652),  INT16_C( 10545),  INT16_C( 24213),  INT16_C( 13862), -INT16_C(  6620), -INT16_C( 12408),
         INT16_C(  3574), -INT16_C( 23653), -INT16_C( 31104), -INT16_C( 12230),  INT16_C( 11126),  INT16_C( 21084),  INT16_C( 14882), -INT16_C(  1808) },
      { -INT16_C( 27397), -INT16_C(  5287), -INT16_C(  4542), -INT16_C(  2801), -INT16_C(  8745),  INT16_C( 11944),  INT16_C(  8101),  INT16_C( 16619),
        -INT16_C( 32448), -INT16_C( 11055),       INT16_MAX,  INT16_C(  7301),  INT16_C( 28274),       INT16_MIN, -INT16_C(  1294),  INT16_C( 15311),
         INT16_C( 10490),  INT16_C( 15398),  INT16_C(  5654), -INT16_C(  4795),  INT16_C(  3643), -INT16_C(  7830),  INT16_C( 21804),  INT16_C(  2185),
         INT16_C( 23095), -INT16_C(  1315),  INT16_C( 25321),  INT16_C( 23574),  INT16_C( 16336), -INT16_C( 15374), -INT16_C( 16071),  INT16_C( 13566) } },
    { {  INT16_C( 26410),  INT16_C( 24233), -INT16_C(  9524),  INT16_C( 24967), -INT16_C( 21192),  INT16_C( 23959),  INT16_C(  8084), -INT16_C( 30164),
        -INT16_C( 14292), -INT16_C( 21459),  INT16_C( 26446), -INT16_C( 15236), -INT16_C(  9838), -INT16_C( 19178),  INT16_C(  1555),  INT16_C( 15789),
         INT16_C( 22126),  INT16_C( 15004),  INT16_C(  9009),  INT16_C( 27035),  INT16_C( 13265),  INT16_C( 26054), -INT16_C(  3246),  INT16_C( 32751),
         INT16_C(  7355),  INT16_C(  2347), -INT16_C( 22397),  INT16_C(  5581), -INT16_C(  7295), -INT16_C( 27446),  INT16_C( 30954),  INT16_C( 22738) },
      UINT32_C(4287786702),
      {  INT16_C( 11665),  INT16_C( 25193),  INT16_C( 12128), -INT16_C( 19513), -INT16_C( 18910), -INT16_C(  8910),  INT16_C( 24018),  INT16_C( 21990),
        -INT16_C( 19707), -INT16_C( 31125),  INT16_C( 13719), -INT16_C( 32485), -INT16_C(  4691),  INT16_C( 31961),  INT16_C( 27483), -INT16_C(  4997),
        -INT16_C(  7016), -INT16_C(  1713),  INT16_C(  5652),  INT16_C( 13996), -INT16_C(  8499), -INT16_C( 24812), -INT16_C(  1477),  INT16_C( 16885),
         INT16_C( 24750),  INT16_C( 17863), -INT16_C(  7531),  INT16_C( 17350), -INT16_C( 24625),  INT16_C( 10943),  INT16_C( 14858), -INT16_C( 24041) },
      {  INT16_C( 26143),  INT16_C( 13211),  INT16_C( 18300),  INT16_C( 18793),  INT16_C( 32037),  INT16_C( 25065), -INT16_C(  8584),  INT16_C(  9890),
         INT16_C( 26942), -INT16_C( 11413),  INT16_C( 12620),  INT16_C(  6934), -INT16_C( 10800), -INT16_C(  9658),  INT16_C( 23824),  INT16_C( 12156),
         INT16_C(  6339),  INT16_C( 16226), -INT16_C( 13473), -INT16_C( 31351),  INT16_C( 29257), -INT16_C( 15898), -INT16_C( 30640), -INT16_C( 28953),
         INT16_C( 21233),  INT16_C( 15713),  INT16_C( 30851),  INT16_C( 21337), -INT16_C( 24755),  INT16_C( 23853), -INT16_C( 22020), -INT16_C( 16500) },
      {  INT16_C( 26410),       INT16_MAX,  INT16_C( 30428), -INT16_C(   720), -INT16_C( 21192),  INT16_C( 23959),  INT16_C( 15434),  INT16_C( 31880),
        -INT16_C( 14292),       INT16_MIN,  INT16_C( 26339), -INT16_C( 25551), -INT16_C(  9838),  INT16_C( 22303),       INT16_MAX,  INT16_C( 15789),
         INT16_C( 22126),  INT16_C( 14513),  INT16_C(  9009),  INT16_C( 27035),  INT16_C( 20758),  INT16_C( 26054), -INT16_C(  3246), -INT16_C( 12068),
              INT16_MAX,       INT16_MAX,  INT16_C( 23320),       INT16_MAX,       INT16_MIN,       INT16_MAX, -INT16_C(  7162),       INT16_MIN } },
    { { -INT16_C(  4415),  INT16_C(  8702), -INT16_C( 30790),  INT16_C(   934), -INT16_C( 29447),  INT16_C( 18884), -INT16_C( 21740),  INT16_C(  1495),
         INT16_C( 14845), -INT16_C( 32701), -INT16_C( 25423), -INT16_C(   301),  INT16_C(    59),  INT16_C( 14172), -INT16_C(  5975),  INT16_C( 27638),
        -INT16_C(  2857), -INT16_C( 28276),  INT16_C( 12924),  INT16_C( 30100),  INT16_C( 22718), -INT16_C( 11585), -INT16_C( 27133),  INT16_C(   215),
         INT16_C(  6863), -INT16_C( 32640),  INT16_C( 21430), -INT16_C(  3713), -INT16_C(  9389), -INT16_C(   984),  INT16_C(  7875), -INT16_C( 26009) },
      UINT32_C(2402022163),
      { -INT16_C( 16603), -INT16_C(  7420), -INT16_C( 15593),  INT16_C(  6837), -INT16_C( 29350),  INT16_C( 10522), -INT16_C( 25945),  INT16_C( 24234),
         INT16_C( 10733),  INT16_C( 16463),  INT16_C( 30724), -INT16_C( 14531), -INT16_C( 23402), -INT16_C( 22174), -INT16_C( 29288), -INT16_C( 17096),
         INT16_C( 15693),  INT16_C( 25761),  INT16_C( 22016),  INT16_C( 23167), -INT16_C( 26141), -INT16_C( 29820),  INT16_C( 11828),  INT16_C(  8681),
         INT16_C( 14423),  INT16_C( 23394), -INT16_C( 24656),  INT16_C( 18210), -INT16_C( 31677), -INT16_C(  9232),  INT16_C( 10514),  INT16_C( 24473) },
      {  INT16_C( 14950),  INT16_C( 26307),  INT16_C( 17040),  INT16_C( 29889),  INT16_C( 17884),  INT16_C(  4351), -INT16_C(  6029), -INT16_C( 13775),
        -INT16_C( 27872), -INT16_C( 11995),  INT16_C( 18226),  INT16_C( 30232),  INT16_C(  2252), -INT16_C(  8623), -INT16_C(  5583), -INT16_C( 26819),
         INT16_C(    36), -INT16_C( 18946), -INT16_C( 16573),  INT16_C(  7977),  INT16_C( 10244),  INT16_C( 30511),  INT16_C( 24592),  INT16_C( 12353),
         INT16_C( 26356),  INT16_C(  9729),  INT16_C(  6573),  INT16_C( 31132), -INT16_C(  4574),  INT16_C( 21335), -INT16_C( 27432), -INT16_C(   533) },
      { -INT16_C(  1653),  INT16_C( 18887), -INT16_C( 30790),  INT16_C(   934), -INT16_C( 11466),  INT16_C( 18884), -INT16_C( 21740),  INT16_C(  1495),
        -INT16_C( 17139),  INT16_C(  4468), -INT16_C( 25423), -INT16_C(   301), -INT16_C( 21150), -INT16_C( 30797),       INT16_MIN,       INT16_MIN,
         INT16_C( 15729),  INT16_C(  6815),  INT16_C( 12924),  INT16_C( 31144),  INT16_C( 22718),  INT16_C(   691), -INT16_C( 27133),  INT16_C(   215),
              INT16_MAX,       INT16_MAX, -INT16_C( 18083),       INT16_MAX, -INT16_C(  9389), -INT16_C(   984),  INT16_C(  7875),  INT16_C( 23940) } },
    { { -INT16_C(  5739), -INT16_C( 10062), -INT16_C(  9304), -INT16_C( 21257),  INT16_C(  9731),  INT16_C(  4899),  INT16_C( 25734),  INT16_C( 31299),
         INT16_C( 17866),  INT16_C( 30625),  INT16_C( 15710), -INT16_C( 32527),  INT16_C( 18475),  INT16_C(  1236), -INT16_C( 16419),  INT16_C( 29185),
        -INT16_C( 19544),  INT16_C( 20554),  INT16_C( 16782), -INT16_C( 28164),  INT16_C(  8039), -INT16_C(  4700), -INT16_C(  6269),  INT16_C( 19816),
         INT16_C(  2348), -INT16_C( 29756), -INT16_C( 19130),  INT16_C( 29195), -INT16_C(  8194), -INT16_C(  9354),  INT16_C( 30622),  INT16_C( 17997) },
      UINT32_C(3096876842),
      { -INT16_C( 27944),  INT16_C( 16201), -INT16_C(  4687),  INT16_C( 13356), -INT16_C( 27436),  INT16_C(   385),  INT16_C( 18077), -INT16_C(  7028),
        -INT16_C( 26629), -INT16_C(  1706), -INT16_C( 13193),  INT16_C(  5588),  INT16_C(  8515),  INT16_C( 27996), -INT16_C(  3400), -INT16_C( 28635),
         INT16_C( 28293),  INT16_C( 14031), -INT16_C(   933),  INT16_C( 12139), -INT16_C(  4976),  INT16_C( 11824), -INT16_C( 17358),  INT16_C( 11794),
         INT16_C( 26708), -INT16_C( 13529), -INT16_C(   972),  INT16_C( 30688),  INT16_C( 15389), -INT16_C( 10524),  INT16_C(  2351), -INT16_C( 19354) },
      {  INT16_C( 13943), -INT16_C( 11542),  INT16_C( 21810), -INT16_C( 15871),  INT16_C( 12866),  INT16_C( 29936),  INT16_C(   750),  INT16_C( 17058),
        -INT16_C( 13718), -INT16_C( 25075), -INT16_C(  4410), -INT16_C(  7403), -INT16_C(  1750),  INT16_C( 22969),  INT16_C(  8194),  INT16_C( 30989),
        -INT16_C(  1962), -INT16_C( 30645),  INT16_C( 19789), -INT16_C( 28854),  INT16_C( 15231),  INT16_C( 27908), -INT16_C( 22979), -INT16_C( 22352),
        -INT16_C( 17040),  INT16_C( 13894),  INT16_C( 23723), -INT16_C( 10726), -INT16_C( 11435),  INT16_C( 22575),  INT16_C( 15859),  INT16_C( 18897) },
      { -INT16_C(  5739),  INT16_C(  4659), -INT16_C(  9304), -INT16_C(  2515),  INT16_C(  9731),  INT16_C( 30321),  INT16_C( 25734),  INT16_C( 31299),
              INT16_MIN, -INT16_C( 26781), -INT16_C( 17603), -INT16_C( 32527),  INT16_C(  6765),  INT16_C(  1236), -INT16_C( 16419),  INT16_C(  2354),
        -INT16_C( 19544), -INT16_C( 16614),  INT16_C( 18856), -INT16_C( 28164),  INT16_C( 10255), -INT16_C(  4700), -INT16_C(  6269), -INT16_C( 10558),
         INT16_C(  2348), -INT16_C( 29756), -INT16_C( 19130),  INT16_C( 19962),  INT16_C(  3954),  INT16_C( 12051),  INT16_C( 30622), -INT16_C(   457) } },
    { {  INT16_C(  7477), -INT16_C( 32047),  INT16_C(  7274), -INT16_C(  5870),  INT16_C(  5719), -INT16_C( 27562),  INT16_C(  1724),  INT16_C( 11580),
        -INT16_C( 31804),  INT16_C( 28515),  INT16_C( 32223),  INT16_C( 13381),  INT16_C( 30033),  INT16_C( 17548),  INT16_C( 24242), -INT16_C(  6258),
         INT16_C( 24443), -INT16_C(  6807),  INT16_C( 31611), -INT16_C( 11570),  INT16_C(  9361),  INT16_C( 20071), -INT16_C( 23765), -INT16_C(  4229),
        -INT16_C(  8666),  INT16_C(  1374), -INT16_C( 23460), -INT16_C( 21190), -INT16_C( 14823), -INT16_C( 13327),  INT16_C( 32548), -INT16_C( 24654) },
      UINT32_C(1518607327),
      {  INT16_C( 21143),  INT16_C( 10285), -INT16_C( 27529), -INT16_C( 23946), -INT16_C(  3785),  INT16_C( 24209), -INT16_C(  4144),  INT16_C( 11363),
        -INT16_C( 25197), -INT16_C( 21287), -INT16_C( 13724), -INT16_C( 30601),  INT16_C( 10570),  INT16_C( 10536), -INT16_C( 21435), -INT16_C(  9085),
        -INT16_C( 20225),  INT16_C( 30212),  INT16_C( 31556),  INT16_C( 31768), -INT16_C( 22164),  INT16_C( 15578),  INT16_C( 15768),  INT16_C( 11368),
         INT16_C( 16859),  INT16_C( 16344),  INT16_C( 20492),  INT16_C( 22215), -INT16_C(  4231), -INT16_C( 16769),  INT16_C(   668), -INT16_C( 25702) },
      { -INT16_C( 24653), -INT16_C(  2287),  INT16_C( 10522), -INT16_C( 31117),  INT16_C( 19922),  INT16_C( 27331),  INT16_C( 11147),  INT16_C( 26262),
         INT16_C( 28525),  INT16_C( 31141),  INT16_C( 27839),  INT16_C( 14543),  INT16_C( 20060), -INT16_C(  1801), -INT16_C( 28336),  INT16_C(   915),
        -INT16_C( 23504),  INT16_C( 19195),  INT16_C( 28365), -INT16_C( 24623), -INT16_C( 27460),  INT16_C( 18185), -INT16_C( 24385),  INT16_C( 11437),
         INT16_C( 21007), -INT16_C( 12635),  INT16_C( 29886),  INT16_C(  6662), -INT16_C(   574),  INT16_C(  4882), -INT16_C( 23153), -INT16_C( 16618) },
      { -INT16_C(  3510),  INT16_C(  7998), -INT16_C( 17007),       INT16_MIN,  INT16_C( 16137), -INT16_C( 27562),  INT16_C(  7003),       INT16_MAX,
         INT16_C(  3328),  INT16_C(  9854),  INT16_C( 32223), -INT16_C( 16058),  INT16_C( 30630),  INT16_C( 17548),  INT16_C( 24242), -INT16_C(  6258),
         INT16_C( 24443), -INT16_C(  6807),       INT16_MAX, -INT16_C( 11570),  INT16_C(  9361),  INT16_C( 20071), -INT16_C( 23765),  INT16_C( 22805),
        -INT16_C(  8666),  INT16_C(  3709), -INT16_C( 23460),  INT16_C( 28877), -INT16_C(  4805), -INT16_C( 13327), -INT16_C( 22485), -INT16_C( 24654) } },
    { {  INT16_C(  4425),  INT16_C(  5642), -INT16_C(  9344),  INT16_C( 15541), -INT16_C( 16529),  INT16_C( 11907),  INT16_C( 12383),  INT16_C( 28251),
         INT16_C(   130),  INT16_C( 16444),  INT16_C( 17013),  INT16_C( 14171),  INT16_C( 27968), -INT16_C( 12470),  INT16_C( 24851),  INT16_C( 23694),
        -INT16_C( 26510), -INT16_C(  3469),  INT16_C( 10355), -INT16_C(  7634), -INT16_C( 19993),  INT16_C( 17937),  INT16_C( 27873),  INT16_C( 25524),
        -INT16_C(  3988), -INT16_C(  7772), -INT16_C(   205),  INT16_C( 29465),  INT16_C( 25452),  INT16_C( 32578), -INT16_C( 12092),  INT16_C( 14300) },
      UINT32_C(3693694825),
      {  INT16_C( 22647),  INT16_C( 24511), -INT16_C( 12279), -INT16_C(  5211),  INT16_C( 23100), -INT16_C( 22450), -INT16_C(  3510),  INT16_C( 32138),
        -INT16_C( 23567),  INT16_C( 24304),  INT16_C( 12806), -INT16_C( 13347), -INT16_C( 18173),  INT16_C( 27650),  INT16_C( 11016), -INT16_C( 32696),
         INT16_C(  1923), -INT16_C( 29217), -INT16_C( 31529),  INT16_C(  4984), -INT16_C( 14626),  INT16_C( 10684),  INT16_C( 18105), -INT16_C( 21850),
        -INT16_C( 26647), -INT16_C(  4344), -INT16_C(  6455), -INT16_C( 13126), -INT16_C( 17249), -INT16_C( 22472), -INT16_C( 32280),  INT16_C( 27432) },
      {  INT16_C(  1928),  INT16_C( 24824),  INT16_C( 28811),  INT16_C( 27251),  INT16_C( 12087), -INT16_C(  3949),  INT16_C( 14709),  INT16_C( 24218),
        -INT16_C( 23600), -INT16_C( 26034),  INT16_C(  2185),  INT16_C( 10342), -INT16_C( 24635), -INT16_C( 21040), -INT16_C(  2016), -INT16_C( 22504),
         INT16_C(  4607), -INT16_C( 29944),  INT16_C( 31873), -INT16_C( 18187), -INT16_C( 30549),  INT16_C(  8616),  INT16_C( 17345), -INT16_C( 28033),
        -INT16_C( 12826),  INT16_C( 28460), -INT16_C( 27946), -INT16_C( 25705),  INT16_C( 26673),  INT16_C( 20808),  INT16_C( 24672),  INT16_C( 24826) },
      {  INT16_C( 24575),  INT16_C(  5642), -INT16_C(  9344),  INT16_C( 22040), -INT16_C( 16529), -INT16_C( 26399),  INT16_C( 11199),  INT16_C( 28251),
              INT16_MIN, -INT16_C(  1730),  INT16_C( 14991), -INT16_C(  3005),  INT16_C( 27968), -INT16_C( 12470),  INT16_C(  9000),  INT16_C( 23694),
         INT16_C(  6530), -INT16_C(  3469),  INT16_C( 10355), -INT16_C( 13203), -INT16_C( 19993),  INT16_C( 19300),  INT16_C( 27873),  INT16_C( 25524),
        -INT16_C(  3988), -INT16_C(  7772),       INT16_MIN,       INT16_MIN,  INT16_C(  9424),  INT16_C( 32578), -INT16_C(  7608),       INT16_MAX } },
    { {  INT16_C(   625), -INT16_C(  3093), -INT16_C(  8066),  INT16_C( 10923),  INT16_C( 21608),  INT16_C( 10571), -INT16_C( 13673),  INT16_C( 32187),
        -INT16_C(  6248),  INT16_C( 28396), -INT16_C( 31878), -INT16_C( 21751),  INT16_C( 20971),  INT16_C( 19709), -INT16_C(  2127),  INT16_C(  9132),
        -INT16_C( 26631),  INT16_C( 30742), -INT16_C( 16009), -INT16_C(  8286), -INT16_C(  4843), -INT16_C( 21496), -INT16_C( 15177),  INT16_C( 20265),
         INT16_C(  5547),  INT16_C(  9661), -INT16_C( 14695), -INT16_C( 31535), -INT16_C( 12777), -INT16_C( 13872),  INT16_C( 31941), -INT16_C( 16660) },
      UINT32_C(2318795283),
      { -INT16_C( 10045), -INT16_C(  9879),  INT16_C( 29381),  INT16_C( 32133), -INT16_C( 20682), -INT16_C(  7732), -INT16_C( 30012),  INT16_C( 23815),
        -INT16_C( 10160),  INT16_C( 26850), -INT16_C( 19802),  INT16_C( 27441),  INT16_C(  7471),  INT16_C( 16937),  INT16_C( 24607), -INT16_C(  7475),
         INT16_C( 13880), -INT16_C(   325),  INT16_C( 16808), -INT16_C(  8581),  INT16_C( 18416), -INT16_C( 19264), -INT16_C( 14383),  INT16_C(  8722),
        -INT16_C(  2913),  INT16_C( 17802), -INT16_C( 17498), -INT16_C( 10832), -INT16_C(  9768), -INT16_C(  2280), -INT16_C(  6855),  INT16_C( 29401) },
      { -INT16_C( 27365), -INT16_C( 15248), -INT16_C(  5162), -INT16_C( 14686),  INT16_C( 25138),  INT16_C(  1146), -INT16_C( 29655), -INT16_C( 14298),
        -INT16_C( 20352),  INT16_C(  9997), -INT16_C( 17045),  INT16_C( 17404),  INT16_C(  5271), -INT16_C( 12230),  INT16_C(  5113),  INT16_C(  5442),
        -INT16_C( 19800),  INT16_C( 32473),  INT16_C( 31645), -INT16_C( 12220), -INT16_C( 16418),  INT16_C(  2004), -INT16_C(  1461), -INT16_C( 13104),
        -INT16_C(  8790),  INT16_C(  5619), -INT16_C(  4197),  INT16_C( 12888), -INT16_C( 28156), -INT16_C(   766),  INT16_C( 17829),  INT16_C( 19986) },
      {       INT16_MIN, -INT16_C( 25127), -INT16_C(  8066),  INT16_C( 10923),  INT16_C(  4456),  INT16_C( 10571), -INT16_C( 13673),  INT16_C( 32187),
        -INT16_C(  6248),       INT16_MAX, -INT16_C( 31878), -INT16_C( 21751),  INT16_C( 20971),  INT16_C( 19709), -INT16_C(  2127),  INT16_C(  9132),
        -INT16_C( 26631),  INT16_C( 32148),       INT16_MAX, -INT16_C(  8286),  INT16_C(  1998), -INT16_C( 17260), -INT16_C( 15177),  INT16_C( 20265),
         INT16_C(  5547),  INT16_C( 23421), -INT16_C( 14695),  INT16_C(  2056), -INT16_C( 12777), -INT16_C( 13872),  INT16_C( 31941),       INT16_MAX } },
    { { -INT16_C(  5129), -INT16_C( 27188),  INT16_C(  4455),  INT16_C( 17765),  INT16_C( 14800),  INT16_C(  6988),  INT16_C(  7219), -INT16_C(  8729),
        -INT16_C(  9478), -INT16_C( 27150),  INT16_C( 19146), -INT16_C( 12601), -INT16_C( 13860), -INT16_C( 32309), -INT16_C(  8690),  INT16_C(  1743),
        -INT16_C( 25399),  INT16_C( 12443),  INT16_C(   173),  INT16_C( 32117), -INT16_C( 15815),  INT16_C( 27800), -INT16_C( 32546), -INT16_C( 10167),
         INT16_C( 15194),  INT16_C(  9325),  INT16_C( 13445),  INT16_C( 25074), -INT16_C( 16642),  INT16_C(  3298), -INT16_C( 19812),  INT16_C( 25874) },
      UINT32_C(4220955982),
      {  INT16_C(  2989), -INT16_C(  6536),  INT16_C(  4301), -INT16_C( 21422), -INT16_C( 25712), -INT16_C(  5244), -INT16_C(  3370),  INT16_C( 23311),
         INT16_C(   550),  INT16_C(  9404), -INT16_C( 24640),  INT16_C( 23601),  INT16_C( 17233), -INT16_C( 24639),  INT16_C( 22513), -INT16_C( 24934),
         INT16_C(  4707),  INT16_C( 12421), -INT16_C( 10462), -INT16_C( 19492),  INT16_C( 24947),  INT16_C( 18846), -INT16_C( 21165),  INT16_C( 31141),
         INT16_C( 25007),  INT16_C( 28574), -INT16_C( 12544),  INT16_C( 20939), -INT16_C( 29422),  INT16_C(  1008), -INT16_C( 29980),  INT16_C( 18338) },
      {  INT16_C( 10140), -INT16_C( 16520),  INT16_C( 21758),  INT16_C( 29042),  INT16_C(  4277),  INT16_C(  2235),  INT16_C( 24765),  INT16_C( 28034),
         INT16_C(  8385), -INT16_C( 15652), -INT16_C( 22289),  INT16_C(   275),  INT16_C(  1077),  INT16_C(  6405), -INT16_C( 22642),  INT16_C( 11105),
        -INT16_C(  9778), -INT16_C( 13078),  INT16_C( 23597), -INT16_C(  7362), -INT16_C(  1684),  INT16_C( 10731),  INT16_C( 27993),  INT16_C(  6806),
         INT16_C( 29581),  INT16_C( 31964), -INT16_C(  4069),  INT16_C( 20606), -INT16_C( 31756), -INT16_C( 32151), -INT16_C( 13782), -INT16_C(  1875) },
      { -INT16_C(  5129), -INT16_C( 23056),  INT16_C( 26059),  INT16_C(  7620),  INT16_C( 14800),  INT16_C(  6988),  INT16_C( 21395), -INT16_C(  8729),
         INT16_C(  8935), -INT16_C( 27150),       INT16_MIN,  INT16_C( 23876), -INT16_C( 13860), -INT16_C( 18234), -INT16_C(  8690), -INT16_C( 13829),
        -INT16_C( 25399), -INT16_C(   657),  INT16_C( 13135),  INT16_C( 32117),  INT16_C( 23263),  INT16_C( 27800), -INT16_C( 32546),       INT16_MAX,
              INT16_MAX,       INT16_MAX,  INT16_C( 13445),       INT16_MAX,       INT16_MIN, -INT16_C( 31143),       INT16_MIN,  INT16_C( 16463) } }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
    simde__m512i src = simde_mm512_loadu_epi16(test_vec[i].src);
    simde__m512i a = simde_mm512_loadu_epi16(test_vec[i].a);
    simde__m512i b = simde_mm512_loadu_epi16(test_vec[i].b);
    simde__m512i r = simde_mm512_mask_adds_epi16(src, test_vec[i].k, a, b);
    simde_test_x86_assert_equal_i16x32(r, simde_mm512_loadu_epi16(test_vec[i].r));
  }

  return 0;
}

static int
test_simde_mm512_maskz_adds_epi16 (SIMDE_MUNIT_TEST_ARGS) {
  static const struct {
    const simde__mmask32 k;
    const int16_t a[32];
    const int16_t b[32];
    const int16_t r[32];
  } test_vec[] = {
    { UINT32_C(1382488990),
      {  INT16_C( 13382), -INT16_C(  1131), -INT16_C(  8449),  INT16_C(  8490),  INT16_C( 27735),  INT16_C( 28052), -INT16_C( 21201),  INT16_C( 29768),
         INT16_C( 19795), -INT16_C( 30934), -INT16_C( 32642),  INT16_C( 22005),  INT16_C(  9346),  INT16_C(  8543), -INT16_C( 14529), -INT16_C( 31373),
         INT16_C(  2299), -INT16_C(  1408), -INT16_C( 21530),  INT16_C( 15643), -INT16_C( 20713),  INT16_C( 18091), -INT16_C(  3236), -INT16_C( 20549),
        -INT16_C(  6847), -INT16_C( 16586),  INT16_C( 11109), -INT16_C(  6124),  INT16_C( 29776), -INT16_C( 28919),  INT16_C( 31803),  INT16_C( 13845) },
      { -INT16_C( 27260),  INT16_C( 27184),  INT16_C( 19264),  INT16_C( 22695),  INT16_C( 21242),  INT16_C( 22174),  INT16_C( 22854), -INT16_C( 30971),
         INT16_C( 15423), -INT16_C( 23482),  INT16_C( 23399), -INT16_C( 18548), -INT16_C( 27185),  INT16_C(  2631),  INT16_C( 23569), -INT16_C( 27328),
         INT16_C( 28913),  INT16_C( 13055), -INT16_C( 22597), -INT16_C( 19062),  INT16_C( 10489),  INT16_C( 16139),  INT16_C(  4226), -INT16_C( 15930),
         INT16_C(  3404), -INT16_C( 19355), -INT16_C(  3480),  INT16_C( 14187), -INT16_C( 19833), -INT16_C( 26303), -INT16_C( 32498),  INT16_C(    46) },
      {  INT16_C(     0),  INT16_C( 26053),  INT16_C( 10815),  INT16_C( 31185),       INT16_MAX,  INT16_C(     0),  INT16_C(     0), -INT16_C(  1203),
              INT16_MAX,       INT16_MIN,  INT16_C(     0),  INT16_C(  3457), -INT16_C( 17839),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C( 31212),  INT16_C( 11647),       INT16_MIN,  INT16_C(     0),  INT16_C(     0),       INT16_MAX,  INT16_C(   990),  INT16_C(     0),
         INT16_C(     0),       INT16_MIN,  INT16_C(     0),  INT16_C(     0),  INT16_C(  9943),  INT16_C(     0), -INT16_C(   695),  INT16_C(     0) } },
    { UINT32_C(2888969969),
      { -INT16_C( 17195), -INT16_C( 12703),  INT16_C( 27876),  INT16_C( 26126), -INT16_C( 11140), -INT16_C( 14041), -INT16_C( 29215),  INT16_C( 18813),
        -INT16_C(  6017),  INT16_C(  1664), -INT16_C( 15973), -INT16_C( 22113), -INT16_C( 12734),  INT16_C( 13225), -INT16_C(  9220), -INT16_C( 11809),
         INT16_C( 16535),  INT16_C( 31903), -INT16_C( 21076),  INT16_C( 10722),  INT16_C(  2690),  INT16_C( 25586),  INT16_C( 28567),  INT16_C(  5805),
         INT16_C( 11607), -INT16_C(  3556), -INT16_C( 17169),  INT16_C( 12700),  INT16_C( 17802), -INT16_C( 31131),  INT16_C( 17441), -INT16_C( 18345) },
      { -INT16_C(  2427),  INT16_C( 12596),  INT16_C(  6052),  INT16_C(  9818),  INT16_C( 19489), -INT16_C( 18295),  INT16_C( 14011),  INT16_C(  5070),
        -INT16_C(  5532),  INT16_C( 21253), -INT16_C( 24154),  INT16_C( 12420), -INT16_C(  5657),  INT16_C(  2230),  INT16_C(  3374), -INT16_C( 19520),
        -INT16_C(  2812), -INT16_C( 22300),  INT16_C( 16140),  INT16_C( 11726),  INT16_C( 22411),  INT16_C( 18405), -INT16_C( 19570), -INT16_C(  3494),
         INT16_C( 24477),  INT16_C( 17477), -INT16_C( 14079), -INT16_C(  6028),  INT16_C( 11187), -INT16_C(  7696), -INT16_C( 20424),  INT16_C( 15508) },
      { -INT16_C( 19622),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(  8349), -INT16_C( 32336), -INT16_C( 15204),  INT16_C( 23883),
         INT16_C(     0),  INT16_C( 22917),       INT16_MIN, -INT16_C(  9693),  INT16_C(     0),  INT16_C( 15455),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C(  9603),  INT16_C(     0),  INT16_C(     0),  INT16_C( 25101),       INT16_MAX,  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0), -INT16_C( 31248),  INT16_C(  6672),  INT16_C(     0),       INT16_MIN,  INT16_C(     0), -INT16_C(  2837) } },
    { UINT32_C(2984540325),
      { -INT16_C( 19785),  INT16_C( 17374), -INT16_C( 15606), -INT16_C( 26486), -INT16_C(  7050),  INT16_C(  5258), -INT16_C( 12477),  INT16_C( 17496),
        -INT16_C( 13160),  INT16_C( 19244),  INT16_C(  7415),  INT16_C( 12332), -INT16_C( 16179),  INT16_C( 29292),  INT16_C( 20793), -INT16_C(  4060),
         INT16_C(   515),  INT16_C(  3379), -INT16_C( 16954),  INT16_C( 15525),  INT16_C( 12193), -INT16_C(  6832), -INT16_C( 22274), -INT16_C( 26839),
         INT16_C( 22133),  INT16_C( 27874),  INT16_C(  3954),  INT16_C( 16284),  INT16_C(  2511),  INT16_C(  2226), -INT16_C( 10662),  INT16_C( 24057) },
      {  INT16_C( 11480), -INT16_C( 24981),  INT16_C(  4330), -INT16_C( 29733),  INT16_C( 11072),  INT16_C( 15984), -INT16_C( 25900),  INT16_C( 18901),
        -INT16_C( 18192),  INT16_C( 25269),  INT16_C( 21191), -INT16_C( 26974),  INT16_C( 21595), -INT16_C( 19041), -INT16_C( 26582),  INT16_C(   530),
         INT16_C( 32196), -INT16_C( 20831),  INT16_C( 31886), -INT16_C( 12742), -INT16_C( 21849),  INT16_C( 31500), -INT16_C(  7612),  INT16_C( 13508),
         INT16_C( 31386),  INT16_C( 24983),  INT16_C( 14796),  INT16_C( 10231), -INT16_C( 26995), -INT16_C( 18468), -INT16_C(  4562), -INT16_C(  3143) },
      { -INT16_C(  8305),  INT16_C(     0), -INT16_C( 11276),  INT16_C(     0),  INT16_C(     0),  INT16_C( 21242),  INT16_C(     0),       INT16_MAX,
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0), -INT16_C( 14642),  INT16_C(  5416),  INT16_C( 10251), -INT16_C(  5789),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0),  INT16_C( 14932),  INT16_C(     0),  INT16_C(     0),  INT16_C( 24668), -INT16_C( 29886), -INT16_C( 13331),
              INT16_MAX,  INT16_C(     0),  INT16_C(     0),  INT16_C(     0), -INT16_C( 24484), -INT16_C( 16242),  INT16_C(     0),  INT16_C( 20914) } },
    { UINT32_C(4204878444),
      { -INT16_C(  9258),  INT16_C( 32456), -INT16_C( 11130), -INT16_C( 13575), -INT16_C( 16714),  INT16_C( 20735), -INT16_C( 27080),  INT16_C(  1201),
        -INT16_C( 22065),  INT16_C( 23595),  INT16_C(  1855),  INT16_C( 28179), -INT16_C( 13067),  INT16_C( 24929),  INT16_C(   551), -INT16_C(   677),
         INT16_C(  9182),  INT16_C( 25723),  INT16_C( 30200), -INT16_C( 20946),  INT16_C( 11571),  INT16_C( 27647), -INT16_C( 20285), -INT16_C( 28049),
        -INT16_C( 26023), -INT16_C( 26130),  INT16_C(   417), -INT16_C( 27129),  INT16_C( 26830), -INT16_C(  2568),  INT16_C( 21354),  INT16_C( 18674) },
      {  INT16_C( 28279),  INT16_C( 28588), -INT16_C(  9245),  INT16_C(  5661),  INT16_C(  7176), -INT16_C( 13183), -INT16_C(  3891),  INT16_C(  9822),
         INT16_C( 19850),  INT16_C( 11199), -INT16_C( 14770),  INT16_C(  7361), -INT16_C( 18130), -INT16_C( 26351),  INT16_C(  1037), -INT16_C( 31519),
        -INT16_C( 29070),  INT16_C( 22003),  INT16_C(  4201),  INT16_C( 29035), -INT16_C(  5075), -INT16_C(  1475), -INT16_C( 25380),  INT16_C( 26144),
        -INT16_C(  7959),  INT16_C( 14225),  INT16_C( 21158), -INT16_C( 10924),  INT16_C( 25868),  INT16_C(  6510),  INT16_C( 20329), -INT16_C(  9315) },
      {  INT16_C(     0),  INT16_C(     0), -INT16_C( 20375), -INT16_C(  7914),  INT16_C(     0),  INT16_C(  7552), -INT16_C( 30971),  INT16_C(     0),
         INT16_C(     0),       INT16_MAX,  INT16_C(     0),       INT16_MAX, -INT16_C( 31197),  INT16_C(     0),  INT16_C(  1588),  INT16_C(     0),
        -INT16_C( 19888),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C( 26172),  INT16_C(     0), -INT16_C(  1905),
         INT16_C(     0), -INT16_C( 11905),  INT16_C(     0),       INT16_MIN,       INT16_MAX,  INT16_C(  3942),       INT16_MAX,  INT16_C(  9359) } },
    { UINT32_C(1177587933),
      { -INT16_C( 25696), -INT16_C( 12872), -INT16_C(  2681),  INT16_C( 25543), -INT16_C(  5999),  INT16_C( 31433),  INT16_C( 23240),  INT16_C( 28338),
         INT16_C(  1709), -INT16_C( 18109), -INT16_C( 20117), -INT16_C( 10798),  INT16_C( 28417), -INT16_C(  8528), -INT16_C(  7681), -INT16_C( 24795),
        -INT16_C(  8836),  INT16_C(  1133),  INT16_C( 13522),  INT16_C( 25703),  INT16_C( 12572), -INT16_C(  6946), -INT16_C( 28533),  INT16_C( 14419),
        -INT16_C( 26986),  INT16_C(   753), -INT16_C( 15544),  INT16_C( 18903), -INT16_C( 30926),  INT16_C( 12583),  INT16_C( 19560), -INT16_C(  6703) },
      {  INT16_C( 15913), -INT16_C(   791),  INT16_C( 20594), -INT16_C( 28832),  INT16_C( 16001),  INT16_C(  3443), -INT16_C( 14641),  INT16_C( 25925),
         INT16_C( 14173), -INT16_C( 23193),  INT16_C( 16122),  INT16_C( 11758),  INT16_C(  5574),  INT16_C( 11870),  INT16_C( 12130), -INT16_C( 29933),
        -INT16_C(   915), -INT16_C(  8057), -INT16_C(  6323), -INT16_C( 12689), -INT16_C(  7642), -INT16_C(  2597),  INT16_C(  8617),  INT16_C(  1626),
        -INT16_C( 15784),  INT16_C( 21163), -INT16_C( 26368), -INT16_C( 14721), -INT16_C(  8530),  INT16_C(  4341),  INT16_C(  2061),  INT16_C( 31644) },
      { -INT16_C(  9783),  INT16_C(     0),  INT16_C( 17913), -INT16_C(  3289),  INT16_C( 10002),  INT16_C(     0),  INT16_C(  8599),       INT16_MAX,
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),       INT16_MAX,  INT16_C(     0),  INT16_C(     0),       INT16_MIN,
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(  4930), -INT16_C(  9543),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C( 21916),       INT16_MIN,  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C( 21621),  INT16_C(     0) } },
    { UINT32_C(1381704453),
      { -INT16_C( 13813),  INT16_C( 12576), -INT16_C(   852),  INT16_C( 21798), -INT16_C( 32739),  INT16_C( 30043),  INT16_C(  1602),  INT16_C( 17351),
         INT16_C( 18335),  INT16_C( 19977), -INT16_C(   475),  INT16_C( 12894), -INT16_C(  1529),  INT16_C(  3245),  INT16_C(  2078),  INT16_C( 10590),
         INT16_C( 32466),  INT16_C( 32602), -INT16_C( 32646), -INT16_C( 26668),  INT16_C( 12288),  INT16_C( 17164), -INT16_C( 11210), -INT16_C( 10618),
        -INT16_C( 28901),  INT16_C( 16420), -INT16_C( 32114), -INT16_C( 27278),  INT16_C(  8317), -INT16_C( 25695), -INT16_C(   216), -INT16_C(  1084) },
      {  INT16_C(  7805), -INT16_C(  1926),  INT16_C( 20126), -INT16_C( 24945), -INT16_C( 25474), -INT16_C( 18975),  INT16_C( 26480), -INT16_C( 29813),
        -INT16_C( 20489), -INT16_C( 31285),  INT16_C( 15665), -INT16_C( 20966), -INT16_C( 17571), -INT16_C( 31159),  INT16_C(  3514),  INT16_C( 14209),
        -INT16_C(  1237), -INT16_C( 14033), -INT16_C( 16567), -INT16_C( 14232),  INT16_C( 18779), -INT16_C( 13443),  INT16_C(  2225), -INT16_C( 22442),
         INT16_C(  8631), -INT16_C(  6099),  INT16_C( 18270), -INT16_C( 17257), -INT16_C(  8190), -INT16_C( 17342), -INT16_C( 15378),  INT16_C(  6643) },
      { -INT16_C(  6008),  INT16_C(     0),  INT16_C( 19274),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
        -INT16_C(  2154), -INT16_C( 11308),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0), -INT16_C( 27914),  INT16_C(     0),  INT16_C(     0),
         INT16_C( 31229),  INT16_C( 18569),  INT16_C(     0),       INT16_MIN,  INT16_C( 31067),  INT16_C(     0), -INT16_C(  8985),  INT16_C(     0),
         INT16_C(     0),  INT16_C( 10321),  INT16_C(     0),  INT16_C(     0),  INT16_C(   127),  INT16_C(     0), -INT16_C( 15594),  INT16_C(     0) } },
    { UINT32_C( 132326334),
      {  INT16_C( 19426),  INT16_C( 15823),  INT16_C( 19604),  INT16_C( 17672),  INT16_C( 24148),  INT16_C(  3053),  INT16_C(  6783), -INT16_C(  8716),
        -INT16_C( 29855),  INT16_C( 25497), -INT16_C(  9365),  INT16_C( 22815),  INT16_C(  5022),  INT16_C( 23667),  INT16_C( 22070),  INT16_C(  6244),
         INT16_C( 13217),  INT16_C( 13653),  INT16_C( 23936), -INT16_C( 11141),  INT16_C( 26811),  INT16_C( 15072), -INT16_C( 11133), -INT16_C(  7145),
        -INT16_C( 20129), -INT16_C( 13752),  INT16_C( 26508),  INT16_C( 11044), -INT16_C( 26758), -INT16_C( 20345), -INT16_C(  5139), -INT16_C( 28984) },
      {  INT16_C(  7455), -INT16_C( 24637),  INT16_C( 15994),  INT16_C( 13683),  INT16_C( 21415),  INT16_C( 10863), -INT16_C( 30937), -INT16_C( 31218),
         INT16_C( 22072), -INT16_C( 15279),  INT16_C( 30142),  INT16_C( 14575),  INT16_C( 30476), -INT16_C(  1559), -INT16_C( 20126), -INT16_C( 32377),
         INT16_C( 19151),  INT16_C( 18720), -INT16_C( 27511),  INT16_C( 12415), -INT16_C(  4377),  INT16_C(  3930),  INT16_C( 26741), -INT16_C( 21099),
        -INT16_C(  6465),  INT16_C( 32114),  INT16_C( 24923),  INT16_C( 26549), -INT16_C( 24872),  INT16_C( 15200), -INT16_C(  6320),  INT16_C(  8124) },
      {  INT16_C(     0), -INT16_C(  8814),       INT16_MAX,  INT16_C( 31355),       INT16_MAX,  INT16_C( 13916),  INT16_C(     0),       INT16_MIN,
        -INT16_C(  7783),  INT16_C( 10218),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C( 22108),  INT16_C(     0),  INT16_C(     0),
         INT16_C( 32368),  INT16_C( 32373),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C( 19002),  INT16_C( 15608), -INT16_C( 28244),
        -INT16_C( 26594),  INT16_C( 18362),       INT16_MAX,  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0) } },
    { UINT32_C(3144211762),
      { -INT16_C(  6287),  INT16_C( 22763),  INT16_C( 17878),  INT16_C( 19303), -INT16_C(   595),  INT16_C( 27897),  INT16_C( 27619),  INT16_C( 16361),
        -INT16_C( 24628), -INT16_C( 23130),  INT16_C(  1853), -INT16_C( 29216), -INT16_C( 25362),  INT16_C(  8364),  INT16_C(  5497), -INT16_C(  5413),
        -INT16_C( 14596), -INT16_C( 11709), -INT16_C( 22005), -INT16_C( 18146),  INT16_C(  6055), -INT16_C( 29915),  INT16_C(  3970),  INT16_C( 20170),
         INT16_C( 28846), -INT16_C(  5133), -INT16_C( 11401),  INT16_C( 26233),  INT16_C(  9584), -INT16_C(  5754),  INT16_C( 25146),  INT16_C( 14292) },
      {  INT16_C(  5928),  INT16_C( 13321),  INT16_C( 10177),  INT16_C( 27117),  INT16_C(  4670), -INT16_C( 16140), -INT16_C( 16863), -INT16_C( 12529),
         INT16_C(   558), -INT16_C( 22853),  INT16_C( 13526),  INT16_C( 17932), -INT16_C( 28071), -INT16_C( 27601),  INT16_C(  1012),  INT16_C(  7627),
        -INT16_C( 11238), -INT16_C(  9135),  INT16_C( 16124),  INT16_C( 14917),  INT16_C( 14672),  INT16_C( 29435),  INT16_C(  2807),  INT16_C(  9537),
        -INT16_C(  1012), -INT16_C(  7477), -INT16_C( 10448), -INT16_C( 30168),  INT16_C( 22634),  INT16_C( 24094), -INT16_C(  5797),  INT16_C( 30331) },
      {  INT16_C(     0),       INT16_MAX,  INT16_C(     0),  INT16_C(     0),  INT16_C(  4075),  INT16_C( 11757),  INT16_C(     0),  INT16_C(     0),
        -INT16_C( 24070),  INT16_C(     0),  INT16_C( 15379), -INT16_C( 11284),       INT16_MIN,  INT16_C(     0),  INT16_C(  6509),  INT16_C(  2214),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0), -INT16_C(  3229),  INT16_C(     0), -INT16_C(   480),  INT16_C(  6777),  INT16_C(     0),
         INT16_C( 27834), -INT16_C( 12610),  INT16_C(     0), -INT16_C(  3935),  INT16_C( 32218),  INT16_C( 18340),  INT16_C(     0),       INT16_MAX } }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
    simde__m512i a = simde_mm512_loadu_epi16(test_vec[i].a);
    simde__m512i b = simde_mm512_loadu_epi16(test_vec[i].b);
    simde__m512i r = simde_mm512_maskz_adds_epi16(test_vec[i].k, a, b);
    simde_test_x86_assert_equal_i16x32(r, simde_mm512_loadu_epi16(test_vec[i].r));
  }

  return 0;
}

static int
test_simde_mm512_adds_epu8(SIMDE_MUNIT_TEST_ARGS) {
  const struct {
    simde__m512i a;
    simde__m512i b;
    simde__m512i r;
  } test_vec[8] = {
    { simde_x_mm512_set_epu8(UINT8_C( 52), UINT8_C( 29), UINT8_C( 31), UINT8_C(206),
                             UINT8_C( 40), UINT8_C(160), UINT8_C(244), UINT8_C( 85),
                             UINT8_C( 47), UINT8_C(153), UINT8_C(218), UINT8_C(226),
                             UINT8_C( 99), UINT8_C(129), UINT8_C( 68), UINT8_C(218),
                             UINT8_C(122), UINT8_C( 56), UINT8_C(240), UINT8_C( 10),
                             UINT8_C(228), UINT8_C( 40), UINT8_C( 70), UINT8_C( 14),
                             UINT8_C( 67), UINT8_C( 37), UINT8_C( 87), UINT8_C(131),
                             UINT8_C( 29), UINT8_C(175), UINT8_C(167), UINT8_C(223),
                             UINT8_C(170), UINT8_C( 76), UINT8_C( 39), UINT8_C(254),
                             UINT8_C(222), UINT8_C(105), UINT8_C(193), UINT8_C(144),
                             UINT8_C(182), UINT8_C(106), UINT8_C(199), UINT8_C(161),
                             UINT8_C(173), UINT8_C( 65), UINT8_C( 54), UINT8_C(148),
                             UINT8_C(222), UINT8_C(  9), UINT8_C(237), UINT8_C( 76),
                             UINT8_C(149), UINT8_C(196), UINT8_C(194), UINT8_C(114),
                             UINT8_C(167), UINT8_C( 47), UINT8_C(174), UINT8_C(135),
                             UINT8_C(170), UINT8_C(  1), UINT8_C( 40), UINT8_C( 68)),
      simde_x_mm512_set_epu8(UINT8_C(183), UINT8_C(129), UINT8_C(214), UINT8_C( 34),
                             UINT8_C(187), UINT8_C(142), UINT8_C(238), UINT8_C(248),
                             UINT8_C(175), UINT8_C(127), UINT8_C(231), UINT8_C(164),
                             UINT8_C( 16), UINT8_C(128), UINT8_C( 32), UINT8_C( 28),
                             UINT8_C(111), UINT8_C( 40), UINT8_C(  8), UINT8_C(160),
                             UINT8_C( 37), UINT8_C(193), UINT8_C(195), UINT8_C(135),
                             UINT8_C(102), UINT8_C( 87), UINT8_C(146), UINT8_C(206),
                             UINT8_C( 94), UINT8_C(109), UINT8_C(112), UINT8_C( 83),
                             UINT8_C( 63), UINT8_C(215), UINT8_C( 46), UINT8_C( 55),
                             UINT8_C( 78), UINT8_C(211), UINT8_C(175), UINT8_C(210),
                             UINT8_C( 60), UINT8_C(205), UINT8_C(118), UINT8_C(142),
                             UINT8_C(109), UINT8_C( 48), UINT8_C( 54), UINT8_C( 54),
                             UINT8_C( 99), UINT8_C(248), UINT8_C(120), UINT8_C(165),
                             UINT8_C(189), UINT8_C(132), UINT8_C(130), UINT8_C( 16),
                             UINT8_C(  6), UINT8_C(104), UINT8_C(176), UINT8_C(111),
                             UINT8_C(254), UINT8_C(193), UINT8_C(106), UINT8_C(  5)),
      simde_x_mm512_set_epu8(UINT8_C(235), UINT8_C(158), UINT8_C(245), UINT8_C(240),
                             UINT8_C(227), UINT8_C(255), UINT8_C(255), UINT8_C(255),
                             UINT8_C(222), UINT8_C(255), UINT8_C(255), UINT8_C(255),
                             UINT8_C(115), UINT8_C(255), UINT8_C(100), UINT8_C(246),
                             UINT8_C(233), UINT8_C( 96), UINT8_C(248), UINT8_C(170),
                             UINT8_C(255), UINT8_C(233), UINT8_C(255), UINT8_C(149),
                             UINT8_C(169), UINT8_C(124), UINT8_C(233), UINT8_C(255),
                             UINT8_C(123), UINT8_C(255), UINT8_C(255), UINT8_C(255),
                             UINT8_C(233), UINT8_C(255), UINT8_C( 85), UINT8_C(255),
                             UINT8_C(255), UINT8_C(255), UINT8_C(255), UINT8_C(255),
                             UINT8_C(242), UINT8_C(255), UINT8_C(255), UINT8_C(255),
                             UINT8_C(255), UINT8_C(113), UINT8_C(108), UINT8_C(202),
                             UINT8_C(255), UINT8_C(255), UINT8_C(255), UINT8_C(241),
                             UINT8_C(255), UINT8_C(255), UINT8_C(255), UINT8_C(130),
                             UINT8_C(173), UINT8_C(151), UINT8_C(255), UINT8_C(246),
                             UINT8_C(255), UINT8_C(194), UINT8_C(146), UINT8_C( 73)) },
    { simde_x_mm512_set_epu8(UINT8_C( 38), UINT8_C(254), UINT8_C(204), UINT8_C( 72),
                             UINT8_C(177), UINT8_C( 63), UINT8_C( 67), UINT8_C( 50),
                             UINT8_C( 71), UINT8_C(226), UINT8_C(146), UINT8_C(  4),
                             UINT8_C(134), UINT8_C( 91), UINT8_C(195), UINT8_C(148),
                             UINT8_C( 28), UINT8_C(158), UINT8_C(223), UINT8_C(181),
                             UINT8_C(218), UINT8_C(114), UINT8_C(200), UINT8_C(243),
                             UINT8_C(255), UINT8_C( 48), UINT8_C(233), UINT8_C( 82),
                             UINT8_C( 22), UINT8_C( 26), UINT8_C(128), UINT8_C(166),
                             UINT8_C( 79), UINT8_C(206), UINT8_C(109), UINT8_C(113),
                             UINT8_C( 86), UINT8_C(112), UINT8_C(215), UINT8_C(187),
                             UINT8_C(174), UINT8_C(250), UINT8_C(225), UINT8_C(206),
                             UINT8_C(242), UINT8_C(141), UINT8_C(197), UINT8_C(179),
                             UINT8_C( 88), UINT8_C(237), UINT8_C(191), UINT8_C(149),
                             UINT8_C(130), UINT8_C( 63), UINT8_C( 54), UINT8_C(129),
                             UINT8_C(126), UINT8_C( 18), UINT8_C( 43), UINT8_C(251),
                             UINT8_C(214), UINT8_C(155), UINT8_C( 61), UINT8_C(138)),
      simde_x_mm512_set_epu8(UINT8_C(142), UINT8_C( 33), UINT8_C( 51), UINT8_C(244),
                             UINT8_C( 33), UINT8_C(106), UINT8_C( 75), UINT8_C(210),
                             UINT8_C(121), UINT8_C( 52), UINT8_C(233), UINT8_C(109),
                             UINT8_C(205), UINT8_C(175), UINT8_C(230), UINT8_C( 70),
                             UINT8_C( 28), UINT8_C(216), UINT8_C( 76), UINT8_C(137),
                             UINT8_C(129), UINT8_C(  5), UINT8_C(149), UINT8_C(132),
                             UINT8_C(159), UINT8_C( 55), UINT8_C( 47), UINT8_C(212),
                             UINT8_C(202), UINT8_C( 26), UINT8_C(247), UINT8_C( 19),
                             UINT8_C(109), UINT8_C( 59), UINT8_C( 49), UINT8_C(175),
                             UINT8_C( 15), UINT8_C(240), UINT8_C(155), UINT8_C( 20),
                             UINT8_C( 85), UINT8_C( 57), UINT8_C( 91), UINT8_C(177),
                             UINT8_C(179), UINT8_C(200), UINT8_C( 26), UINT8_C( 99),
                             UINT8_C(  9), UINT8_C(177), UINT8_C(151), UINT8_C(246),
                             UINT8_C(116), UINT8_C(162), UINT8_C(144), UINT8_C( 44),
                             UINT8_C(240), UINT8_C(226), UINT8_C(215), UINT8_C(206),
                             UINT8_C(114), UINT8_C(250), UINT8_C(170), UINT8_C(220)),
      simde_x_mm512_set_epu8(UINT8_C(180), UINT8_C(255), UINT8_C(255), UINT8_C(255),
                             UINT8_C(210), UINT8_C(169), UINT8_C(142), UINT8_C(255),
                             UINT8_C(192), UINT8_C(255), UINT8_C(255), UINT8_C(113),
                             UINT8_C(255), UINT8_C(255), UINT8_C(255), UINT8_C(218),
                             UINT8_C( 56), UINT8_C(255), UINT8_C(255), UINT8_C(255),
                             UINT8_C(255), UINT8_C(119), UINT8_C(255), UINT8_C(255),
                             UINT8_C(255), UINT8_C(103), UINT8_C(255), UINT8_C(255),
                             UINT8_C(224), UINT8_C( 52), UINT8_C(255), UINT8_C(185),
                             UINT8_C(188), UINT8_C(255), UINT8_C(158), UINT8_C(255),
                             UINT8_C(101), UINT8_C(255), UINT8_C(255), UINT8_C(207),
                             UINT8_C(255), UINT8_C(255), UINT8_C(255), UINT8_C(255),
                             UINT8_C(255), UINT8_C(255), UINT8_C(223), UINT8_C(255),
                             UINT8_C( 97), UINT8_C(255), UINT8_C(255), UINT8_C(255),
                             UINT8_C(246), UINT8_C(225), UINT8_C(198), UINT8_C(173),
                             UINT8_C(255), UINT8_C(244), UINT8_C(255), UINT8_C(255),
                             UINT8_C(255), UINT8_C(255), UINT8_C(231), UINT8_C(255)) },
    { simde_x_mm512_set_epu8(UINT8_C(103), UINT8_C(253), UINT8_C( 31), UINT8_C(185),
                             UINT8_C(101), UINT8_C(201), UINT8_C( 20), UINT8_C( 77),
                             UINT8_C(110), UINT8_C(116), UINT8_C(226), UINT8_C( 37),
                             UINT8_C(155), UINT8_C( 44), UINT8_C(198), UINT8_C(182),
                             UINT8_C(132), UINT8_C( 61), UINT8_C(104), UINT8_C(181),
                             UINT8_C( 77), UINT8_C(161), UINT8_C(154), UINT8_C(195),
                             UINT8_C(148), UINT8_C(239), UINT8_C(178), UINT8_C(165),
                             UINT8_C(  6), UINT8_C(251), UINT8_C( 97), UINT8_C(247),
                             UINT8_C(  8), UINT8_C( 52), UINT8_C( 96), UINT8_C( 34),
                             UINT8_C(233), UINT8_C(  1), UINT8_C(  7), UINT8_C(254),
                             UINT8_C(  3), UINT8_C(  8), UINT8_C(168), UINT8_C(221),
                             UINT8_C(238), UINT8_C(144), UINT8_C( 18), UINT8_C(245),
                             UINT8_C(216), UINT8_C(239), UINT8_C(128), UINT8_C(174),
                             UINT8_C(108), UINT8_C(236), UINT8_C(204), UINT8_C(151),
                             UINT8_C( 83), UINT8_C(224), UINT8_C(253), UINT8_C( 94),
                             UINT8_C( 40), UINT8_C( 10), UINT8_C(195), UINT8_C( 72)),
      simde_x_mm512_set_epu8(UINT8_C(196), UINT8_C(220), UINT8_C(209), UINT8_C(146),
                             UINT8_C( 66), UINT8_C(240), UINT8_C(160), UINT8_C( 58),
                             UINT8_C(206), UINT8_C(157), UINT8_C(225), UINT8_C(238),
                             UINT8_C(235), UINT8_C( 53), UINT8_C( 91), UINT8_C( 97),
                             UINT8_C(175), UINT8_C( 22), UINT8_C( 33), UINT8_C(101),
                             UINT8_C(189), UINT8_C(131), UINT8_C(219), UINT8_C( 30),
                             UINT8_C( 36), UINT8_C( 11), UINT8_C(180), UINT8_C( 46),
                             UINT8_C(126), UINT8_C(239), UINT8_C(135), UINT8_C( 44),
                             UINT8_C(198), UINT8_C(149), UINT8_C(235), UINT8_C( 72),
                             UINT8_C( 18), UINT8_C(214), UINT8_C( 92), UINT8_C(199),
                             UINT8_C( 79), UINT8_C( 28), UINT8_C(156), UINT8_C( 37),
                             UINT8_C(212), UINT8_C(167), UINT8_C( 62), UINT8_C(201),
                             UINT8_C(139), UINT8_C(215), UINT8_C( 68), UINT8_C(117),
                             UINT8_C( 83), UINT8_C(105), UINT8_C(232), UINT8_C(251),
                             UINT8_C(  6), UINT8_C(165), UINT8_C(199), UINT8_C(183),
                             UINT8_C(254), UINT8_C( 55), UINT8_C(167), UINT8_C(238)),
      simde_x_mm512_set_epu8(UINT8_C(255), UINT8_C(255), UINT8_C(240), UINT8_C(255),
                             UINT8_C(167), UINT8_C(255), UINT8_C(180), UINT8_C(135),
                             UINT8_C(255), UINT8_C(255), UINT8_C(255), UINT8_C(255),
                             UINT8_C(255), UINT8_C( 97), UINT8_C(255), UINT8_C(255),
                             UINT8_C(255), UINT8_C( 83), UINT8_C(137), UINT8_C(255),
                             UINT8_C(255), UINT8_C(255), UINT8_C(255), UINT8_C(225),
                             UINT8_C(184), UINT8_C(250), UINT8_C(255), UINT8_C(211),
                             UINT8_C(132), UINT8_C(255), UINT8_C(232), UINT8_C(255),
                             UINT8_C(206), UINT8_C(201), UINT8_C(255), UINT8_C(106),
                             UINT8_C(251), UINT8_C(215), UINT8_C( 99), UINT8_C(255),
                             UINT8_C( 82), UINT8_C( 36), UINT8_C(255), UINT8_C(255),
                             UINT8_C(255), UINT8_C(255), UINT8_C( 80), UINT8_C(255),
                             UINT8_C(255), UINT8_C(255), UINT8_C(196), UINT8_C(255),
                             UINT8_C(191), UINT8_C(255), UINT8_C(255), UINT8_C(255),
                             UINT8_C( 89), UINT8_C(255), UINT8_C(255), UINT8_C(255),
                             UINT8_C(255), UINT8_C( 65), UINT8_C(255), UINT8_C(255)) },
    { simde_x_mm512_set_epu8(UINT8_C(  7), UINT8_C( 99), UINT8_C(210), UINT8_C(110),
                             UINT8_C(202), UINT8_C( 10), UINT8_C(247), UINT8_C( 68),
                             UINT8_C(177), UINT8_C(186), UINT8_C(247), UINT8_C( 36),
                             UINT8_C(212), UINT8_C(146), UINT8_C(251), UINT8_C( 66),
                             UINT8_C(  0), UINT8_C(  8), UINT8_C(116), UINT8_C(102),
                             UINT8_C(175), UINT8_C(223), UINT8_C( 15), UINT8_C(232),
                             UINT8_C(127), UINT8_C( 63), UINT8_C( 84), UINT8_C(165),
                             UINT8_C( 18), UINT8_C(250), UINT8_C( 71), UINT8_C( 18),
                             UINT8_C(132), UINT8_C(155), UINT8_C(102), UINT8_C( 18),
                             UINT8_C(177), UINT8_C(146), UINT8_C(169), UINT8_C(139),
                             UINT8_C( 21), UINT8_C( 79), UINT8_C(  4), UINT8_C(129),
                             UINT8_C(168), UINT8_C( 42), UINT8_C(  9), UINT8_C(184),
                             UINT8_C( 46), UINT8_C( 53), UINT8_C(243), UINT8_C(140),
                             UINT8_C(158), UINT8_C(112), UINT8_C( 35), UINT8_C( 49),
                             UINT8_C(253), UINT8_C(233), UINT8_C( 33), UINT8_C(178),
                             UINT8_C(117), UINT8_C(161), UINT8_C(168), UINT8_C( 39)),
      simde_x_mm512_set_epu8(UINT8_C( 75), UINT8_C(218), UINT8_C(162), UINT8_C( 30),
                             UINT8_C(119), UINT8_C(231), UINT8_C(193), UINT8_C(230),
                             UINT8_C(151), UINT8_C( 49), UINT8_C(234), UINT8_C( 78),
                             UINT8_C( 76), UINT8_C( 37), UINT8_C(174), UINT8_C(105),
                             UINT8_C(224), UINT8_C(210), UINT8_C(188), UINT8_C(142),
                             UINT8_C(116), UINT8_C(129), UINT8_C( 93), UINT8_C(124),
                             UINT8_C(248), UINT8_C(145), UINT8_C(230), UINT8_C( 41),
                             UINT8_C( 66), UINT8_C(115), UINT8_C(180), UINT8_C( 47),
                             UINT8_C( 55), UINT8_C(104), UINT8_C(123), UINT8_C(150),
                             UINT8_C(165), UINT8_C( 22), UINT8_C(  0), UINT8_C(101),
                             UINT8_C( 55), UINT8_C( 23), UINT8_C( 90), UINT8_C( 64),
                             UINT8_C( 52), UINT8_C(254), UINT8_C(116), UINT8_C(243),
                             UINT8_C(  4), UINT8_C( 84), UINT8_C( 82), UINT8_C(103),
                             UINT8_C( 43), UINT8_C(237), UINT8_C(  7), UINT8_C( 76),
                             UINT8_C( 88), UINT8_C(212), UINT8_C( 63), UINT8_C(146),
                             UINT8_C(224), UINT8_C(223), UINT8_C(207), UINT8_C(220)),
      simde_x_mm512_set_epu8(UINT8_C( 82), UINT8_C(255), UINT8_C(255), UINT8_C(140),
                             UINT8_C(255), UINT8_C(241), UINT8_C(255), UINT8_C(255),
                             UINT8_C(255), UINT8_C(235), UINT8_C(255), UINT8_C(114),
                             UINT8_C(255), UINT8_C(183), UINT8_C(255), UINT8_C(171),
                             UINT8_C(224), UINT8_C(218), UINT8_C(255), UINT8_C(244),
                             UINT8_C(255), UINT8_C(255), UINT8_C(108), UINT8_C(255),
                             UINT8_C(255), UINT8_C(208), UINT8_C(255), UINT8_C(206),
                             UINT8_C( 84), UINT8_C(255), UINT8_C(251), UINT8_C( 65),
                             UINT8_C(187), UINT8_C(255), UINT8_C(225), UINT8_C(168),
                             UINT8_C(255), UINT8_C(168), UINT8_C(169), UINT8_C(240),
                             UINT8_C( 76), UINT8_C(102), UINT8_C( 94), UINT8_C(193),
                             UINT8_C(220), UINT8_C(255), UINT8_C(125), UINT8_C(255),
                             UINT8_C( 50), UINT8_C(137), UINT8_C(255), UINT8_C(243),
                             UINT8_C(201), UINT8_C(255), UINT8_C( 42), UINT8_C(125),
                             UINT8_C(255), UINT8_C(255), UINT8_C( 96), UINT8_C(255),
                             UINT8_C(255), UINT8_C(255), UINT8_C(255), UINT8_C(255)) },
    { simde_x_mm512_set_epu8(UINT8_C(233), UINT8_C(112), UINT8_C( 62), UINT8_C( 65),
                             UINT8_C( 37), UINT8_C(247), UINT8_C(105), UINT8_C( 54),
                             UINT8_C(214), UINT8_C(255), UINT8_C(145), UINT8_C( 18),
                             UINT8_C(160), UINT8_C( 92), UINT8_C( 29), UINT8_C(253),
                             UINT8_C(230), UINT8_C( 83), UINT8_C(176), UINT8_C( 43),
                             UINT8_C( 78), UINT8_C( 31), UINT8_C(113), UINT8_C(239),
                             UINT8_C( 38), UINT8_C(192), UINT8_C(127), UINT8_C( 44),
                             UINT8_C(218), UINT8_C(134), UINT8_C(224), UINT8_C( 35),
                             UINT8_C(155), UINT8_C(171), UINT8_C( 44), UINT8_C( 53),
                             UINT8_C(101), UINT8_C(234), UINT8_C(121), UINT8_C( 95),
                             UINT8_C(232), UINT8_C(104), UINT8_C( 20), UINT8_C( 52),
                             UINT8_C( 59), UINT8_C( 62), UINT8_C( 55), UINT8_C( 43),
                             UINT8_C(246), UINT8_C( 36), UINT8_C( 25), UINT8_C( 98),
                             UINT8_C(155), UINT8_C(231), UINT8_C( 43), UINT8_C(203),
                             UINT8_C( 77), UINT8_C( 43), UINT8_C( 80), UINT8_C( 85),
                             UINT8_C(227), UINT8_C( 34), UINT8_C( 77), UINT8_C(179)),
      simde_x_mm512_set_epu8(UINT8_C( 68), UINT8_C(183), UINT8_C(190), UINT8_C(248),
                             UINT8_C( 54), UINT8_C(194), UINT8_C(  0), UINT8_C(190),
                             UINT8_C(102), UINT8_C(185), UINT8_C(  5), UINT8_C(238),
                             UINT8_C(188), UINT8_C(104), UINT8_C(139), UINT8_C(163),
                             UINT8_C(242), UINT8_C( 94), UINT8_C(181), UINT8_C(214),
                             UINT8_C(170), UINT8_C(182), UINT8_C(139), UINT8_C( 96),
                             UINT8_C( 80), UINT8_C( 38), UINT8_C(151), UINT8_C(132),
                             UINT8_C(243), UINT8_C( 37), UINT8_C(120), UINT8_C( 30),
                             UINT8_C(115), UINT8_C( 34), UINT8_C(222), UINT8_C(121),
                             UINT8_C(112), UINT8_C(205), UINT8_C(161), UINT8_C( 52),
                             UINT8_C(142), UINT8_C(118), UINT8_C(195), UINT8_C(200),
                             UINT8_C( 59), UINT8_C(  6), UINT8_C(115), UINT8_C(109),
                             UINT8_C( 93), UINT8_C(174), UINT8_C(200), UINT8_C(190),
                             UINT8_C(151), UINT8_C(126), UINT8_C(210), UINT8_C(200),
                             UINT8_C( 79), UINT8_C( 43), UINT8_C( 20), UINT8_C(239),
                             UINT8_C(149), UINT8_C(119), UINT8_C( 96), UINT8_C(120)),
      simde_x_mm512_set_epu8(UINT8_C(255), UINT8_C(255), UINT8_C(252), UINT8_C(255),
                             UINT8_C( 91), UINT8_C(255), UINT8_C(105), UINT8_C(244),
                             UINT8_C(255), UINT8_C(255), UINT8_C(150), UINT8_C(255),
                             UINT8_C(255), UINT8_C(196), UINT8_C(168), UINT8_C(255),
                             UINT8_C(255), UINT8_C(177), UINT8_C(255), UINT8_C(255),
                             UINT8_C(248), UINT8_C(213), UINT8_C(252), UINT8_C(255),
                             UINT8_C(118), UINT8_C(230), UINT8_C(255), UINT8_C(176),
                             UINT8_C(255), UINT8_C(171), UINT8_C(255), UINT8_C( 65),
                             UINT8_C(255), UINT8_C(205), UINT8_C(255), UINT8_C(174),
                             UINT8_C(213), UINT8_C(255), UINT8_C(255), UINT8_C(147),
                             UINT8_C(255), UINT8_C(222), UINT8_C(215), UINT8_C(252),
                             UINT8_C(118), UINT8_C( 68), UINT8_C(170), UINT8_C(152),
                             UINT8_C(255), UINT8_C(210), UINT8_C(225), UINT8_C(255),
                             UINT8_C(255), UINT8_C(255), UINT8_C(253), UINT8_C(255),
                             UINT8_C(156), UINT8_C( 86), UINT8_C(100), UINT8_C(255),
                             UINT8_C(255), UINT8_C(153), UINT8_C(173), UINT8_C(255)) },
    { simde_x_mm512_set_epu8(UINT8_C(150), UINT8_C(150), UINT8_C(146), UINT8_C(157),
                             UINT8_C(103), UINT8_C( 31), UINT8_C(236), UINT8_C(192),
                             UINT8_C(155), UINT8_C( 46), UINT8_C(170), UINT8_C(176),
                             UINT8_C(189), UINT8_C( 74), UINT8_C(246), UINT8_C(  0),
                             UINT8_C( 85), UINT8_C( 30), UINT8_C(190), UINT8_C( 12),
                             UINT8_C(117), UINT8_C( 74), UINT8_C(194), UINT8_C( 97),
                             UINT8_C(132), UINT8_C( 63), UINT8_C(227), UINT8_C( 21),
                             UINT8_C(244), UINT8_C(229), UINT8_C(176), UINT8_C(122),
                             UINT8_C(159), UINT8_C( 35), UINT8_C(115), UINT8_C(240),
                             UINT8_C( 88), UINT8_C(151), UINT8_C(101), UINT8_C(194),
                             UINT8_C( 49), UINT8_C(128), UINT8_C( 87), UINT8_C(152),
                             UINT8_C(173), UINT8_C(242), UINT8_C(150), UINT8_C( 26),
                             UINT8_C(183), UINT8_C( 56), UINT8_C(181), UINT8_C(193),
                             UINT8_C(231), UINT8_C(135), UINT8_C(190), UINT8_C( 42),
                             UINT8_C( 33), UINT8_C(174), UINT8_C( 57), UINT8_C(232),
                             UINT8_C(176), UINT8_C(125), UINT8_C( 87), UINT8_C( 79)),
      simde_x_mm512_set_epu8(UINT8_C( 68), UINT8_C(  1), UINT8_C(208), UINT8_C( 74),
                             UINT8_C(102), UINT8_C(168), UINT8_C( 41), UINT8_C( 41),
                             UINT8_C( 83), UINT8_C( 95), UINT8_C(152), UINT8_C(131),
                             UINT8_C(230), UINT8_C( 27), UINT8_C(126), UINT8_C(230),
                             UINT8_C(128), UINT8_C(133), UINT8_C(107), UINT8_C(197),
                             UINT8_C( 23), UINT8_C(  2), UINT8_C(108), UINT8_C(207),
                             UINT8_C( 82), UINT8_C(175), UINT8_C(247), UINT8_C(180),
                             UINT8_C( 57), UINT8_C( 31), UINT8_C(124), UINT8_C(203),
                             UINT8_C(246), UINT8_C(195), UINT8_C(173), UINT8_C(161),
                             UINT8_C(132), UINT8_C(162), UINT8_C( 13), UINT8_C(205),
                             UINT8_C(225), UINT8_C( 25), UINT8_C( 39), UINT8_C(181),
                             UINT8_C(149), UINT8_C(149), UINT8_C(138), UINT8_C(158),
                             UINT8_C(215), UINT8_C(147), UINT8_C(  0), UINT8_C( 87),
                             UINT8_C(244), UINT8_C( 10), UINT8_C(  1), UINT8_C( 19),
                             UINT8_C(173), UINT8_C(221), UINT8_C(118), UINT8_C( 51),
                             UINT8_C( 98), UINT8_C(183), UINT8_C(125), UINT8_C( 92)),
      simde_x_mm512_set_epu8(UINT8_C(218), UINT8_C(151), UINT8_C(255), UINT8_C(231),
                             UINT8_C(205), UINT8_C(199), UINT8_C(255), UINT8_C(233),
                             UINT8_C(238), UINT8_C(141), UINT8_C(255), UINT8_C(255),
                             UINT8_C(255), UINT8_C(101), UINT8_C(255), UINT8_C(230),
                             UINT8_C(213), UINT8_C(163), UINT8_C(255), UINT8_C(209),
                             UINT8_C(140), UINT8_C( 76), UINT8_C(255), UINT8_C(255),
                             UINT8_C(214), UINT8_C(238), UINT8_C(255), UINT8_C(201),
                             UINT8_C(255), UINT8_C(255), UINT8_C(255), UINT8_C(255),
                             UINT8_C(255), UINT8_C(230), UINT8_C(255), UINT8_C(255),
                             UINT8_C(220), UINT8_C(255), UINT8_C(114), UINT8_C(255),
                             UINT8_C(255), UINT8_C(153), UINT8_C(126), UINT8_C(255),
                             UINT8_C(255), UINT8_C(255), UINT8_C(255), UINT8_C(184),
                             UINT8_C(255), UINT8_C(203), UINT8_C(181), UINT8_C(255),
                             UINT8_C(255), UINT8_C(145), UINT8_C(191), UINT8_C( 61),
                             UINT8_C(206), UINT8_C(255), UINT8_C(175), UINT8_C(255),
                             UINT8_C(255), UINT8_C(255), UINT8_C(212), UINT8_C(171)) },
    { simde_x_mm512_set_epu8(UINT8_C(166), UINT8_C(112), UINT8_C( 16), UINT8_C( 20),
                             UINT8_C(189), UINT8_C( 23), UINT8_C( 28), UINT8_C(226),
                             UINT8_C( 92), UINT8_C(105), UINT8_C(249), UINT8_C( 71),
                             UINT8_C( 22), UINT8_C(153), UINT8_C( 38), UINT8_C( 58),
                             UINT8_C( 86), UINT8_C(191), UINT8_C( 97), UINT8_C(186),
                             UINT8_C(117), UINT8_C( 93), UINT8_C( 63), UINT8_C(142),
                             UINT8_C( 82), UINT8_C(123), UINT8_C(210), UINT8_C(159),
                             UINT8_C(175), UINT8_C(187), UINT8_C( 33), UINT8_C(134),
                             UINT8_C(156), UINT8_C(243), UINT8_C(191), UINT8_C(139),
                             UINT8_C(173), UINT8_C( 70), UINT8_C(113), UINT8_C( 30),
                             UINT8_C(184), UINT8_C( 82), UINT8_C(234), UINT8_C(177),
                             UINT8_C(234), UINT8_C(131), UINT8_C(180), UINT8_C( 12),
                             UINT8_C( 47), UINT8_C(213), UINT8_C( 54), UINT8_C(222),
                             UINT8_C(114), UINT8_C(251), UINT8_C(236), UINT8_C( 57),
                             UINT8_C(205), UINT8_C(187), UINT8_C( 48), UINT8_C(112),
                             UINT8_C( 34), UINT8_C( 49), UINT8_C( 95), UINT8_C(198)),
      simde_x_mm512_set_epu8(UINT8_C(116), UINT8_C(101), UINT8_C(212), UINT8_C(199),
                             UINT8_C( 88), UINT8_C(165), UINT8_C(253), UINT8_C( 88),
                             UINT8_C(138), UINT8_C( 27), UINT8_C(153), UINT8_C(155),
                             UINT8_C(248), UINT8_C(175), UINT8_C(152), UINT8_C(246),
                             UINT8_C( 17), UINT8_C(224), UINT8_C( 49), UINT8_C(127),
                             UINT8_C(200), UINT8_C( 46), UINT8_C( 58), UINT8_C(159),
                             UINT8_C(177), UINT8_C( 24), UINT8_C(139), UINT8_C(240),
                             UINT8_C( 45), UINT8_C(115), UINT8_C(179), UINT8_C(230),
                             UINT8_C(249), UINT8_C(217), UINT8_C(202), UINT8_C( 21),
                             UINT8_C(134), UINT8_C(111), UINT8_C( 79), UINT8_C(153),
                             UINT8_C(130), UINT8_C( 83), UINT8_C(196), UINT8_C(101),
                             UINT8_C(151), UINT8_C(117), UINT8_C(152), UINT8_C(155),
                             UINT8_C(116), UINT8_C(201), UINT8_C(241), UINT8_C( 71),
                             UINT8_C( 24), UINT8_C(105), UINT8_C(212), UINT8_C(191),
                             UINT8_C(  1), UINT8_C(252), UINT8_C( 15), UINT8_C( 49),
                             UINT8_C(105), UINT8_C(159), UINT8_C(109), UINT8_C( 31)),
      simde_x_mm512_set_epu8(UINT8_C(255), UINT8_C(213), UINT8_C(228), UINT8_C(219),
                             UINT8_C(255), UINT8_C(188), UINT8_C(255), UINT8_C(255),
                             UINT8_C(230), UINT8_C(132), UINT8_C(255), UINT8_C(226),
                             UINT8_C(255), UINT8_C(255), UINT8_C(190), UINT8_C(255),
                             UINT8_C(103), UINT8_C(255), UINT8_C(146), UINT8_C(255),
                             UINT8_C(255), UINT8_C(139), UINT8_C(121), UINT8_C(255),
                             UINT8_C(255), UINT8_C(147), UINT8_C(255), UINT8_C(255),
                             UINT8_C(220), UINT8_C(255), UINT8_C(212), UINT8_C(255),
                             UINT8_C(255), UINT8_C(255), UINT8_C(255), UINT8_C(160),
                             UINT8_C(255), UINT8_C(181), UINT8_C(192), UINT8_C(183),
                             UINT8_C(255), UINT8_C(165), UINT8_C(255), UINT8_C(255),
                             UINT8_C(255), UINT8_C(248), UINT8_C(255), UINT8_C(167),
                             UINT8_C(163), UINT8_C(255), UINT8_C(255), UINT8_C(255),
                             UINT8_C(138), UINT8_C(255), UINT8_C(255), UINT8_C(248),
                             UINT8_C(206), UINT8_C(255), UINT8_C( 63), UINT8_C(161),
                             UINT8_C(139), UINT8_C(208), UINT8_C(204), UINT8_C(229)) },
    { simde_x_mm512_set_epu8(UINT8_C(239), UINT8_C(174), UINT8_C( 81), UINT8_C( 89),
                             UINT8_C( 63), UINT8_C(160), UINT8_C(219), UINT8_C(204),
                             UINT8_C(161), UINT8_C(  4), UINT8_C(134), UINT8_C(137),
                             UINT8_C( 48), UINT8_C( 33), UINT8_C(178), UINT8_C(122),
                             UINT8_C( 99), UINT8_C(167), UINT8_C( 95), UINT8_C(109),
                             UINT8_C( 38), UINT8_C(191), UINT8_C(  3), UINT8_C( 48),
                             UINT8_C(143), UINT8_C( 51), UINT8_C( 81), UINT8_C( 76),
                             UINT8_C(251), UINT8_C(204), UINT8_C(198), UINT8_C(  1),
                             UINT8_C(175), UINT8_C(123), UINT8_C( 24), UINT8_C(237),
                             UINT8_C(190), UINT8_C( 62), UINT8_C( 87), UINT8_C(255),
                             UINT8_C(119), UINT8_C(202), UINT8_C(  4), UINT8_C( 40),
                             UINT8_C(152), UINT8_C(128), UINT8_C(116), UINT8_C( 72),
                             UINT8_C(245), UINT8_C(148), UINT8_C( 39), UINT8_C(106),
                             UINT8_C(195), UINT8_C(186), UINT8_C(241), UINT8_C(178),
                             UINT8_C( 68), UINT8_C(210), UINT8_C( 61), UINT8_C(218),
                             UINT8_C(116), UINT8_C( 98), UINT8_C( 41), UINT8_C( 22)),
      simde_x_mm512_set_epu8(UINT8_C(  3), UINT8_C(245), UINT8_C(  8), UINT8_C(179),
                             UINT8_C(242), UINT8_C( 19), UINT8_C(107), UINT8_C(170),
                             UINT8_C(178), UINT8_C(175), UINT8_C(174), UINT8_C(170),
                             UINT8_C( 72), UINT8_C(195), UINT8_C(199), UINT8_C( 66),
                             UINT8_C(182), UINT8_C(183), UINT8_C( 58), UINT8_C(245),
                             UINT8_C( 62), UINT8_C( 31), UINT8_C( 93), UINT8_C( 74),
                             UINT8_C(114), UINT8_C( 92), UINT8_C(199), UINT8_C( 53),
                             UINT8_C( 94), UINT8_C(185), UINT8_C(107), UINT8_C(124),
                             UINT8_C(160), UINT8_C(193), UINT8_C( 17), UINT8_C( 65),
                             UINT8_C(242), UINT8_C( 55), UINT8_C(163), UINT8_C(102),
                             UINT8_C( 59), UINT8_C(173), UINT8_C(244), UINT8_C(232),
                             UINT8_C(182), UINT8_C(139), UINT8_C(254), UINT8_C( 81),
                             UINT8_C(228), UINT8_C(175), UINT8_C(104), UINT8_C(167),
                             UINT8_C( 38), UINT8_C(114), UINT8_C(184), UINT8_C(118),
                             UINT8_C(167), UINT8_C( 58), UINT8_C(153), UINT8_C(103),
                             UINT8_C(204), UINT8_C(126), UINT8_C(111), UINT8_C( 63)),
      simde_x_mm512_set_epu8(UINT8_C(242), UINT8_C(255), UINT8_C( 89), UINT8_C(255),
                             UINT8_C(255), UINT8_C(179), UINT8_C(255), UINT8_C(255),
                             UINT8_C(255), UINT8_C(179), UINT8_C(255), UINT8_C(255),
                             UINT8_C(120), UINT8_C(228), UINT8_C(255), UINT8_C(188),
                             UINT8_C(255), UINT8_C(255), UINT8_C(153), UINT8_C(255),
                             UINT8_C(100), UINT8_C(222), UINT8_C( 96), UINT8_C(122),
                             UINT8_C(255), UINT8_C(143), UINT8_C(255), UINT8_C(129),
                             UINT8_C(255), UINT8_C(255), UINT8_C(255), UINT8_C(125),
                             UINT8_C(255), UINT8_C(255), UINT8_C( 41), UINT8_C(255),
                             UINT8_C(255), UINT8_C(117), UINT8_C(250), UINT8_C(255),
                             UINT8_C(178), UINT8_C(255), UINT8_C(248), UINT8_C(255),
                             UINT8_C(255), UINT8_C(255), UINT8_C(255), UINT8_C(153),
                             UINT8_C(255), UINT8_C(255), UINT8_C(143), UINT8_C(255),
                             UINT8_C(233), UINT8_C(255), UINT8_C(255), UINT8_C(255),
                             UINT8_C(235), UINT8_C(255), UINT8_C(214), UINT8_C(255),
                             UINT8_C(255), UINT8_C(224), UINT8_C(152), UINT8_C( 85)) }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])); i++) {
    simde__m512i r = simde_mm512_adds_epu8(test_vec[i].a, test_vec[i].b);
    simde_assert_m512i_u8(r, ==, test_vec[i].r);
  }

  return 0;
}

static int
test_simde_mm512_mask_adds_epu8(SIMDE_MUNIT_TEST_ARGS) {
  const struct {
    simde__m512i src;
    simde__mmask64 k;
    simde__m512i a;
    simde__m512i b;
    simde__m512i r;
  } test_vec[8] = {
    { simde_x_mm512_set_epu8(UINT8_C(  92), UINT8_C( 116), UINT8_C( 178), UINT8_C( 237),
                             UINT8_C( 183), UINT8_C(  22), UINT8_C( 190), UINT8_C( 227),
                             UINT8_C(  55), UINT8_C(  78), UINT8_C( 211), UINT8_C( 137),
                             UINT8_C(  30), UINT8_C( 227), UINT8_C( 233), UINT8_C(  89),
                             UINT8_C(  15), UINT8_C( 119), UINT8_C( 168), UINT8_C( 109),
                             UINT8_C( 240), UINT8_C( 246), UINT8_C(   0), UINT8_C( 238),
                             UINT8_C(   1), UINT8_C( 116), UINT8_C(  62), UINT8_C( 183),
                             UINT8_C( 134), UINT8_C(   0), UINT8_C( 111), UINT8_C(  95),
                             UINT8_C( 236), UINT8_C(   3), UINT8_C( 122), UINT8_C( 135),
                             UINT8_C(  13), UINT8_C(  25), UINT8_C( 221), UINT8_C( 129),
                             UINT8_C(  82), UINT8_C(  90), UINT8_C(  53), UINT8_C( 123),
                             UINT8_C(  73), UINT8_C( 108), UINT8_C( 238), UINT8_C(  15),
                             UINT8_C(  81), UINT8_C( 229), UINT8_C( 102), UINT8_C( 118),
                             UINT8_C(  39), UINT8_C( 179), UINT8_C(  45), UINT8_C(  81),
                             UINT8_C( 239), UINT8_C( 228), UINT8_C(  67), UINT8_C( 138),
                             UINT8_C(  79), UINT8_C( 143), UINT8_C( 134), UINT8_C( 124)),
      UINT64_C(10224647434006242820),
      simde_x_mm512_set_epu8(UINT8_C(  68), UINT8_C( 148), UINT8_C( 135), UINT8_C( 141),
                             UINT8_C( 197), UINT8_C( 178), UINT8_C( 145), UINT8_C(  56),
                             UINT8_C(   9), UINT8_C( 135), UINT8_C( 120), UINT8_C( 220),
                             UINT8_C(  36), UINT8_C( 153), UINT8_C( 152), UINT8_C(  25),
                             UINT8_C( 145), UINT8_C( 193), UINT8_C( 221), UINT8_C( 136),
                             UINT8_C(  28), UINT8_C( 212), UINT8_C( 230), UINT8_C( 170),
                             UINT8_C( 243), UINT8_C(  53), UINT8_C( 168), UINT8_C( 149),
                             UINT8_C(  68), UINT8_C(  42), UINT8_C( 138), UINT8_C( 111),
                             UINT8_C(  54), UINT8_C( 198), UINT8_C( 243), UINT8_C(  27),
                             UINT8_C(  23), UINT8_C(  41), UINT8_C( 137), UINT8_C(  44),
                             UINT8_C(   7), UINT8_C( 136), UINT8_C(  32), UINT8_C( 213),
                             UINT8_C( 114), UINT8_C( 184), UINT8_C(  73), UINT8_C( 160),
                             UINT8_C(  96), UINT8_C( 110), UINT8_C( 175), UINT8_C( 180),
                             UINT8_C( 103), UINT8_C( 156), UINT8_C( 234), UINT8_C(  18),
                             UINT8_C( 115), UINT8_C(  54), UINT8_C( 216), UINT8_C( 125),
                             UINT8_C( 110), UINT8_C(  31), UINT8_C(  51), UINT8_C( 152)),
      simde_x_mm512_set_epu8(UINT8_C( 242), UINT8_C(  85), UINT8_C( 176), UINT8_C(  80),
                             UINT8_C(  48), UINT8_C(  93), UINT8_C(  79), UINT8_C( 127),
                             UINT8_C(  16), UINT8_C(  41), UINT8_C(  54), UINT8_C( 140),
                             UINT8_C(  17), UINT8_C(  42), UINT8_C( 170), UINT8_C(  38),
                             UINT8_C( 138), UINT8_C( 200), UINT8_C(  60), UINT8_C(  19),
                             UINT8_C( 156), UINT8_C( 149), UINT8_C( 105), UINT8_C( 180),
                             UINT8_C(  10), UINT8_C( 247), UINT8_C( 244), UINT8_C( 200),
                             UINT8_C( 185), UINT8_C(  96), UINT8_C(   6), UINT8_C(  24),
                             UINT8_C(  69), UINT8_C(  73), UINT8_C( 229), UINT8_C(   3),
                             UINT8_C( 161), UINT8_C(  50), UINT8_C( 189), UINT8_C( 217),
                             UINT8_C(  97), UINT8_C(  62), UINT8_C( 101), UINT8_C(  56),
                             UINT8_C( 177), UINT8_C(  83), UINT8_C( 157), UINT8_C( 200),
                             UINT8_C( 239), UINT8_C( 200), UINT8_C( 248), UINT8_C( 240),
                             UINT8_C(  84), UINT8_C( 161), UINT8_C( 183), UINT8_C(  54),
                             UINT8_C( 125), UINT8_C(  85), UINT8_C(  78), UINT8_C( 191),
                             UINT8_C(   4), UINT8_C( 113), UINT8_C( 240), UINT8_C( 203)),
      simde_x_mm512_set_epu8(UINT8_C( 255), UINT8_C( 116), UINT8_C( 178), UINT8_C( 237),
                             UINT8_C( 245), UINT8_C( 255), UINT8_C( 190), UINT8_C( 183),
                             UINT8_C(  25), UINT8_C( 176), UINT8_C( 174), UINT8_C( 137),
                             UINT8_C(  30), UINT8_C( 195), UINT8_C( 233), UINT8_C(  63),
                             UINT8_C(  15), UINT8_C( 119), UINT8_C( 255), UINT8_C( 155),
                             UINT8_C( 184), UINT8_C( 255), UINT8_C( 255), UINT8_C( 238),
                             UINT8_C( 253), UINT8_C( 116), UINT8_C( 255), UINT8_C( 183),
                             UINT8_C( 253), UINT8_C(   0), UINT8_C( 144), UINT8_C( 135),
                             UINT8_C( 236), UINT8_C(   3), UINT8_C( 255), UINT8_C(  30),
                             UINT8_C(  13), UINT8_C(  25), UINT8_C( 221), UINT8_C( 255),
                             UINT8_C( 104), UINT8_C(  90), UINT8_C(  53), UINT8_C( 123),
                             UINT8_C( 255), UINT8_C( 255), UINT8_C( 238), UINT8_C( 255),
                             UINT8_C(  81), UINT8_C( 229), UINT8_C( 255), UINT8_C( 118),
                             UINT8_C(  39), UINT8_C( 255), UINT8_C( 255), UINT8_C(  81),
                             UINT8_C( 239), UINT8_C( 228), UINT8_C(  67), UINT8_C( 138),
                             UINT8_C(  79), UINT8_C( 144), UINT8_C( 134), UINT8_C( 124)) },
    { simde_x_mm512_set_epu8(UINT8_C( 133), UINT8_C( 156), UINT8_C( 217), UINT8_C( 212),
                             UINT8_C(  22), UINT8_C( 112), UINT8_C(  16), UINT8_C(  15),
                             UINT8_C( 152), UINT8_C( 154), UINT8_C( 102), UINT8_C( 161),
                             UINT8_C(  69), UINT8_C(  13), UINT8_C( 235), UINT8_C(  45),
                             UINT8_C(  62), UINT8_C( 136), UINT8_C( 145), UINT8_C(  32),
                             UINT8_C( 149), UINT8_C( 226), UINT8_C(  99), UINT8_C( 192),
                             UINT8_C(   8), UINT8_C( 214), UINT8_C(  81), UINT8_C( 222),
                             UINT8_C( 210), UINT8_C(  26), UINT8_C(  31), UINT8_C( 254),
                             UINT8_C(  68), UINT8_C( 249), UINT8_C( 185), UINT8_C(  46),
                             UINT8_C( 235), UINT8_C( 183), UINT8_C(  21), UINT8_C(  83),
                             UINT8_C( 148), UINT8_C( 159), UINT8_C( 187), UINT8_C(  73),
                             UINT8_C(  57), UINT8_C( 219), UINT8_C(  21), UINT8_C(  82),
                             UINT8_C( 137), UINT8_C( 130), UINT8_C( 126), UINT8_C(  91),
                             UINT8_C( 115), UINT8_C(  31), UINT8_C( 177), UINT8_C(  28),
                             UINT8_C( 150), UINT8_C( 238), UINT8_C(  65), UINT8_C( 152),
                             UINT8_C(  81), UINT8_C(  38), UINT8_C( 172), UINT8_C( 254)),
      UINT64_C( 4597426592773770833),
      simde_x_mm512_set_epu8(UINT8_C(  74), UINT8_C(  72), UINT8_C( 252), UINT8_C(  28),
                             UINT8_C( 141), UINT8_C(  93), UINT8_C( 102), UINT8_C(  44),
                             UINT8_C( 153), UINT8_C( 227), UINT8_C( 206), UINT8_C(  48),
                             UINT8_C( 160), UINT8_C( 206), UINT8_C(  46), UINT8_C( 191),
                             UINT8_C(   4), UINT8_C(  43), UINT8_C( 181), UINT8_C(  97),
                             UINT8_C( 230), UINT8_C( 153), UINT8_C(  71), UINT8_C( 149),
                             UINT8_C(  91), UINT8_C(  45), UINT8_C( 245), UINT8_C(  47),
                             UINT8_C(  29), UINT8_C(  25), UINT8_C(  26), UINT8_C( 247),
                             UINT8_C(  10), UINT8_C(  36), UINT8_C( 177), UINT8_C( 203),
                             UINT8_C(  41), UINT8_C(   1), UINT8_C( 233), UINT8_C( 193),
                             UINT8_C( 129), UINT8_C(  68), UINT8_C(  48), UINT8_C(  36),
                             UINT8_C(  89), UINT8_C( 144), UINT8_C( 225), UINT8_C( 120),
                             UINT8_C(  35), UINT8_C(  62), UINT8_C( 235), UINT8_C( 142),
                             UINT8_C( 152), UINT8_C(  57), UINT8_C(  42), UINT8_C( 145),
                             UINT8_C(  94), UINT8_C( 193), UINT8_C( 247), UINT8_C(  64),
                             UINT8_C( 191), UINT8_C( 254), UINT8_C( 110), UINT8_C( 248)),
      simde_x_mm512_set_epu8(UINT8_C(  44), UINT8_C( 164), UINT8_C( 225), UINT8_C(  26),
                             UINT8_C( 157), UINT8_C( 203), UINT8_C( 117), UINT8_C(  18),
                             UINT8_C( 193), UINT8_C(  45), UINT8_C(  12), UINT8_C(  24),
                             UINT8_C( 148), UINT8_C(  18), UINT8_C( 196), UINT8_C(  28),
                             UINT8_C(  50), UINT8_C( 245), UINT8_C( 188), UINT8_C( 225),
                             UINT8_C( 105), UINT8_C( 150), UINT8_C(  98), UINT8_C(  51),
                             UINT8_C(  58), UINT8_C( 103), UINT8_C( 111), UINT8_C( 129),
                             UINT8_C(  68), UINT8_C( 200), UINT8_C( 124), UINT8_C( 137),
                             UINT8_C(  74), UINT8_C( 194), UINT8_C( 140), UINT8_C(  37),
                             UINT8_C( 244), UINT8_C( 114), UINT8_C(   0), UINT8_C(  61),
                             UINT8_C( 103), UINT8_C( 252), UINT8_C( 151), UINT8_C( 188),
                             UINT8_C(  39), UINT8_C( 156), UINT8_C( 163), UINT8_C(  11),
                             UINT8_C( 176), UINT8_C( 237), UINT8_C( 234), UINT8_C( 217),
                             UINT8_C( 127), UINT8_C( 218), UINT8_C( 131), UINT8_C( 145),
                             UINT8_C(  84), UINT8_C( 160), UINT8_C(  87), UINT8_C( 234),
                             UINT8_C( 251), UINT8_C( 253), UINT8_C( 129), UINT8_C(  41)),
      simde_x_mm512_set_epu8(UINT8_C( 133), UINT8_C( 156), UINT8_C( 255), UINT8_C(  54),
                             UINT8_C( 255), UINT8_C( 255), UINT8_C( 219), UINT8_C(  62),
                             UINT8_C( 255), UINT8_C( 255), UINT8_C( 102), UINT8_C( 161),
                             UINT8_C( 255), UINT8_C( 224), UINT8_C( 235), UINT8_C( 219),
                             UINT8_C(  62), UINT8_C( 255), UINT8_C( 145), UINT8_C( 255),
                             UINT8_C( 149), UINT8_C( 255), UINT8_C( 169), UINT8_C( 200),
                             UINT8_C(   8), UINT8_C( 214), UINT8_C( 255), UINT8_C( 222),
                             UINT8_C( 210), UINT8_C(  26), UINT8_C(  31), UINT8_C( 254),
                             UINT8_C(  84), UINT8_C( 249), UINT8_C( 255), UINT8_C( 240),
                             UINT8_C( 255), UINT8_C( 115), UINT8_C( 233), UINT8_C( 254),
                             UINT8_C( 148), UINT8_C( 159), UINT8_C( 199), UINT8_C( 224),
                             UINT8_C(  57), UINT8_C( 255), UINT8_C( 255), UINT8_C( 131),
                             UINT8_C( 137), UINT8_C( 130), UINT8_C( 126), UINT8_C(  91),
                             UINT8_C( 255), UINT8_C( 255), UINT8_C( 173), UINT8_C(  28),
                             UINT8_C( 150), UINT8_C( 255), UINT8_C(  65), UINT8_C( 255),
                             UINT8_C(  81), UINT8_C(  38), UINT8_C( 172), UINT8_C( 255)) },
    { simde_x_mm512_set_epu8(UINT8_C( 226), UINT8_C( 219), UINT8_C(  51), UINT8_C( 220),
                             UINT8_C(   8), UINT8_C(  52), UINT8_C(  97), UINT8_C( 123),
                             UINT8_C( 207), UINT8_C( 132), UINT8_C(  95), UINT8_C( 173),
                             UINT8_C(  70), UINT8_C( 206), UINT8_C( 195), UINT8_C(  25),
                             UINT8_C( 159), UINT8_C(  28), UINT8_C( 198), UINT8_C(  11),
                             UINT8_C( 242), UINT8_C( 126), UINT8_C(  81), UINT8_C(  45),
                             UINT8_C( 233), UINT8_C( 120), UINT8_C( 173), UINT8_C( 240),
                             UINT8_C(   7), UINT8_C(  51), UINT8_C( 199), UINT8_C( 206),
                             UINT8_C( 235), UINT8_C(  98), UINT8_C(  88), UINT8_C(   0),
                             UINT8_C( 190), UINT8_C(   3), UINT8_C( 124), UINT8_C( 143),
                             UINT8_C(  50), UINT8_C(  88), UINT8_C( 171), UINT8_C( 163),
                             UINT8_C( 212), UINT8_C( 243), UINT8_C( 162), UINT8_C(  17),
                             UINT8_C( 254), UINT8_C(  79), UINT8_C( 140), UINT8_C(  43),
                             UINT8_C( 179), UINT8_C( 131), UINT8_C( 233), UINT8_C( 136),
                             UINT8_C(  96), UINT8_C( 192), UINT8_C( 233), UINT8_C( 210),
                             UINT8_C( 227), UINT8_C( 185), UINT8_C(  71), UINT8_C(  90)),
      UINT64_C(12627002542648829104),
      simde_x_mm512_set_epu8(UINT8_C(  56), UINT8_C( 211), UINT8_C( 148), UINT8_C( 237),
                             UINT8_C( 132), UINT8_C( 229), UINT8_C(  22), UINT8_C( 126),
                             UINT8_C( 150), UINT8_C( 188), UINT8_C( 196), UINT8_C(   8),
                             UINT8_C(  60), UINT8_C(  93), UINT8_C( 223), UINT8_C( 229),
                             UINT8_C( 249), UINT8_C(  27), UINT8_C( 134), UINT8_C( 218),
                             UINT8_C(  23), UINT8_C(   6), UINT8_C(  45), UINT8_C( 235),
                             UINT8_C( 233), UINT8_C( 155), UINT8_C( 116), UINT8_C( 127),
                             UINT8_C(  96), UINT8_C(  40), UINT8_C( 159), UINT8_C(  40),
                             UINT8_C(  86), UINT8_C( 212), UINT8_C(  70), UINT8_C( 185),
                             UINT8_C(  62), UINT8_C( 235), UINT8_C(  66), UINT8_C(  68),
                             UINT8_C( 169), UINT8_C( 195), UINT8_C(  48), UINT8_C( 186),
                             UINT8_C(  18), UINT8_C( 178), UINT8_C( 158), UINT8_C( 117),
                             UINT8_C(  74), UINT8_C(  32), UINT8_C(  93), UINT8_C( 125),
                             UINT8_C( 209), UINT8_C( 196), UINT8_C( 170), UINT8_C( 117),
                             UINT8_C( 122), UINT8_C( 202), UINT8_C(  50), UINT8_C( 123),
                             UINT8_C( 225), UINT8_C( 182), UINT8_C( 192), UINT8_C(  54)),
      simde_x_mm512_set_epu8(UINT8_C( 115), UINT8_C(  51), UINT8_C( 165), UINT8_C(  56),
                             UINT8_C(  64), UINT8_C( 217), UINT8_C( 137), UINT8_C( 228),
                             UINT8_C( 202), UINT8_C(  28), UINT8_C(  54), UINT8_C( 248),
                             UINT8_C( 202), UINT8_C( 128), UINT8_C( 228), UINT8_C( 185),
                             UINT8_C( 107), UINT8_C( 190), UINT8_C( 142), UINT8_C( 168),
                             UINT8_C(  34), UINT8_C( 173), UINT8_C( 235), UINT8_C( 192),
                             UINT8_C( 121), UINT8_C( 236), UINT8_C( 167), UINT8_C( 162),
                             UINT8_C( 112), UINT8_C( 229), UINT8_C(  81), UINT8_C( 202),
                             UINT8_C( 192), UINT8_C( 142), UINT8_C(  48), UINT8_C( 167),
                             UINT8_C( 195), UINT8_C(  26), UINT8_C(  43), UINT8_C(  29),
                             UINT8_C(   0), UINT8_C(  64), UINT8_C( 123), UINT8_C( 189),
                             UINT8_C(  15), UINT8_C( 120), UINT8_C(  36), UINT8_C(  40),
                             UINT8_C( 106), UINT8_C( 138), UINT8_C( 148), UINT8_C( 198),
                             UINT8_C(  26), UINT8_C( 145), UINT8_C(  63), UINT8_C( 158),
                             UINT8_C( 243), UINT8_C( 244), UINT8_C( 132), UINT8_C(  96),
                             UINT8_C( 243), UINT8_C( 158), UINT8_C(  99), UINT8_C( 243)),
      simde_x_mm512_set_epu8(UINT8_C( 171), UINT8_C( 219), UINT8_C( 255), UINT8_C( 220),
                             UINT8_C( 196), UINT8_C( 255), UINT8_C( 159), UINT8_C( 255),
                             UINT8_C( 207), UINT8_C( 132), UINT8_C( 250), UINT8_C( 255),
                             UINT8_C( 255), UINT8_C( 221), UINT8_C( 195), UINT8_C(  25),
                             UINT8_C( 159), UINT8_C(  28), UINT8_C( 198), UINT8_C( 255),
                             UINT8_C(  57), UINT8_C( 179), UINT8_C( 255), UINT8_C( 255),
                             UINT8_C( 255), UINT8_C( 255), UINT8_C( 255), UINT8_C( 240),
                             UINT8_C( 208), UINT8_C(  51), UINT8_C( 199), UINT8_C( 242),
                             UINT8_C( 235), UINT8_C( 255), UINT8_C( 118), UINT8_C(   0),
                             UINT8_C( 255), UINT8_C( 255), UINT8_C( 124), UINT8_C( 143),
                             UINT8_C( 169), UINT8_C(  88), UINT8_C( 171), UINT8_C( 163),
                             UINT8_C(  33), UINT8_C( 243), UINT8_C( 162), UINT8_C( 157),
                             UINT8_C( 180), UINT8_C(  79), UINT8_C( 241), UINT8_C(  43),
                             UINT8_C( 179), UINT8_C( 255), UINT8_C( 233), UINT8_C( 136),
                             UINT8_C( 255), UINT8_C( 192), UINT8_C( 182), UINT8_C( 219),
                             UINT8_C( 227), UINT8_C( 185), UINT8_C(  71), UINT8_C(  90)) },
    { simde_x_mm512_set_epu8(UINT8_C(  72), UINT8_C(  45), UINT8_C( 120), UINT8_C( 251),
                             UINT8_C( 147), UINT8_C(  62), UINT8_C(  17), UINT8_C(  31),
                             UINT8_C( 226), UINT8_C( 198), UINT8_C(  56), UINT8_C(  21),
                             UINT8_C(  72), UINT8_C( 182), UINT8_C( 216), UINT8_C( 120),
                             UINT8_C(  95), UINT8_C( 108), UINT8_C(  32), UINT8_C(  64),
                             UINT8_C( 128), UINT8_C( 102), UINT8_C( 235), UINT8_C(  28),
                             UINT8_C( 105), UINT8_C(  52), UINT8_C(  85), UINT8_C( 152),
                             UINT8_C(  57), UINT8_C( 225), UINT8_C( 218), UINT8_C( 132),
                             UINT8_C( 149), UINT8_C( 254), UINT8_C(  55), UINT8_C(  46),
                             UINT8_C( 185), UINT8_C(  77), UINT8_C(  18), UINT8_C(  70),
                             UINT8_C(  89), UINT8_C( 125), UINT8_C( 214), UINT8_C( 131),
                             UINT8_C( 121), UINT8_C( 245), UINT8_C( 187), UINT8_C( 197),
                             UINT8_C( 203), UINT8_C(  34), UINT8_C(   9), UINT8_C(  64),
                             UINT8_C( 195), UINT8_C( 231), UINT8_C( 141), UINT8_C( 100),
                             UINT8_C(  65), UINT8_C(   8), UINT8_C(  69), UINT8_C( 248),
                             UINT8_C( 241), UINT8_C( 205), UINT8_C(   1), UINT8_C(  90)),
      UINT64_C(14515151237088493607),
      simde_x_mm512_set_epu8(UINT8_C( 230), UINT8_C( 247), UINT8_C(  66), UINT8_C(   1),
                             UINT8_C( 243), UINT8_C(  60), UINT8_C( 137), UINT8_C( 173),
                             UINT8_C( 134), UINT8_C( 192), UINT8_C( 173), UINT8_C( 182),
                             UINT8_C( 119), UINT8_C( 248), UINT8_C(  12), UINT8_C( 113),
                             UINT8_C( 244), UINT8_C( 172), UINT8_C(   6), UINT8_C(  69),
                             UINT8_C(   2), UINT8_C( 181), UINT8_C( 222), UINT8_C( 130),
                             UINT8_C(   3), UINT8_C( 128), UINT8_C( 247), UINT8_C(  24),
                             UINT8_C(  11), UINT8_C( 162), UINT8_C( 224), UINT8_C( 110),
                             UINT8_C(  33), UINT8_C( 232), UINT8_C( 125), UINT8_C(  35),
                             UINT8_C( 153), UINT8_C( 208), UINT8_C( 234), UINT8_C(  38),
                             UINT8_C( 175), UINT8_C(   9), UINT8_C( 245), UINT8_C( 132),
                             UINT8_C(  71), UINT8_C(  31), UINT8_C( 214), UINT8_C(  93),
                             UINT8_C(  67), UINT8_C(  45), UINT8_C(  51), UINT8_C( 164),
                             UINT8_C( 126), UINT8_C( 108), UINT8_C( 133), UINT8_C( 185),
                             UINT8_C( 113), UINT8_C(  32), UINT8_C(  71), UINT8_C(  55),
                             UINT8_C( 230), UINT8_C(  82), UINT8_C( 175), UINT8_C( 236)),
      simde_x_mm512_set_epu8(UINT8_C( 131), UINT8_C( 121), UINT8_C( 128), UINT8_C( 103),
                             UINT8_C(   0), UINT8_C( 101), UINT8_C( 215), UINT8_C(  89),
                             UINT8_C( 173), UINT8_C( 191), UINT8_C(   9), UINT8_C( 249),
                             UINT8_C( 193), UINT8_C(  13), UINT8_C( 105), UINT8_C(  92),
                             UINT8_C( 238), UINT8_C( 235), UINT8_C( 154), UINT8_C( 142),
                             UINT8_C(  74), UINT8_C( 121), UINT8_C( 211), UINT8_C(  52),
                             UINT8_C( 193), UINT8_C( 163), UINT8_C(  98), UINT8_C( 106),
                             UINT8_C( 147), UINT8_C( 209), UINT8_C(  37), UINT8_C(  70),
                             UINT8_C( 100), UINT8_C( 121), UINT8_C(  18), UINT8_C(  28),
                             UINT8_C( 139), UINT8_C( 107), UINT8_C(   3), UINT8_C( 194),
                             UINT8_C(  42), UINT8_C(  72), UINT8_C(  91), UINT8_C(  86),
                             UINT8_C( 184), UINT8_C(   9), UINT8_C( 176), UINT8_C( 118),
                             UINT8_C( 122), UINT8_C( 148), UINT8_C( 186), UINT8_C( 193),
                             UINT8_C(  56), UINT8_C(  71), UINT8_C( 242), UINT8_C(  49),
                             UINT8_C( 183), UINT8_C(  53), UINT8_C( 227), UINT8_C(   3),
                             UINT8_C( 183), UINT8_C(  43), UINT8_C( 234), UINT8_C(  85)),
      simde_x_mm512_set_epu8(UINT8_C( 255), UINT8_C( 255), UINT8_C( 120), UINT8_C( 251),
                             UINT8_C( 243), UINT8_C(  62), UINT8_C(  17), UINT8_C( 255),
                             UINT8_C( 226), UINT8_C( 255), UINT8_C( 182), UINT8_C( 255),
                             UINT8_C(  72), UINT8_C( 182), UINT8_C( 216), UINT8_C( 120),
                             UINT8_C(  95), UINT8_C( 108), UINT8_C( 160), UINT8_C(  64),
                             UINT8_C(  76), UINT8_C( 255), UINT8_C( 235), UINT8_C( 182),
                             UINT8_C( 105), UINT8_C(  52), UINT8_C( 255), UINT8_C( 152),
                             UINT8_C(  57), UINT8_C( 255), UINT8_C( 218), UINT8_C( 180),
                             UINT8_C( 149), UINT8_C( 255), UINT8_C(  55), UINT8_C(  46),
                             UINT8_C( 185), UINT8_C(  77), UINT8_C( 237), UINT8_C( 232),
                             UINT8_C( 217), UINT8_C( 125), UINT8_C( 255), UINT8_C( 218),
                             UINT8_C( 255), UINT8_C( 245), UINT8_C( 255), UINT8_C( 211),
                             UINT8_C( 203), UINT8_C( 193), UINT8_C(   9), UINT8_C(  64),
                             UINT8_C( 195), UINT8_C( 231), UINT8_C( 141), UINT8_C( 100),
                             UINT8_C(  65), UINT8_C(   8), UINT8_C( 255), UINT8_C( 248),
                             UINT8_C( 241), UINT8_C( 125), UINT8_C( 255), UINT8_C( 255)) },
    { simde_x_mm512_set_epu8(UINT8_C( 209), UINT8_C(  84), UINT8_C( 130), UINT8_C( 192),
                             UINT8_C(  14), UINT8_C(  11), UINT8_C(  37), UINT8_C( 233),
                             UINT8_C(  67), UINT8_C( 124), UINT8_C(  58), UINT8_C( 162),
                             UINT8_C(  30), UINT8_C( 223), UINT8_C(  70), UINT8_C( 232),
                             UINT8_C(  38), UINT8_C( 159), UINT8_C( 200), UINT8_C( 196),
                             UINT8_C( 197), UINT8_C(  65), UINT8_C( 182), UINT8_C(  45),
                             UINT8_C( 245), UINT8_C(  55), UINT8_C( 174), UINT8_C(  12),
                             UINT8_C( 106), UINT8_C(  22), UINT8_C( 132), UINT8_C( 252),
                             UINT8_C(   2), UINT8_C( 175), UINT8_C(  14), UINT8_C(  90),
                             UINT8_C( 156), UINT8_C( 134), UINT8_C( 221), UINT8_C(  81),
                             UINT8_C( 242), UINT8_C( 214), UINT8_C( 125), UINT8_C( 131),
                             UINT8_C( 199), UINT8_C(  90), UINT8_C( 247), UINT8_C(  63),
                             UINT8_C(  53), UINT8_C(  77), UINT8_C(  63), UINT8_C( 172),
                             UINT8_C(  27), UINT8_C(  22), UINT8_C(   3), UINT8_C( 219),
                             UINT8_C(  65), UINT8_C( 118), UINT8_C( 130), UINT8_C(  97),
                             UINT8_C( 109), UINT8_C(   7), UINT8_C( 142), UINT8_C( 181)),
      UINT64_C( 8707623543556880126),
      simde_x_mm512_set_epu8(UINT8_C(  84), UINT8_C( 185), UINT8_C(   8), UINT8_C(  12),
                             UINT8_C( 245), UINT8_C( 180), UINT8_C(  62), UINT8_C(  93),
                             UINT8_C( 181), UINT8_C( 179), UINT8_C( 172), UINT8_C( 148),
                             UINT8_C( 221), UINT8_C(  14), UINT8_C( 196), UINT8_C(  18),
                             UINT8_C(  23), UINT8_C( 196), UINT8_C( 193), UINT8_C( 142),
                             UINT8_C( 201), UINT8_C(  75), UINT8_C( 157), UINT8_C( 201),
                             UINT8_C(  58), UINT8_C(  76), UINT8_C( 154), UINT8_C( 138),
                             UINT8_C( 226), UINT8_C(  39), UINT8_C( 119), UINT8_C(  85),
                             UINT8_C( 248), UINT8_C( 184), UINT8_C( 196), UINT8_C( 162),
                             UINT8_C( 144), UINT8_C( 119), UINT8_C( 124), UINT8_C(  76),
                             UINT8_C( 214), UINT8_C( 132), UINT8_C(  54), UINT8_C(  74),
                             UINT8_C( 164), UINT8_C(  99), UINT8_C(  79), UINT8_C( 253),
                             UINT8_C(  61), UINT8_C( 167), UINT8_C(  84), UINT8_C( 162),
                             UINT8_C(  31), UINT8_C( 140), UINT8_C( 189), UINT8_C( 154),
                             UINT8_C( 184), UINT8_C( 165), UINT8_C( 151), UINT8_C( 148),
                             UINT8_C( 212), UINT8_C(  74), UINT8_C( 228), UINT8_C( 124)),
      simde_x_mm512_set_epu8(UINT8_C(   1), UINT8_C(  75), UINT8_C(  21), UINT8_C( 220),
                             UINT8_C( 130), UINT8_C( 122), UINT8_C(  71), UINT8_C(  76),
                             UINT8_C(  28), UINT8_C( 200), UINT8_C(  32), UINT8_C( 101),
                             UINT8_C( 149), UINT8_C( 145), UINT8_C( 168), UINT8_C( 237),
                             UINT8_C( 179), UINT8_C(  19), UINT8_C( 235), UINT8_C( 145),
                             UINT8_C( 188), UINT8_C(  82), UINT8_C( 138), UINT8_C( 180),
                             UINT8_C(  47), UINT8_C( 127), UINT8_C(  62), UINT8_C( 240),
                             UINT8_C(  10), UINT8_C( 242), UINT8_C( 156), UINT8_C(  86),
                             UINT8_C(  29), UINT8_C( 107), UINT8_C(  56), UINT8_C(  21),
                             UINT8_C(  24), UINT8_C(  68), UINT8_C( 160), UINT8_C(  64),
                             UINT8_C(  48), UINT8_C(  13), UINT8_C( 173), UINT8_C(   4),
                             UINT8_C( 253), UINT8_C( 192), UINT8_C(  17), UINT8_C( 141),
                             UINT8_C(  21), UINT8_C( 108), UINT8_C( 125), UINT8_C( 196),
                             UINT8_C( 184), UINT8_C(  74), UINT8_C( 251), UINT8_C( 198),
                             UINT8_C( 215), UINT8_C(  22), UINT8_C( 141), UINT8_C( 102),
                             UINT8_C(  59), UINT8_C( 176), UINT8_C( 241), UINT8_C( 193)),
      simde_x_mm512_set_epu8(UINT8_C( 209), UINT8_C( 255), UINT8_C(  29), UINT8_C( 232),
                             UINT8_C( 255), UINT8_C(  11), UINT8_C(  37), UINT8_C( 233),
                             UINT8_C( 209), UINT8_C( 255), UINT8_C(  58), UINT8_C( 249),
                             UINT8_C(  30), UINT8_C( 159), UINT8_C( 255), UINT8_C( 255),
                             UINT8_C( 202), UINT8_C( 159), UINT8_C( 255), UINT8_C( 255),
                             UINT8_C( 197), UINT8_C(  65), UINT8_C( 182), UINT8_C( 255),
                             UINT8_C( 245), UINT8_C( 203), UINT8_C( 216), UINT8_C( 255),
                             UINT8_C( 236), UINT8_C(  22), UINT8_C( 255), UINT8_C( 252),
                             UINT8_C(   2), UINT8_C( 255), UINT8_C(  14), UINT8_C( 183),
                             UINT8_C( 156), UINT8_C( 187), UINT8_C( 255), UINT8_C( 140),
                             UINT8_C( 255), UINT8_C( 214), UINT8_C( 125), UINT8_C( 131),
                             UINT8_C( 255), UINT8_C(  90), UINT8_C( 247), UINT8_C( 255),
                             UINT8_C(  53), UINT8_C(  77), UINT8_C( 209), UINT8_C( 255),
                             UINT8_C(  27), UINT8_C( 214), UINT8_C( 255), UINT8_C( 219),
                             UINT8_C( 255), UINT8_C( 187), UINT8_C( 255), UINT8_C( 250),
                             UINT8_C( 255), UINT8_C( 250), UINT8_C( 255), UINT8_C( 181)) },
    { simde_x_mm512_set_epu8(UINT8_C( 192), UINT8_C( 203), UINT8_C( 214), UINT8_C( 126),
                             UINT8_C(  67), UINT8_C(  50), UINT8_C( 238), UINT8_C(  76),
                             UINT8_C( 237), UINT8_C( 123), UINT8_C( 169), UINT8_C( 106),
                             UINT8_C( 182), UINT8_C(  44), UINT8_C( 117), UINT8_C( 103),
                             UINT8_C(  81), UINT8_C( 122), UINT8_C(  56), UINT8_C( 246),
                             UINT8_C(  67), UINT8_C(  79), UINT8_C(  83), UINT8_C( 218),
                             UINT8_C( 243), UINT8_C(  43), UINT8_C(  27), UINT8_C( 159),
                             UINT8_C( 102), UINT8_C( 126), UINT8_C(  38), UINT8_C( 194),
                             UINT8_C( 232), UINT8_C( 117), UINT8_C( 218), UINT8_C( 163),
                             UINT8_C( 198), UINT8_C( 132), UINT8_C( 181), UINT8_C(  10),
                             UINT8_C(  18), UINT8_C( 182), UINT8_C(  14), UINT8_C(  36),
                             UINT8_C( 249), UINT8_C( 113), UINT8_C(  40), UINT8_C(  48),
                             UINT8_C( 149), UINT8_C( 222), UINT8_C( 181), UINT8_C(  85),
                             UINT8_C( 221), UINT8_C( 140), UINT8_C(  65), UINT8_C( 235),
                             UINT8_C(  15), UINT8_C(   3), UINT8_C(  45), UINT8_C(  21),
                             UINT8_C(  72), UINT8_C(  93), UINT8_C( 108), UINT8_C( 125)),
      UINT64_C(12576710173448868104),
      simde_x_mm512_set_epu8(UINT8_C(  90), UINT8_C( 218), UINT8_C( 158), UINT8_C( 186),
                             UINT8_C( 148), UINT8_C(  20), UINT8_C(  43), UINT8_C( 128),
                             UINT8_C(  77), UINT8_C( 108), UINT8_C(  53), UINT8_C(  82),
                             UINT8_C( 206), UINT8_C(  52), UINT8_C(  56), UINT8_C(  58),
                             UINT8_C( 136), UINT8_C( 213), UINT8_C( 114), UINT8_C(  93),
                             UINT8_C( 212), UINT8_C( 241), UINT8_C(  38), UINT8_C( 239),
                             UINT8_C( 146), UINT8_C( 133), UINT8_C( 217), UINT8_C( 114),
                             UINT8_C(  51), UINT8_C( 141), UINT8_C( 182), UINT8_C(  43),
                             UINT8_C(  41), UINT8_C( 220), UINT8_C(  19), UINT8_C(  69),
                             UINT8_C(  60), UINT8_C( 203), UINT8_C( 112), UINT8_C( 108),
                             UINT8_C(   8), UINT8_C(  46), UINT8_C( 221), UINT8_C(  26),
                             UINT8_C(  11), UINT8_C(  42), UINT8_C(  47), UINT8_C(  59),
                             UINT8_C( 199), UINT8_C(  94), UINT8_C( 131), UINT8_C( 132),
                             UINT8_C(  36), UINT8_C(  57), UINT8_C(  68), UINT8_C( 204),
                             UINT8_C(  39), UINT8_C(  50), UINT8_C( 208), UINT8_C(  94),
                             UINT8_C(  53), UINT8_C(  11), UINT8_C(  29), UINT8_C(  65)),
      simde_x_mm512_set_epu8(UINT8_C( 149), UINT8_C( 120), UINT8_C( 198), UINT8_C( 107),
                             UINT8_C( 224), UINT8_C( 224), UINT8_C(  88), UINT8_C( 213),
                             UINT8_C(  31), UINT8_C( 224), UINT8_C( 192), UINT8_C(  27),
                             UINT8_C(  82), UINT8_C( 166), UINT8_C( 202), UINT8_C( 172),
                             UINT8_C( 226), UINT8_C(  63), UINT8_C(  24), UINT8_C(  81),
                             UINT8_C( 248), UINT8_C(   9), UINT8_C( 221), UINT8_C( 155),
                             UINT8_C(  83), UINT8_C( 107), UINT8_C( 209), UINT8_C( 200),
                             UINT8_C(  57), UINT8_C( 168), UINT8_C( 141), UINT8_C( 236),
                             UINT8_C(  58), UINT8_C(  75), UINT8_C(  56), UINT8_C(  93),
                             UINT8_C(  49), UINT8_C(  43), UINT8_C( 108), UINT8_C( 118),
                             UINT8_C( 177), UINT8_C( 112), UINT8_C(  44), UINT8_C( 144),
                             UINT8_C( 204), UINT8_C(  10), UINT8_C(  28), UINT8_C( 170),
                             UINT8_C(  65), UINT8_C(  62), UINT8_C(  86), UINT8_C( 149),
                             UINT8_C(  24), UINT8_C( 201), UINT8_C(  54), UINT8_C( 146),
                             UINT8_C( 223), UINT8_C( 110), UINT8_C( 140), UINT8_C( 217),
                             UINT8_C(  39), UINT8_C( 144), UINT8_C(  64), UINT8_C(  43)),
      simde_x_mm512_set_epu8(UINT8_C( 239), UINT8_C( 203), UINT8_C( 255), UINT8_C( 126),
                             UINT8_C( 255), UINT8_C( 244), UINT8_C( 131), UINT8_C(  76),
                             UINT8_C( 108), UINT8_C( 123), UINT8_C( 169), UINT8_C( 106),
                             UINT8_C( 255), UINT8_C(  44), UINT8_C( 117), UINT8_C( 230),
                             UINT8_C(  81), UINT8_C( 255), UINT8_C( 138), UINT8_C( 174),
                             UINT8_C(  67), UINT8_C(  79), UINT8_C( 255), UINT8_C( 255),
                             UINT8_C( 243), UINT8_C( 240), UINT8_C(  27), UINT8_C( 159),
                             UINT8_C( 102), UINT8_C( 255), UINT8_C(  38), UINT8_C( 194),
                             UINT8_C(  99), UINT8_C( 117), UINT8_C(  75), UINT8_C( 162),
                             UINT8_C( 109), UINT8_C( 132), UINT8_C( 220), UINT8_C( 226),
                             UINT8_C(  18), UINT8_C( 158), UINT8_C( 255), UINT8_C( 170),
                             UINT8_C( 249), UINT8_C(  52), UINT8_C(  75), UINT8_C(  48),
                             UINT8_C( 149), UINT8_C( 222), UINT8_C( 181), UINT8_C( 255),
                             UINT8_C( 221), UINT8_C( 140), UINT8_C(  65), UINT8_C( 255),
                             UINT8_C(  15), UINT8_C(   3), UINT8_C(  45), UINT8_C(  21),
                             UINT8_C(  92), UINT8_C(  93), UINT8_C( 108), UINT8_C( 125)) },
    { simde_x_mm512_set_epu8(UINT8_C( 153), UINT8_C( 132), UINT8_C(  13), UINT8_C( 176),
                             UINT8_C( 224), UINT8_C( 123), UINT8_C( 115), UINT8_C( 207),
                             UINT8_C( 113), UINT8_C( 205), UINT8_C( 119), UINT8_C( 189),
                             UINT8_C( 235), UINT8_C(  19), UINT8_C( 244), UINT8_C(  29),
                             UINT8_C(  91), UINT8_C( 192), UINT8_C(  88), UINT8_C( 151),
                             UINT8_C(  24), UINT8_C(  31), UINT8_C(  77), UINT8_C(  92),
                             UINT8_C( 171), UINT8_C(  48), UINT8_C( 143), UINT8_C( 142),
                             UINT8_C(  16), UINT8_C(  18), UINT8_C( 212), UINT8_C( 190),
                             UINT8_C(  25), UINT8_C( 151), UINT8_C( 156), UINT8_C( 165),
                             UINT8_C(  26), UINT8_C( 133), UINT8_C( 223), UINT8_C( 219),
                             UINT8_C(  63), UINT8_C(  13), UINT8_C( 132), UINT8_C(  41),
                             UINT8_C( 152), UINT8_C( 197), UINT8_C( 254), UINT8_C( 202),
                             UINT8_C(  73), UINT8_C(   3), UINT8_C( 238), UINT8_C(  10),
                             UINT8_C(  19), UINT8_C(  58), UINT8_C( 244), UINT8_C( 181),
                             UINT8_C( 168), UINT8_C(  59), UINT8_C( 104), UINT8_C( 216),
                             UINT8_C( 174), UINT8_C(  42), UINT8_C( 183), UINT8_C( 162)),
      UINT64_C( 2633789449456316803),
      simde_x_mm512_set_epu8(UINT8_C( 118), UINT8_C(  44), UINT8_C( 242), UINT8_C(  84),
                             UINT8_C( 187), UINT8_C( 208), UINT8_C(  40), UINT8_C(  86),
                             UINT8_C( 255), UINT8_C( 121), UINT8_C( 216), UINT8_C(  44),
                             UINT8_C( 255), UINT8_C(  38), UINT8_C( 212), UINT8_C(  38),
                             UINT8_C(  93), UINT8_C( 149), UINT8_C( 252), UINT8_C( 195),
                             UINT8_C( 204), UINT8_C(  22), UINT8_C( 202), UINT8_C( 131),
                             UINT8_C( 227), UINT8_C(  25), UINT8_C( 179), UINT8_C( 188),
                             UINT8_C(   9), UINT8_C( 221), UINT8_C( 245), UINT8_C(  53),
                             UINT8_C(  28), UINT8_C(  61), UINT8_C( 221), UINT8_C( 150),
                             UINT8_C( 210), UINT8_C( 121), UINT8_C( 154), UINT8_C( 121),
                             UINT8_C( 202), UINT8_C( 196), UINT8_C(   7), UINT8_C(   2),
                             UINT8_C( 137), UINT8_C( 111), UINT8_C( 236), UINT8_C( 198),
                             UINT8_C( 158), UINT8_C(  83), UINT8_C(  32), UINT8_C( 207),
                             UINT8_C( 245), UINT8_C(  48), UINT8_C(  92), UINT8_C(  47),
                             UINT8_C( 218), UINT8_C(  11), UINT8_C(  26), UINT8_C(  90),
                             UINT8_C( 251), UINT8_C(  73), UINT8_C(  45), UINT8_C( 254)),
      simde_x_mm512_set_epu8(UINT8_C( 225), UINT8_C( 126), UINT8_C( 138), UINT8_C( 199),
                             UINT8_C( 130), UINT8_C(  29), UINT8_C( 101), UINT8_C( 241),
                             UINT8_C( 195), UINT8_C( 118), UINT8_C( 102), UINT8_C(  12),
                             UINT8_C( 197), UINT8_C( 215), UINT8_C( 196), UINT8_C(  46),
                             UINT8_C(  63), UINT8_C(  78), UINT8_C(  87), UINT8_C(  18),
                             UINT8_C(  18), UINT8_C(  32), UINT8_C( 230), UINT8_C( 250),
                             UINT8_C( 236), UINT8_C( 133), UINT8_C(  99), UINT8_C(  65),
                             UINT8_C(  13), UINT8_C(  25), UINT8_C( 108), UINT8_C( 135),
                             UINT8_C(  42), UINT8_C(   0), UINT8_C( 104), UINT8_C( 239),
                             UINT8_C( 111), UINT8_C( 146), UINT8_C( 217), UINT8_C( 125),
                             UINT8_C( 206), UINT8_C( 209), UINT8_C(  30), UINT8_C(  92),
                             UINT8_C(  19), UINT8_C( 248), UINT8_C( 136), UINT8_C( 127),
                             UINT8_C( 207), UINT8_C(  23), UINT8_C(  16), UINT8_C( 192),
                             UINT8_C( 177), UINT8_C( 116), UINT8_C( 251), UINT8_C( 206),
                             UINT8_C(  32), UINT8_C(  22), UINT8_C( 214), UINT8_C( 253),
                             UINT8_C(  30), UINT8_C(  64), UINT8_C(  96), UINT8_C( 190)),
      simde_x_mm512_set_epu8(UINT8_C( 153), UINT8_C( 132), UINT8_C( 255), UINT8_C( 176),
                             UINT8_C( 224), UINT8_C( 237), UINT8_C( 115), UINT8_C( 207),
                             UINT8_C( 255), UINT8_C( 205), UINT8_C( 119), UINT8_C( 189),
                             UINT8_C( 255), UINT8_C( 253), UINT8_C( 244), UINT8_C(  84),
                             UINT8_C(  91), UINT8_C( 192), UINT8_C(  88), UINT8_C( 213),
                             UINT8_C( 222), UINT8_C(  31), UINT8_C(  77), UINT8_C( 255),
                             UINT8_C( 255), UINT8_C(  48), UINT8_C( 143), UINT8_C( 142),
                             UINT8_C(  22), UINT8_C( 246), UINT8_C( 212), UINT8_C( 190),
                             UINT8_C(  70), UINT8_C(  61), UINT8_C( 156), UINT8_C( 165),
                             UINT8_C(  26), UINT8_C( 255), UINT8_C( 223), UINT8_C( 219),
                             UINT8_C(  63), UINT8_C(  13), UINT8_C( 132), UINT8_C(  41),
                             UINT8_C( 152), UINT8_C( 197), UINT8_C( 255), UINT8_C( 255),
                             UINT8_C( 255), UINT8_C( 106), UINT8_C(  48), UINT8_C( 255),
                             UINT8_C(  19), UINT8_C(  58), UINT8_C( 244), UINT8_C( 253),
                             UINT8_C( 250), UINT8_C(  59), UINT8_C( 104), UINT8_C( 216),
                             UINT8_C( 174), UINT8_C(  42), UINT8_C( 141), UINT8_C( 255)) },
    { simde_x_mm512_set_epu8(UINT8_C( 117), UINT8_C(  69), UINT8_C( 121), UINT8_C( 211),
                             UINT8_C(  30), UINT8_C( 183), UINT8_C(   2), UINT8_C( 216),
                             UINT8_C(  95), UINT8_C( 253), UINT8_C(  16), UINT8_C( 178),
                             UINT8_C( 128), UINT8_C( 215), UINT8_C( 190), UINT8_C(  66),
                             UINT8_C(  93), UINT8_C( 224), UINT8_C( 206), UINT8_C( 254),
                             UINT8_C( 195), UINT8_C(  29), UINT8_C( 168), UINT8_C( 138),
                             UINT8_C( 229), UINT8_C(  42), UINT8_C(  78), UINT8_C( 210),
                             UINT8_C( 177), UINT8_C(  38), UINT8_C( 181), UINT8_C(  14),
                             UINT8_C( 138), UINT8_C( 142), UINT8_C( 136), UINT8_C(  42),
                             UINT8_C(   4), UINT8_C(  79), UINT8_C( 172), UINT8_C( 146),
                             UINT8_C(   0), UINT8_C(  85), UINT8_C( 236), UINT8_C(  61),
                             UINT8_C(  40), UINT8_C( 181), UINT8_C(  69), UINT8_C( 157),
                             UINT8_C(  73), UINT8_C( 222), UINT8_C( 242), UINT8_C(  72),
                             UINT8_C( 101), UINT8_C(  96), UINT8_C( 142), UINT8_C( 132),
                             UINT8_C( 169), UINT8_C(  43), UINT8_C( 138), UINT8_C( 114),
                             UINT8_C( 168), UINT8_C(   8), UINT8_C( 204), UINT8_C(  75)),
      UINT64_C(14890918166471265655),
      simde_x_mm512_set_epu8(UINT8_C( 200), UINT8_C( 186), UINT8_C(  66), UINT8_C( 145),
                             UINT8_C( 187), UINT8_C(  15), UINT8_C( 174), UINT8_C( 244),
                             UINT8_C( 167), UINT8_C(  37), UINT8_C(  80), UINT8_C( 120),
                             UINT8_C( 173), UINT8_C( 136), UINT8_C(  95), UINT8_C(  21),
                             UINT8_C(  91), UINT8_C( 159), UINT8_C( 184), UINT8_C(  42),
                             UINT8_C(  22), UINT8_C( 186), UINT8_C(  71), UINT8_C( 178),
                             UINT8_C( 251), UINT8_C(  52), UINT8_C( 234), UINT8_C( 222),
                             UINT8_C(  16), UINT8_C(  92), UINT8_C(  91), UINT8_C( 184),
                             UINT8_C(   3), UINT8_C( 225), UINT8_C( 161), UINT8_C( 200),
                             UINT8_C( 206), UINT8_C(  68), UINT8_C( 232), UINT8_C( 206),
                             UINT8_C(  94), UINT8_C(  67), UINT8_C( 108), UINT8_C( 138),
                             UINT8_C( 191), UINT8_C(  31), UINT8_C(  70), UINT8_C( 108),
                             UINT8_C( 190), UINT8_C( 107), UINT8_C( 171), UINT8_C(  38),
                             UINT8_C(   2), UINT8_C(  32), UINT8_C(  56), UINT8_C(  66),
                             UINT8_C( 254), UINT8_C( 182), UINT8_C( 112), UINT8_C(  10),
                             UINT8_C(  64), UINT8_C( 100), UINT8_C( 201), UINT8_C(  83)),
      simde_x_mm512_set_epu8(UINT8_C( 187), UINT8_C( 211), UINT8_C(  23), UINT8_C(  70),
                             UINT8_C(  22), UINT8_C( 113), UINT8_C(  75), UINT8_C( 139),
                             UINT8_C(  69), UINT8_C( 182), UINT8_C(  40), UINT8_C( 217),
                             UINT8_C( 205), UINT8_C( 165), UINT8_C(  25), UINT8_C( 252),
                             UINT8_C( 244), UINT8_C( 243), UINT8_C( 179), UINT8_C(  75),
                             UINT8_C( 140), UINT8_C( 220), UINT8_C(  38), UINT8_C( 204),
                             UINT8_C(  13), UINT8_C( 204), UINT8_C( 156), UINT8_C( 210),
                             UINT8_C(  13), UINT8_C(  83), UINT8_C( 162), UINT8_C( 102),
                             UINT8_C( 116), UINT8_C( 196), UINT8_C(  44), UINT8_C( 249),
                             UINT8_C( 104), UINT8_C( 206), UINT8_C( 226), UINT8_C(  17),
                             UINT8_C(  13), UINT8_C( 149), UINT8_C( 111), UINT8_C( 243),
                             UINT8_C(  17), UINT8_C( 211), UINT8_C( 225), UINT8_C(  76),
                             UINT8_C( 154), UINT8_C( 185), UINT8_C( 116), UINT8_C(  72),
                             UINT8_C( 245), UINT8_C( 159), UINT8_C(  93), UINT8_C(  48),
                             UINT8_C( 181), UINT8_C( 166), UINT8_C( 246), UINT8_C( 178),
                             UINT8_C( 248), UINT8_C( 246), UINT8_C(  48), UINT8_C( 245)),
      simde_x_mm512_set_epu8(UINT8_C( 255), UINT8_C( 255), UINT8_C( 121), UINT8_C( 211),
                             UINT8_C( 209), UINT8_C( 128), UINT8_C( 249), UINT8_C( 216),
                             UINT8_C( 236), UINT8_C( 253), UINT8_C( 120), UINT8_C( 178),
                             UINT8_C( 128), UINT8_C( 255), UINT8_C( 120), UINT8_C( 255),
                             UINT8_C(  93), UINT8_C( 224), UINT8_C( 255), UINT8_C( 254),
                             UINT8_C( 162), UINT8_C(  29), UINT8_C( 109), UINT8_C( 255),
                             UINT8_C( 229), UINT8_C(  42), UINT8_C( 255), UINT8_C( 210),
                             UINT8_C(  29), UINT8_C( 175), UINT8_C( 181), UINT8_C( 255),
                             UINT8_C( 138), UINT8_C( 255), UINT8_C( 136), UINT8_C(  42),
                             UINT8_C( 255), UINT8_C(  79), UINT8_C( 255), UINT8_C( 223),
                             UINT8_C( 107), UINT8_C( 216), UINT8_C( 219), UINT8_C(  61),
                             UINT8_C( 208), UINT8_C( 242), UINT8_C( 255), UINT8_C( 157),
                             UINT8_C(  73), UINT8_C( 255), UINT8_C( 242), UINT8_C(  72),
                             UINT8_C( 247), UINT8_C( 191), UINT8_C( 142), UINT8_C( 114),
                             UINT8_C( 169), UINT8_C( 255), UINT8_C( 255), UINT8_C( 188),
                             UINT8_C( 168), UINT8_C( 255), UINT8_C( 249), UINT8_C( 255)) },
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])); i++) {
    simde__m512i r = simde_mm512_mask_adds_epu8(test_vec[i].src, test_vec[i].k, test_vec[i].a, test_vec[i].b);
    simde_assert_m512i_u8(r, ==, test_vec[i].r);
  }

  return 0;
}

static int
test_simde_mm512_maskz_adds_epu8(SIMDE_MUNIT_TEST_ARGS) {
  const struct {
    simde__mmask64 k;
    simde__m512i a;
    simde__m512i b;
    simde__m512i r;
  } test_vec[8] = {
    { UINT64_C(17286015531074160252),
      simde_x_mm512_set_epu8(UINT8_C( 141), UINT8_C( 229), UINT8_C(  62), UINT8_C( 171),
                             UINT8_C(  49), UINT8_C( 141), UINT8_C(  38), UINT8_C(   4),
                             UINT8_C(  92), UINT8_C( 116), UINT8_C( 178), UINT8_C( 237),
                             UINT8_C( 183), UINT8_C(  22), UINT8_C( 190), UINT8_C( 227),
                             UINT8_C(  55), UINT8_C(  78), UINT8_C( 211), UINT8_C( 137),
                             UINT8_C(  30), UINT8_C( 227), UINT8_C( 233), UINT8_C(  89),
                             UINT8_C(  15), UINT8_C( 119), UINT8_C( 168), UINT8_C( 109),
                             UINT8_C( 240), UINT8_C( 246), UINT8_C(   0), UINT8_C( 238),
                             UINT8_C(   1), UINT8_C( 116), UINT8_C(  62), UINT8_C( 183),
                             UINT8_C( 134), UINT8_C(   0), UINT8_C( 111), UINT8_C(  95),
                             UINT8_C( 236), UINT8_C(   3), UINT8_C( 122), UINT8_C( 135),
                             UINT8_C(  13), UINT8_C(  25), UINT8_C( 221), UINT8_C( 129),
                             UINT8_C(  82), UINT8_C(  90), UINT8_C(  53), UINT8_C( 123),
                             UINT8_C(  73), UINT8_C( 108), UINT8_C( 238), UINT8_C(  15),
                             UINT8_C(  81), UINT8_C( 229), UINT8_C( 102), UINT8_C( 118),
                             UINT8_C(  39), UINT8_C( 179), UINT8_C(  45), UINT8_C(  81)),
      simde_x_mm512_set_epu8(UINT8_C(  68), UINT8_C( 148), UINT8_C( 135), UINT8_C( 141),
                             UINT8_C( 197), UINT8_C( 178), UINT8_C( 145), UINT8_C(  56),
                             UINT8_C(   9), UINT8_C( 135), UINT8_C( 120), UINT8_C( 220),
                             UINT8_C(  36), UINT8_C( 153), UINT8_C( 152), UINT8_C(  25),
                             UINT8_C( 145), UINT8_C( 193), UINT8_C( 221), UINT8_C( 136),
                             UINT8_C(  28), UINT8_C( 212), UINT8_C( 230), UINT8_C( 170),
                             UINT8_C( 243), UINT8_C(  53), UINT8_C( 168), UINT8_C( 149),
                             UINT8_C(  68), UINT8_C(  42), UINT8_C( 138), UINT8_C( 111),
                             UINT8_C(  54), UINT8_C( 198), UINT8_C( 243), UINT8_C(  27),
                             UINT8_C(  23), UINT8_C(  41), UINT8_C( 137), UINT8_C(  44),
                             UINT8_C(   7), UINT8_C( 136), UINT8_C(  32), UINT8_C( 213),
                             UINT8_C( 114), UINT8_C( 184), UINT8_C(  73), UINT8_C( 160),
                             UINT8_C(  96), UINT8_C( 110), UINT8_C( 175), UINT8_C( 180),
                             UINT8_C( 103), UINT8_C( 156), UINT8_C( 234), UINT8_C(  18),
                             UINT8_C( 115), UINT8_C(  54), UINT8_C( 216), UINT8_C( 125),
                             UINT8_C( 110), UINT8_C(  31), UINT8_C(  51), UINT8_C( 152)),
      simde_x_mm512_set_epu8(UINT8_C( 209), UINT8_C( 255), UINT8_C( 197), UINT8_C(   0),
                             UINT8_C( 246), UINT8_C( 255), UINT8_C( 183), UINT8_C(  60),
                             UINT8_C( 101), UINT8_C( 251), UINT8_C( 255), UINT8_C(   0),
                             UINT8_C(   0), UINT8_C( 175), UINT8_C(   0), UINT8_C(   0),
                             UINT8_C(   0), UINT8_C( 255), UINT8_C(   0), UINT8_C(   0),
                             UINT8_C(   0), UINT8_C(   0), UINT8_C( 255), UINT8_C( 255),
                             UINT8_C( 255), UINT8_C(   0), UINT8_C(   0), UINT8_C(   0),
                             UINT8_C( 255), UINT8_C(   0), UINT8_C( 138), UINT8_C(   0),
                             UINT8_C(   0), UINT8_C( 255), UINT8_C(   0), UINT8_C(   0),
                             UINT8_C( 157), UINT8_C(  41), UINT8_C( 248), UINT8_C( 139),
                             UINT8_C( 243), UINT8_C(   0), UINT8_C(   0), UINT8_C(   0),
                             UINT8_C( 127), UINT8_C( 209), UINT8_C( 255), UINT8_C( 255),
                             UINT8_C( 178), UINT8_C(   0), UINT8_C(   0), UINT8_C(   0),
                             UINT8_C(   0), UINT8_C( 255), UINT8_C( 255), UINT8_C(   0),
                             UINT8_C(   0), UINT8_C( 255), UINT8_C( 255), UINT8_C( 243),
                             UINT8_C( 149), UINT8_C( 210), UINT8_C(   0), UINT8_C(   0)) },
    { UINT64_C( 9031211210081693899),
      simde_x_mm512_set_epu8(UINT8_C( 150), UINT8_C( 238), UINT8_C(  65), UINT8_C( 152),
                             UINT8_C(  81), UINT8_C(  38), UINT8_C( 172), UINT8_C( 254),
                             UINT8_C( 242), UINT8_C(  85), UINT8_C( 176), UINT8_C(  80),
                             UINT8_C(  48), UINT8_C(  93), UINT8_C(  79), UINT8_C( 127),
                             UINT8_C(  16), UINT8_C(  41), UINT8_C(  54), UINT8_C( 140),
                             UINT8_C(  17), UINT8_C(  42), UINT8_C( 170), UINT8_C(  38),
                             UINT8_C( 138), UINT8_C( 200), UINT8_C(  60), UINT8_C(  19),
                             UINT8_C( 156), UINT8_C( 149), UINT8_C( 105), UINT8_C( 180),
                             UINT8_C(  10), UINT8_C( 247), UINT8_C( 244), UINT8_C( 200),
                             UINT8_C( 185), UINT8_C(  96), UINT8_C(   6), UINT8_C(  24),
                             UINT8_C(  69), UINT8_C(  73), UINT8_C( 229), UINT8_C(   3),
                             UINT8_C( 161), UINT8_C(  50), UINT8_C( 189), UINT8_C( 217),
                             UINT8_C(  97), UINT8_C(  62), UINT8_C( 101), UINT8_C(  56),
                             UINT8_C( 177), UINT8_C(  83), UINT8_C( 157), UINT8_C( 200),
                             UINT8_C( 239), UINT8_C( 200), UINT8_C( 248), UINT8_C( 240),
                             UINT8_C(  84), UINT8_C( 161), UINT8_C( 183), UINT8_C(  54)),
      simde_x_mm512_set_epu8(UINT8_C(  63), UINT8_C( 205), UINT8_C(  87), UINT8_C(  32),
                             UINT8_C( 191), UINT8_C(  55), UINT8_C(  14), UINT8_C(  81),
                             UINT8_C( 133), UINT8_C( 156), UINT8_C( 217), UINT8_C( 212),
                             UINT8_C(  22), UINT8_C( 112), UINT8_C(  16), UINT8_C(  15),
                             UINT8_C( 152), UINT8_C( 154), UINT8_C( 102), UINT8_C( 161),
                             UINT8_C(  69), UINT8_C(  13), UINT8_C( 235), UINT8_C(  45),
                             UINT8_C(  62), UINT8_C( 136), UINT8_C( 145), UINT8_C(  32),
                             UINT8_C( 149), UINT8_C( 226), UINT8_C(  99), UINT8_C( 192),
                             UINT8_C(   8), UINT8_C( 214), UINT8_C(  81), UINT8_C( 222),
                             UINT8_C( 210), UINT8_C(  26), UINT8_C(  31), UINT8_C( 254),
                             UINT8_C(  68), UINT8_C( 249), UINT8_C( 185), UINT8_C(  46),
                             UINT8_C( 235), UINT8_C( 183), UINT8_C(  21), UINT8_C(  83),
                             UINT8_C( 148), UINT8_C( 159), UINT8_C( 187), UINT8_C(  73),
                             UINT8_C(  57), UINT8_C( 219), UINT8_C(  21), UINT8_C(  82),
                             UINT8_C( 137), UINT8_C( 130), UINT8_C( 126), UINT8_C(  91),
                             UINT8_C( 115), UINT8_C(  31), UINT8_C( 177), UINT8_C(  28)),
      simde_x_mm512_set_epu8(UINT8_C(   0), UINT8_C( 255), UINT8_C( 152), UINT8_C( 184),
                             UINT8_C( 255), UINT8_C(  93), UINT8_C(   0), UINT8_C( 255),
                             UINT8_C(   0), UINT8_C( 241), UINT8_C(   0), UINT8_C( 255),
                             UINT8_C(   0), UINT8_C( 205), UINT8_C(   0), UINT8_C( 142),
                             UINT8_C(   0), UINT8_C( 195), UINT8_C(   0), UINT8_C(   0),
                             UINT8_C(  86), UINT8_C(  55), UINT8_C( 255), UINT8_C(   0),
                             UINT8_C( 200), UINT8_C(   0), UINT8_C( 205), UINT8_C(  51),
                             UINT8_C( 255), UINT8_C( 255), UINT8_C( 204), UINT8_C( 255),
                             UINT8_C(   0), UINT8_C(   0), UINT8_C(   0), UINT8_C(   0),
                             UINT8_C(   0), UINT8_C( 122), UINT8_C(   0), UINT8_C(   0),
                             UINT8_C(   0), UINT8_C( 255), UINT8_C( 255), UINT8_C(  49),
                             UINT8_C(   0), UINT8_C(   0), UINT8_C(   0), UINT8_C( 255),
                             UINT8_C( 245), UINT8_C( 221), UINT8_C( 255), UINT8_C( 129),
                             UINT8_C(   0), UINT8_C(   0), UINT8_C(   0), UINT8_C(   0),
                             UINT8_C( 255), UINT8_C( 255), UINT8_C(   0), UINT8_C(   0),
                             UINT8_C( 199), UINT8_C(   0), UINT8_C( 255), UINT8_C(  82)) },
    { UINT64_C( 6828010367541473016),
      simde_x_mm512_set_epu8(UINT8_C(  84), UINT8_C( 160), UINT8_C(  87), UINT8_C( 234),
                             UINT8_C( 251), UINT8_C( 253), UINT8_C( 129), UINT8_C(  41),
                             UINT8_C(  74), UINT8_C(  72), UINT8_C( 252), UINT8_C(  28),
                             UINT8_C( 141), UINT8_C(  93), UINT8_C( 102), UINT8_C(  44),
                             UINT8_C( 153), UINT8_C( 227), UINT8_C( 206), UINT8_C(  48),
                             UINT8_C( 160), UINT8_C( 206), UINT8_C(  46), UINT8_C( 191),
                             UINT8_C(   4), UINT8_C(  43), UINT8_C( 181), UINT8_C(  97),
                             UINT8_C( 230), UINT8_C( 153), UINT8_C(  71), UINT8_C( 149),
                             UINT8_C(  91), UINT8_C(  45), UINT8_C( 245), UINT8_C(  47),
                             UINT8_C(  29), UINT8_C(  25), UINT8_C(  26), UINT8_C( 247),
                             UINT8_C(  10), UINT8_C(  36), UINT8_C( 177), UINT8_C( 203),
                             UINT8_C(  41), UINT8_C(   1), UINT8_C( 233), UINT8_C( 193),
                             UINT8_C( 129), UINT8_C(  68), UINT8_C(  48), UINT8_C(  36),
                             UINT8_C(  89), UINT8_C( 144), UINT8_C( 225), UINT8_C( 120),
                             UINT8_C(  35), UINT8_C(  62), UINT8_C( 235), UINT8_C( 142),
                             UINT8_C( 152), UINT8_C(  57), UINT8_C(  42), UINT8_C( 145)),
      simde_x_mm512_set_epu8(UINT8_C(  96), UINT8_C( 192), UINT8_C( 233), UINT8_C( 210),
                             UINT8_C( 227), UINT8_C( 185), UINT8_C(  71), UINT8_C(  90),
                             UINT8_C(  44), UINT8_C( 164), UINT8_C( 225), UINT8_C(  26),
                             UINT8_C( 157), UINT8_C( 203), UINT8_C( 117), UINT8_C(  18),
                             UINT8_C( 193), UINT8_C(  45), UINT8_C(  12), UINT8_C(  24),
                             UINT8_C( 148), UINT8_C(  18), UINT8_C( 196), UINT8_C(  28),
                             UINT8_C(  50), UINT8_C( 245), UINT8_C( 188), UINT8_C( 225),
                             UINT8_C( 105), UINT8_C( 150), UINT8_C(  98), UINT8_C(  51),
                             UINT8_C(  58), UINT8_C( 103), UINT8_C( 111), UINT8_C( 129),
                             UINT8_C(  68), UINT8_C( 200), UINT8_C( 124), UINT8_C( 137),
                             UINT8_C(  74), UINT8_C( 194), UINT8_C( 140), UINT8_C(  37),
                             UINT8_C( 244), UINT8_C( 114), UINT8_C(   0), UINT8_C(  61),
                             UINT8_C( 103), UINT8_C( 252), UINT8_C( 151), UINT8_C( 188),
                             UINT8_C(  39), UINT8_C( 156), UINT8_C( 163), UINT8_C(  11),
                             UINT8_C( 176), UINT8_C( 237), UINT8_C( 234), UINT8_C( 217),
                             UINT8_C( 127), UINT8_C( 218), UINT8_C( 131), UINT8_C( 145)),
      simde_x_mm512_set_epu8(UINT8_C(   0), UINT8_C( 255), UINT8_C(   0), UINT8_C( 255),
                             UINT8_C( 255), UINT8_C( 255), UINT8_C( 200), UINT8_C(   0),
                             UINT8_C( 118), UINT8_C( 236), UINT8_C(   0), UINT8_C(   0),
                             UINT8_C(   0), UINT8_C(   0), UINT8_C(   0), UINT8_C(  62),
                             UINT8_C( 255), UINT8_C( 255), UINT8_C( 218), UINT8_C(  72),
                             UINT8_C(   0), UINT8_C( 224), UINT8_C( 242), UINT8_C( 219),
                             UINT8_C(   0), UINT8_C( 255), UINT8_C(   0), UINT8_C(   0),
                             UINT8_C(   0), UINT8_C(   0), UINT8_C(   0), UINT8_C(   0),
                             UINT8_C( 149), UINT8_C(   0), UINT8_C( 255), UINT8_C( 176),
                             UINT8_C(  97), UINT8_C( 225), UINT8_C( 150), UINT8_C( 255),
                             UINT8_C(  84), UINT8_C( 230), UINT8_C( 255), UINT8_C( 240),
                             UINT8_C( 255), UINT8_C( 115), UINT8_C( 233), UINT8_C(   0),
                             UINT8_C(   0), UINT8_C( 255), UINT8_C( 199), UINT8_C(   0),
                             UINT8_C( 128), UINT8_C( 255), UINT8_C( 255), UINT8_C(   0),
                             UINT8_C( 211), UINT8_C( 255), UINT8_C( 255), UINT8_C( 255),
                             UINT8_C( 255), UINT8_C(   0), UINT8_C(   0), UINT8_C(   0)) },
    { UINT64_C(18325019528117086600),
      simde_x_mm512_set_epu8(UINT8_C( 122), UINT8_C( 202), UINT8_C(  50), UINT8_C( 123),
                             UINT8_C( 225), UINT8_C( 182), UINT8_C( 192), UINT8_C(  54),
                             UINT8_C( 175), UINT8_C(  60), UINT8_C(  31), UINT8_C( 233),
                             UINT8_C( 108), UINT8_C( 137), UINT8_C( 164), UINT8_C( 176),
                             UINT8_C( 226), UINT8_C( 219), UINT8_C(  51), UINT8_C( 220),
                             UINT8_C(   8), UINT8_C(  52), UINT8_C(  97), UINT8_C( 123),
                             UINT8_C( 207), UINT8_C( 132), UINT8_C(  95), UINT8_C( 173),
                             UINT8_C(  70), UINT8_C( 206), UINT8_C( 195), UINT8_C(  25),
                             UINT8_C( 159), UINT8_C(  28), UINT8_C( 198), UINT8_C(  11),
                             UINT8_C( 242), UINT8_C( 126), UINT8_C(  81), UINT8_C(  45),
                             UINT8_C( 233), UINT8_C( 120), UINT8_C( 173), UINT8_C( 240),
                             UINT8_C(   7), UINT8_C(  51), UINT8_C( 199), UINT8_C( 206),
                             UINT8_C( 235), UINT8_C(  98), UINT8_C(  88), UINT8_C(   0),
                             UINT8_C( 190), UINT8_C(   3), UINT8_C( 124), UINT8_C( 143),
                             UINT8_C(  50), UINT8_C(  88), UINT8_C( 171), UINT8_C( 163),
                             UINT8_C( 212), UINT8_C( 243), UINT8_C( 162), UINT8_C(  17)),
      simde_x_mm512_set_epu8(UINT8_C( 243), UINT8_C( 244), UINT8_C( 132), UINT8_C(  96),
                             UINT8_C( 243), UINT8_C( 158), UINT8_C(  99), UINT8_C( 243),
                             UINT8_C(  56), UINT8_C( 211), UINT8_C( 148), UINT8_C( 237),
                             UINT8_C( 132), UINT8_C( 229), UINT8_C(  22), UINT8_C( 126),
                             UINT8_C( 150), UINT8_C( 188), UINT8_C( 196), UINT8_C(   8),
                             UINT8_C(  60), UINT8_C(  93), UINT8_C( 223), UINT8_C( 229),
                             UINT8_C( 249), UINT8_C(  27), UINT8_C( 134), UINT8_C( 218),
                             UINT8_C(  23), UINT8_C(   6), UINT8_C(  45), UINT8_C( 235),
                             UINT8_C( 233), UINT8_C( 155), UINT8_C( 116), UINT8_C( 127),
                             UINT8_C(  96), UINT8_C(  40), UINT8_C( 159), UINT8_C(  40),
                             UINT8_C(  86), UINT8_C( 212), UINT8_C(  70), UINT8_C( 185),
                             UINT8_C(  62), UINT8_C( 235), UINT8_C(  66), UINT8_C(  68),
                             UINT8_C( 169), UINT8_C( 195), UINT8_C(  48), UINT8_C( 186),
                             UINT8_C(  18), UINT8_C( 178), UINT8_C( 158), UINT8_C( 117),
                             UINT8_C(  74), UINT8_C(  32), UINT8_C(  93), UINT8_C( 125),
                             UINT8_C( 209), UINT8_C( 196), UINT8_C( 170), UINT8_C( 117)),
      simde_x_mm512_set_epu8(UINT8_C( 255), UINT8_C( 255), UINT8_C( 182), UINT8_C( 219),
                             UINT8_C( 255), UINT8_C( 255), UINT8_C( 255), UINT8_C(   0),
                             UINT8_C(   0), UINT8_C( 255), UINT8_C(   0), UINT8_C(   0),
                             UINT8_C( 240), UINT8_C( 255), UINT8_C( 186), UINT8_C( 255),
                             UINT8_C( 255), UINT8_C(   0), UINT8_C(   0), UINT8_C(   0),
                             UINT8_C(  68), UINT8_C( 145), UINT8_C(   0), UINT8_C(   0),
                             UINT8_C(   0), UINT8_C(   0), UINT8_C( 229), UINT8_C(   0),
                             UINT8_C(  93), UINT8_C(   0), UINT8_C( 240), UINT8_C( 255),
                             UINT8_C( 255), UINT8_C(   0), UINT8_C( 255), UINT8_C( 138),
                             UINT8_C(   0), UINT8_C(   0), UINT8_C( 240), UINT8_C(  85),
                             UINT8_C( 255), UINT8_C(   0), UINT8_C(   0), UINT8_C(   0),
                             UINT8_C(   0), UINT8_C(   0), UINT8_C( 255), UINT8_C( 255),
                             UINT8_C( 255), UINT8_C( 255), UINT8_C( 136), UINT8_C(   0),
                             UINT8_C( 208), UINT8_C(   0), UINT8_C(   0), UINT8_C( 255),
                             UINT8_C( 124), UINT8_C(   0), UINT8_C(   0), UINT8_C(   0),
                             UINT8_C( 255), UINT8_C(   0), UINT8_C(   0), UINT8_C(   0)) },
    { UINT64_C( 7677112093376593822),
      simde_x_mm512_set_epu8(UINT8_C( 203), UINT8_C(  34), UINT8_C(   9), UINT8_C(  64),
                             UINT8_C( 195), UINT8_C( 231), UINT8_C( 141), UINT8_C( 100),
                             UINT8_C(  65), UINT8_C(   8), UINT8_C(  69), UINT8_C( 248),
                             UINT8_C( 241), UINT8_C( 205), UINT8_C(   1), UINT8_C(  90),
                             UINT8_C( 115), UINT8_C(  51), UINT8_C( 165), UINT8_C(  56),
                             UINT8_C(  64), UINT8_C( 217), UINT8_C( 137), UINT8_C( 228),
                             UINT8_C( 202), UINT8_C(  28), UINT8_C(  54), UINT8_C( 248),
                             UINT8_C( 202), UINT8_C( 128), UINT8_C( 228), UINT8_C( 185),
                             UINT8_C( 107), UINT8_C( 190), UINT8_C( 142), UINT8_C( 168),
                             UINT8_C(  34), UINT8_C( 173), UINT8_C( 235), UINT8_C( 192),
                             UINT8_C( 121), UINT8_C( 236), UINT8_C( 167), UINT8_C( 162),
                             UINT8_C( 112), UINT8_C( 229), UINT8_C(  81), UINT8_C( 202),
                             UINT8_C( 192), UINT8_C( 142), UINT8_C(  48), UINT8_C( 167),
                             UINT8_C( 195), UINT8_C(  26), UINT8_C(  43), UINT8_C(  29),
                             UINT8_C(   0), UINT8_C(  64), UINT8_C( 123), UINT8_C( 189),
                             UINT8_C(  15), UINT8_C( 120), UINT8_C(  36), UINT8_C(  40)),
      simde_x_mm512_set_epu8(UINT8_C( 113), UINT8_C(  32), UINT8_C(  71), UINT8_C(  55),
                             UINT8_C( 230), UINT8_C(  82), UINT8_C( 175), UINT8_C( 236),
                             UINT8_C( 201), UINT8_C( 112), UINT8_C(  45), UINT8_C(  37),
                             UINT8_C(  67), UINT8_C( 187), UINT8_C(  64), UINT8_C(  39),
                             UINT8_C(  72), UINT8_C(  45), UINT8_C( 120), UINT8_C( 251),
                             UINT8_C( 147), UINT8_C(  62), UINT8_C(  17), UINT8_C(  31),
                             UINT8_C( 226), UINT8_C( 198), UINT8_C(  56), UINT8_C(  21),
                             UINT8_C(  72), UINT8_C( 182), UINT8_C( 216), UINT8_C( 120),
                             UINT8_C(  95), UINT8_C( 108), UINT8_C(  32), UINT8_C(  64),
                             UINT8_C( 128), UINT8_C( 102), UINT8_C( 235), UINT8_C(  28),
                             UINT8_C( 105), UINT8_C(  52), UINT8_C(  85), UINT8_C( 152),
                             UINT8_C(  57), UINT8_C( 225), UINT8_C( 218), UINT8_C( 132),
                             UINT8_C( 149), UINT8_C( 254), UINT8_C(  55), UINT8_C(  46),
                             UINT8_C( 185), UINT8_C(  77), UINT8_C(  18), UINT8_C(  70),
                             UINT8_C(  89), UINT8_C( 125), UINT8_C( 214), UINT8_C( 131),
                             UINT8_C( 121), UINT8_C( 245), UINT8_C( 187), UINT8_C( 197)),
      simde_x_mm512_set_epu8(UINT8_C(   0), UINT8_C(  66), UINT8_C(  80), UINT8_C(   0),
                             UINT8_C( 255), UINT8_C(   0), UINT8_C( 255), UINT8_C(   0),
                             UINT8_C( 255), UINT8_C(   0), UINT8_C(   0), UINT8_C(   0),
                             UINT8_C( 255), UINT8_C(   0), UINT8_C(  65), UINT8_C(   0),
                             UINT8_C( 187), UINT8_C(   0), UINT8_C(   0), UINT8_C( 255),
                             UINT8_C(   0), UINT8_C( 255), UINT8_C(   0), UINT8_C(   0),
                             UINT8_C( 255), UINT8_C( 226), UINT8_C(   0), UINT8_C(   0),
                             UINT8_C(   0), UINT8_C( 255), UINT8_C( 255), UINT8_C(   0),
                             UINT8_C(   0), UINT8_C(   0), UINT8_C(   0), UINT8_C( 232),
                             UINT8_C( 162), UINT8_C(   0), UINT8_C( 255), UINT8_C(   0),
                             UINT8_C( 226), UINT8_C(   0), UINT8_C(   0), UINT8_C( 255),
                             UINT8_C(   0), UINT8_C(   0), UINT8_C(   0), UINT8_C( 255),
                             UINT8_C(   0), UINT8_C(   0), UINT8_C( 103), UINT8_C( 213),
                             UINT8_C( 255), UINT8_C( 103), UINT8_C(  61), UINT8_C(  99),
                             UINT8_C(  89), UINT8_C(   0), UINT8_C(   0), UINT8_C( 255),
                             UINT8_C( 136), UINT8_C( 255), UINT8_C( 223), UINT8_C(   0)) },
    { UINT64_C( 4840581956081845689),
      simde_x_mm512_set_epu8(UINT8_C( 122), UINT8_C( 148), UINT8_C( 186), UINT8_C( 193),
                             UINT8_C(  56), UINT8_C(  71), UINT8_C( 242), UINT8_C(  49),
                             UINT8_C( 183), UINT8_C(  53), UINT8_C( 227), UINT8_C(   3),
                             UINT8_C( 183), UINT8_C(  43), UINT8_C( 234), UINT8_C(  85),
                             UINT8_C( 230), UINT8_C( 247), UINT8_C(  66), UINT8_C(   1),
                             UINT8_C( 243), UINT8_C(  60), UINT8_C( 137), UINT8_C( 173),
                             UINT8_C( 134), UINT8_C( 192), UINT8_C( 173), UINT8_C( 182),
                             UINT8_C( 119), UINT8_C( 248), UINT8_C(  12), UINT8_C( 113),
                             UINT8_C( 244), UINT8_C( 172), UINT8_C(   6), UINT8_C(  69),
                             UINT8_C(   2), UINT8_C( 181), UINT8_C( 222), UINT8_C( 130),
                             UINT8_C(   3), UINT8_C( 128), UINT8_C( 247), UINT8_C(  24),
                             UINT8_C(  11), UINT8_C( 162), UINT8_C( 224), UINT8_C( 110),
                             UINT8_C(  33), UINT8_C( 232), UINT8_C( 125), UINT8_C(  35),
                             UINT8_C( 153), UINT8_C( 208), UINT8_C( 234), UINT8_C(  38),
                             UINT8_C( 175), UINT8_C(   9), UINT8_C( 245), UINT8_C( 132),
                             UINT8_C(  71), UINT8_C(  31), UINT8_C( 214), UINT8_C(  93)),
      simde_x_mm512_set_epu8(UINT8_C(  53), UINT8_C(  77), UINT8_C(  63), UINT8_C( 172),
                             UINT8_C(  27), UINT8_C(  22), UINT8_C(   3), UINT8_C( 219),
                             UINT8_C(  65), UINT8_C( 118), UINT8_C( 130), UINT8_C(  97),
                             UINT8_C( 109), UINT8_C(   7), UINT8_C( 142), UINT8_C( 181),
                             UINT8_C( 131), UINT8_C( 121), UINT8_C( 128), UINT8_C( 103),
                             UINT8_C(   0), UINT8_C( 101), UINT8_C( 215), UINT8_C(  89),
                             UINT8_C( 173), UINT8_C( 191), UINT8_C(   9), UINT8_C( 249),
                             UINT8_C( 193), UINT8_C(  13), UINT8_C( 105), UINT8_C(  92),
                             UINT8_C( 238), UINT8_C( 235), UINT8_C( 154), UINT8_C( 142),
                             UINT8_C(  74), UINT8_C( 121), UINT8_C( 211), UINT8_C(  52),
                             UINT8_C( 193), UINT8_C( 163), UINT8_C(  98), UINT8_C( 106),
                             UINT8_C( 147), UINT8_C( 209), UINT8_C(  37), UINT8_C(  70),
                             UINT8_C( 100), UINT8_C( 121), UINT8_C(  18), UINT8_C(  28),
                             UINT8_C( 139), UINT8_C( 107), UINT8_C(   3), UINT8_C( 194),
                             UINT8_C(  42), UINT8_C(  72), UINT8_C(  91), UINT8_C(  86),
                             UINT8_C( 184), UINT8_C(   9), UINT8_C( 176), UINT8_C( 118)),
      simde_x_mm512_set_epu8(UINT8_C(   0), UINT8_C( 225), UINT8_C(   0), UINT8_C(   0),
                             UINT8_C(   0), UINT8_C(   0), UINT8_C( 245), UINT8_C( 255),
                             UINT8_C(   0), UINT8_C(   0), UINT8_C( 255), UINT8_C(   0),
                             UINT8_C( 255), UINT8_C(  50), UINT8_C(   0), UINT8_C( 255),
                             UINT8_C(   0), UINT8_C(   0), UINT8_C( 194), UINT8_C( 104),
                             UINT8_C(   0), UINT8_C(   0), UINT8_C( 255), UINT8_C( 255),
                             UINT8_C( 255), UINT8_C(   0), UINT8_C( 182), UINT8_C(   0),
                             UINT8_C(   0), UINT8_C( 255), UINT8_C(   0), UINT8_C(   0),
                             UINT8_C(   0), UINT8_C( 255), UINT8_C( 160), UINT8_C( 211),
                             UINT8_C(  76), UINT8_C( 255), UINT8_C( 255), UINT8_C(   0),
                             UINT8_C(   0), UINT8_C( 255), UINT8_C( 255), UINT8_C(   0),
                             UINT8_C( 158), UINT8_C( 255), UINT8_C(   0), UINT8_C(   0),
                             UINT8_C( 133), UINT8_C(   0), UINT8_C(   0), UINT8_C(   0),
                             UINT8_C(   0), UINT8_C( 255), UINT8_C(   0), UINT8_C( 232),
                             UINT8_C( 217), UINT8_C(   0), UINT8_C( 255), UINT8_C( 218),
                             UINT8_C( 255), UINT8_C(   0), UINT8_C(   0), UINT8_C( 211)) },
    { UINT64_C(17498311407133456191),
      simde_x_mm512_set_epu8(UINT8_C(  61), UINT8_C( 167), UINT8_C(  84), UINT8_C( 162),
                             UINT8_C(  31), UINT8_C( 140), UINT8_C( 189), UINT8_C( 154),
                             UINT8_C( 184), UINT8_C( 165), UINT8_C( 151), UINT8_C( 148),
                             UINT8_C( 212), UINT8_C(  74), UINT8_C( 228), UINT8_C( 124),
                             UINT8_C( 120), UINT8_C( 215), UINT8_C( 177), UINT8_C( 122),
                             UINT8_C(  87), UINT8_C( 137), UINT8_C(  54), UINT8_C( 254),
                             UINT8_C( 209), UINT8_C(  84), UINT8_C( 130), UINT8_C( 192),
                             UINT8_C(  14), UINT8_C(  11), UINT8_C(  37), UINT8_C( 233),
                             UINT8_C(  67), UINT8_C( 124), UINT8_C(  58), UINT8_C( 162),
                             UINT8_C(  30), UINT8_C( 223), UINT8_C(  70), UINT8_C( 232),
                             UINT8_C(  38), UINT8_C( 159), UINT8_C( 200), UINT8_C( 196),
                             UINT8_C( 197), UINT8_C(  65), UINT8_C( 182), UINT8_C(  45),
                             UINT8_C( 245), UINT8_C(  55), UINT8_C( 174), UINT8_C(  12),
                             UINT8_C( 106), UINT8_C(  22), UINT8_C( 132), UINT8_C( 252),
                             UINT8_C(   2), UINT8_C( 175), UINT8_C(  14), UINT8_C(  90),
                             UINT8_C( 156), UINT8_C( 134), UINT8_C( 221), UINT8_C(  81)),
      simde_x_mm512_set_epu8(UINT8_C(  21), UINT8_C( 108), UINT8_C( 125), UINT8_C( 196),
                             UINT8_C( 184), UINT8_C(  74), UINT8_C( 251), UINT8_C( 198),
                             UINT8_C( 215), UINT8_C(  22), UINT8_C( 141), UINT8_C( 102),
                             UINT8_C(  59), UINT8_C( 176), UINT8_C( 241), UINT8_C( 193),
                             UINT8_C(  84), UINT8_C( 185), UINT8_C(   8), UINT8_C(  12),
                             UINT8_C( 245), UINT8_C( 180), UINT8_C(  62), UINT8_C(  93),
                             UINT8_C( 181), UINT8_C( 179), UINT8_C( 172), UINT8_C( 148),
                             UINT8_C( 221), UINT8_C(  14), UINT8_C( 196), UINT8_C(  18),
                             UINT8_C(  23), UINT8_C( 196), UINT8_C( 193), UINT8_C( 142),
                             UINT8_C( 201), UINT8_C(  75), UINT8_C( 157), UINT8_C( 201),
                             UINT8_C(  58), UINT8_C(  76), UINT8_C( 154), UINT8_C( 138),
                             UINT8_C( 226), UINT8_C(  39), UINT8_C( 119), UINT8_C(  85),
                             UINT8_C( 248), UINT8_C( 184), UINT8_C( 196), UINT8_C( 162),
                             UINT8_C( 144), UINT8_C( 119), UINT8_C( 124), UINT8_C(  76),
                             UINT8_C( 214), UINT8_C( 132), UINT8_C(  54), UINT8_C(  74),
                             UINT8_C( 164), UINT8_C(  99), UINT8_C(  79), UINT8_C( 253)),
      simde_x_mm512_set_epu8(UINT8_C(  82), UINT8_C( 255), UINT8_C( 209), UINT8_C( 255),
                             UINT8_C(   0), UINT8_C(   0), UINT8_C( 255), UINT8_C(   0),
                             UINT8_C( 255), UINT8_C( 187), UINT8_C(   0), UINT8_C( 250),
                             UINT8_C(   0), UINT8_C( 250), UINT8_C( 255), UINT8_C(   0),
                             UINT8_C(   0), UINT8_C( 255), UINT8_C( 185), UINT8_C( 134),
                             UINT8_C( 255), UINT8_C( 255), UINT8_C(   0), UINT8_C( 255),
                             UINT8_C( 255), UINT8_C(   0), UINT8_C(   0), UINT8_C(   0),
                             UINT8_C(   0), UINT8_C(   0), UINT8_C( 233), UINT8_C( 251),
                             UINT8_C(  90), UINT8_C( 255), UINT8_C(   0), UINT8_C(   0),
                             UINT8_C(   0), UINT8_C( 255), UINT8_C( 227), UINT8_C( 255),
                             UINT8_C(   0), UINT8_C( 235), UINT8_C(   0), UINT8_C( 255),
                             UINT8_C( 255), UINT8_C(   0), UINT8_C( 255), UINT8_C(   0),
                             UINT8_C( 255), UINT8_C( 239), UINT8_C( 255), UINT8_C( 174),
                             UINT8_C(   0), UINT8_C( 141), UINT8_C( 255), UINT8_C( 255),
                             UINT8_C(   0), UINT8_C(   0), UINT8_C(  68), UINT8_C( 164),
                             UINT8_C( 255), UINT8_C( 233), UINT8_C( 255), UINT8_C( 255)) },
    { UINT64_C( 3462613925466476941),
      simde_x_mm512_set_epu8(UINT8_C(  18), UINT8_C( 182), UINT8_C(  14), UINT8_C(  36),
                             UINT8_C( 249), UINT8_C( 113), UINT8_C(  40), UINT8_C(  48),
                             UINT8_C( 149), UINT8_C( 222), UINT8_C( 181), UINT8_C(  85),
                             UINT8_C( 221), UINT8_C( 140), UINT8_C(  65), UINT8_C( 235),
                             UINT8_C(  15), UINT8_C(   3), UINT8_C(  45), UINT8_C(  21),
                             UINT8_C(  72), UINT8_C(  93), UINT8_C( 108), UINT8_C( 125),
                             UINT8_C(   1), UINT8_C(  75), UINT8_C(  21), UINT8_C( 220),
                             UINT8_C( 130), UINT8_C( 122), UINT8_C(  71), UINT8_C(  76),
                             UINT8_C(  28), UINT8_C( 200), UINT8_C(  32), UINT8_C( 101),
                             UINT8_C( 149), UINT8_C( 145), UINT8_C( 168), UINT8_C( 237),
                             UINT8_C( 179), UINT8_C(  19), UINT8_C( 235), UINT8_C( 145),
                             UINT8_C( 188), UINT8_C(  82), UINT8_C( 138), UINT8_C( 180),
                             UINT8_C(  47), UINT8_C( 127), UINT8_C(  62), UINT8_C( 240),
                             UINT8_C(  10), UINT8_C( 242), UINT8_C( 156), UINT8_C(  86),
                             UINT8_C(  29), UINT8_C( 107), UINT8_C(  56), UINT8_C(  21),
                             UINT8_C(  24), UINT8_C(  68), UINT8_C( 160), UINT8_C(  64)),
      simde_x_mm512_set_epu8(UINT8_C( 199), UINT8_C(  94), UINT8_C( 131), UINT8_C( 132),
                             UINT8_C(  36), UINT8_C(  57), UINT8_C(  68), UINT8_C( 204),
                             UINT8_C(  39), UINT8_C(  50), UINT8_C( 208), UINT8_C(  94),
                             UINT8_C(  53), UINT8_C(  11), UINT8_C(  29), UINT8_C(  65),
                             UINT8_C( 174), UINT8_C( 137), UINT8_C( 115), UINT8_C(  68),
                             UINT8_C( 187), UINT8_C( 118), UINT8_C(  17), UINT8_C(   8),
                             UINT8_C( 192), UINT8_C( 203), UINT8_C( 214), UINT8_C( 126),
                             UINT8_C(  67), UINT8_C(  50), UINT8_C( 238), UINT8_C(  76),
                             UINT8_C( 237), UINT8_C( 123), UINT8_C( 169), UINT8_C( 106),
                             UINT8_C( 182), UINT8_C(  44), UINT8_C( 117), UINT8_C( 103),
                             UINT8_C(  81), UINT8_C( 122), UINT8_C(  56), UINT8_C( 246),
                             UINT8_C(  67), UINT8_C(  79), UINT8_C(  83), UINT8_C( 218),
                             UINT8_C( 243), UINT8_C(  43), UINT8_C(  27), UINT8_C( 159),
                             UINT8_C( 102), UINT8_C( 126), UINT8_C(  38), UINT8_C( 194),
                             UINT8_C( 232), UINT8_C( 117), UINT8_C( 218), UINT8_C( 163),
                             UINT8_C( 198), UINT8_C( 132), UINT8_C( 181), UINT8_C(  10)),
      simde_x_mm512_set_epu8(UINT8_C(   0), UINT8_C(   0), UINT8_C( 145), UINT8_C( 168),
                             UINT8_C(   0), UINT8_C(   0), UINT8_C(   0), UINT8_C(   0),
                             UINT8_C(   0), UINT8_C(   0), UINT8_C(   0), UINT8_C(   0),
                             UINT8_C( 255), UINT8_C( 151), UINT8_C(   0), UINT8_C( 255),
                             UINT8_C( 189), UINT8_C(   0), UINT8_C( 160), UINT8_C(   0),
                             UINT8_C( 255), UINT8_C( 211), UINT8_C(   0), UINT8_C( 133),
                             UINT8_C(   0), UINT8_C(   0), UINT8_C(   0), UINT8_C(   0),
                             UINT8_C(   0), UINT8_C( 172), UINT8_C(   0), UINT8_C(   0),
                             UINT8_C( 255), UINT8_C( 255), UINT8_C( 201), UINT8_C( 207),
                             UINT8_C( 255), UINT8_C( 189), UINT8_C(   0), UINT8_C( 255),
                             UINT8_C( 255), UINT8_C( 141), UINT8_C(   0), UINT8_C(   0),
                             UINT8_C(   0), UINT8_C(   0), UINT8_C(   0), UINT8_C(   0),
                             UINT8_C(   0), UINT8_C(   0), UINT8_C(   0), UINT8_C( 255),
                             UINT8_C(   0), UINT8_C(   0), UINT8_C(   0), UINT8_C( 255),
                             UINT8_C( 255), UINT8_C(   0), UINT8_C(   0), UINT8_C(   0),
                             UINT8_C( 222), UINT8_C( 200), UINT8_C(   0), UINT8_C(  74)) },
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])); i++) {
    simde__m512i r = simde_mm512_maskz_adds_epu8(test_vec[i].k, test_vec[i].a, test_vec[i].b);
    simde_assert_m512i_u8(r, ==, test_vec[i].r);
  }

  return 0;
}

static int
test_simde_mm512_adds_epu16(SIMDE_MUNIT_TEST_ARGS) {
  const struct {
    simde__m512i a;
    simde__m512i b;
    simde__m512i r;
  } test_vec[8] = {
    { simde_x_mm512_set_epu16(UINT16_C( 57245), UINT16_C( 31803), UINT16_C(  9053), UINT16_C( 21282),
                              UINT16_C( 45515), UINT16_C( 57894), UINT16_C( 50445), UINT16_C( 50583),
                              UINT16_C( 54723), UINT16_C( 52144), UINT16_C( 13347), UINT16_C( 57624),
                              UINT16_C( 20975), UINT16_C( 65317), UINT16_C( 16493), UINT16_C( 47193),
                              UINT16_C(  8805), UINT16_C( 17012), UINT16_C( 15383), UINT16_C(  5484),
                              UINT16_C( 64480), UINT16_C( 10898), UINT16_C( 37488), UINT16_C(  8763),
                              UINT16_C( 45480), UINT16_C(  3307), UINT16_C(  9193), UINT16_C( 26229),
                              UINT16_C( 20008), UINT16_C( 59713), UINT16_C( 53564), UINT16_C( 62675)),
      simde_x_mm512_set_epu16(UINT16_C( 56619), UINT16_C( 61703), UINT16_C(  3086), UINT16_C( 41224),
                              UINT16_C(  8421), UINT16_C( 52766), UINT16_C(  7424), UINT16_C( 48822),
                              UINT16_C( 41975), UINT16_C( 22918), UINT16_C( 59915), UINT16_C( 26727),
                              UINT16_C( 53323), UINT16_C( 34707), UINT16_C( 14572), UINT16_C(   716),
                              UINT16_C( 56087), UINT16_C(  9094), UINT16_C( 20814), UINT16_C( 56962),
                              UINT16_C( 14110), UINT16_C( 52082), UINT16_C(  8468), UINT16_C( 11854),
                              UINT16_C(  1576), UINT16_C( 12690), UINT16_C( 32737), UINT16_C( 51663),
                              UINT16_C( 37115), UINT16_C( 18115), UINT16_C( 50682), UINT16_C(  1653)),
      simde_x_mm512_set_epu16(UINT16_C( 65535), UINT16_C( 65535), UINT16_C( 12139), UINT16_C( 62506),
                              UINT16_C( 53936), UINT16_C( 65535), UINT16_C( 57869), UINT16_C( 65535),
                              UINT16_C( 65535), UINT16_C( 65535), UINT16_C( 65535), UINT16_C( 65535),
                              UINT16_C( 65535), UINT16_C( 65535), UINT16_C( 31065), UINT16_C( 47909),
                              UINT16_C( 64892), UINT16_C( 26106), UINT16_C( 36197), UINT16_C( 62446),
                              UINT16_C( 65535), UINT16_C( 62980), UINT16_C( 45956), UINT16_C( 20617),
                              UINT16_C( 47056), UINT16_C( 15997), UINT16_C( 41930), UINT16_C( 65535),
                              UINT16_C( 57123), UINT16_C( 65535), UINT16_C( 65535), UINT16_C( 64328)) },
    { simde_x_mm512_set_epu16(UINT16_C(  1128), UINT16_C( 14143), UINT16_C( 19763), UINT16_C( 47819),
                              UINT16_C( 62972), UINT16_C( 13428), UINT16_C( 18537), UINT16_C( 38297),
                              UINT16_C( 21721), UINT16_C( 58861), UINT16_C( 42577), UINT16_C( 39379),
                              UINT16_C( 55643), UINT16_C( 20439), UINT16_C( 34514), UINT16_C( 49721),
                              UINT16_C( 18526), UINT16_C( 46886), UINT16_C( 20377), UINT16_C( 31658),
                              UINT16_C( 32537), UINT16_C( 50044), UINT16_C( 28503), UINT16_C(  5895),
                              UINT16_C(  1666), UINT16_C( 50137), UINT16_C( 30976), UINT16_C(  4047),
                              UINT16_C( 24589), UINT16_C( 29183), UINT16_C( 13128), UINT16_C(  3541)),
      simde_x_mm512_set_epu16(UINT16_C( 38521), UINT16_C( 64382), UINT16_C( 35873), UINT16_C( 42497),
                              UINT16_C( 46178), UINT16_C( 38904), UINT16_C( 15657), UINT16_C(  6453),
                              UINT16_C( 15377), UINT16_C( 45418), UINT16_C( 38208), UINT16_C( 44948),
                              UINT16_C( 17985), UINT16_C( 28923), UINT16_C( 11094), UINT16_C( 61254),
                              UINT16_C( 41028), UINT16_C(  4939), UINT16_C( 61438), UINT16_C( 34821),
                              UINT16_C(  9578), UINT16_C( 46329), UINT16_C( 53213), UINT16_C( 42297),
                              UINT16_C( 42846), UINT16_C( 12973), UINT16_C( 32628), UINT16_C( 10992),
                              UINT16_C( 56871), UINT16_C( 37695), UINT16_C( 16317), UINT16_C(  4356)),
      simde_x_mm512_set_epu16(UINT16_C( 39649), UINT16_C( 65535), UINT16_C( 55636), UINT16_C( 65535),
                              UINT16_C( 65535), UINT16_C( 52332), UINT16_C( 34194), UINT16_C( 44750),
                              UINT16_C( 37098), UINT16_C( 65535), UINT16_C( 65535), UINT16_C( 65535),
                              UINT16_C( 65535), UINT16_C( 49362), UINT16_C( 45608), UINT16_C( 65535),
                              UINT16_C( 59554), UINT16_C( 51825), UINT16_C( 65535), UINT16_C( 65535),
                              UINT16_C( 42115), UINT16_C( 65535), UINT16_C( 65535), UINT16_C( 48192),
                              UINT16_C( 44512), UINT16_C( 63110), UINT16_C( 63604), UINT16_C( 15039),
                              UINT16_C( 65535), UINT16_C( 65535), UINT16_C( 29445), UINT16_C(  7897)) },
    { simde_x_mm512_set_epu16(UINT16_C( 14747), UINT16_C( 30570), UINT16_C( 56275), UINT16_C( 58793),
                              UINT16_C( 48636), UINT16_C( 11396), UINT16_C( 12142), UINT16_C( 25883),
                              UINT16_C( 48137), UINT16_C( 31445), UINT16_C( 15524), UINT16_C( 49322),
                              UINT16_C(  6761), UINT16_C( 42681), UINT16_C(  8586), UINT16_C( 53309),
                              UINT16_C( 48898), UINT16_C( 23142), UINT16_C( 17912), UINT16_C( 20578),
                              UINT16_C( 42157), UINT16_C( 25705), UINT16_C( 39154), UINT16_C( 32521),
                              UINT16_C(  7302), UINT16_C( 65263), UINT16_C(  7623), UINT16_C( 47267),
                              UINT16_C( 41612), UINT16_C(  7723), UINT16_C( 51815), UINT16_C( 23273)),
      simde_x_mm512_set_epu16(UINT16_C( 29783), UINT16_C( 35133), UINT16_C( 18722), UINT16_C( 24788),
                              UINT16_C(  4507), UINT16_C( 64908), UINT16_C( 18120), UINT16_C( 53792),
                              UINT16_C( 40447), UINT16_C(  2013), UINT16_C( 19329), UINT16_C( 18474),
                              UINT16_C( 45067), UINT16_C( 37105), UINT16_C( 40003), UINT16_C( 11523),
                              UINT16_C( 28865), UINT16_C(  9988), UINT16_C( 16394), UINT16_C( 60605),
                              UINT16_C( 29530), UINT16_C(   612), UINT16_C( 21547), UINT16_C( 12463),
                              UINT16_C( 46586), UINT16_C(  6619), UINT16_C( 39845), UINT16_C(  4328),
                              UINT16_C( 31818), UINT16_C( 16334), UINT16_C( 57400), UINT16_C( 58095)),
      simde_x_mm512_set_epu16(UINT16_C( 44530), UINT16_C( 65535), UINT16_C( 65535), UINT16_C( 65535),
                              UINT16_C( 53143), UINT16_C( 65535), UINT16_C( 30262), UINT16_C( 65535),
                              UINT16_C( 65535), UINT16_C( 33458), UINT16_C( 34853), UINT16_C( 65535),
                              UINT16_C( 51828), UINT16_C( 65535), UINT16_C( 48589), UINT16_C( 64832),
                              UINT16_C( 65535), UINT16_C( 33130), UINT16_C( 34306), UINT16_C( 65535),
                              UINT16_C( 65535), UINT16_C( 26317), UINT16_C( 60701), UINT16_C( 44984),
                              UINT16_C( 53888), UINT16_C( 65535), UINT16_C( 47468), UINT16_C( 51595),
                              UINT16_C( 65535), UINT16_C( 24057), UINT16_C( 65535), UINT16_C( 65535)) },
    { simde_x_mm512_set_epu16(UINT16_C( 30682), UINT16_C( 30851), UINT16_C(  8660), UINT16_C( 19219),
                              UINT16_C( 10963), UINT16_C(   474), UINT16_C( 23728), UINT16_C( 46528),
                              UINT16_C( 63120), UINT16_C( 45881), UINT16_C( 63086), UINT16_C( 25197),
                              UINT16_C(  2704), UINT16_C(  4513), UINT16_C( 59294), UINT16_C( 60752),
                              UINT16_C( 50954), UINT16_C( 23266), UINT16_C( 27902), UINT16_C(  8814),
                              UINT16_C(  4863), UINT16_C(  1260), UINT16_C( 11681), UINT16_C( 46962),
                              UINT16_C( 62057), UINT16_C(  1167), UINT16_C( 44133), UINT16_C( 29723),
                              UINT16_C( 20503), UINT16_C( 47951), UINT16_C(  6645), UINT16_C( 27511)),
      simde_x_mm512_set_epu16(UINT16_C( 15286), UINT16_C(  5686), UINT16_C( 62529), UINT16_C( 52414),
                              UINT16_C( 64942), UINT16_C( 55157), UINT16_C(  1921), UINT16_C(   414),
                              UINT16_C( 57075), UINT16_C( 38949), UINT16_C( 49837), UINT16_C( 16574),
                              UINT16_C( 63519), UINT16_C( 21815), UINT16_C( 16534), UINT16_C(  5264),
                              UINT16_C( 40611), UINT16_C(  7582), UINT16_C( 27508), UINT16_C( 40060),
                              UINT16_C( 17332), UINT16_C( 48486), UINT16_C( 46457), UINT16_C(  3074),
                              UINT16_C( 49520), UINT16_C( 35694), UINT16_C( 14820), UINT16_C( 26739),
                              UINT16_C( 52931), UINT16_C( 30426), UINT16_C( 34639), UINT16_C( 60126)),
      simde_x_mm512_set_epu16(UINT16_C( 45968), UINT16_C( 36537), UINT16_C( 65535), UINT16_C( 65535),
                              UINT16_C( 65535), UINT16_C( 55631), UINT16_C( 25649), UINT16_C( 46942),
                              UINT16_C( 65535), UINT16_C( 65535), UINT16_C( 65535), UINT16_C( 41771),
                              UINT16_C( 65535), UINT16_C( 26328), UINT16_C( 65535), UINT16_C( 65535),
                              UINT16_C( 65535), UINT16_C( 30848), UINT16_C( 55410), UINT16_C( 48874),
                              UINT16_C( 22195), UINT16_C( 49746), UINT16_C( 58138), UINT16_C( 50036),
                              UINT16_C( 65535), UINT16_C( 36861), UINT16_C( 58953), UINT16_C( 56462),
                              UINT16_C( 65535), UINT16_C( 65535), UINT16_C( 41284), UINT16_C( 65535)) },
    { simde_x_mm512_set_epu16(UINT16_C( 20277), UINT16_C(  2901), UINT16_C(  9119), UINT16_C( 39166),
                              UINT16_C( 42714), UINT16_C( 26596), UINT16_C( 65466), UINT16_C( 41724),
                              UINT16_C( 43509), UINT16_C( 36161), UINT16_C( 14559), UINT16_C( 39814),
                              UINT16_C( 39598), UINT16_C( 35810), UINT16_C( 32670), UINT16_C(  2206),
                              UINT16_C( 28889), UINT16_C( 41636), UINT16_C( 48990), UINT16_C( 37294),
                              UINT16_C( 39242), UINT16_C( 39778), UINT16_C(  6979), UINT16_C( 54232),
                              UINT16_C( 47738), UINT16_C( 57923), UINT16_C( 37900), UINT16_C( 45798),
                              UINT16_C( 44781), UINT16_C( 27960), UINT16_C(  1998), UINT16_C( 61149)),
      simde_x_mm512_set_epu16(UINT16_C( 20730), UINT16_C( 18080), UINT16_C( 51364), UINT16_C( 27968),
                              UINT16_C( 47873), UINT16_C( 51993), UINT16_C( 18829), UINT16_C( 15054),
                              UINT16_C( 50771), UINT16_C( 37023), UINT16_C( 39205), UINT16_C( 18252),
                              UINT16_C( 53613), UINT16_C( 36736), UINT16_C( 53958), UINT16_C( 13137),
                              UINT16_C( 43763), UINT16_C( 19789), UINT16_C(  2934), UINT16_C( 22986),
                              UINT16_C( 46964), UINT16_C( 64986), UINT16_C( 13395), UINT16_C( 61287),
                              UINT16_C( 61677), UINT16_C( 22301), UINT16_C( 41322), UINT16_C( 35063),
                              UINT16_C( 22663), UINT16_C( 28062), UINT16_C( 45351), UINT16_C( 21097)),
      simde_x_mm512_set_epu16(UINT16_C( 41007), UINT16_C( 20981), UINT16_C( 60483), UINT16_C( 65535),
                              UINT16_C( 65535), UINT16_C( 65535), UINT16_C( 65535), UINT16_C( 56778),
                              UINT16_C( 65535), UINT16_C( 65535), UINT16_C( 53764), UINT16_C( 58066),
                              UINT16_C( 65535), UINT16_C( 65535), UINT16_C( 65535), UINT16_C( 15343),
                              UINT16_C( 65535), UINT16_C( 61425), UINT16_C( 51924), UINT16_C( 60280),
                              UINT16_C( 65535), UINT16_C( 65535), UINT16_C( 20374), UINT16_C( 65535),
                              UINT16_C( 65535), UINT16_C( 65535), UINT16_C( 65535), UINT16_C( 65535),
                              UINT16_C( 65535), UINT16_C( 56022), UINT16_C( 47349), UINT16_C( 65535)) },
    { simde_x_mm512_set_epu16(UINT16_C( 29192), UINT16_C(  8654), UINT16_C( 22850), UINT16_C( 62764),
                              UINT16_C( 24193), UINT16_C( 41054), UINT16_C( 47201), UINT16_C( 29473),
                              UINT16_C(  7514), UINT16_C( 21604), UINT16_C( 55170), UINT16_C( 17089),
                              UINT16_C( 58910), UINT16_C( 18576), UINT16_C( 50942), UINT16_C( 19375),
                              UINT16_C( 32394), UINT16_C(  6670), UINT16_C( 34291), UINT16_C( 10597),
                              UINT16_C( 63848), UINT16_C( 24622), UINT16_C( 55141), UINT16_C( 33399),
                              UINT16_C( 17676), UINT16_C( 53111), UINT16_C( 57678), UINT16_C( 53869),
                              UINT16_C(  1069), UINT16_C( 35377), UINT16_C( 20392), UINT16_C(  6033)),
      simde_x_mm512_set_epu16(UINT16_C( 30110), UINT16_C(  5765), UINT16_C( 21533), UINT16_C( 32154),
                              UINT16_C( 47788), UINT16_C(  4708), UINT16_C( 49450), UINT16_C( 15569),
                              UINT16_C( 11433), UINT16_C( 48528), UINT16_C( 18868), UINT16_C( 49914),
                              UINT16_C( 29591), UINT16_C( 10234), UINT16_C( 18676), UINT16_C( 18833),
                              UINT16_C( 53298), UINT16_C( 44056), UINT16_C(   163), UINT16_C( 14043),
                              UINT16_C( 52308), UINT16_C( 55462), UINT16_C(  1379), UINT16_C( 56593),
                              UINT16_C( 40649), UINT16_C( 10209), UINT16_C( 62181), UINT16_C(  6865),
                              UINT16_C( 33659), UINT16_C( 12643), UINT16_C( 58853), UINT16_C( 27590)),
      simde_x_mm512_set_epu16(UINT16_C( 59302), UINT16_C( 14419), UINT16_C( 44383), UINT16_C( 65535),
                              UINT16_C( 65535), UINT16_C( 45762), UINT16_C( 65535), UINT16_C( 45042),
                              UINT16_C( 18947), UINT16_C( 65535), UINT16_C( 65535), UINT16_C( 65535),
                              UINT16_C( 65535), UINT16_C( 28810), UINT16_C( 65535), UINT16_C( 38208),
                              UINT16_C( 65535), UINT16_C( 50726), UINT16_C( 34454), UINT16_C( 24640),
                              UINT16_C( 65535), UINT16_C( 65535), UINT16_C( 56520), UINT16_C( 65535),
                              UINT16_C( 58325), UINT16_C( 63320), UINT16_C( 65535), UINT16_C( 60734),
                              UINT16_C( 34728), UINT16_C( 48020), UINT16_C( 65535), UINT16_C( 33623)) },
    { simde_x_mm512_set_epu16(UINT16_C( 54408), UINT16_C( 44486), UINT16_C( 24517), UINT16_C( 51207),
                              UINT16_C(  2791), UINT16_C( 45592), UINT16_C( 48586), UINT16_C( 36784),
                              UINT16_C( 53369), UINT16_C( 43811), UINT16_C( 65046), UINT16_C( 44235),
                              UINT16_C( 48681), UINT16_C( 21401), UINT16_C( 55417), UINT16_C(  5581),
                              UINT16_C( 56410), UINT16_C( 42092), UINT16_C( 49678), UINT16_C( 22777),
                              UINT16_C( 15839), UINT16_C( 59069), UINT16_C(  3836), UINT16_C( 55877),
                              UINT16_C( 35316), UINT16_C( 40611), UINT16_C( 30925), UINT16_C( 38925),
                              UINT16_C( 44290), UINT16_C( 48844), UINT16_C( 41388), UINT16_C( 24135)),
      simde_x_mm512_set_epu16(UINT16_C(  7663), UINT16_C(  4305), UINT16_C( 48670), UINT16_C( 39779),
                              UINT16_C(  2052), UINT16_C( 40026), UINT16_C( 47264), UINT16_C(  7297),
                              UINT16_C( 11022), UINT16_C( 64822), UINT16_C( 63292), UINT16_C( 56921),
                              UINT16_C(  8160), UINT16_C( 61766), UINT16_C( 22014), UINT16_C( 41597),
                              UINT16_C( 60919), UINT16_C( 45399), UINT16_C( 45462), UINT16_C( 35135),
                              UINT16_C( 13486), UINT16_C( 42127), UINT16_C(  6466), UINT16_C(  5931),
                              UINT16_C( 30448), UINT16_C( 27493), UINT16_C( 24921), UINT16_C( 23842),
                              UINT16_C( 21170), UINT16_C( 62954), UINT16_C(  7914), UINT16_C( 35527)),
      simde_x_mm512_set_epu16(UINT16_C( 62071), UINT16_C( 48791), UINT16_C( 65535), UINT16_C( 65535),
                              UINT16_C(  4843), UINT16_C( 65535), UINT16_C( 65535), UINT16_C( 44081),
                              UINT16_C( 64391), UINT16_C( 65535), UINT16_C( 65535), UINT16_C( 65535),
                              UINT16_C( 56841), UINT16_C( 65535), UINT16_C( 65535), UINT16_C( 47178),
                              UINT16_C( 65535), UINT16_C( 65535), UINT16_C( 65535), UINT16_C( 57912),
                              UINT16_C( 29325), UINT16_C( 65535), UINT16_C( 10302), UINT16_C( 61808),
                              UINT16_C( 65535), UINT16_C( 65535), UINT16_C( 55846), UINT16_C( 62767),
                              UINT16_C( 65460), UINT16_C( 65535), UINT16_C( 49302), UINT16_C( 59662)) },
    { simde_x_mm512_set_epu16(UINT16_C( 61865), UINT16_C( 23426), UINT16_C(  1768), UINT16_C( 58636),
                              UINT16_C( 57533), UINT16_C( 19108), UINT16_C( 59802), UINT16_C( 30792),
                              UINT16_C( 61240), UINT16_C(  6209), UINT16_C( 32476), UINT16_C( 14300),
                              UINT16_C(  7420), UINT16_C(  1985), UINT16_C( 25770), UINT16_C( 58800),
                              UINT16_C( 51482), UINT16_C( 20894), UINT16_C(   680), UINT16_C( 29487),
                              UINT16_C( 45202), UINT16_C( 20181), UINT16_C( 14712), UINT16_C( 17612),
                              UINT16_C( 16683), UINT16_C(  1453), UINT16_C( 15990), UINT16_C( 36509),
                              UINT16_C( 51737), UINT16_C( 56324), UINT16_C( 34493), UINT16_C( 17761)),
      simde_x_mm512_set_epu16(UINT16_C( 37550), UINT16_C( 51250), UINT16_C( 42874), UINT16_C(  8384),
                              UINT16_C( 13698), UINT16_C( 33689), UINT16_C( 64372), UINT16_C( 20393),
                              UINT16_C( 17692), UINT16_C( 65383), UINT16_C(   545), UINT16_C( 27220),
                              UINT16_C( 18321), UINT16_C( 26532), UINT16_C( 40835), UINT16_C( 14036),
                              UINT16_C(  3666), UINT16_C(  2040), UINT16_C( 61839), UINT16_C( 38748),
                              UINT16_C( 62699), UINT16_C( 55831), UINT16_C( 23293), UINT16_C( 13208),
                              UINT16_C( 60975), UINT16_C( 12632), UINT16_C( 13392), UINT16_C( 63703),
                              UINT16_C( 41286), UINT16_C(  6117), UINT16_C( 32645), UINT16_C( 56152)),
      simde_x_mm512_set_epu16(UINT16_C( 65535), UINT16_C( 65535), UINT16_C( 44642), UINT16_C( 65535),
                              UINT16_C( 65535), UINT16_C( 52797), UINT16_C( 65535), UINT16_C( 51185),
                              UINT16_C( 65535), UINT16_C( 65535), UINT16_C( 33021), UINT16_C( 41520),
                              UINT16_C( 25741), UINT16_C( 28517), UINT16_C( 65535), UINT16_C( 65535),
                              UINT16_C( 55148), UINT16_C( 22934), UINT16_C( 62519), UINT16_C( 65535),
                              UINT16_C( 65535), UINT16_C( 65535), UINT16_C( 38005), UINT16_C( 30820),
                              UINT16_C( 65535), UINT16_C( 14085), UINT16_C( 29382), UINT16_C( 65535),
                              UINT16_C( 65535), UINT16_C( 62441), UINT16_C( 65535), UINT16_C( 65535)) }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])); i++) {
    simde__m512i r = simde_mm512_adds_epu16(test_vec[i].a, test_vec[i].b);
    simde_assert_m512i_u16(r, ==, test_vec[i].r);
  }

  return 0;
}

static int
test_simde_mm512_mask_adds_epu16 (SIMDE_MUNIT_TEST_ARGS) {
  static const struct {
    const int16_t src[32];
    const simde__mmask32 k;
    const uint16_t a[32];
    const uint16_t b[32];
    const uint16_t r[32];
  } test_vec[] = {
    { { -INT16_C( 25480),  INT16_C( 16389),  INT16_C( 16810),  INT16_C( 20465), -INT16_C( 11763),  INT16_C(  1143),  INT16_C( 11613),  INT16_C(  5547),
        -INT16_C(   217),  INT16_C(  4795),  INT16_C(  5277), -INT16_C( 31526), -INT16_C(  1895),  INT16_C(  7976), -INT16_C(  7252),  INT16_C(  9466),
        -INT16_C(   129),  INT16_C( 10853),  INT16_C( 22080),  INT16_C( 19833), -INT16_C(  4056), -INT16_C( 31151), -INT16_C(   994),  INT16_C( 17819),
         INT16_C( 22267), -INT16_C( 26281),  INT16_C( 12651),  INT16_C(  1053),  INT16_C( 17962), -INT16_C( 10716),  INT16_C(  7721), -INT16_C( 22278) },
      UINT32_C(1590845213),
      { UINT16_C(19382), UINT16_C(57003), UINT16_C(64828), UINT16_C(23140), UINT16_C(65529), UINT16_C(62879), UINT16_C(63062), UINT16_C(49550),
        UINT16_C(43815), UINT16_C(20933), UINT16_C(59889), UINT16_C( 6695), UINT16_C( 8711), UINT16_C( 9667), UINT16_C(38273), UINT16_C(14211),
        UINT16_C(12001), UINT16_C( 7446), UINT16_C(31275), UINT16_C( 9591), UINT16_C( 5754), UINT16_C(53274), UINT16_C(43020), UINT16_C(13201),
        UINT16_C(22099), UINT16_C(17797), UINT16_C(44096), UINT16_C(18271), UINT16_C( 8910), UINT16_C(20588), UINT16_C(61368), UINT16_C(39303) },
      { UINT16_C(40222), UINT16_C(18870), UINT16_C(11544), UINT16_C(37486), UINT16_C(34883), UINT16_C(20322), UINT16_C(62256), UINT16_C(33922),
        UINT16_C( 1865), UINT16_C(35273), UINT16_C(10420), UINT16_C(33489), UINT16_C(15691), UINT16_C(  978), UINT16_C(23085), UINT16_C(19356),
        UINT16_C(21239), UINT16_C( 3988), UINT16_C(  895), UINT16_C(49825), UINT16_C(  907), UINT16_C(48145), UINT16_C(37878), UINT16_C(16448),
        UINT16_C( 2459), UINT16_C(20425), UINT16_C(39473), UINT16_C(31953), UINT16_C(42200), UINT16_C( 1407), UINT16_C( 7166), UINT16_C(62800) },
      { UINT16_C(59604), UINT16_C(16389),      UINT16_MAX, UINT16_C(60626),      UINT16_MAX, UINT16_C( 1143), UINT16_C(11613), UINT16_C( 5547),
        UINT16_C(45680), UINT16_C(56206),      UINT16_MAX, UINT16_C(40184), UINT16_C(24402), UINT16_C( 7976), UINT16_C(61358), UINT16_C( 9466),
        UINT16_C(65407), UINT16_C(11434), UINT16_C(22080), UINT16_C(19833), UINT16_C( 6661), UINT16_C(34385),      UINT16_MAX, UINT16_C(29649),
        UINT16_C(22267), UINT16_C(38222),      UINT16_MAX, UINT16_C(50224), UINT16_C(51110), UINT16_C(54820),      UINT16_MAX, UINT16_C(43258) } },
    { { -INT16_C(  7059), -INT16_C(  5115), -INT16_C( 22809),  INT16_C( 29614), -INT16_C( 16470), -INT16_C( 24529),  INT16_C( 28499), -INT16_C(  4384),
        -INT16_C( 21896), -INT16_C( 22211),  INT16_C(  3652),  INT16_C(  7206), -INT16_C( 23118), -INT16_C( 20447),  INT16_C( 29121),  INT16_C( 11942),
        -INT16_C( 21674),  INT16_C( 15643), -INT16_C( 13999), -INT16_C(  1104), -INT16_C(  8311), -INT16_C(  9060),  INT16_C( 31822), -INT16_C( 14646),
         INT16_C(  1830),  INT16_C( 27504), -INT16_C( 27115), -INT16_C( 14201), -INT16_C( 22213), -INT16_C(   904),  INT16_C(  7706),  INT16_C( 28715) },
      UINT32_C( 464406217),
      { UINT16_C(24079), UINT16_C(38934), UINT16_C(45630), UINT16_C(35956), UINT16_C(15919), UINT16_C(21843), UINT16_C(49989), UINT16_C(23488),
        UINT16_C(18521), UINT16_C(37923), UINT16_C(39921), UINT16_C( 2961), UINT16_C(48314), UINT16_C(33660), UINT16_C(10754), UINT16_C( 4510),
        UINT16_C(46472), UINT16_C(50858), UINT16_C( 7783), UINT16_C(38483), UINT16_C(42589), UINT16_C(41708), UINT16_C(44137), UINT16_C(49917),
        UINT16_C( 8436), UINT16_C(58710), UINT16_C(59324), UINT16_C(30449), UINT16_C(28067), UINT16_C(42489), UINT16_C(39063), UINT16_C( 8119) },
      { UINT16_C(24909), UINT16_C(46310), UINT16_C(14719), UINT16_C(56395), UINT16_C(14303), UINT16_C(18559), UINT16_C(31971), UINT16_C(55306),
        UINT16_C(24733), UINT16_C(22973), UINT16_C(44616), UINT16_C(60367), UINT16_C(51227), UINT16_C(45713), UINT16_C(18528), UINT16_C(44498),
        UINT16_C(47273), UINT16_C(10338), UINT16_C(44529), UINT16_C(53253), UINT16_C(34020), UINT16_C(50968), UINT16_C( 8704), UINT16_C(40351),
        UINT16_C(23938), UINT16_C(51958), UINT16_C(50443), UINT16_C(10166), UINT16_C(18318), UINT16_C(61145), UINT16_C(43919), UINT16_C(14492) },
      { UINT16_C(48988), UINT16_C(60421), UINT16_C(42727),      UINT16_MAX, UINT16_C(49066), UINT16_C(41007),      UINT16_MAX,      UINT16_MAX,
        UINT16_C(43640), UINT16_C(60896),      UINT16_MAX, UINT16_C( 7206), UINT16_C(42418), UINT16_C(45089), UINT16_C(29282), UINT16_C(11942),
        UINT16_C(43862), UINT16_C(61196), UINT16_C(52312),      UINT16_MAX, UINT16_C(57225),      UINT16_MAX, UINT16_C(31822),      UINT16_MAX,
        UINT16_C(32374),      UINT16_MAX, UINT16_C(38421), UINT16_C(40615), UINT16_C(46385), UINT16_C(64632), UINT16_C( 7706), UINT16_C(28715) } },
    { { -INT16_C(   413),  INT16_C( 21600),  INT16_C( 26027), -INT16_C( 28892),  INT16_C( 15593), -INT16_C(  5546), -INT16_C(  2466), -INT16_C(  7801),
         INT16_C( 32339),  INT16_C( 24235),  INT16_C( 24899), -INT16_C( 11899),  INT16_C( 24488),  INT16_C( 14272),  INT16_C( 23562),  INT16_C( 28271),
        -INT16_C( 12198),  INT16_C(  1474), -INT16_C(  6347),  INT16_C(  8084), -INT16_C(  5597), -INT16_C( 32247), -INT16_C( 28448),  INT16_C( 13155),
         INT16_C(  3598),  INT16_C( 21138),  INT16_C(  6000),  INT16_C(  6179), -INT16_C(  7306), -INT16_C( 32432), -INT16_C( 16577), -INT16_C( 26129) },
      UINT32_C(3315511695),
      { UINT16_C(12952), UINT16_C(48356), UINT16_C(60701), UINT16_C(64830), UINT16_C(41341), UINT16_C(35889), UINT16_C(50095), UINT16_C( 8158),
        UINT16_C(  474), UINT16_C(20792), UINT16_C(35045), UINT16_C( 9426), UINT16_C(49479), UINT16_C(55230), UINT16_C(23666), UINT16_C( 2972),
        UINT16_C(32911), UINT16_C(44231), UINT16_C( 1389), UINT16_C(60073), UINT16_C(55974), UINT16_C(21878), UINT16_C(21661), UINT16_C(30837),
        UINT16_C(44374), UINT16_C(15305), UINT16_C(39733), UINT16_C(31839), UINT16_C( 7516), UINT16_C(52819), UINT16_C(61306), UINT16_C( 2521) },
      { UINT16_C(41071), UINT16_C(56501), UINT16_C(24229), UINT16_C(19399), UINT16_C(15673), UINT16_C(54945), UINT16_C( 5778), UINT16_C(59470),
        UINT16_C( 6083), UINT16_C(63523), UINT16_C(33458), UINT16_C( 3700), UINT16_C(51360), UINT16_C( 6877), UINT16_C(46775), UINT16_C(10019),
        UINT16_C(55383), UINT16_C(64515), UINT16_C(51766), UINT16_C(28488), UINT16_C(59656), UINT16_C(39494), UINT16_C(38143), UINT16_C(49794),
        UINT16_C(42412), UINT16_C(24250), UINT16_C(11815), UINT16_C(51053), UINT16_C(19190), UINT16_C(44769), UINT16_C( 1024), UINT16_C(22485) },
      { UINT16_C(54023),      UINT16_MAX,      UINT16_MAX,      UINT16_MAX, UINT16_C(15593), UINT16_C(59990), UINT16_C(63070),      UINT16_MAX,
        UINT16_C( 6557), UINT16_C(24235), UINT16_C(24899), UINT16_C(53637),      UINT16_MAX, UINT16_C(62107), UINT16_C(23562), UINT16_C(12991),
        UINT16_C(53338),      UINT16_MAX, UINT16_C(53155),      UINT16_MAX,      UINT16_MAX, UINT16_C(33289), UINT16_C(37088),      UINT16_MAX,
             UINT16_MAX, UINT16_C(21138), UINT16_C(51548), UINT16_C( 6179), UINT16_C(58230), UINT16_C(33104), UINT16_C(62330), UINT16_C(25006) } },
    { { -INT16_C( 10020),  INT16_C(  4948), -INT16_C( 25437), -INT16_C( 21630), -INT16_C( 14203), -INT16_C( 31675), -INT16_C( 14499),  INT16_C(  2374),
         INT16_C(   108), -INT16_C( 27801), -INT16_C( 11218),  INT16_C(  9563),  INT16_C( 15390),  INT16_C(  8147), -INT16_C( 22463),  INT16_C(  7542),
        -INT16_C( 13696),  INT16_C(  9008), -INT16_C( 19610), -INT16_C(  5170),  INT16_C(  4987), -INT16_C( 10129), -INT16_C( 18982),  INT16_C( 18145),
         INT16_C( 18869), -INT16_C(  6950),  INT16_C( 13597),  INT16_C( 15369), -INT16_C(  9103), -INT16_C( 19877), -INT16_C( 11900),  INT16_C(  1232) },
      UINT32_C(  36176028),
      { UINT16_C(63155), UINT16_C(12270), UINT16_C(23818), UINT16_C(58375), UINT16_C(59667), UINT16_C(51243), UINT16_C( 1330), UINT16_C(20396),
        UINT16_C(46394), UINT16_C(43915), UINT16_C(59025), UINT16_C( 5470), UINT16_C(11960), UINT16_C(21530), UINT16_C(16942), UINT16_C(57942),
        UINT16_C(17464), UINT16_C(16913), UINT16_C( 6306), UINT16_C(46375), UINT16_C(20993), UINT16_C(13181), UINT16_C(10839), UINT16_C(37251),
        UINT16_C( 3807), UINT16_C(28988), UINT16_C(39669), UINT16_C(44422), UINT16_C(41160), UINT16_C(63233), UINT16_C(22498), UINT16_C( 7129) },
      { UINT16_C(60060), UINT16_C(15965), UINT16_C(33794), UINT16_C( 1267), UINT16_C(28886), UINT16_C(11575), UINT16_C(47770), UINT16_C(31422),
        UINT16_C(64457), UINT16_C(48875), UINT16_C(29077), UINT16_C(24171), UINT16_C(27666), UINT16_C(62549), UINT16_C(11971), UINT16_C(24335),
        UINT16_C(27928), UINT16_C( 6813), UINT16_C(37105), UINT16_C(51230), UINT16_C(22017), UINT16_C(39925), UINT16_C(46096), UINT16_C(55573),
        UINT16_C(  175), UINT16_C(17559), UINT16_C(  626), UINT16_C(33954), UINT16_C(63342), UINT16_C(12920), UINT16_C(34853), UINT16_C(15761) },
      { UINT16_C(55516), UINT16_C( 4948), UINT16_C(57612), UINT16_C(59642),      UINT16_MAX, UINT16_C(33861), UINT16_C(51037), UINT16_C(51818),
        UINT16_C(  108), UINT16_C(37735), UINT16_C(54318), UINT16_C( 9563), UINT16_C(15390), UINT16_C( 8147), UINT16_C(43073), UINT16_C( 7542),
        UINT16_C(51840), UINT16_C( 9008), UINT16_C(45926),      UINT16_MAX, UINT16_C( 4987), UINT16_C(53106), UINT16_C(46554), UINT16_C(18145),
        UINT16_C(18869), UINT16_C(46547), UINT16_C(13597), UINT16_C(15369), UINT16_C(56433), UINT16_C(45659), UINT16_C(53636), UINT16_C( 1232) } },
    { {  INT16_C( 12277), -INT16_C(  6568),  INT16_C( 30399), -INT16_C( 16210), -INT16_C( 23348), -INT16_C(  8868),  INT16_C( 29016),  INT16_C(  1974),
         INT16_C( 20082), -INT16_C(  7093), -INT16_C(  4528), -INT16_C( 16536), -INT16_C(  7963),  INT16_C(  3057), -INT16_C( 32152),  INT16_C( 23880),
        -INT16_C( 24399),  INT16_C( 28996), -INT16_C(  3561), -INT16_C(  7375), -INT16_C( 29290), -INT16_C(  4416),  INT16_C( 30719),  INT16_C( 29173),
         INT16_C( 16837),  INT16_C(  5461), -INT16_C( 17105),  INT16_C(  5332), -INT16_C( 14947),  INT16_C(  1567),  INT16_C( 26696), -INT16_C(  1693) },
      UINT32_C( 527083272),
      { UINT16_C(40090), UINT16_C(12291), UINT16_C(49961), UINT16_C(10271), UINT16_C( 5178), UINT16_C(65433), UINT16_C(61013), UINT16_C(33813),
        UINT16_C(59819), UINT16_C(18841), UINT16_C(47279), UINT16_C(63311), UINT16_C(45600), UINT16_C(10736), UINT16_C(23386), UINT16_C(62536),
        UINT16_C(19447), UINT16_C( 8228), UINT16_C(17167), UINT16_C(18761), UINT16_C(57944), UINT16_C(44361), UINT16_C(24273), UINT16_C(31794),
        UINT16_C(52039), UINT16_C(63173), UINT16_C( 5251), UINT16_C(42221), UINT16_C(57031), UINT16_C( 8653), UINT16_C( 5433), UINT16_C(12309) },
      { UINT16_C(14689), UINT16_C(28752), UINT16_C(39293), UINT16_C(54713), UINT16_C(  636), UINT16_C(19842), UINT16_C(46176), UINT16_C(43209),
        UINT16_C(36735), UINT16_C(  926), UINT16_C(36003), UINT16_C(27303), UINT16_C(29802), UINT16_C(41867), UINT16_C(41097), UINT16_C(60115),
        UINT16_C( 9178), UINT16_C(22362), UINT16_C( 5309), UINT16_C(14636), UINT16_C(44566), UINT16_C(30598), UINT16_C(20323), UINT16_C(57887),
        UINT16_C(48606), UINT16_C(33509), UINT16_C(35913), UINT16_C(46060), UINT16_C(30720), UINT16_C(35414), UINT16_C(10520), UINT16_C(62068) },
      { UINT16_C(12277), UINT16_C(58968), UINT16_C(30399), UINT16_C(64984), UINT16_C(42188), UINT16_C(56668), UINT16_C(29016), UINT16_C( 1974),
             UINT16_MAX, UINT16_C(19767),      UINT16_MAX, UINT16_C(49000), UINT16_C(57573), UINT16_C(52603), UINT16_C(33384),      UINT16_MAX,
        UINT16_C(41137), UINT16_C(30590), UINT16_C(61975), UINT16_C(33397), UINT16_C(36246),      UINT16_MAX, UINT16_C(44596), UINT16_C(29173),
             UINT16_MAX,      UINT16_MAX, UINT16_C(41164),      UINT16_MAX,      UINT16_MAX, UINT16_C( 1567), UINT16_C(26696), UINT16_C(63843) } },
    { { -INT16_C( 12467),  INT16_C(  2633),  INT16_C( 30179), -INT16_C(  1725), -INT16_C( 14044), -INT16_C( 30864), -INT16_C( 28904), -INT16_C(  2199),
         INT16_C( 20301), -INT16_C( 27015),  INT16_C( 26075), -INT16_C(  9142), -INT16_C( 24355), -INT16_C(  2458), -INT16_C(  9526),  INT16_C(  6120),
         INT16_C( 12969), -INT16_C( 29663),  INT16_C( 25767), -INT16_C( 13434), -INT16_C(  2515),  INT16_C( 17746), -INT16_C( 17274), -INT16_C( 11460),
        -INT16_C( 19189), -INT16_C(  6551), -INT16_C( 19685), -INT16_C(  1854),  INT16_C( 10324),  INT16_C(  7918), -INT16_C( 10493), -INT16_C( 21451) },
      UINT32_C(2956547593),
      { UINT16_C(49082), UINT16_C(59260), UINT16_C(52917), UINT16_C(15148), UINT16_C(27018), UINT16_C(38158), UINT16_C(30750), UINT16_C(14716),
        UINT16_C(15915), UINT16_C(32562), UINT16_C( 8295), UINT16_C(27293), UINT16_C(54007), UINT16_C(   22), UINT16_C(20264), UINT16_C(58033),
        UINT16_C(11534), UINT16_C(50377), UINT16_C(63227), UINT16_C(34559), UINT16_C( 3679), UINT16_C(32027), UINT16_C(38790), UINT16_C(45495),
        UINT16_C(59862), UINT16_C(15665), UINT16_C(52745), UINT16_C(  423), UINT16_C(48545), UINT16_C(51457), UINT16_C(45581), UINT16_C( 7084) },
      { UINT16_C(30175), UINT16_C(56287), UINT16_C(57195), UINT16_C(51809), UINT16_C(31981), UINT16_C(29512), UINT16_C(65300), UINT16_C(59940),
        UINT16_C(21992), UINT16_C(61735), UINT16_C(52772), UINT16_C(50674), UINT16_C(62603), UINT16_C(39054), UINT16_C(15014), UINT16_C(34484),
        UINT16_C(37808), UINT16_C( 7009), UINT16_C(49778), UINT16_C(24550), UINT16_C(11838), UINT16_C(21202), UINT16_C(63277), UINT16_C( 5436),
        UINT16_C(25420), UINT16_C(28678), UINT16_C(63793), UINT16_C(48437), UINT16_C(50413), UINT16_C(37717), UINT16_C( 2558), UINT16_C(44569) },
      {      UINT16_MAX, UINT16_C( 2633), UINT16_C(30179),      UINT16_MAX, UINT16_C(51492), UINT16_C(34672), UINT16_C(36632), UINT16_C(63337),
        UINT16_C(20301),      UINT16_MAX, UINT16_C(61067), UINT16_C(56394),      UINT16_MAX, UINT16_C(63078), UINT16_C(35278), UINT16_C( 6120),
        UINT16_C(49342), UINT16_C(35873), UINT16_C(25767), UINT16_C(59109), UINT16_C(15517), UINT16_C(53229), UINT16_C(48262), UINT16_C(54076),
        UINT16_C(46347), UINT16_C(58985), UINT16_C(45851), UINT16_C(63682),      UINT16_MAX,      UINT16_MAX, UINT16_C(55043), UINT16_C(51653) } },
    { {  INT16_C( 31389),  INT16_C(  4042), -INT16_C( 20420),  INT16_C( 31599),  INT16_C( 16862),  INT16_C(  3021),  INT16_C(  2616), -INT16_C( 31456),
         INT16_C(  9837), -INT16_C( 24587),  INT16_C( 11039),  INT16_C(  3164), -INT16_C( 19985), -INT16_C(  4704), -INT16_C( 17989),  INT16_C( 22684),
         INT16_C( 26164),  INT16_C( 28775), -INT16_C( 10730), -INT16_C(  2837), -INT16_C( 18152),  INT16_C( 20735),  INT16_C(  8131),  INT16_C( 12501),
        -INT16_C( 13499),  INT16_C( 26063),  INT16_C( 11254), -INT16_C(  6799),  INT16_C(  4573), -INT16_C( 26414),  INT16_C( 28363), -INT16_C(    16) },
      UINT32_C(3933165524),
      { UINT16_C(23342), UINT16_C(18142), UINT16_C(56596), UINT16_C(55190), UINT16_C(27900), UINT16_C(16903), UINT16_C(55095), UINT16_C(11687),
        UINT16_C( 6146), UINT16_C(57106), UINT16_C(58410), UINT16_C(62839), UINT16_C(26451), UINT16_C(10228), UINT16_C(25535), UINT16_C(60690),
        UINT16_C(61630), UINT16_C(53811), UINT16_C(51662), UINT16_C(51881), UINT16_C(45365), UINT16_C(27660), UINT16_C(45960), UINT16_C(35481),
        UINT16_C(43980), UINT16_C(63082), UINT16_C(57744), UINT16_C(58347), UINT16_C(57161), UINT16_C( 2058), UINT16_C( 7234), UINT16_C(  501) },
      { UINT16_C(10253), UINT16_C(56275), UINT16_C(32241), UINT16_C(10149), UINT16_C(45614), UINT16_C(46739), UINT16_C(11621), UINT16_C(12608),
        UINT16_C(43736), UINT16_C(26663), UINT16_C( 4748), UINT16_C(54603), UINT16_C(22257), UINT16_C(13533), UINT16_C(53874), UINT16_C(32565),
        UINT16_C( 2298), UINT16_C(60250), UINT16_C(  133), UINT16_C(45842), UINT16_C(42674), UINT16_C( 5993), UINT16_C(43731), UINT16_C(43849),
        UINT16_C(28756), UINT16_C(57364), UINT16_C(24451), UINT16_C(29877), UINT16_C(37557), UINT16_C(10408), UINT16_C(56676), UINT16_C(24231) },
      { UINT16_C(31389), UINT16_C( 4042),      UINT16_MAX, UINT16_C(31599),      UINT16_MAX, UINT16_C( 3021),      UINT16_MAX, UINT16_C(24295),
        UINT16_C(49882),      UINT16_MAX, UINT16_C(63158), UINT16_C( 3164), UINT16_C(48708), UINT16_C(60832),      UINT16_MAX, UINT16_C(22684),
        UINT16_C(63928),      UINT16_MAX, UINT16_C(51795),      UINT16_MAX, UINT16_C(47384), UINT16_C(33653),      UINT16_MAX, UINT16_C(12501),
        UINT16_C(52037),      UINT16_MAX, UINT16_C(11254),      UINT16_MAX, UINT16_C( 4573), UINT16_C(12466), UINT16_C(63910), UINT16_C(24732) } },
    { {  INT16_C(   742),  INT16_C( 27466),  INT16_C( 23554), -INT16_C( 19425), -INT16_C( 30718), -INT16_C( 10805),  INT16_C(  5170), -INT16_C( 30847),
        -INT16_C( 27259),  INT16_C(  2151),  INT16_C(  7668), -INT16_C( 21892),  INT16_C(  9647),  INT16_C(  5330),  INT16_C( 30978), -INT16_C(  6030),
        -INT16_C( 17285),  INT16_C( 32084),  INT16_C( 29465),  INT16_C(  6961), -INT16_C(   517),  INT16_C( 12017),  INT16_C( 29201), -INT16_C( 26955),
         INT16_C(  7175), -INT16_C(  1122),  INT16_C(  6969), -INT16_C(  5723),  INT16_C( 30528),  INT16_C( 17149),  INT16_C( 28657),  INT16_C( 27691) },
      UINT32_C(1172995884),
      { UINT16_C( 7154), UINT16_C(60768), UINT16_C(20760), UINT16_C(10779), UINT16_C(53443), UINT16_C(51904), UINT16_C(24557), UINT16_C( 9926),
        UINT16_C(27514), UINT16_C(47631), UINT16_C( 3299), UINT16_C(54524), UINT16_C(10108), UINT16_C(43072), UINT16_C(10918), UINT16_C(39149),
        UINT16_C(19782), UINT16_C(24198), UINT16_C(41375), UINT16_C(25224), UINT16_C(18802), UINT16_C(24365), UINT16_C(62376), UINT16_C( 8837),
        UINT16_C(38238), UINT16_C(16860), UINT16_C(55457), UINT16_C( 7445), UINT16_C(22016), UINT16_C(42693), UINT16_C(45696), UINT16_C(50751) },
      { UINT16_C(50432), UINT16_C(40741), UINT16_C(44390), UINT16_C(55297), UINT16_C(12022), UINT16_C(40503), UINT16_C(48417), UINT16_C(32960),
        UINT16_C(40018), UINT16_C(62401), UINT16_C(55157), UINT16_C(29969), UINT16_C(54829), UINT16_C(44315), UINT16_C(23177), UINT16_C(35188),
        UINT16_C(39199), UINT16_C(34344), UINT16_C(10566), UINT16_C(15710), UINT16_C(38488), UINT16_C(31195), UINT16_C(40019), UINT16_C(42489),
        UINT16_C(47928), UINT16_C(44440), UINT16_C(43410), UINT16_C(48930), UINT16_C(16000), UINT16_C( 2412), UINT16_C(57496), UINT16_C(47250) },
      { UINT16_C(  742), UINT16_C(27466), UINT16_C(65150),      UINT16_MAX, UINT16_C(34818),      UINT16_MAX, UINT16_C( 5170), UINT16_C(34689),
             UINT16_MAX,      UINT16_MAX, UINT16_C(58456),      UINT16_MAX, UINT16_C(64937),      UINT16_MAX, UINT16_C(34095), UINT16_C(59506),
        UINT16_C(48251), UINT16_C(58542), UINT16_C(29465), UINT16_C(40934), UINT16_C(65019), UINT16_C(55560),      UINT16_MAX, UINT16_C(51326),
             UINT16_MAX, UINT16_C(64414),      UINT16_MAX, UINT16_C(59813), UINT16_C(30528), UINT16_C(17149),      UINT16_MAX, UINT16_C(27691) } }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
    simde__m512i src = simde_mm512_loadu_epi16(test_vec[i].src);
    simde__m512i a = simde_mm512_loadu_epi16(test_vec[i].a);
    simde__m512i b = simde_mm512_loadu_epi16(test_vec[i].b);
    simde__m512i r = simde_mm512_mask_adds_epu16(src, test_vec[i].k, a, b);
    simde_test_x86_assert_equal_u16x32(r, simde_mm512_loadu_epi16(test_vec[i].r));
  }

  return 0;
}

static int
test_simde_mm512_maskz_adds_epu16 (SIMDE_MUNIT_TEST_ARGS) {
  static const struct {
    const simde__mmask32 k;
    const uint16_t a[32];
    const uint16_t b[32];
    const uint16_t r[32];
  } test_vec[] = {
    { UINT32_C( 298122215),
      { UINT16_C(43877), UINT16_C(21426), UINT16_C(12985), UINT16_C(37214), UINT16_C(44901), UINT16_C(48588), UINT16_C(18525), UINT16_C(41048),
        UINT16_C(22359), UINT16_C(46043), UINT16_C(52738), UINT16_C(43622), UINT16_C(52530), UINT16_C( 6625), UINT16_C(42696), UINT16_C(11818),
        UINT16_C(56401), UINT16_C( 2689), UINT16_C(57359), UINT16_C(29852), UINT16_C(26767), UINT16_C(60465), UINT16_C(35504), UINT16_C( 2188),
        UINT16_C(26593), UINT16_C(58555), UINT16_C( 8501), UINT16_C(26510), UINT16_C(28654), UINT16_C(46976), UINT16_C(43541), UINT16_C(26597) },
      { UINT16_C(26246), UINT16_C(38257), UINT16_C( 3398), UINT16_C(54538), UINT16_C(15221), UINT16_C( 9921), UINT16_C(19909), UINT16_C(42798),
        UINT16_C(59828), UINT16_C(59787), UINT16_C( 6411), UINT16_C(63824), UINT16_C(53384), UINT16_C(40624), UINT16_C(38266), UINT16_C(  261),
        UINT16_C(30460), UINT16_C(17046), UINT16_C(41092), UINT16_C(63768), UINT16_C(55772), UINT16_C(41247), UINT16_C(19751), UINT16_C(56136),
        UINT16_C(54071), UINT16_C(17093), UINT16_C( 5612), UINT16_C(30011), UINT16_C(60646), UINT16_C(24595), UINT16_C( 6273), UINT16_C(32097) },
      {      UINT16_MAX, UINT16_C(59683), UINT16_C(16383), UINT16_C(    0), UINT16_C(    0), UINT16_C(58509), UINT16_C(38434),      UINT16_MAX,
             UINT16_MAX,      UINT16_MAX, UINT16_C(    0),      UINT16_MAX,      UINT16_MAX, UINT16_C(47249),      UINT16_MAX, UINT16_C(12079),
        UINT16_C(    0), UINT16_C(    0),      UINT16_MAX, UINT16_C(    0), UINT16_C(    0), UINT16_C(    0), UINT16_C(55255), UINT16_C(58324),
             UINT16_MAX, UINT16_C(    0), UINT16_C(    0), UINT16_C(    0),      UINT16_MAX, UINT16_C(    0), UINT16_C(    0), UINT16_C(    0) } },
    { UINT32_C( 314636430),
      { UINT16_C(55448), UINT16_C(29708), UINT16_C(11185), UINT16_C(55318), UINT16_C(24185), UINT16_C(45236), UINT16_C(31026), UINT16_C( 7922),
        UINT16_C(11662), UINT16_C(29843), UINT16_C(42521), UINT16_C(39893), UINT16_C(14014), UINT16_C(19736), UINT16_C(55342), UINT16_C(51039),
        UINT16_C(27568), UINT16_C(25147), UINT16_C(20887), UINT16_C( 4154), UINT16_C(61104), UINT16_C(58048), UINT16_C(45671), UINT16_C(62976),
        UINT16_C(38111), UINT16_C(63850), UINT16_C(16186), UINT16_C(63892), UINT16_C(44150), UINT16_C(42054), UINT16_C(42373), UINT16_C(13675) },
      { UINT16_C(42769), UINT16_C(43159), UINT16_C(54008), UINT16_C(43192), UINT16_C(30912), UINT16_C(10378), UINT16_C(35626), UINT16_C( 2334),
        UINT16_C(34847), UINT16_C(22786), UINT16_C(38600), UINT16_C(15954), UINT16_C(38979), UINT16_C(51426), UINT16_C(20030), UINT16_C(20477),
        UINT16_C(38389), UINT16_C(60919), UINT16_C(44903), UINT16_C(10134), UINT16_C( 8231), UINT16_C(20815), UINT16_C(28075), UINT16_C(51802),
        UINT16_C(24054), UINT16_C(48676), UINT16_C(30451), UINT16_C(14076), UINT16_C(56847), UINT16_C(19966), UINT16_C(64556), UINT16_C( 8604) },
      { UINT16_C(    0),      UINT16_MAX, UINT16_C(65193),      UINT16_MAX, UINT16_C(    0), UINT16_C(    0), UINT16_C(    0), UINT16_C(10256),
        UINT16_C(    0), UINT16_C(    0), UINT16_C(    0), UINT16_C(55847), UINT16_C(52993),      UINT16_MAX,      UINT16_MAX,      UINT16_MAX,
        UINT16_C(    0), UINT16_C(    0), UINT16_C(    0), UINT16_C(    0), UINT16_C(    0), UINT16_C(    0),      UINT16_MAX,      UINT16_MAX,
        UINT16_C(    0),      UINT16_MAX, UINT16_C(    0), UINT16_C(    0),      UINT16_MAX, UINT16_C(    0), UINT16_C(    0), UINT16_C(    0) } },
    { UINT32_C(4161770385),
      { UINT16_C(42306), UINT16_C(26911), UINT16_C(28613), UINT16_C(29114), UINT16_C( 5340), UINT16_C(53819), UINT16_C(24433), UINT16_C(26000),
        UINT16_C(36054), UINT16_C(58779), UINT16_C(39531), UINT16_C(38706), UINT16_C(52886), UINT16_C(10169), UINT16_C(51297), UINT16_C(41759),
        UINT16_C(15981), UINT16_C(12812), UINT16_C(50861), UINT16_C(35491), UINT16_C(57306), UINT16_C(19548), UINT16_C(60734), UINT16_C( 5297),
        UINT16_C(19577), UINT16_C(58617), UINT16_C(11238), UINT16_C(31868), UINT16_C(13817), UINT16_C(23203), UINT16_C(49917), UINT16_C(27389) },
      { UINT16_C( 2305), UINT16_C(44700), UINT16_C(16591), UINT16_C(43576), UINT16_C(38175), UINT16_C(24054), UINT16_C(42882), UINT16_C(64370),
        UINT16_C(27635), UINT16_C(56032), UINT16_C(23703), UINT16_C(36950), UINT16_C(64145), UINT16_C(36587), UINT16_C(59580), UINT16_C(48632),
        UINT16_C(38130), UINT16_C(49516), UINT16_C(42196), UINT16_C(62315), UINT16_C(24889), UINT16_C(47953), UINT16_C(49928), UINT16_C(64695),
        UINT16_C(38702), UINT16_C(50646), UINT16_C(11507), UINT16_C(33878), UINT16_C(16678), UINT16_C(58130), UINT16_C( 2601), UINT16_C( 7072) },
      { UINT16_C(44611), UINT16_C(    0), UINT16_C(    0), UINT16_C(    0), UINT16_C(43515), UINT16_C(    0), UINT16_C(    0),      UINT16_MAX,
        UINT16_C(63689),      UINT16_MAX, UINT16_C(    0), UINT16_C(    0),      UINT16_MAX, UINT16_C(    0), UINT16_C(    0),      UINT16_MAX,
        UINT16_C(54111), UINT16_C(62328),      UINT16_MAX,      UINT16_MAX, UINT16_C(    0), UINT16_C(    0), UINT16_C(    0), UINT16_C(    0),
        UINT16_C(    0), UINT16_C(    0), UINT16_C(    0),      UINT16_MAX, UINT16_C(30495),      UINT16_MAX, UINT16_C(52518), UINT16_C(34461) } },
    { UINT32_C(1943866526),
      { UINT16_C(18609), UINT16_C(60006), UINT16_C(47018), UINT16_C(45734), UINT16_C(23930), UINT16_C(43438), UINT16_C(34036), UINT16_C(59246),
        UINT16_C(50353), UINT16_C(55147), UINT16_C(32005), UINT16_C(12218), UINT16_C(23431), UINT16_C( 9546), UINT16_C(10087), UINT16_C( 6296),
        UINT16_C(65392), UINT16_C( 6659), UINT16_C(43446), UINT16_C(12748), UINT16_C(31494), UINT16_C(64218), UINT16_C(18687), UINT16_C(45281),
        UINT16_C(19469), UINT16_C( 4744), UINT16_C(17097), UINT16_C(20545), UINT16_C(35997), UINT16_C( 1397), UINT16_C( 3763), UINT16_C( 8989) },
      { UINT16_C( 8205), UINT16_C(49981), UINT16_C( 2761), UINT16_C(53236), UINT16_C(52869), UINT16_C(33993), UINT16_C(43543), UINT16_C( 9269),
        UINT16_C(48630), UINT16_C(48950), UINT16_C(30975), UINT16_C(40207), UINT16_C(34052), UINT16_C(47010), UINT16_C(49043), UINT16_C(41179),
        UINT16_C( 6368), UINT16_C(43363), UINT16_C(22562), UINT16_C(42873), UINT16_C(16934), UINT16_C(15660), UINT16_C(25069), UINT16_C(58209),
        UINT16_C(38942), UINT16_C( 7587), UINT16_C(45584), UINT16_C( 5306), UINT16_C(23607), UINT16_C(51915), UINT16_C(42524), UINT16_C(64618) },
      { UINT16_C(    0),      UINT16_MAX, UINT16_C(49779),      UINT16_MAX,      UINT16_MAX, UINT16_C(    0), UINT16_C(    0),      UINT16_MAX,
        UINT16_C(    0), UINT16_C(    0), UINT16_C(62980), UINT16_C(52425), UINT16_C(    0), UINT16_C(    0), UINT16_C(    0), UINT16_C(    0),
             UINT16_MAX, UINT16_C(    0),      UINT16_MAX, UINT16_C(55621), UINT16_C(48428), UINT16_C(    0), UINT16_C(43756),      UINT16_MAX,
        UINT16_C(58411), UINT16_C(12331), UINT16_C(    0), UINT16_C(    0), UINT16_C(59604), UINT16_C(53312), UINT16_C(46287), UINT16_C(    0) } },
    { UINT32_C(3785739967),
      { UINT16_C( 7718), UINT16_C(19593), UINT16_C(46433), UINT16_C(20106), UINT16_C(60182), UINT16_C(13361), UINT16_C(54403), UINT16_C(37713),
        UINT16_C( 3207), UINT16_C(48807), UINT16_C(29544), UINT16_C(33929), UINT16_C(62233), UINT16_C(55424), UINT16_C( 9921), UINT16_C(59322),
        UINT16_C(17220), UINT16_C(42292), UINT16_C(48888), UINT16_C( 3827), UINT16_C( 9641), UINT16_C(11586), UINT16_C(37881), UINT16_C(32960),
        UINT16_C(26783), UINT16_C( 2111), UINT16_C(51419), UINT16_C(62604), UINT16_C( 3515), UINT16_C(32205), UINT16_C(34611), UINT16_C(30564) },
      { UINT16_C(39114), UINT16_C(49693), UINT16_C( 4182), UINT16_C(  208), UINT16_C( 4661), UINT16_C(12077), UINT16_C(60837), UINT16_C(17839),
        UINT16_C(61013), UINT16_C(12365), UINT16_C(55734), UINT16_C(29221), UINT16_C(62182), UINT16_C( 6639), UINT16_C(21369), UINT16_C(17297),
        UINT16_C(44780), UINT16_C(16901), UINT16_C(54718), UINT16_C(62530), UINT16_C(28647), UINT16_C(35875), UINT16_C(53853), UINT16_C(45777),
        UINT16_C( 7873), UINT16_C(30691), UINT16_C( 2296), UINT16_C(57065), UINT16_C(55546), UINT16_C(29688), UINT16_C(35116), UINT16_C( 6326) },
      { UINT16_C(46832),      UINT16_MAX, UINT16_C(50615), UINT16_C(20314), UINT16_C(64843), UINT16_C(25438), UINT16_C(    0), UINT16_C(55552),
        UINT16_C(    0), UINT16_C(61172),      UINT16_MAX, UINT16_C(63150), UINT16_C(    0), UINT16_C(    0), UINT16_C(31290),      UINT16_MAX,
        UINT16_C(62000), UINT16_C(    0),      UINT16_MAX, UINT16_C(    0), UINT16_C(    0), UINT16_C(47461), UINT16_C(    0),      UINT16_MAX,
        UINT16_C(34656), UINT16_C(    0), UINT16_C(    0), UINT16_C(    0), UINT16_C(    0), UINT16_C(61893),      UINT16_MAX, UINT16_C(36890) } },
    { UINT32_C(4116364087),
      { UINT16_C(40336), UINT16_C(30697), UINT16_C( 3084), UINT16_C(26883), UINT16_C(54751), UINT16_C(40988), UINT16_C(65523), UINT16_C(60183),
        UINT16_C(  263), UINT16_C(  458), UINT16_C(49881), UINT16_C( 1396), UINT16_C(10827), UINT16_C(33309), UINT16_C(30949), UINT16_C(30071),
        UINT16_C(24853), UINT16_C( 8684), UINT16_C(61293), UINT16_C(19595), UINT16_C(42948), UINT16_C(47340), UINT16_C( 1190), UINT16_C(44451),
        UINT16_C(27909), UINT16_C(57006), UINT16_C( 8751), UINT16_C(31460), UINT16_C(  332), UINT16_C(12796), UINT16_C(29817), UINT16_C(36518) },
      { UINT16_C(37589), UINT16_C(17072), UINT16_C(15233), UINT16_C(18063), UINT16_C(31714), UINT16_C(35070), UINT16_C(41343), UINT16_C(33845),
        UINT16_C(58127), UINT16_C(15971), UINT16_C(18181), UINT16_C(20921), UINT16_C(46408), UINT16_C(49794), UINT16_C(10281), UINT16_C(65104),
        UINT16_C(  186), UINT16_C(15169), UINT16_C(53307), UINT16_C( 7553), UINT16_C(32587), UINT16_C(52133), UINT16_C(55841), UINT16_C(12367),
        UINT16_C(45757), UINT16_C(49774), UINT16_C(10233), UINT16_C(16915), UINT16_C(38365), UINT16_C( 1540), UINT16_C(21693), UINT16_C(30469) },
      {      UINT16_MAX, UINT16_C(47769), UINT16_C(18317), UINT16_C(    0),      UINT16_MAX,      UINT16_MAX, UINT16_C(    0), UINT16_C(    0),
        UINT16_C(58390), UINT16_C(16429), UINT16_C(    0), UINT16_C(22317), UINT16_C(57235),      UINT16_MAX, UINT16_C(    0),      UINT16_MAX,
        UINT16_C(    0), UINT16_C(23853), UINT16_C(    0), UINT16_C(27148),      UINT16_MAX, UINT16_C(    0), UINT16_C(57031), UINT16_C(    0),
             UINT16_MAX, UINT16_C(    0), UINT16_C(18984), UINT16_C(    0), UINT16_C(38697), UINT16_C(14336), UINT16_C(51510),      UINT16_MAX } },
    { UINT32_C(2427668053),
      { UINT16_C(13334), UINT16_C(25006), UINT16_C(21428), UINT16_C(54572), UINT16_C(31790), UINT16_C(60165), UINT16_C(29486), UINT16_C(10414),
        UINT16_C(49563), UINT16_C(30826), UINT16_C(28247), UINT16_C( 5246), UINT16_C(33730), UINT16_C( 6028), UINT16_C(16329), UINT16_C(57256),
        UINT16_C(22131), UINT16_C(10049), UINT16_C(28073), UINT16_C(55292), UINT16_C(  489), UINT16_C( 6339), UINT16_C(29045), UINT16_C( 4160),
        UINT16_C(43570), UINT16_C(35208), UINT16_C( 1560), UINT16_C(55966), UINT16_C(10890), UINT16_C(21490), UINT16_C(39529), UINT16_C(56371) },
      { UINT16_C(29936), UINT16_C(39172), UINT16_C(  225), UINT16_C(52081), UINT16_C(13314), UINT16_C(30691), UINT16_C( 9125), UINT16_C(55175),
        UINT16_C( 4045), UINT16_C(58721), UINT16_C(65301), UINT16_C(40895), UINT16_C(45353), UINT16_C(37619), UINT16_C( 9803), UINT16_C(15214),
        UINT16_C(29338), UINT16_C(31701), UINT16_C(18035), UINT16_C(30022), UINT16_C(10618), UINT16_C( 8172), UINT16_C(29516), UINT16_C( 6646),
        UINT16_C(22402), UINT16_C(38910), UINT16_C(48726), UINT16_C(32567), UINT16_C(10863), UINT16_C(47889), UINT16_C(32848), UINT16_C(60150) },
      { UINT16_C(43270), UINT16_C(    0), UINT16_C(21653), UINT16_C(    0), UINT16_C(45104), UINT16_C(    0), UINT16_C(38611), UINT16_C(    0),
        UINT16_C(    0),      UINT16_MAX,      UINT16_MAX, UINT16_C(    0), UINT16_C(    0), UINT16_C(    0), UINT16_C(26132), UINT16_C(    0),
        UINT16_C(51469), UINT16_C(41750), UINT16_C(    0), UINT16_C(    0), UINT16_C(11107), UINT16_C(14511), UINT16_C(    0), UINT16_C(10806),
        UINT16_C(    0), UINT16_C(    0), UINT16_C(    0), UINT16_C(    0), UINT16_C(21753), UINT16_C(    0), UINT16_C(    0),      UINT16_MAX } },
    { UINT32_C(1701170162),
      { UINT16_C(44049), UINT16_C(35802), UINT16_C(50901), UINT16_C( 8874), UINT16_C(41273), UINT16_C(47931), UINT16_C(15096), UINT16_C(20307),
        UINT16_C(35576), UINT16_C(26574), UINT16_C(57524), UINT16_C( 1058), UINT16_C( 6496), UINT16_C(21230), UINT16_C(21476), UINT16_C(63160),
        UINT16_C(37631), UINT16_C(54657), UINT16_C(11353), UINT16_C(37623), UINT16_C(13005), UINT16_C(50510), UINT16_C(41324), UINT16_C(25620),
        UINT16_C(58155), UINT16_C(57292), UINT16_C(61123), UINT16_C( 9187), UINT16_C(53511), UINT16_C(60533), UINT16_C(11556), UINT16_C( 9442) },
      { UINT16_C(25536), UINT16_C( 6649), UINT16_C(61583), UINT16_C(23723), UINT16_C(63778), UINT16_C(36642), UINT16_C(13978), UINT16_C(50675),
        UINT16_C(48921), UINT16_C(56484), UINT16_C(34734), UINT16_C(46591), UINT16_C(30040), UINT16_C(32161), UINT16_C(33698), UINT16_C(25249),
        UINT16_C(39655), UINT16_C(30331), UINT16_C(10122), UINT16_C(44243), UINT16_C(62752), UINT16_C(47931), UINT16_C(12075), UINT16_C(17792),
        UINT16_C( 9710), UINT16_C(39969), UINT16_C( 8620), UINT16_C( 1362), UINT16_C(62358), UINT16_C(14466), UINT16_C( 9079), UINT16_C(24219) },
      { UINT16_C(    0), UINT16_C(42451), UINT16_C(    0), UINT16_C(    0),      UINT16_MAX,      UINT16_MAX, UINT16_C(29074),      UINT16_MAX,
             UINT16_MAX,      UINT16_MAX, UINT16_C(    0), UINT16_C(47649), UINT16_C(    0), UINT16_C(    0), UINT16_C(55174),      UINT16_MAX,
             UINT16_MAX, UINT16_C(    0), UINT16_C(21475), UINT16_C(    0), UINT16_C(    0),      UINT16_MAX, UINT16_C(53399), UINT16_C(    0),
             UINT16_MAX, UINT16_C(    0),      UINT16_MAX, UINT16_C(    0), UINT16_C(    0),      UINT16_MAX, UINT16_C(20635), UINT16_C(    0) } }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
    simde__m512i a = simde_mm512_loadu_epi16(test_vec[i].a);
    simde__m512i b = simde_mm512_loadu_epi16(test_vec[i].b);
    simde__m512i r = simde_mm512_maskz_adds_epu16(test_vec[i].k, a, b);
    simde_test_x86_assert_equal_u16x32(r, simde_mm512_loadu_epi16(test_vec[i].r));
  }

  return 0;
}

static int
test_simde_mm512_avg_epu8(SIMDE_MUNIT_TEST_ARGS) {
  const struct {
    simde__m512i a;
    simde__m512i b;
    simde__m512i r;
  } test_vec[8] = {
    { simde_x_mm512_set_epu8(UINT8_C( 54), UINT8_C( 98), UINT8_C(144), UINT8_C( 33),
                             UINT8_C(227), UINT8_C( 68), UINT8_C( 44), UINT8_C(252),
                             UINT8_C(188), UINT8_C(131), UINT8_C( 22), UINT8_C(137),
                             UINT8_C(110), UINT8_C(230), UINT8_C(116), UINT8_C( 30),
                             UINT8_C(237), UINT8_C(136), UINT8_C(151), UINT8_C(122),
                             UINT8_C( 83), UINT8_C(138), UINT8_C(146), UINT8_C(187),
                             UINT8_C( 83), UINT8_C(179), UINT8_C(167), UINT8_C( 88),
                             UINT8_C(248), UINT8_C( 88), UINT8_C(101), UINT8_C(132),
                             UINT8_C(203), UINT8_C( 36), UINT8_C( 53), UINT8_C(174),
                             UINT8_C( 78), UINT8_C( 97), UINT8_C(124), UINT8_C(201),
                             UINT8_C( 12), UINT8_C(233), UINT8_C(196), UINT8_C(121),
                             UINT8_C( 77), UINT8_C(  2), UINT8_C(189), UINT8_C(251),
                             UINT8_C(252), UINT8_C(129), UINT8_C( 38), UINT8_C(107),
                             UINT8_C(130), UINT8_C(227), UINT8_C(158), UINT8_C(158),
                             UINT8_C(195), UINT8_C( 10), UINT8_C(101), UINT8_C( 55),
                             UINT8_C( 64), UINT8_C(106), UINT8_C(118), UINT8_C( 58)),
      simde_x_mm512_set_epu8(UINT8_C(139), UINT8_C( 91), UINT8_C( 12), UINT8_C(185),
                             UINT8_C( 48), UINT8_C(130), UINT8_C(230), UINT8_C(176),
                             UINT8_C(212), UINT8_C( 20), UINT8_C(110), UINT8_C(217),
                             UINT8_C(186), UINT8_C(186), UINT8_C(132), UINT8_C(114),
                             UINT8_C(188), UINT8_C(251), UINT8_C(225), UINT8_C(230),
                             UINT8_C(165), UINT8_C(108), UINT8_C( 17), UINT8_C(  9),
                             UINT8_C(245), UINT8_C(227), UINT8_C(125), UINT8_C(240),
                             UINT8_C( 47), UINT8_C( 91), UINT8_C(  3), UINT8_C(135),
                             UINT8_C(243), UINT8_C(103), UINT8_C(152), UINT8_C(185),
                             UINT8_C( 49), UINT8_C(  8), UINT8_C( 66), UINT8_C(147),
                             UINT8_C( 50), UINT8_C(167), UINT8_C( 57), UINT8_C(102),
                             UINT8_C(142), UINT8_C( 47), UINT8_C(173), UINT8_C( 47),
                             UINT8_C(172), UINT8_C(237), UINT8_C( 57), UINT8_C(255),
                             UINT8_C(101), UINT8_C(227), UINT8_C(198), UINT8_C(199),
                             UINT8_C( 25), UINT8_C(175), UINT8_C(229), UINT8_C(172),
                             UINT8_C(210), UINT8_C(198), UINT8_C(215), UINT8_C(150)),
      simde_x_mm512_set_epu8(UINT8_C( 97), UINT8_C( 95), UINT8_C( 78), UINT8_C(109),
                             UINT8_C(138), UINT8_C( 99), UINT8_C(137), UINT8_C(214),
                             UINT8_C(200), UINT8_C( 76), UINT8_C( 66), UINT8_C(177),
                             UINT8_C(148), UINT8_C(208), UINT8_C(124), UINT8_C( 72),
                             UINT8_C(213), UINT8_C(194), UINT8_C(188), UINT8_C(176),
                             UINT8_C(124), UINT8_C(123), UINT8_C( 82), UINT8_C( 98),
                             UINT8_C(164), UINT8_C(203), UINT8_C(146), UINT8_C(164),
                             UINT8_C(148), UINT8_C( 90), UINT8_C( 52), UINT8_C(134),
                             UINT8_C(223), UINT8_C( 70), UINT8_C(103), UINT8_C(180),
                             UINT8_C( 64), UINT8_C( 53), UINT8_C( 95), UINT8_C(174),
                             UINT8_C( 31), UINT8_C(200), UINT8_C(127), UINT8_C(112),
                             UINT8_C(110), UINT8_C( 25), UINT8_C(181), UINT8_C(149),
                             UINT8_C(212), UINT8_C(183), UINT8_C( 48), UINT8_C(181),
                             UINT8_C(116), UINT8_C(227), UINT8_C(178), UINT8_C(179),
                             UINT8_C(110), UINT8_C( 93), UINT8_C(165), UINT8_C(114),
                             UINT8_C(137), UINT8_C(152), UINT8_C(167), UINT8_C(104)) },
    { simde_x_mm512_set_epu8(UINT8_C(208), UINT8_C(219), UINT8_C( 57), UINT8_C(220),
                             UINT8_C(  6), UINT8_C( 65), UINT8_C( 21), UINT8_C( 70),
                             UINT8_C( 42), UINT8_C( 69), UINT8_C(205), UINT8_C( 75),
                             UINT8_C( 45), UINT8_C( 93), UINT8_C(126), UINT8_C(  6),
                             UINT8_C(174), UINT8_C( 50), UINT8_C( 17), UINT8_C(221),
                             UINT8_C(217), UINT8_C(127), UINT8_C(111), UINT8_C(120),
                             UINT8_C(131), UINT8_C(148), UINT8_C(141), UINT8_C(152),
                             UINT8_C(144), UINT8_C(136), UINT8_C( 66), UINT8_C( 61),
                             UINT8_C(132), UINT8_C(112), UINT8_C( 28), UINT8_C(152),
                             UINT8_C(127), UINT8_C(231), UINT8_C(109), UINT8_C(161),
                             UINT8_C(158), UINT8_C(  6), UINT8_C(213), UINT8_C(173),
                             UINT8_C(118), UINT8_C(179), UINT8_C( 79), UINT8_C(178),
                             UINT8_C( 46), UINT8_C(236), UINT8_C( 49), UINT8_C( 56),
                             UINT8_C(157), UINT8_C(129), UINT8_C( 46), UINT8_C(200),
                             UINT8_C( 89), UINT8_C(130), UINT8_C(187), UINT8_C(247),
                             UINT8_C(213), UINT8_C( 39), UINT8_C(146), UINT8_C(142)),
      simde_x_mm512_set_epu8(UINT8_C( 76), UINT8_C(227), UINT8_C(192), UINT8_C(129),
                             UINT8_C(228), UINT8_C( 26), UINT8_C(165), UINT8_C(150),
                             UINT8_C(111), UINT8_C( 32), UINT8_C( 11), UINT8_C( 66),
                             UINT8_C( 65), UINT8_C(106), UINT8_C(209), UINT8_C(140),
                             UINT8_C( 66), UINT8_C(  2), UINT8_C(157), UINT8_C(126),
                             UINT8_C( 65), UINT8_C(  8), UINT8_C( 57), UINT8_C( 55),
                             UINT8_C(150), UINT8_C( 40), UINT8_C(164), UINT8_C( 54),
                             UINT8_C( 94), UINT8_C(153), UINT8_C(234), UINT8_C(140),
                             UINT8_C( 45), UINT8_C( 64), UINT8_C(136), UINT8_C(209),
                             UINT8_C(101), UINT8_C(213), UINT8_C(147), UINT8_C(253),
                             UINT8_C( 57), UINT8_C(116), UINT8_C( 96), UINT8_C( 87),
                             UINT8_C(172), UINT8_C( 78), UINT8_C(156), UINT8_C(126),
                             UINT8_C(  3), UINT8_C(150), UINT8_C(133), UINT8_C( 13),
                             UINT8_C(226), UINT8_C( 18), UINT8_C(106), UINT8_C(202),
                             UINT8_C( 95), UINT8_C( 92), UINT8_C( 59), UINT8_C(210),
                             UINT8_C(140), UINT8_C( 87), UINT8_C(213), UINT8_C( 52)),
      simde_x_mm512_set_epu8(UINT8_C(142), UINT8_C(223), UINT8_C(125), UINT8_C(175),
                             UINT8_C(117), UINT8_C( 46), UINT8_C( 93), UINT8_C(110),
                             UINT8_C( 77), UINT8_C( 51), UINT8_C(108), UINT8_C( 71),
                             UINT8_C( 55), UINT8_C(100), UINT8_C(168), UINT8_C( 73),
                             UINT8_C(120), UINT8_C( 26), UINT8_C( 87), UINT8_C(174),
                             UINT8_C(141), UINT8_C( 68), UINT8_C( 84), UINT8_C( 88),
                             UINT8_C(141), UINT8_C( 94), UINT8_C(153), UINT8_C(103),
                             UINT8_C(119), UINT8_C(145), UINT8_C(150), UINT8_C(101),
                             UINT8_C( 89), UINT8_C( 88), UINT8_C( 82), UINT8_C(181),
                             UINT8_C(114), UINT8_C(222), UINT8_C(128), UINT8_C(207),
                             UINT8_C(108), UINT8_C( 61), UINT8_C(155), UINT8_C(130),
                             UINT8_C(145), UINT8_C(129), UINT8_C(118), UINT8_C(152),
                             UINT8_C( 25), UINT8_C(193), UINT8_C( 91), UINT8_C( 35),
                             UINT8_C(192), UINT8_C( 74), UINT8_C( 76), UINT8_C(201),
                             UINT8_C( 92), UINT8_C(111), UINT8_C(123), UINT8_C(229),
                             UINT8_C(177), UINT8_C( 63), UINT8_C(180), UINT8_C( 97)) },
    { simde_x_mm512_set_epu8(UINT8_C( 11), UINT8_C(110), UINT8_C(145), UINT8_C( 98),
                             UINT8_C(192), UINT8_C(110), UINT8_C(161), UINT8_C( 50),
                             UINT8_C(252), UINT8_C(104), UINT8_C(187), UINT8_C( 15),
                             UINT8_C(183), UINT8_C(198), UINT8_C( 79), UINT8_C(  9),
                             UINT8_C( 68), UINT8_C(123), UINT8_C(137), UINT8_C(144),
                             UINT8_C(105), UINT8_C( 90), UINT8_C( 86), UINT8_C( 94),
                             UINT8_C( 93), UINT8_C( 77), UINT8_C(192), UINT8_C(  8),
                             UINT8_C( 44), UINT8_C( 25), UINT8_C( 87), UINT8_C(143),
                             UINT8_C(226), UINT8_C( 88), UINT8_C(154), UINT8_C(252),
                             UINT8_C( 55), UINT8_C(166), UINT8_C(142), UINT8_C(195),
                             UINT8_C(169), UINT8_C(178), UINT8_C(205), UINT8_C( 91),
                             UINT8_C( 65), UINT8_C(198), UINT8_C(127), UINT8_C( 53),
                             UINT8_C(245), UINT8_C( 24), UINT8_C(177), UINT8_C(240),
                             UINT8_C(199), UINT8_C( 24), UINT8_C(143), UINT8_C(108),
                             UINT8_C( 39), UINT8_C(170), UINT8_C(163), UINT8_C(222),
                             UINT8_C( 56), UINT8_C(160), UINT8_C(200), UINT8_C(122)),
      simde_x_mm512_set_epu8(UINT8_C( 57), UINT8_C( 48), UINT8_C(248), UINT8_C( 92),
                             UINT8_C( 57), UINT8_C(154), UINT8_C( 83), UINT8_C(125),
                             UINT8_C( 10), UINT8_C(154), UINT8_C( 72), UINT8_C(111),
                             UINT8_C( 67), UINT8_C( 46), UINT8_C(125), UINT8_C(202),
                             UINT8_C( 45), UINT8_C( 61), UINT8_C( 52), UINT8_C(168),
                             UINT8_C(212), UINT8_C( 16), UINT8_C( 37), UINT8_C(131),
                             UINT8_C( 48), UINT8_C( 90), UINT8_C(210), UINT8_C(233),
                             UINT8_C(148), UINT8_C(  2), UINT8_C( 10), UINT8_C( 62),
                             UINT8_C( 89), UINT8_C(180), UINT8_C( 94), UINT8_C( 22),
                             UINT8_C(254), UINT8_C( 77), UINT8_C(  0), UINT8_C(151),
                             UINT8_C(212), UINT8_C( 38), UINT8_C(106), UINT8_C(205),
                             UINT8_C( 72), UINT8_C(159), UINT8_C(226), UINT8_C( 51),
                             UINT8_C( 53), UINT8_C(162), UINT8_C(189), UINT8_C( 88),
                             UINT8_C( 42), UINT8_C(136), UINT8_C(104), UINT8_C(208),
                             UINT8_C(154), UINT8_C(241), UINT8_C(187), UINT8_C(143),
                             UINT8_C(157), UINT8_C( 95), UINT8_C( 29), UINT8_C( 97)),
      simde_x_mm512_set_epu8(UINT8_C( 34), UINT8_C( 79), UINT8_C(197), UINT8_C( 95),
                             UINT8_C(125), UINT8_C(132), UINT8_C(122), UINT8_C( 88),
                             UINT8_C(131), UINT8_C(129), UINT8_C(130), UINT8_C( 63),
                             UINT8_C(125), UINT8_C(122), UINT8_C(102), UINT8_C(106),
                             UINT8_C( 57), UINT8_C( 92), UINT8_C( 95), UINT8_C(156),
                             UINT8_C(159), UINT8_C( 53), UINT8_C( 62), UINT8_C(113),
                             UINT8_C( 71), UINT8_C( 84), UINT8_C(201), UINT8_C(121),
                             UINT8_C( 96), UINT8_C( 14), UINT8_C( 49), UINT8_C(103),
                             UINT8_C(158), UINT8_C(134), UINT8_C(124), UINT8_C(137),
                             UINT8_C(155), UINT8_C(122), UINT8_C( 71), UINT8_C(173),
                             UINT8_C(191), UINT8_C(108), UINT8_C(156), UINT8_C(148),
                             UINT8_C( 69), UINT8_C(179), UINT8_C(177), UINT8_C( 52),
                             UINT8_C(149), UINT8_C( 93), UINT8_C(183), UINT8_C(164),
                             UINT8_C(121), UINT8_C( 80), UINT8_C(124), UINT8_C(158),
                             UINT8_C( 97), UINT8_C(206), UINT8_C(175), UINT8_C(183),
                             UINT8_C(107), UINT8_C(128), UINT8_C(115), UINT8_C(110)) },
    { simde_x_mm512_set_epu8(UINT8_C(130), UINT8_C( 79), UINT8_C( 82), UINT8_C(  5),
                             UINT8_C(236), UINT8_C(119), UINT8_C( 25), UINT8_C( 77),
                             UINT8_C(139), UINT8_C(103), UINT8_C(204), UINT8_C( 53),
                             UINT8_C( 70), UINT8_C( 81), UINT8_C( 35), UINT8_C(154),
                             UINT8_C(229), UINT8_C( 64), UINT8_C( 94), UINT8_C(131),
                             UINT8_C(217), UINT8_C(  4), UINT8_C(103), UINT8_C(204),
                             UINT8_C( 53), UINT8_C( 46), UINT8_C(123), UINT8_C(123),
                             UINT8_C(251), UINT8_C(227), UINT8_C(153), UINT8_C( 16),
                             UINT8_C( 79), UINT8_C(199), UINT8_C( 15), UINT8_C(177),
                             UINT8_C( 83), UINT8_C( 15), UINT8_C( 37), UINT8_C(215),
                             UINT8_C(178), UINT8_C(145), UINT8_C(240), UINT8_C( 53),
                             UINT8_C(116), UINT8_C(195), UINT8_C(101), UINT8_C(243),
                             UINT8_C(134), UINT8_C( 93), UINT8_C( 64), UINT8_C(103),
                             UINT8_C( 73), UINT8_C( 82), UINT8_C(189), UINT8_C( 37),
                             UINT8_C(202), UINT8_C( 62), UINT8_C(157), UINT8_C( 97),
                             UINT8_C(142), UINT8_C(  6), UINT8_C( 38), UINT8_C( 24)),
      simde_x_mm512_set_epu8(UINT8_C( 57), UINT8_C( 93), UINT8_C(144), UINT8_C( 30),
                             UINT8_C( 11), UINT8_C(223), UINT8_C( 55), UINT8_C(131),
                             UINT8_C( 29), UINT8_C(176), UINT8_C( 52), UINT8_C( 84),
                             UINT8_C( 79), UINT8_C( 47), UINT8_C(128), UINT8_C( 28),
                             UINT8_C( 73), UINT8_C(131), UINT8_C(138), UINT8_C(  1),
                             UINT8_C( 98), UINT8_C(110), UINT8_C(210), UINT8_C(168),
                             UINT8_C(208), UINT8_C(103), UINT8_C(151), UINT8_C( 58),
                             UINT8_C(149), UINT8_C( 16), UINT8_C(113), UINT8_C( 41),
                             UINT8_C(201), UINT8_C( 13), UINT8_C(211), UINT8_C(230),
                             UINT8_C(208), UINT8_C(154), UINT8_C( 49), UINT8_C(127),
                             UINT8_C( 93), UINT8_C(  7), UINT8_C(136), UINT8_C( 53),
                             UINT8_C( 19), UINT8_C( 95), UINT8_C(187), UINT8_C(149),
                             UINT8_C(  0), UINT8_C(161), UINT8_C(228), UINT8_C( 84),
                             UINT8_C( 84), UINT8_C(105), UINT8_C( 90), UINT8_C( 17),
                             UINT8_C(  3), UINT8_C(183), UINT8_C(131), UINT8_C( 24),
                             UINT8_C(201), UINT8_C(  5), UINT8_C(128), UINT8_C( 80)),
      simde_x_mm512_set_epu8(UINT8_C( 94), UINT8_C( 86), UINT8_C(113), UINT8_C( 18),
                             UINT8_C(124), UINT8_C(171), UINT8_C( 40), UINT8_C(104),
                             UINT8_C( 84), UINT8_C(140), UINT8_C(128), UINT8_C( 69),
                             UINT8_C( 75), UINT8_C( 64), UINT8_C( 82), UINT8_C( 91),
                             UINT8_C(151), UINT8_C( 98), UINT8_C(116), UINT8_C( 66),
                             UINT8_C(158), UINT8_C( 57), UINT8_C(157), UINT8_C(186),
                             UINT8_C(131), UINT8_C( 75), UINT8_C(137), UINT8_C( 91),
                             UINT8_C(200), UINT8_C(122), UINT8_C(133), UINT8_C( 29),
                             UINT8_C(140), UINT8_C(106), UINT8_C(113), UINT8_C(204),
                             UINT8_C(146), UINT8_C( 85), UINT8_C( 43), UINT8_C(171),
                             UINT8_C(136), UINT8_C( 76), UINT8_C(188), UINT8_C( 53),
                             UINT8_C( 68), UINT8_C(145), UINT8_C(144), UINT8_C(196),
                             UINT8_C( 67), UINT8_C(127), UINT8_C(146), UINT8_C( 94),
                             UINT8_C( 79), UINT8_C( 94), UINT8_C(140), UINT8_C( 27),
                             UINT8_C(103), UINT8_C(123), UINT8_C(144), UINT8_C( 61),
                             UINT8_C(172), UINT8_C(  6), UINT8_C( 83), UINT8_C( 52)) },
    { simde_x_mm512_set_epu8(UINT8_C( 64), UINT8_C( 98), UINT8_C(116), UINT8_C(169),
                             UINT8_C(168), UINT8_C(153), UINT8_C(192), UINT8_C(140),
                             UINT8_C( 79), UINT8_C( 29), UINT8_C(180), UINT8_C(232),
                             UINT8_C( 89), UINT8_C( 84), UINT8_C(140), UINT8_C(130),
                             UINT8_C(108), UINT8_C(184), UINT8_C(116), UINT8_C( 83),
                             UINT8_C(161), UINT8_C(105), UINT8_C( 17), UINT8_C(119),
                             UINT8_C(  0), UINT8_C(101), UINT8_C(104), UINT8_C(103),
                             UINT8_C(226), UINT8_C( 60), UINT8_C( 23), UINT8_C(129),
                             UINT8_C(141), UINT8_C(179), UINT8_C( 87), UINT8_C(113),
                             UINT8_C(251), UINT8_C(219), UINT8_C(107), UINT8_C(119),
                             UINT8_C( 70), UINT8_C(169), UINT8_C( 11), UINT8_C( 91),
                             UINT8_C( 23), UINT8_C(156), UINT8_C( 99), UINT8_C( 36),
                             UINT8_C(154), UINT8_C( 26), UINT8_C( 23), UINT8_C(168),
                             UINT8_C( 12), UINT8_C(101), UINT8_C(189), UINT8_C(124),
                             UINT8_C(154), UINT8_C( 52), UINT8_C(134), UINT8_C(128),
                             UINT8_C(213), UINT8_C( 85), UINT8_C(189), UINT8_C(209)),
      simde_x_mm512_set_epu8(UINT8_C( 21), UINT8_C( 27), UINT8_C( 57), UINT8_C(175),
                             UINT8_C(191), UINT8_C( 35), UINT8_C( 75), UINT8_C(  5),
                             UINT8_C(168), UINT8_C( 42), UINT8_C(198), UINT8_C(223),
                             UINT8_C(239), UINT8_C(225), UINT8_C(227), UINT8_C(  5),
                             UINT8_C( 85), UINT8_C(196), UINT8_C(184), UINT8_C(155),
                             UINT8_C( 73), UINT8_C(109), UINT8_C(131), UINT8_C(103),
                             UINT8_C(131), UINT8_C(155), UINT8_C(105), UINT8_C( 70),
                             UINT8_C(164), UINT8_C(114), UINT8_C(114), UINT8_C(212),
                             UINT8_C(157), UINT8_C( 34), UINT8_C(220), UINT8_C(250),
                             UINT8_C(254), UINT8_C(227), UINT8_C(240), UINT8_C( 41),
                             UINT8_C(208), UINT8_C( 26), UINT8_C(221), UINT8_C(132),
                             UINT8_C(121), UINT8_C(178), UINT8_C(219), UINT8_C( 55),
                             UINT8_C( 45), UINT8_C( 78), UINT8_C(233), UINT8_C( 53),
                             UINT8_C( 87), UINT8_C(172), UINT8_C(122), UINT8_C(147),
                             UINT8_C(187), UINT8_C(115), UINT8_C( 22), UINT8_C(254),
                             UINT8_C(  9), UINT8_C(218), UINT8_C(224), UINT8_C(214)),
      simde_x_mm512_set_epu8(UINT8_C( 43), UINT8_C( 63), UINT8_C( 87), UINT8_C(172),
                             UINT8_C(180), UINT8_C( 94), UINT8_C(134), UINT8_C( 73),
                             UINT8_C(124), UINT8_C( 36), UINT8_C(189), UINT8_C(228),
                             UINT8_C(164), UINT8_C(155), UINT8_C(184), UINT8_C( 68),
                             UINT8_C( 97), UINT8_C(190), UINT8_C(150), UINT8_C(119),
                             UINT8_C(117), UINT8_C(107), UINT8_C( 74), UINT8_C(111),
                             UINT8_C( 66), UINT8_C(128), UINT8_C(105), UINT8_C( 87),
                             UINT8_C(195), UINT8_C( 87), UINT8_C( 69), UINT8_C(171),
                             UINT8_C(149), UINT8_C(107), UINT8_C(154), UINT8_C(182),
                             UINT8_C(253), UINT8_C(223), UINT8_C(174), UINT8_C( 80),
                             UINT8_C(139), UINT8_C( 98), UINT8_C(116), UINT8_C(112),
                             UINT8_C( 72), UINT8_C(167), UINT8_C(159), UINT8_C( 46),
                             UINT8_C(100), UINT8_C( 52), UINT8_C(128), UINT8_C(111),
                             UINT8_C( 50), UINT8_C(137), UINT8_C(156), UINT8_C(136),
                             UINT8_C(171), UINT8_C( 84), UINT8_C( 78), UINT8_C(191),
                             UINT8_C(111), UINT8_C(152), UINT8_C(207), UINT8_C(212)) },
    { simde_x_mm512_set_epu8(UINT8_C(136), UINT8_C( 77), UINT8_C( 92), UINT8_C(127),
                             UINT8_C(250), UINT8_C( 34), UINT8_C(180), UINT8_C(171),
                             UINT8_C( 31), UINT8_C(112), UINT8_C(162), UINT8_C(182),
                             UINT8_C(240), UINT8_C(136), UINT8_C( 96), UINT8_C( 85),
                             UINT8_C( 41), UINT8_C( 52), UINT8_C( 59), UINT8_C(203),
                             UINT8_C(213), UINT8_C(103), UINT8_C(221), UINT8_C(176),
                             UINT8_C( 99), UINT8_C(  2), UINT8_C( 21), UINT8_C(182),
                             UINT8_C(  7), UINT8_C(176), UINT8_C(125), UINT8_C(109),
                             UINT8_C(233), UINT8_C(242), UINT8_C(  5), UINT8_C(109),
                             UINT8_C( 73), UINT8_C(240), UINT8_C(175), UINT8_C( 24),
                             UINT8_C( 44), UINT8_C(103), UINT8_C(204), UINT8_C( 40),
                             UINT8_C( 78), UINT8_C(117), UINT8_C(221), UINT8_C(168),
                             UINT8_C(194), UINT8_C( 10), UINT8_C( 15), UINT8_C(227),
                             UINT8_C( 13), UINT8_C(241), UINT8_C( 93), UINT8_C( 23),
                             UINT8_C( 31), UINT8_C( 84), UINT8_C(219), UINT8_C( 76),
                             UINT8_C( 52), UINT8_C( 31), UINT8_C( 22), UINT8_C(183)),
      simde_x_mm512_set_epu8(UINT8_C(  0), UINT8_C( 70), UINT8_C(193), UINT8_C(116),
                             UINT8_C(  9), UINT8_C( 85), UINT8_C(190), UINT8_C(154),
                             UINT8_C( 37), UINT8_C(184), UINT8_C(193), UINT8_C(107),
                             UINT8_C( 79), UINT8_C(235), UINT8_C( 33), UINT8_C(125),
                             UINT8_C(111), UINT8_C(108), UINT8_C( 99), UINT8_C(162),
                             UINT8_C(175), UINT8_C(211), UINT8_C( 79), UINT8_C(167),
                             UINT8_C(166), UINT8_C( 89), UINT8_C( 21), UINT8_C(138),
                             UINT8_C( 15), UINT8_C(105), UINT8_C(191), UINT8_C(205),
                             UINT8_C( 34), UINT8_C(122), UINT8_C(209), UINT8_C(143),
                             UINT8_C(216), UINT8_C(162), UINT8_C(239), UINT8_C(190),
                             UINT8_C(212), UINT8_C(246), UINT8_C(251), UINT8_C(206),
                             UINT8_C( 61), UINT8_C( 80), UINT8_C(151), UINT8_C( 93),
                             UINT8_C( 56), UINT8_C(135), UINT8_C(169), UINT8_C(  8),
                             UINT8_C(191), UINT8_C( 66), UINT8_C( 60), UINT8_C( 24),
                             UINT8_C( 93), UINT8_C(156), UINT8_C( 32), UINT8_C( 27),
                             UINT8_C( 48), UINT8_C(210), UINT8_C(231), UINT8_C( 10)),
      simde_x_mm512_set_epu8(UINT8_C( 68), UINT8_C( 74), UINT8_C(143), UINT8_C(122),
                             UINT8_C(130), UINT8_C( 60), UINT8_C(185), UINT8_C(163),
                             UINT8_C( 34), UINT8_C(148), UINT8_C(178), UINT8_C(145),
                             UINT8_C(160), UINT8_C(186), UINT8_C( 65), UINT8_C(105),
                             UINT8_C( 76), UINT8_C( 80), UINT8_C( 79), UINT8_C(183),
                             UINT8_C(194), UINT8_C(157), UINT8_C(150), UINT8_C(172),
                             UINT8_C(133), UINT8_C( 46), UINT8_C( 21), UINT8_C(160),
                             UINT8_C( 11), UINT8_C(141), UINT8_C(158), UINT8_C(157),
                             UINT8_C(134), UINT8_C(182), UINT8_C(107), UINT8_C(126),
                             UINT8_C(145), UINT8_C(201), UINT8_C(207), UINT8_C(107),
                             UINT8_C(128), UINT8_C(175), UINT8_C(228), UINT8_C(123),
                             UINT8_C( 70), UINT8_C( 99), UINT8_C(186), UINT8_C(131),
                             UINT8_C(125), UINT8_C( 73), UINT8_C( 92), UINT8_C(118),
                             UINT8_C(102), UINT8_C(154), UINT8_C( 77), UINT8_C( 24),
                             UINT8_C( 62), UINT8_C(120), UINT8_C(126), UINT8_C( 52),
                             UINT8_C( 50), UINT8_C(121), UINT8_C(127), UINT8_C( 97)) },
    { simde_x_mm512_set_epu8(UINT8_C(234), UINT8_C(192), UINT8_C(234), UINT8_C(237),
                             UINT8_C(  5), UINT8_C(121), UINT8_C(180), UINT8_C( 23),
                             UINT8_C( 48), UINT8_C(184), UINT8_C(208), UINT8_C(106),
                             UINT8_C( 94), UINT8_C(238), UINT8_C(124), UINT8_C( 15),
                             UINT8_C(123), UINT8_C(203), UINT8_C( 16), UINT8_C( 14),
                             UINT8_C(131), UINT8_C(218), UINT8_C( 99), UINT8_C(178),
                             UINT8_C(217), UINT8_C(189), UINT8_C(211), UINT8_C(222),
                             UINT8_C( 27), UINT8_C( 25), UINT8_C( 55), UINT8_C(187),
                             UINT8_C( 24), UINT8_C(250), UINT8_C( 44), UINT8_C(207),
                             UINT8_C(143), UINT8_C(198), UINT8_C(115), UINT8_C(  4),
                             UINT8_C( 18), UINT8_C( 78), UINT8_C( 97), UINT8_C( 62),
                             UINT8_C( 38), UINT8_C(184), UINT8_C(216), UINT8_C(124),
                             UINT8_C(155), UINT8_C( 45), UINT8_C( 66), UINT8_C( 36),
                             UINT8_C(  7), UINT8_C( 22), UINT8_C(106), UINT8_C( 14),
                             UINT8_C( 55), UINT8_C(  9), UINT8_C(104), UINT8_C(136),
                             UINT8_C(167), UINT8_C(129), UINT8_C(  7), UINT8_C( 98)),
      simde_x_mm512_set_epu8(UINT8_C(  4), UINT8_C( 28), UINT8_C(178), UINT8_C(230),
                             UINT8_C(  8), UINT8_C( 80), UINT8_C(138), UINT8_C(121),
                             UINT8_C(141), UINT8_C(178), UINT8_C(150), UINT8_C( 72),
                             UINT8_C(121), UINT8_C( 20), UINT8_C( 28), UINT8_C(243),
                             UINT8_C(255), UINT8_C(153), UINT8_C( 78), UINT8_C(119),
                             UINT8_C( 23), UINT8_C(182), UINT8_C(133), UINT8_C(168),
                             UINT8_C(148), UINT8_C(129), UINT8_C(203), UINT8_C(206),
                             UINT8_C( 25), UINT8_C(232), UINT8_C( 71), UINT8_C( 92),
                             UINT8_C( 90), UINT8_C(159), UINT8_C(196), UINT8_C( 86),
                             UINT8_C(163), UINT8_C(105), UINT8_C(169), UINT8_C(248),
                             UINT8_C(169), UINT8_C( 85), UINT8_C(177), UINT8_C(146),
                             UINT8_C( 77), UINT8_C( 44), UINT8_C(150), UINT8_C( 64),
                             UINT8_C(145), UINT8_C( 33), UINT8_C(163), UINT8_C(255),
                             UINT8_C( 33), UINT8_C( 86), UINT8_C(  3), UINT8_C(162),
                             UINT8_C(241), UINT8_C(203), UINT8_C( 13), UINT8_C( 95),
                             UINT8_C(247), UINT8_C( 54), UINT8_C( 73), UINT8_C(154)),
      simde_x_mm512_set_epu8(UINT8_C(119), UINT8_C(110), UINT8_C(206), UINT8_C(234),
                             UINT8_C(  7), UINT8_C(101), UINT8_C(159), UINT8_C( 72),
                             UINT8_C( 95), UINT8_C(181), UINT8_C(179), UINT8_C( 89),
                             UINT8_C(108), UINT8_C(129), UINT8_C( 76), UINT8_C(129),
                             UINT8_C(189), UINT8_C(178), UINT8_C( 47), UINT8_C( 67),
                             UINT8_C( 77), UINT8_C(200), UINT8_C(116), UINT8_C(173),
                             UINT8_C(183), UINT8_C(159), UINT8_C(207), UINT8_C(214),
                             UINT8_C( 26), UINT8_C(129), UINT8_C( 63), UINT8_C(140),
                             UINT8_C( 57), UINT8_C(205), UINT8_C(120), UINT8_C(147),
                             UINT8_C(153), UINT8_C(152), UINT8_C(142), UINT8_C(126),
                             UINT8_C( 94), UINT8_C( 82), UINT8_C(137), UINT8_C(104),
                             UINT8_C( 58), UINT8_C(114), UINT8_C(183), UINT8_C( 94),
                             UINT8_C(150), UINT8_C( 39), UINT8_C(115), UINT8_C(146),
                             UINT8_C( 20), UINT8_C( 54), UINT8_C( 55), UINT8_C( 88),
                             UINT8_C(148), UINT8_C(106), UINT8_C( 59), UINT8_C(116),
                             UINT8_C(207), UINT8_C( 92), UINT8_C( 40), UINT8_C(126)) },
    { simde_x_mm512_set_epu8(UINT8_C( 83), UINT8_C(142), UINT8_C( 42), UINT8_C(220),
                             UINT8_C( 37), UINT8_C( 62), UINT8_C( 98), UINT8_C(238),
                             UINT8_C(153), UINT8_C( 28), UINT8_C(206), UINT8_C(122),
                             UINT8_C( 85), UINT8_C(118), UINT8_C(175), UINT8_C(149),
                             UINT8_C(220), UINT8_C( 77), UINT8_C( 29), UINT8_C( 65),
                             UINT8_C(199), UINT8_C(150), UINT8_C( 85), UINT8_C(205),
                             UINT8_C(179), UINT8_C(171), UINT8_C( 47), UINT8_C( 79),
                             UINT8_C(186), UINT8_C(189), UINT8_C(  5), UINT8_C( 88),
                             UINT8_C(186), UINT8_C(241), UINT8_C(203), UINT8_C(126),
                             UINT8_C(116), UINT8_C( 53), UINT8_C( 43), UINT8_C(208),
                             UINT8_C(141), UINT8_C(174), UINT8_C(168), UINT8_C( 33),
                             UINT8_C(144), UINT8_C(236), UINT8_C( 92), UINT8_C(185),
                             UINT8_C(194), UINT8_C( 20), UINT8_C(  6), UINT8_C( 82),
                             UINT8_C( 17), UINT8_C(156), UINT8_C(193), UINT8_C(  6),
                             UINT8_C( 65), UINT8_C( 12), UINT8_C( 82), UINT8_C(186),
                             UINT8_C(  9), UINT8_C( 38), UINT8_C(161), UINT8_C(250)),
      simde_x_mm512_set_epu8(UINT8_C(  7), UINT8_C(237), UINT8_C(219), UINT8_C(171),
                             UINT8_C(236), UINT8_C(104), UINT8_C( 84), UINT8_C(  1),
                             UINT8_C(226), UINT8_C( 80), UINT8_C( 28), UINT8_C(225),
                             UINT8_C(190), UINT8_C(201), UINT8_C(130), UINT8_C(143),
                             UINT8_C( 85), UINT8_C(214), UINT8_C(162), UINT8_C(248),
                             UINT8_C(236), UINT8_C(124), UINT8_C(162), UINT8_C(253),
                             UINT8_C(116), UINT8_C(105), UINT8_C(252), UINT8_C(254),
                             UINT8_C( 40), UINT8_C( 36), UINT8_C( 40), UINT8_C(179),
                             UINT8_C(113), UINT8_C(185), UINT8_C( 37), UINT8_C(245),
                             UINT8_C( 41), UINT8_C(  6), UINT8_C(210), UINT8_C( 50),
                             UINT8_C( 82), UINT8_C(223), UINT8_C(202), UINT8_C( 34),
                             UINT8_C(124), UINT8_C( 12), UINT8_C(156), UINT8_C(107),
                             UINT8_C( 75), UINT8_C(221), UINT8_C(108), UINT8_C(193),
                             UINT8_C(  4), UINT8_C(112), UINT8_C(113), UINT8_C(115),
                             UINT8_C(250), UINT8_C( 35), UINT8_C(161), UINT8_C( 10),
                             UINT8_C(151), UINT8_C(213), UINT8_C(128), UINT8_C(  1)),
      simde_x_mm512_set_epu8(UINT8_C( 45), UINT8_C(190), UINT8_C(131), UINT8_C(196),
                             UINT8_C(137), UINT8_C( 83), UINT8_C( 91), UINT8_C(120),
                             UINT8_C(190), UINT8_C( 54), UINT8_C(117), UINT8_C(174),
                             UINT8_C(138), UINT8_C(160), UINT8_C(153), UINT8_C(146),
                             UINT8_C(153), UINT8_C(146), UINT8_C( 96), UINT8_C(157),
                             UINT8_C(218), UINT8_C(137), UINT8_C(124), UINT8_C(229),
                             UINT8_C(148), UINT8_C(138), UINT8_C(150), UINT8_C(167),
                             UINT8_C(113), UINT8_C(113), UINT8_C( 23), UINT8_C(134),
                             UINT8_C(150), UINT8_C(213), UINT8_C(120), UINT8_C(186),
                             UINT8_C( 79), UINT8_C( 30), UINT8_C(127), UINT8_C(129),
                             UINT8_C(112), UINT8_C(199), UINT8_C(185), UINT8_C( 34),
                             UINT8_C(134), UINT8_C(124), UINT8_C(124), UINT8_C(146),
                             UINT8_C(135), UINT8_C(121), UINT8_C( 57), UINT8_C(138),
                             UINT8_C( 11), UINT8_C(134), UINT8_C(153), UINT8_C( 61),
                             UINT8_C(158), UINT8_C( 24), UINT8_C(122), UINT8_C( 98),
                             UINT8_C( 80), UINT8_C(126), UINT8_C(145), UINT8_C(126)) }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])); i++) {
    simde__m512i r = simde_mm512_avg_epu8(test_vec[i].a, test_vec[i].b);
    simde_assert_m512i_u8(r, ==, test_vec[i].r);
  }

  return 0;
}

static int
test_simde_mm512_mask_avg_epu8(SIMDE_MUNIT_TEST_ARGS) {
  const struct {
    simde__m512i src;
    simde__mmask64 k;
    simde__m512i a;
    simde__m512i b;
    simde__m512i r;
  } test_vec[8] = {
    { simde_x_mm512_set_epu8(UINT8_C(117), UINT8_C(152), UINT8_C(221), UINT8_C(216),
                             UINT8_C(255), UINT8_C( 43), UINT8_C( 10), UINT8_C(211),
                             UINT8_C(214), UINT8_C( 80), UINT8_C(187), UINT8_C(241),
                             UINT8_C(242), UINT8_C(134), UINT8_C( 60), UINT8_C( 93),
                             UINT8_C( 23), UINT8_C(122), UINT8_C( 10), UINT8_C(108),
                             UINT8_C(232), UINT8_C(191), UINT8_C(217), UINT8_C(158),
                             UINT8_C(199), UINT8_C(250), UINT8_C( 81), UINT8_C(211),
                             UINT8_C(229), UINT8_C( 28), UINT8_C(171), UINT8_C( 15),
                             UINT8_C(138), UINT8_C( 52), UINT8_C( 10), UINT8_C(140),
                             UINT8_C( 26), UINT8_C(213), UINT8_C(218), UINT8_C(229),
                             UINT8_C( 66), UINT8_C(204), UINT8_C(  5), UINT8_C(255),
                             UINT8_C(228), UINT8_C(  3), UINT8_C(123), UINT8_C(140),
                             UINT8_C(222), UINT8_C(224), UINT8_C( 98), UINT8_C(103),
                             UINT8_C(237), UINT8_C(138), UINT8_C(179), UINT8_C(224),
                             UINT8_C( 60), UINT8_C(176), UINT8_C( 22), UINT8_C(230),
                             UINT8_C( 60), UINT8_C(244), UINT8_C(191), UINT8_C( 88)),
      UINT64_C(          2117573942),
      simde_x_mm512_set_epu8(UINT8_C( 32), UINT8_C( 22), UINT8_C( 88), UINT8_C(222),
                             UINT8_C( 12), UINT8_C( 90), UINT8_C(155), UINT8_C(252),
                             UINT8_C(242), UINT8_C( 42), UINT8_C(169), UINT8_C(105),
                             UINT8_C( 22), UINT8_C( 34), UINT8_C(113), UINT8_C(184),
                             UINT8_C(216), UINT8_C(186), UINT8_C(232), UINT8_C(159),
                             UINT8_C(188), UINT8_C(250), UINT8_C( 98), UINT8_C(132),
                             UINT8_C(221), UINT8_C( 11), UINT8_C(138), UINT8_C(207),
                             UINT8_C(214), UINT8_C( 24), UINT8_C(222), UINT8_C( 73),
                             UINT8_C(253), UINT8_C(184), UINT8_C(153), UINT8_C( 26),
                             UINT8_C(220), UINT8_C(147), UINT8_C( 37), UINT8_C( 50),
                             UINT8_C( 26), UINT8_C( 78), UINT8_C( 33), UINT8_C( 67),
                             UINT8_C(248), UINT8_C(190), UINT8_C( 29), UINT8_C( 31),
                             UINT8_C( 34), UINT8_C( 40), UINT8_C(189), UINT8_C( 86),
                             UINT8_C( 38), UINT8_C(128), UINT8_C(150), UINT8_C(241),
                             UINT8_C(100), UINT8_C( 53), UINT8_C( 42), UINT8_C( 55),
                             UINT8_C( 87), UINT8_C(241), UINT8_C(251), UINT8_C(171)),
      simde_x_mm512_set_epu8(UINT8_C(229), UINT8_C(148), UINT8_C(139), UINT8_C(168),
                             UINT8_C(149), UINT8_C( 53), UINT8_C(240), UINT8_C(255),
                             UINT8_C(164), UINT8_C(137), UINT8_C( 17), UINT8_C(134),
                             UINT8_C( 22), UINT8_C(243), UINT8_C(  7), UINT8_C(130),
                             UINT8_C(232), UINT8_C(205), UINT8_C(227), UINT8_C(142),
                             UINT8_C(100), UINT8_C(203), UINT8_C(  0), UINT8_C(144),
                             UINT8_C(176), UINT8_C( 89), UINT8_C( 91), UINT8_C(  1),
                             UINT8_C(102), UINT8_C(254), UINT8_C(189), UINT8_C(168),
                             UINT8_C(251), UINT8_C(171), UINT8_C( 24), UINT8_C( 13),
                             UINT8_C( 67), UINT8_C( 49), UINT8_C( 20), UINT8_C(185),
                             UINT8_C(232), UINT8_C( 19), UINT8_C(238), UINT8_C( 58),
                             UINT8_C(109), UINT8_C(140), UINT8_C( 95), UINT8_C( 71),
                             UINT8_C( 47), UINT8_C(118), UINT8_C(241), UINT8_C(225),
                             UINT8_C(186), UINT8_C(175), UINT8_C( 45), UINT8_C( 88),
                             UINT8_C(164), UINT8_C( 95), UINT8_C(253), UINT8_C(227),
                             UINT8_C( 20), UINT8_C(170), UINT8_C(251), UINT8_C( 57)),
      simde_x_mm512_set_epu8(UINT8_C(117), UINT8_C(152), UINT8_C(221), UINT8_C(216),
                             UINT8_C(255), UINT8_C( 43), UINT8_C( 10), UINT8_C(211),
                             UINT8_C(214), UINT8_C( 80), UINT8_C(187), UINT8_C(241),
                             UINT8_C(242), UINT8_C(134), UINT8_C( 60), UINT8_C( 93),
                             UINT8_C( 23), UINT8_C(122), UINT8_C( 10), UINT8_C(108),
                             UINT8_C(232), UINT8_C(191), UINT8_C(217), UINT8_C(158),
                             UINT8_C(199), UINT8_C(250), UINT8_C( 81), UINT8_C(211),
                             UINT8_C(229), UINT8_C( 28), UINT8_C(171), UINT8_C( 15),
                             UINT8_C(138), UINT8_C(178), UINT8_C( 89), UINT8_C( 20),
                             UINT8_C(144), UINT8_C( 98), UINT8_C( 29), UINT8_C(229),
                             UINT8_C( 66), UINT8_C(204), UINT8_C(136), UINT8_C( 63),
                             UINT8_C(228), UINT8_C(165), UINT8_C( 62), UINT8_C( 51),
                             UINT8_C( 41), UINT8_C(224), UINT8_C( 98), UINT8_C(156),
                             UINT8_C(112), UINT8_C(152), UINT8_C(179), UINT8_C(165),
                             UINT8_C( 60), UINT8_C(176), UINT8_C(148), UINT8_C(141),
                             UINT8_C( 60), UINT8_C(206), UINT8_C(251), UINT8_C( 88)) },
    { simde_x_mm512_set_epu8(UINT8_C(248), UINT8_C(153), UINT8_C(124), UINT8_C(192),
                             UINT8_C(251), UINT8_C( 73), UINT8_C( 83), UINT8_C(149),
                             UINT8_C(192), UINT8_C(225), UINT8_C( 11), UINT8_C( 45),
                             UINT8_C(242), UINT8_C(146), UINT8_C(100), UINT8_C(250),
                             UINT8_C(206), UINT8_C(133), UINT8_C(162), UINT8_C( 12),
                             UINT8_C(227), UINT8_C(156), UINT8_C( 97), UINT8_C(141),
                             UINT8_C(103), UINT8_C(177), UINT8_C(102), UINT8_C(250),
                             UINT8_C(236), UINT8_C(151), UINT8_C(250), UINT8_C( 69),
                             UINT8_C( 19), UINT8_C(102), UINT8_C(130), UINT8_C(239),
                             UINT8_C( 26), UINT8_C(151), UINT8_C( 91), UINT8_C(218),
                             UINT8_C(106), UINT8_C(  8), UINT8_C( 85), UINT8_C(190),
                             UINT8_C( 40), UINT8_C(207), UINT8_C( 10), UINT8_C( 15),
                             UINT8_C( 30), UINT8_C( 97), UINT8_C(208), UINT8_C( 26),
                             UINT8_C( 77), UINT8_C(104), UINT8_C(138), UINT8_C( 49),
                             UINT8_C(222), UINT8_C(133), UINT8_C( 22), UINT8_C(114),
                             UINT8_C(226), UINT8_C( 75), UINT8_C(  2), UINT8_C(236)),
      UINT64_C(           474091127),
      simde_x_mm512_set_epu8(UINT8_C( 64), UINT8_C( 45), UINT8_C(186), UINT8_C( 94),
                             UINT8_C(127), UINT8_C(186), UINT8_C(127), UINT8_C(178),
                             UINT8_C(198), UINT8_C( 92), UINT8_C(231), UINT8_C(248),
                             UINT8_C( 21), UINT8_C( 89), UINT8_C(  8), UINT8_C(  1),
                             UINT8_C( 85), UINT8_C(  5), UINT8_C(111), UINT8_C(109),
                             UINT8_C(  6), UINT8_C(229), UINT8_C( 18), UINT8_C( 62),
                             UINT8_C(249), UINT8_C(126), UINT8_C(234), UINT8_C(220),
                             UINT8_C(246), UINT8_C(255), UINT8_C(  1), UINT8_C(115),
                             UINT8_C( 87), UINT8_C( 93), UINT8_C(185), UINT8_C(156),
                             UINT8_C(164), UINT8_C(103), UINT8_C(237), UINT8_C(252),
                             UINT8_C(126), UINT8_C(112), UINT8_C(184), UINT8_C( 45),
                             UINT8_C( 61), UINT8_C(246), UINT8_C( 68), UINT8_C(163),
                             UINT8_C(  5), UINT8_C(127), UINT8_C(109), UINT8_C(194),
                             UINT8_C(167), UINT8_C(139), UINT8_C(130), UINT8_C( 52),
                             UINT8_C(248), UINT8_C(164), UINT8_C(233), UINT8_C(208),
                             UINT8_C(104), UINT8_C(136), UINT8_C(254), UINT8_C(148)),
      simde_x_mm512_set_epu8(UINT8_C( 10), UINT8_C(152), UINT8_C(249), UINT8_C(150),
                             UINT8_C(250), UINT8_C(  9), UINT8_C(168), UINT8_C( 52),
                             UINT8_C( 69), UINT8_C( 91), UINT8_C(134), UINT8_C( 83),
                             UINT8_C( 54), UINT8_C(214), UINT8_C(  9), UINT8_C(100),
                             UINT8_C( 84), UINT8_C( 66), UINT8_C( 99), UINT8_C(199),
                             UINT8_C( 20), UINT8_C(200), UINT8_C(215), UINT8_C( 34),
                             UINT8_C( 96), UINT8_C(125), UINT8_C( 40), UINT8_C(246),
                             UINT8_C( 37), UINT8_C(202), UINT8_C(215), UINT8_C(111),
                             UINT8_C(239), UINT8_C( 73), UINT8_C( 10), UINT8_C( 78),
                             UINT8_C(192), UINT8_C( 57), UINT8_C( 95), UINT8_C( 52),
                             UINT8_C(133), UINT8_C(102), UINT8_C(165), UINT8_C(231),
                             UINT8_C(182), UINT8_C( 23), UINT8_C(129), UINT8_C(213),
                             UINT8_C(123), UINT8_C(235), UINT8_C(187), UINT8_C( 72),
                             UINT8_C(170), UINT8_C( 39), UINT8_C(204), UINT8_C( 88),
                             UINT8_C( 48), UINT8_C( 73), UINT8_C(134), UINT8_C( 45),
                             UINT8_C(127), UINT8_C( 12), UINT8_C( 19), UINT8_C(132)),
      simde_x_mm512_set_epu8(UINT8_C(248), UINT8_C(153), UINT8_C(124), UINT8_C(192),
                             UINT8_C(251), UINT8_C( 73), UINT8_C( 83), UINT8_C(149),
                             UINT8_C(192), UINT8_C(225), UINT8_C( 11), UINT8_C( 45),
                             UINT8_C(242), UINT8_C(146), UINT8_C(100), UINT8_C(250),
                             UINT8_C(206), UINT8_C(133), UINT8_C(162), UINT8_C( 12),
                             UINT8_C(227), UINT8_C(156), UINT8_C( 97), UINT8_C(141),
                             UINT8_C(103), UINT8_C(177), UINT8_C(102), UINT8_C(250),
                             UINT8_C(236), UINT8_C(151), UINT8_C(250), UINT8_C( 69),
                             UINT8_C( 19), UINT8_C(102), UINT8_C(130), UINT8_C(117),
                             UINT8_C(178), UINT8_C( 80), UINT8_C( 91), UINT8_C(218),
                             UINT8_C(106), UINT8_C(107), UINT8_C( 85), UINT8_C(190),
                             UINT8_C( 40), UINT8_C(207), UINT8_C( 99), UINT8_C( 15),
                             UINT8_C( 30), UINT8_C( 97), UINT8_C(208), UINT8_C( 26),
                             UINT8_C(169), UINT8_C( 89), UINT8_C(167), UINT8_C( 49),
                             UINT8_C(222), UINT8_C(119), UINT8_C(184), UINT8_C(127),
                             UINT8_C(226), UINT8_C( 74), UINT8_C(137), UINT8_C(140)) },
    { simde_x_mm512_set_epu8(UINT8_C(221), UINT8_C(100), UINT8_C(182), UINT8_C(149),
                             UINT8_C( 44), UINT8_C(198), UINT8_C( 20), UINT8_C( 23),
                             UINT8_C(105), UINT8_C(188), UINT8_C(118), UINT8_C(243),
                             UINT8_C(175), UINT8_C( 41), UINT8_C(183), UINT8_C(141),
                             UINT8_C(145), UINT8_C( 21), UINT8_C( 99), UINT8_C(117),
                             UINT8_C(242), UINT8_C(144), UINT8_C( 71), UINT8_C( 21),
                             UINT8_C(142), UINT8_C(181), UINT8_C( 66), UINT8_C(137),
                             UINT8_C(194), UINT8_C(226), UINT8_C( 86), UINT8_C(128),
                             UINT8_C(109), UINT8_C( 15), UINT8_C(187), UINT8_C( 22),
                             UINT8_C(243), UINT8_C( 38), UINT8_C(163), UINT8_C(215),
                             UINT8_C( 96), UINT8_C( 79), UINT8_C(232), UINT8_C(216),
                             UINT8_C( 90), UINT8_C( 31), UINT8_C(221), UINT8_C( 22),
                             UINT8_C(144), UINT8_C(219), UINT8_C( 29), UINT8_C( 29),
                             UINT8_C(  7), UINT8_C(  8), UINT8_C(106), UINT8_C(210),
                             UINT8_C( 85), UINT8_C(118), UINT8_C(120), UINT8_C(208),
                             UINT8_C(112), UINT8_C( 80), UINT8_C(173), UINT8_C( 55)),
      UINT64_C(            66155005),
      simde_x_mm512_set_epu8(UINT8_C( 90), UINT8_C(190), UINT8_C(204), UINT8_C( 44),
                             UINT8_C(145), UINT8_C( 10), UINT8_C(145), UINT8_C( 20),
                             UINT8_C(245), UINT8_C(128), UINT8_C(239), UINT8_C(216),
                             UINT8_C(215), UINT8_C(  0), UINT8_C(241), UINT8_C(105),
                             UINT8_C( 81), UINT8_C(  3), UINT8_C( 23), UINT8_C(107),
                             UINT8_C(238), UINT8_C( 80), UINT8_C(150), UINT8_C( 52),
                             UINT8_C( 80), UINT8_C(120), UINT8_C( 83), UINT8_C(139),
                             UINT8_C( 84), UINT8_C(178), UINT8_C( 47), UINT8_C(223),
                             UINT8_C(103), UINT8_C( 66), UINT8_C( 79), UINT8_C( 53),
                             UINT8_C(211), UINT8_C( 20), UINT8_C(111), UINT8_C(197),
                             UINT8_C(238), UINT8_C( 30), UINT8_C( 70), UINT8_C(231),
                             UINT8_C(199), UINT8_C( 18), UINT8_C(252), UINT8_C(101),
                             UINT8_C( 75), UINT8_C( 12), UINT8_C( 85), UINT8_C( 93),
                             UINT8_C(177), UINT8_C(243), UINT8_C( 43), UINT8_C( 45),
                             UINT8_C( 40), UINT8_C(175), UINT8_C( 99), UINT8_C(172),
                             UINT8_C(  7), UINT8_C(156), UINT8_C(188), UINT8_C(130)),
      simde_x_mm512_set_epu8(UINT8_C( 42), UINT8_C( 32), UINT8_C(165), UINT8_C(130),
                             UINT8_C(119), UINT8_C( 88), UINT8_C(110), UINT8_C( 93),
                             UINT8_C( 75), UINT8_C(207), UINT8_C(193), UINT8_C(214),
                             UINT8_C( 54), UINT8_C(185), UINT8_C( 87), UINT8_C(255),
                             UINT8_C(231), UINT8_C(196), UINT8_C(102), UINT8_C(158),
                             UINT8_C(161), UINT8_C(222), UINT8_C(210), UINT8_C( 94),
                             UINT8_C(118), UINT8_C(127), UINT8_C(194), UINT8_C(186),
                             UINT8_C( 80), UINT8_C(125), UINT8_C(244), UINT8_C( 33),
                             UINT8_C(110), UINT8_C(247), UINT8_C(227), UINT8_C(141),
                             UINT8_C(139), UINT8_C( 52), UINT8_C(130), UINT8_C(241),
                             UINT8_C(138), UINT8_C(133), UINT8_C(240), UINT8_C( 72),
                             UINT8_C( 84), UINT8_C( 54), UINT8_C( 76), UINT8_C(208),
                             UINT8_C(177), UINT8_C(100), UINT8_C(198), UINT8_C( 30),
                             UINT8_C( 35), UINT8_C( 68), UINT8_C(216), UINT8_C(  8),
                             UINT8_C( 68), UINT8_C(120), UINT8_C(187), UINT8_C(206),
                             UINT8_C(102), UINT8_C(133), UINT8_C( 95), UINT8_C(110)),
      simde_x_mm512_set_epu8(UINT8_C(221), UINT8_C(100), UINT8_C(182), UINT8_C(149),
                             UINT8_C( 44), UINT8_C(198), UINT8_C( 20), UINT8_C( 23),
                             UINT8_C(105), UINT8_C(188), UINT8_C(118), UINT8_C(243),
                             UINT8_C(175), UINT8_C( 41), UINT8_C(183), UINT8_C(141),
                             UINT8_C(145), UINT8_C( 21), UINT8_C( 99), UINT8_C(117),
                             UINT8_C(242), UINT8_C(144), UINT8_C( 71), UINT8_C( 21),
                             UINT8_C(142), UINT8_C(181), UINT8_C( 66), UINT8_C(137),
                             UINT8_C(194), UINT8_C(226), UINT8_C( 86), UINT8_C(128),
                             UINT8_C(109), UINT8_C( 15), UINT8_C(187), UINT8_C( 22),
                             UINT8_C(243), UINT8_C( 38), UINT8_C(121), UINT8_C(219),
                             UINT8_C(188), UINT8_C( 82), UINT8_C(155), UINT8_C(152),
                             UINT8_C( 90), UINT8_C( 31), UINT8_C(221), UINT8_C(155),
                             UINT8_C(144), UINT8_C( 56), UINT8_C(142), UINT8_C( 62),
                             UINT8_C(  7), UINT8_C(  8), UINT8_C(106), UINT8_C( 27),
                             UINT8_C( 54), UINT8_C(148), UINT8_C(143), UINT8_C(189),
                             UINT8_C( 55), UINT8_C(145), UINT8_C(173), UINT8_C(120)) },
    { simde_x_mm512_set_epu8(UINT8_C(197), UINT8_C(175), UINT8_C(198), UINT8_C( 71),
                             UINT8_C(137), UINT8_C(191), UINT8_C(178), UINT8_C(155),
                             UINT8_C(242), UINT8_C(  4), UINT8_C(232), UINT8_C(161),
                             UINT8_C(106), UINT8_C( 31), UINT8_C(104), UINT8_C( 20),
                             UINT8_C( 65), UINT8_C(248), UINT8_C(181), UINT8_C(128),
                             UINT8_C(175), UINT8_C( 68), UINT8_C(170), UINT8_C( 98),
                             UINT8_C(201), UINT8_C( 10), UINT8_C( 75), UINT8_C( 51),
                             UINT8_C(199), UINT8_C(145), UINT8_C( 87), UINT8_C( 47),
                             UINT8_C(235), UINT8_C(105), UINT8_C( 17), UINT8_C(107),
                             UINT8_C(137), UINT8_C(238), UINT8_C(133), UINT8_C( 81),
                             UINT8_C( 54), UINT8_C(134), UINT8_C(173), UINT8_C( 81),
                             UINT8_C( 21), UINT8_C( 13), UINT8_C(  6), UINT8_C(200),
                             UINT8_C(140), UINT8_C(177), UINT8_C(141), UINT8_C( 81),
                             UINT8_C( 31), UINT8_C( 29), UINT8_C(140), UINT8_C(138),
                             UINT8_C(175), UINT8_C( 98), UINT8_C( 23), UINT8_C(148),
                             UINT8_C(130), UINT8_C( 95), UINT8_C(212), UINT8_C(200)),
      UINT64_C(           518008675),
      simde_x_mm512_set_epu8(UINT8_C(155), UINT8_C(133), UINT8_C( 64), UINT8_C(186),
                             UINT8_C(210), UINT8_C(255), UINT8_C( 70), UINT8_C(210),
                             UINT8_C( 96), UINT8_C( 45), UINT8_C( 57), UINT8_C(248),
                             UINT8_C( 23), UINT8_C( 34), UINT8_C(240), UINT8_C(208),
                             UINT8_C( 74), UINT8_C( 85), UINT8_C(150), UINT8_C( 98),
                             UINT8_C( 81), UINT8_C(149), UINT8_C(213), UINT8_C( 64),
                             UINT8_C(146), UINT8_C(124), UINT8_C(134), UINT8_C(133),
                             UINT8_C( 20), UINT8_C(122), UINT8_C( 57), UINT8_C(241),
                             UINT8_C( 58), UINT8_C( 90), UINT8_C(153), UINT8_C( 57),
                             UINT8_C( 51), UINT8_C(138), UINT8_C( 37), UINT8_C(177),
                             UINT8_C( 13), UINT8_C(116), UINT8_C(177), UINT8_C(238),
                             UINT8_C(169), UINT8_C(177), UINT8_C(173), UINT8_C(231),
                             UINT8_C(226), UINT8_C(216), UINT8_C(126), UINT8_C( 80),
                             UINT8_C(182), UINT8_C( 71), UINT8_C(188), UINT8_C( 53),
                             UINT8_C(255), UINT8_C(200), UINT8_C(176), UINT8_C( 17),
                             UINT8_C(127), UINT8_C( 83), UINT8_C(247), UINT8_C(  0)),
      simde_x_mm512_set_epu8(UINT8_C(226), UINT8_C(  1), UINT8_C(238), UINT8_C(252),
                             UINT8_C( 39), UINT8_C( 85), UINT8_C( 69), UINT8_C( 68),
                             UINT8_C(143), UINT8_C(218), UINT8_C( 28), UINT8_C( 83),
                             UINT8_C(225), UINT8_C( 61), UINT8_C( 37), UINT8_C( 67),
                             UINT8_C( 46), UINT8_C(213), UINT8_C( 32), UINT8_C(183),
                             UINT8_C(230), UINT8_C(  2), UINT8_C(250), UINT8_C(122),
                             UINT8_C(205), UINT8_C(118), UINT8_C(  3), UINT8_C( 17),
                             UINT8_C( 32), UINT8_C( 82), UINT8_C( 40), UINT8_C(  0),
                             UINT8_C( 28), UINT8_C( 37), UINT8_C(253), UINT8_C(171),
                             UINT8_C(164), UINT8_C( 45), UINT8_C(233), UINT8_C(198),
                             UINT8_C(148), UINT8_C( 44), UINT8_C( 28), UINT8_C( 77),
                             UINT8_C( 12), UINT8_C( 81), UINT8_C(153), UINT8_C(  7),
                             UINT8_C(234), UINT8_C( 32), UINT8_C(228), UINT8_C(142),
                             UINT8_C(168), UINT8_C( 42), UINT8_C( 92), UINT8_C( 70),
                             UINT8_C(144), UINT8_C(203), UINT8_C(149), UINT8_C( 41),
                             UINT8_C(206), UINT8_C(198), UINT8_C( 56), UINT8_C( 54)),
      simde_x_mm512_set_epu8(UINT8_C(197), UINT8_C(175), UINT8_C(198), UINT8_C( 71),
                             UINT8_C(137), UINT8_C(191), UINT8_C(178), UINT8_C(155),
                             UINT8_C(242), UINT8_C(  4), UINT8_C(232), UINT8_C(161),
                             UINT8_C(106), UINT8_C( 31), UINT8_C(104), UINT8_C( 20),
                             UINT8_C( 65), UINT8_C(248), UINT8_C(181), UINT8_C(128),
                             UINT8_C(175), UINT8_C( 68), UINT8_C(170), UINT8_C( 98),
                             UINT8_C(201), UINT8_C( 10), UINT8_C( 75), UINT8_C( 51),
                             UINT8_C(199), UINT8_C(145), UINT8_C( 87), UINT8_C( 47),
                             UINT8_C(235), UINT8_C(105), UINT8_C( 17), UINT8_C(114),
                             UINT8_C(108), UINT8_C( 92), UINT8_C(135), UINT8_C( 81),
                             UINT8_C( 81), UINT8_C( 80), UINT8_C(103), UINT8_C( 81),
                             UINT8_C( 21), UINT8_C( 13), UINT8_C(  6), UINT8_C(200),
                             UINT8_C(140), UINT8_C(177), UINT8_C(177), UINT8_C( 81),
                             UINT8_C(175), UINT8_C( 57), UINT8_C(140), UINT8_C( 62),
                             UINT8_C(175), UINT8_C(202), UINT8_C(163), UINT8_C(148),
                             UINT8_C(130), UINT8_C( 95), UINT8_C(152), UINT8_C( 27)) },
    { simde_x_mm512_set_epu8(UINT8_C(121), UINT8_C(  9), UINT8_C(193), UINT8_C(106),
                             UINT8_C( 93), UINT8_C( 44), UINT8_C(  0), UINT8_C(223),
                             UINT8_C(203), UINT8_C(101), UINT8_C( 76), UINT8_C( 37),
                             UINT8_C( 94), UINT8_C(224), UINT8_C(152), UINT8_C(236),
                             UINT8_C(208), UINT8_C( 45), UINT8_C( 88), UINT8_C(163),
                             UINT8_C(104), UINT8_C( 42), UINT8_C(157), UINT8_C( 59),
                             UINT8_C( 90), UINT8_C(187), UINT8_C(107), UINT8_C( 16),
                             UINT8_C(138), UINT8_C(137), UINT8_C(196), UINT8_C( 51),
                             UINT8_C(126), UINT8_C(178), UINT8_C(114), UINT8_C(181),
                             UINT8_C(181), UINT8_C( 19), UINT8_C(113), UINT8_C( 84),
                             UINT8_C( 47), UINT8_C(173), UINT8_C(230), UINT8_C(218),
                             UINT8_C( 64), UINT8_C(150), UINT8_C(107), UINT8_C( 56),
                             UINT8_C(130), UINT8_C(248), UINT8_C( 35), UINT8_C(112),
                             UINT8_C(178), UINT8_C( 75), UINT8_C(231), UINT8_C(  1),
                             UINT8_C(229), UINT8_C(189), UINT8_C( 49), UINT8_C( 75),
                             UINT8_C(217), UINT8_C(188), UINT8_C(205), UINT8_C( 42)),
      UINT64_C(          4020943947),
      simde_x_mm512_set_epu8(UINT8_C(244), UINT8_C(209), UINT8_C(117), UINT8_C( 40),
                             UINT8_C( 42), UINT8_C( 16), UINT8_C(230), UINT8_C(122),
                             UINT8_C(122), UINT8_C(219), UINT8_C(158), UINT8_C(236),
                             UINT8_C( 86), UINT8_C(169), UINT8_C(166), UINT8_C(144),
                             UINT8_C(141), UINT8_C( 79), UINT8_C(123), UINT8_C( 33),
                             UINT8_C(201), UINT8_C(131), UINT8_C(102), UINT8_C( 59),
                             UINT8_C(199), UINT8_C( 19), UINT8_C(252), UINT8_C(201),
                             UINT8_C(170), UINT8_C( 88), UINT8_C(209), UINT8_C( 29),
                             UINT8_C(140), UINT8_C(198), UINT8_C(115), UINT8_C(193),
                             UINT8_C(241), UINT8_C(202), UINT8_C( 84), UINT8_C(255),
                             UINT8_C(  5), UINT8_C(223), UINT8_C(160), UINT8_C( 93),
                             UINT8_C( 97), UINT8_C(124), UINT8_C( 26), UINT8_C(222),
                             UINT8_C(175), UINT8_C(168), UINT8_C( 26), UINT8_C(155),
                             UINT8_C(117), UINT8_C(221), UINT8_C(174), UINT8_C( 92),
                             UINT8_C(115), UINT8_C(243), UINT8_C(104), UINT8_C( 83),
                             UINT8_C( 80), UINT8_C(138), UINT8_C( 34), UINT8_C( 48)),
      simde_x_mm512_set_epu8(UINT8_C(168), UINT8_C(187), UINT8_C(118), UINT8_C( 36),
                             UINT8_C(110), UINT8_C( 81), UINT8_C(219), UINT8_C( 36),
                             UINT8_C(182), UINT8_C(147), UINT8_C( 47), UINT8_C( 12),
                             UINT8_C(227), UINT8_C(175), UINT8_C( 76), UINT8_C(234),
                             UINT8_C( 91), UINT8_C(125), UINT8_C( 98), UINT8_C( 17),
                             UINT8_C(115), UINT8_C( 58), UINT8_C(149), UINT8_C( 90),
                             UINT8_C(115), UINT8_C(232), UINT8_C( 83), UINT8_C( 17),
                             UINT8_C(245), UINT8_C( 20), UINT8_C( 81), UINT8_C( 54),
                             UINT8_C(197), UINT8_C(112), UINT8_C(154), UINT8_C( 13),
                             UINT8_C(  8), UINT8_C(151), UINT8_C(229), UINT8_C(129),
                             UINT8_C(144), UINT8_C(125), UINT8_C( 21), UINT8_C( 55),
                             UINT8_C( 24), UINT8_C( 58), UINT8_C(  7), UINT8_C(127),
                             UINT8_C(150), UINT8_C(222), UINT8_C(105), UINT8_C(207),
                             UINT8_C(223), UINT8_C(121), UINT8_C(  0), UINT8_C(127),
                             UINT8_C(191), UINT8_C(166), UINT8_C(133), UINT8_C(112),
                             UINT8_C(199), UINT8_C( 77), UINT8_C( 42), UINT8_C( 34)),
      simde_x_mm512_set_epu8(UINT8_C(121), UINT8_C(  9), UINT8_C(193), UINT8_C(106),
                             UINT8_C( 93), UINT8_C( 44), UINT8_C(  0), UINT8_C(223),
                             UINT8_C(203), UINT8_C(101), UINT8_C( 76), UINT8_C( 37),
                             UINT8_C( 94), UINT8_C(224), UINT8_C(152), UINT8_C(236),
                             UINT8_C(208), UINT8_C( 45), UINT8_C( 88), UINT8_C(163),
                             UINT8_C(104), UINT8_C( 42), UINT8_C(157), UINT8_C( 59),
                             UINT8_C( 90), UINT8_C(187), UINT8_C(107), UINT8_C( 16),
                             UINT8_C(138), UINT8_C(137), UINT8_C(196), UINT8_C( 51),
                             UINT8_C(169), UINT8_C(155), UINT8_C(135), UINT8_C(181),
                             UINT8_C(125), UINT8_C(177), UINT8_C(157), UINT8_C(192),
                             UINT8_C( 75), UINT8_C(173), UINT8_C( 91), UINT8_C(218),
                             UINT8_C( 61), UINT8_C(150), UINT8_C( 17), UINT8_C( 56),
                             UINT8_C(163), UINT8_C(248), UINT8_C( 66), UINT8_C(181),
                             UINT8_C(170), UINT8_C(171), UINT8_C(231), UINT8_C(  1),
                             UINT8_C(229), UINT8_C(205), UINT8_C( 49), UINT8_C( 75),
                             UINT8_C(140), UINT8_C(188), UINT8_C( 38), UINT8_C( 41)) },
    { simde_x_mm512_set_epu8(UINT8_C( 84), UINT8_C(222), UINT8_C( 36), UINT8_C(132),
                             UINT8_C( 32), UINT8_C(182), UINT8_C( 73), UINT8_C(182),
                             UINT8_C( 77), UINT8_C(116), UINT8_C( 50), UINT8_C( 82),
                             UINT8_C( 68), UINT8_C( 72), UINT8_C( 23), UINT8_C( 32),
                             UINT8_C(202), UINT8_C( 82), UINT8_C( 53), UINT8_C( 71),
                             UINT8_C( 22), UINT8_C( 92), UINT8_C( 42), UINT8_C(133),
                             UINT8_C(215), UINT8_C( 34), UINT8_C( 75), UINT8_C( 63),
                             UINT8_C(139), UINT8_C( 23), UINT8_C(141), UINT8_C( 66),
                             UINT8_C(166), UINT8_C( 99), UINT8_C(183), UINT8_C(237),
                             UINT8_C(213), UINT8_C(192), UINT8_C(235), UINT8_C( 20),
                             UINT8_C(108), UINT8_C(253), UINT8_C(147), UINT8_C(214),
                             UINT8_C( 44), UINT8_C(210), UINT8_C( 20), UINT8_C( 90),
                             UINT8_C(  2), UINT8_C(252), UINT8_C(108), UINT8_C( 27),
                             UINT8_C(207), UINT8_C( 69), UINT8_C(172), UINT8_C( 82),
                             UINT8_C(  9), UINT8_C(  0), UINT8_C( 42), UINT8_C(118),
                             UINT8_C(253), UINT8_C(189), UINT8_C(  6), UINT8_C( 30)),
      UINT64_C(           589511266),
      simde_x_mm512_set_epu8(UINT8_C(159), UINT8_C(199), UINT8_C( 92), UINT8_C(122),
                             UINT8_C( 12), UINT8_C(  6), UINT8_C( 73), UINT8_C(222),
                             UINT8_C( 93), UINT8_C(236), UINT8_C(196), UINT8_C(151),
                             UINT8_C( 37), UINT8_C(206), UINT8_C(135), UINT8_C(234),
                             UINT8_C(134), UINT8_C( 99), UINT8_C(198), UINT8_C( 81),
                             UINT8_C( 12), UINT8_C(102), UINT8_C(195), UINT8_C(222),
                             UINT8_C( 31), UINT8_C( 64), UINT8_C( 80), UINT8_C( 65),
                             UINT8_C(110), UINT8_C(185), UINT8_C(  8), UINT8_C( 98),
                             UINT8_C(113), UINT8_C( 81), UINT8_C(193), UINT8_C(220),
                             UINT8_C(195), UINT8_C(204), UINT8_C(  7), UINT8_C(184),
                             UINT8_C(203), UINT8_C(  3), UINT8_C(246), UINT8_C(115),
                             UINT8_C(106), UINT8_C(122), UINT8_C( 85), UINT8_C(105),
                             UINT8_C( 90), UINT8_C( 75), UINT8_C(186), UINT8_C( 89),
                             UINT8_C( 25), UINT8_C(170), UINT8_C(216), UINT8_C(247),
                             UINT8_C(137), UINT8_C(237), UINT8_C(110), UINT8_C(230),
                             UINT8_C(130), UINT8_C(124), UINT8_C(  6), UINT8_C(245)),
      simde_x_mm512_set_epu8(UINT8_C( 79), UINT8_C( 23), UINT8_C(207), UINT8_C( 80),
                             UINT8_C(207), UINT8_C( 81), UINT8_C(  7), UINT8_C(130),
                             UINT8_C(181), UINT8_C(246), UINT8_C(189), UINT8_C(163),
                             UINT8_C(120), UINT8_C( 35), UINT8_C(200), UINT8_C(  3),
                             UINT8_C( 24), UINT8_C(158), UINT8_C(243), UINT8_C(  3),
                             UINT8_C(150), UINT8_C(228), UINT8_C(184), UINT8_C(101),
                             UINT8_C(219), UINT8_C(121), UINT8_C( 65), UINT8_C( 30),
                             UINT8_C(249), UINT8_C( 33), UINT8_C(115), UINT8_C(122),
                             UINT8_C(244), UINT8_C(143), UINT8_C(149), UINT8_C( 29),
                             UINT8_C(178), UINT8_C(131), UINT8_C(101), UINT8_C(120),
                             UINT8_C( 82), UINT8_C(219), UINT8_C(186), UINT8_C(193),
                             UINT8_C(234), UINT8_C(139), UINT8_C( 28), UINT8_C( 91),
                             UINT8_C(105), UINT8_C(250), UINT8_C(223), UINT8_C(189),
                             UINT8_C(224), UINT8_C(245), UINT8_C(188), UINT8_C( 51),
                             UINT8_C( 24), UINT8_C( 89), UINT8_C( 22), UINT8_C( 52),
                             UINT8_C(174), UINT8_C(224), UINT8_C( 67), UINT8_C(156)),
      simde_x_mm512_set_epu8(UINT8_C( 84), UINT8_C(222), UINT8_C( 36), UINT8_C(132),
                             UINT8_C( 32), UINT8_C(182), UINT8_C( 73), UINT8_C(182),
                             UINT8_C( 77), UINT8_C(116), UINT8_C( 50), UINT8_C( 82),
                             UINT8_C( 68), UINT8_C( 72), UINT8_C( 23), UINT8_C( 32),
                             UINT8_C(202), UINT8_C( 82), UINT8_C( 53), UINT8_C( 71),
                             UINT8_C( 22), UINT8_C( 92), UINT8_C( 42), UINT8_C(133),
                             UINT8_C(215), UINT8_C( 34), UINT8_C( 75), UINT8_C( 63),
                             UINT8_C(139), UINT8_C( 23), UINT8_C(141), UINT8_C( 66),
                             UINT8_C(166), UINT8_C( 99), UINT8_C(171), UINT8_C(237),
                             UINT8_C(213), UINT8_C(192), UINT8_C( 54), UINT8_C(152),
                             UINT8_C(108), UINT8_C(253), UINT8_C(216), UINT8_C(214),
                             UINT8_C( 44), UINT8_C(210), UINT8_C( 57), UINT8_C( 98),
                             UINT8_C(  2), UINT8_C(252), UINT8_C(205), UINT8_C(139),
                             UINT8_C(125), UINT8_C( 69), UINT8_C(202), UINT8_C( 82),
                             UINT8_C(  9), UINT8_C(163), UINT8_C( 66), UINT8_C(118),
                             UINT8_C(253), UINT8_C(189), UINT8_C( 37), UINT8_C( 30)) },
    { simde_x_mm512_set_epu8(UINT8_C(122), UINT8_C( 31), UINT8_C(165), UINT8_C(180),
                             UINT8_C(160), UINT8_C(238), UINT8_C( 21), UINT8_C( 93),
                             UINT8_C(118), UINT8_C( 87), UINT8_C(251), UINT8_C( 43),
                             UINT8_C(165), UINT8_C(232), UINT8_C(151), UINT8_C(210),
                             UINT8_C(191), UINT8_C( 60), UINT8_C(141), UINT8_C(172),
                             UINT8_C(143), UINT8_C(152), UINT8_C( 64), UINT8_C(105),
                             UINT8_C( 15), UINT8_C(129), UINT8_C(227), UINT8_C( 58),
                             UINT8_C( 92), UINT8_C(145), UINT8_C( 98), UINT8_C(228),
                             UINT8_C(166), UINT8_C( 72), UINT8_C(150), UINT8_C( 59),
                             UINT8_C( 16), UINT8_C(  1), UINT8_C(194), UINT8_C( 73),
                             UINT8_C(230), UINT8_C(150), UINT8_C(242), UINT8_C( 38),
                             UINT8_C(140), UINT8_C(234), UINT8_C( 77), UINT8_C( 54),
                             UINT8_C(  3), UINT8_C(126), UINT8_C(200), UINT8_C(132),
                             UINT8_C(171), UINT8_C(245), UINT8_C(169), UINT8_C(148),
                             UINT8_C(166), UINT8_C(  7), UINT8_C(  6), UINT8_C(227),
                             UINT8_C( 91), UINT8_C(103), UINT8_C( 93), UINT8_C(244)),
      UINT64_C(          1742408254),
      simde_x_mm512_set_epu8(UINT8_C(195), UINT8_C(222), UINT8_C( 29), UINT8_C(255),
                             UINT8_C(195), UINT8_C(117), UINT8_C(247), UINT8_C(187),
                             UINT8_C( 69), UINT8_C(188), UINT8_C(174), UINT8_C(241),
                             UINT8_C(175), UINT8_C(167), UINT8_C(226), UINT8_C( 66),
                             UINT8_C(177), UINT8_C(104), UINT8_C(172), UINT8_C(245),
                             UINT8_C( 53), UINT8_C( 17), UINT8_C( 64), UINT8_C( 70),
                             UINT8_C(209), UINT8_C(113), UINT8_C( 86), UINT8_C(118),
                             UINT8_C( 56), UINT8_C( 92), UINT8_C(177), UINT8_C(185),
                             UINT8_C(205), UINT8_C(241), UINT8_C(149), UINT8_C(204),
                             UINT8_C(155), UINT8_C( 35), UINT8_C(114), UINT8_C( 12),
                             UINT8_C(212), UINT8_C( 63), UINT8_C( 66), UINT8_C( 74),
                             UINT8_C( 97), UINT8_C(253), UINT8_C(218), UINT8_C( 22),
                             UINT8_C( 38), UINT8_C( 68), UINT8_C(247), UINT8_C(250),
                             UINT8_C(215), UINT8_C( 66), UINT8_C( 67), UINT8_C( 91),
                             UINT8_C(177), UINT8_C(159), UINT8_C(198), UINT8_C(145),
                             UINT8_C(183), UINT8_C( 26), UINT8_C( 66), UINT8_C(165)),
      simde_x_mm512_set_epu8(UINT8_C(104), UINT8_C(148), UINT8_C(187), UINT8_C(240),
                             UINT8_C(224), UINT8_C(131), UINT8_C(  1), UINT8_C(106),
                             UINT8_C( 77), UINT8_C(151), UINT8_C(127), UINT8_C(197),
                             UINT8_C(118), UINT8_C( 35), UINT8_C( 55), UINT8_C(144),
                             UINT8_C( 54), UINT8_C(201), UINT8_C( 41), UINT8_C(221),
                             UINT8_C(189), UINT8_C( 99), UINT8_C(112), UINT8_C(181),
                             UINT8_C( 52), UINT8_C(200), UINT8_C(153), UINT8_C(231),
                             UINT8_C(146), UINT8_C(105), UINT8_C(102), UINT8_C(227),
                             UINT8_C(214), UINT8_C(182), UINT8_C( 31), UINT8_C( 41),
                             UINT8_C( 93), UINT8_C(234), UINT8_C( 82), UINT8_C( 71),
                             UINT8_C( 52), UINT8_C(241), UINT8_C(224), UINT8_C( 69),
                             UINT8_C( 73), UINT8_C( 93), UINT8_C(195), UINT8_C( 84),
                             UINT8_C(170), UINT8_C(173), UINT8_C(170), UINT8_C( 88),
                             UINT8_C( 60), UINT8_C(109), UINT8_C( 86), UINT8_C(119),
                             UINT8_C(141), UINT8_C(206), UINT8_C( 51), UINT8_C(  6),
                             UINT8_C( 71), UINT8_C(253), UINT8_C( 22), UINT8_C( 92)),
      simde_x_mm512_set_epu8(UINT8_C(122), UINT8_C( 31), UINT8_C(165), UINT8_C(180),
                             UINT8_C(160), UINT8_C(238), UINT8_C( 21), UINT8_C( 93),
                             UINT8_C(118), UINT8_C( 87), UINT8_C(251), UINT8_C( 43),
                             UINT8_C(165), UINT8_C(232), UINT8_C(151), UINT8_C(210),
                             UINT8_C(191), UINT8_C( 60), UINT8_C(141), UINT8_C(172),
                             UINT8_C(143), UINT8_C(152), UINT8_C( 64), UINT8_C(105),
                             UINT8_C( 15), UINT8_C(129), UINT8_C(227), UINT8_C( 58),
                             UINT8_C( 92), UINT8_C(145), UINT8_C( 98), UINT8_C(228),
                             UINT8_C(166), UINT8_C(212), UINT8_C( 90), UINT8_C( 59),
                             UINT8_C( 16), UINT8_C(135), UINT8_C( 98), UINT8_C( 42),
                             UINT8_C(132), UINT8_C(152), UINT8_C(242), UINT8_C( 72),
                             UINT8_C( 85), UINT8_C(234), UINT8_C(207), UINT8_C( 53),
                             UINT8_C(  3), UINT8_C(126), UINT8_C(200), UINT8_C(132),
                             UINT8_C(138), UINT8_C(245), UINT8_C( 77), UINT8_C(148),
                             UINT8_C(166), UINT8_C(  7), UINT8_C(125), UINT8_C( 76),
                             UINT8_C(127), UINT8_C(140), UINT8_C( 44), UINT8_C(244)) },
    { simde_x_mm512_set_epu8(UINT8_C(204), UINT8_C( 72), UINT8_C(160), UINT8_C( 51),
                             UINT8_C( 17), UINT8_C( 91), UINT8_C( 99), UINT8_C(232),
                             UINT8_C(230), UINT8_C( 75), UINT8_C( 98), UINT8_C(249),
                             UINT8_C(240), UINT8_C(193), UINT8_C( 40), UINT8_C(144),
                             UINT8_C( 13), UINT8_C(232), UINT8_C(120), UINT8_C( 62),
                             UINT8_C(136), UINT8_C(  7), UINT8_C(252), UINT8_C(  3),
                             UINT8_C(225), UINT8_C( 43), UINT8_C(176), UINT8_C(138),
                             UINT8_C(205), UINT8_C( 22), UINT8_C(172), UINT8_C( 52),
                             UINT8_C(224), UINT8_C(163), UINT8_C( 92), UINT8_C(198),
                             UINT8_C(193), UINT8_C( 77), UINT8_C(  2), UINT8_C( 58),
                             UINT8_C(117), UINT8_C(166), UINT8_C( 25), UINT8_C( 65),
                             UINT8_C( 70), UINT8_C( 62), UINT8_C(155), UINT8_C(179),
                             UINT8_C(194), UINT8_C(252), UINT8_C(155), UINT8_C(113),
                             UINT8_C( 69), UINT8_C( 48), UINT8_C( 10), UINT8_C( 99),
                             UINT8_C( 95), UINT8_C(207), UINT8_C( 28), UINT8_C(202),
                             UINT8_C(125), UINT8_C(229), UINT8_C(112), UINT8_C( 77)),
      UINT64_C(          3364149510),
      simde_x_mm512_set_epu8(UINT8_C( 11), UINT8_C( 82), UINT8_C( 84), UINT8_C(224),
                             UINT8_C(162), UINT8_C(242), UINT8_C(204), UINT8_C( 68),
                             UINT8_C(182), UINT8_C( 59), UINT8_C( 47), UINT8_C(221),
                             UINT8_C( 34), UINT8_C(151), UINT8_C(204), UINT8_C( 95),
                             UINT8_C(116), UINT8_C( 40), UINT8_C(133), UINT8_C(233),
                             UINT8_C(222), UINT8_C( 50), UINT8_C( 44), UINT8_C( 33),
                             UINT8_C( 29), UINT8_C(204), UINT8_C(121), UINT8_C( 27),
                             UINT8_C(138), UINT8_C(185), UINT8_C(  5), UINT8_C(107),
                             UINT8_C(  3), UINT8_C( 36), UINT8_C( 56), UINT8_C(124),
                             UINT8_C(129), UINT8_C( 58), UINT8_C( 37), UINT8_C(111),
                             UINT8_C(254), UINT8_C(180), UINT8_C( 54), UINT8_C(250),
                             UINT8_C( 42), UINT8_C( 75), UINT8_C(154), UINT8_C(231),
                             UINT8_C(115), UINT8_C(171), UINT8_C(247), UINT8_C(142),
                             UINT8_C(  9), UINT8_C(239), UINT8_C(101), UINT8_C( 47),
                             UINT8_C( 79), UINT8_C(209), UINT8_C(133), UINT8_C(218),
                             UINT8_C(253), UINT8_C( 22), UINT8_C( 28), UINT8_C(216)),
      simde_x_mm512_set_epu8(UINT8_C( 60), UINT8_C( 92), UINT8_C(115), UINT8_C(  5),
                             UINT8_C(100), UINT8_C( 27), UINT8_C(227), UINT8_C(100),
                             UINT8_C( 89), UINT8_C(205), UINT8_C( 67), UINT8_C( 82),
                             UINT8_C(155), UINT8_C(204), UINT8_C(152), UINT8_C(151),
                             UINT8_C(209), UINT8_C(229), UINT8_C(210), UINT8_C( 14),
                             UINT8_C(231), UINT8_C( 89), UINT8_C(236), UINT8_C(229),
                             UINT8_C(214), UINT8_C( 93), UINT8_C( 51), UINT8_C(119),
                             UINT8_C( 13), UINT8_C( 60), UINT8_C(212), UINT8_C(222),
                             UINT8_C( 67), UINT8_C( 38), UINT8_C( 63), UINT8_C(141),
                             UINT8_C( 12), UINT8_C(159), UINT8_C( 36), UINT8_C(134),
                             UINT8_C(  6), UINT8_C(139), UINT8_C( 90), UINT8_C(132),
                             UINT8_C(140), UINT8_C(228), UINT8_C(152), UINT8_C(216),
                             UINT8_C(137), UINT8_C(105), UINT8_C(237), UINT8_C(202),
                             UINT8_C( 29), UINT8_C(230), UINT8_C( 44), UINT8_C(  5),
                             UINT8_C( 39), UINT8_C( 73), UINT8_C(177), UINT8_C(242),
                             UINT8_C(209), UINT8_C( 96), UINT8_C( 58), UINT8_C(209)),
      simde_x_mm512_set_epu8(UINT8_C(204), UINT8_C( 72), UINT8_C(160), UINT8_C( 51),
                             UINT8_C( 17), UINT8_C( 91), UINT8_C( 99), UINT8_C(232),
                             UINT8_C(230), UINT8_C( 75), UINT8_C( 98), UINT8_C(249),
                             UINT8_C(240), UINT8_C(193), UINT8_C( 40), UINT8_C(144),
                             UINT8_C( 13), UINT8_C(232), UINT8_C(120), UINT8_C( 62),
                             UINT8_C(136), UINT8_C(  7), UINT8_C(252), UINT8_C(  3),
                             UINT8_C(225), UINT8_C( 43), UINT8_C(176), UINT8_C(138),
                             UINT8_C(205), UINT8_C( 22), UINT8_C(172), UINT8_C( 52),
                             UINT8_C( 35), UINT8_C( 37), UINT8_C( 92), UINT8_C(198),
                             UINT8_C( 71), UINT8_C( 77), UINT8_C(  2), UINT8_C( 58),
                             UINT8_C(130), UINT8_C(166), UINT8_C( 25), UINT8_C( 65),
                             UINT8_C( 70), UINT8_C(152), UINT8_C(155), UINT8_C(179),
                             UINT8_C(126), UINT8_C(138), UINT8_C(155), UINT8_C(172),
                             UINT8_C( 19), UINT8_C( 48), UINT8_C( 10), UINT8_C( 26),
                             UINT8_C( 95), UINT8_C(207), UINT8_C( 28), UINT8_C(202),
                             UINT8_C(125), UINT8_C( 59), UINT8_C( 43), UINT8_C( 77)) }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])); i++) {
    simde__m512i r = simde_mm512_mask_avg_epu8(test_vec[i].src, test_vec[i].k, test_vec[i].a, test_vec[i].b);
    simde_assert_m512i_u32(r, ==, test_vec[i].r);
  }

  return 0;
}

static int
test_simde_mm512_maskz_avg_epu8(SIMDE_MUNIT_TEST_ARGS) {
  const struct {
    simde__mmask64 k;
    simde__m512i a;
    simde__m512i b;
    simde__m512i r;
  } test_vec[8] = {
{ UINT64_C(          1713497089),
      simde_x_mm512_set_epu8(UINT8_C(151), UINT8_C( 80), UINT8_C(240), UINT8_C(132),
                             UINT8_C(208), UINT8_C( 76), UINT8_C(165), UINT8_C(128),
                             UINT8_C( 54), UINT8_C( 63), UINT8_C(114), UINT8_C(183),
                             UINT8_C(230), UINT8_C(208), UINT8_C(232), UINT8_C(243),
                             UINT8_C(  5), UINT8_C(123), UINT8_C(211), UINT8_C(199),
                             UINT8_C(149), UINT8_C( 47), UINT8_C( 90), UINT8_C(202),
                             UINT8_C(  1), UINT8_C(118), UINT8_C( 37), UINT8_C(249),
                             UINT8_C( 83), UINT8_C( 31), UINT8_C(233), UINT8_C(236),
                             UINT8_C(152), UINT8_C(114), UINT8_C( 63), UINT8_C( 25),
                             UINT8_C(176), UINT8_C( 17), UINT8_C( 37), UINT8_C(212),
                             UINT8_C(144), UINT8_C( 41), UINT8_C(238), UINT8_C( 86),
                             UINT8_C(114), UINT8_C(233), UINT8_C(170), UINT8_C(157),
                             UINT8_C(114), UINT8_C( 25), UINT8_C( 94), UINT8_C( 34),
                             UINT8_C(208), UINT8_C(252), UINT8_C(133), UINT8_C(212),
                             UINT8_C(188), UINT8_C( 19), UINT8_C( 47), UINT8_C(134),
                             UINT8_C(117), UINT8_C( 69), UINT8_C(135), UINT8_C( 66)),
      simde_x_mm512_set_epu8(UINT8_C(180), UINT8_C(237), UINT8_C(100), UINT8_C( 59),
                             UINT8_C(192), UINT8_C(196), UINT8_C(203), UINT8_C( 16),
                             UINT8_C(  0), UINT8_C(167), UINT8_C( 13), UINT8_C( 17),
                             UINT8_C(116), UINT8_C( 41), UINT8_C( 54), UINT8_C(248),
                             UINT8_C(144), UINT8_C(109), UINT8_C( 94), UINT8_C( 19),
                             UINT8_C( 46), UINT8_C(201), UINT8_C(103), UINT8_C(  7),
                             UINT8_C(241), UINT8_C(244), UINT8_C(234), UINT8_C(127),
                             UINT8_C(208), UINT8_C(173), UINT8_C(247), UINT8_C(171),
                             UINT8_C(177), UINT8_C(244), UINT8_C( 76), UINT8_C(191),
                             UINT8_C(166), UINT8_C( 19), UINT8_C( 33), UINT8_C(206),
                             UINT8_C( 89), UINT8_C(216), UINT8_C(139), UINT8_C(111),
                             UINT8_C( 48), UINT8_C(119), UINT8_C(201), UINT8_C( 66),
                             UINT8_C(113), UINT8_C(254), UINT8_C(207), UINT8_C(146),
                             UINT8_C(201), UINT8_C( 44), UINT8_C(125), UINT8_C(195),
                             UINT8_C(221), UINT8_C(218), UINT8_C(229), UINT8_C(236),
                             UINT8_C( 32), UINT8_C(197), UINT8_C(234), UINT8_C(125)),
      simde_x_mm512_set_epu8(UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(179), UINT8_C( 70), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C( 18), UINT8_C( 35), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(189), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(112),
                             UINT8_C(114), UINT8_C(140), UINT8_C(151), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(148), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C( 96)) },
    { UINT64_C(          4250428108),
      simde_x_mm512_set_epu8(UINT8_C(107), UINT8_C(163), UINT8_C(179), UINT8_C( 53),
                             UINT8_C(126), UINT8_C( 10), UINT8_C(123), UINT8_C(143),
                             UINT8_C(215), UINT8_C(148), UINT8_C(197), UINT8_C(220),
                             UINT8_C(232), UINT8_C(205), UINT8_C(188), UINT8_C(218),
                             UINT8_C( 19), UINT8_C(120), UINT8_C(138), UINT8_C( 63),
                             UINT8_C( 24), UINT8_C( 72), UINT8_C( 39), UINT8_C( 31),
                             UINT8_C(164), UINT8_C( 52), UINT8_C( 81), UINT8_C( 39),
                             UINT8_C(186), UINT8_C( 73), UINT8_C( 76), UINT8_C(114),
                             UINT8_C(249), UINT8_C(  4), UINT8_C(201), UINT8_C(188),
                             UINT8_C(120), UINT8_C( 98), UINT8_C(141), UINT8_C(200),
                             UINT8_C( 93), UINT8_C(254), UINT8_C( 78), UINT8_C( 16),
                             UINT8_C( 88), UINT8_C( 71), UINT8_C(144), UINT8_C(138),
                             UINT8_C(  4), UINT8_C(168), UINT8_C( 76), UINT8_C( 88),
                             UINT8_C(159), UINT8_C(107), UINT8_C(228), UINT8_C(197),
                             UINT8_C(209), UINT8_C(111), UINT8_C( 61), UINT8_C(147),
                             UINT8_C(137), UINT8_C( 97), UINT8_C(105), UINT8_C(160)),
      simde_x_mm512_set_epu8(UINT8_C( 95), UINT8_C(238), UINT8_C( 11), UINT8_C( 96),
                             UINT8_C(252), UINT8_C(162), UINT8_C(116), UINT8_C(225),
                             UINT8_C( 52), UINT8_C(254), UINT8_C( 98), UINT8_C( 10),
                             UINT8_C(  5), UINT8_C( 19), UINT8_C(191), UINT8_C( 10),
                             UINT8_C(147), UINT8_C( 52), UINT8_C(171), UINT8_C(224),
                             UINT8_C( 38), UINT8_C( 92), UINT8_C(  6), UINT8_C(185),
                             UINT8_C(177), UINT8_C( 79), UINT8_C(162), UINT8_C(113),
                             UINT8_C(139), UINT8_C( 20), UINT8_C(174), UINT8_C( 82),
                             UINT8_C(136), UINT8_C(114), UINT8_C(204), UINT8_C(188),
                             UINT8_C(236), UINT8_C(209), UINT8_C(166), UINT8_C(169),
                             UINT8_C( 79), UINT8_C(219), UINT8_C( 63), UINT8_C(167),
                             UINT8_C(216), UINT8_C(189), UINT8_C(187), UINT8_C(139),
                             UINT8_C(254), UINT8_C(206), UINT8_C(156), UINT8_C(171),
                             UINT8_C(128), UINT8_C(139), UINT8_C( 97), UINT8_C(237),
                             UINT8_C( 71), UINT8_C(239), UINT8_C(  0), UINT8_C(174),
                             UINT8_C(229), UINT8_C(124), UINT8_C( 45), UINT8_C( 57)),
      simde_x_mm512_set_epu8(UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(193), UINT8_C( 59), UINT8_C(203), UINT8_C(188),
                             UINT8_C(178), UINT8_C(154), UINT8_C(  0), UINT8_C(185),
                             UINT8_C(  0), UINT8_C(237), UINT8_C(  0), UINT8_C( 92),
                             UINT8_C(152), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(187), UINT8_C(116), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(163), UINT8_C(  0),
                             UINT8_C(140), UINT8_C(175), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(183), UINT8_C(111), UINT8_C(  0), UINT8_C(  0)) },
    { UINT64_C(          3228288806),
      simde_x_mm512_set_epu8(UINT8_C( 83), UINT8_C( 39), UINT8_C(120), UINT8_C(115),
                             UINT8_C(205), UINT8_C(228), UINT8_C(102), UINT8_C(158),
                             UINT8_C(179), UINT8_C(121), UINT8_C( 42), UINT8_C(114),
                             UINT8_C(255), UINT8_C(112), UINT8_C( 17), UINT8_C(225),
                             UINT8_C(108), UINT8_C(229), UINT8_C( 66), UINT8_C( 23),
                             UINT8_C( 69), UINT8_C(166), UINT8_C(210), UINT8_C(165),
                             UINT8_C(175), UINT8_C(169), UINT8_C(  1), UINT8_C(245),
                             UINT8_C( 84), UINT8_C(139), UINT8_C( 79), UINT8_C(146),
                             UINT8_C(212), UINT8_C(226), UINT8_C( 33), UINT8_C( 53),
                             UINT8_C( 64), UINT8_C(240), UINT8_C(145), UINT8_C(215),
                             UINT8_C(154), UINT8_C( 13), UINT8_C( 97), UINT8_C(201),
                             UINT8_C( 19), UINT8_C(240), UINT8_C(188), UINT8_C(173),
                             UINT8_C(228), UINT8_C( 88), UINT8_C( 41), UINT8_C( 18),
                             UINT8_C(177), UINT8_C(249), UINT8_C(161), UINT8_C(144),
                             UINT8_C(168), UINT8_C(228), UINT8_C(181), UINT8_C( 34),
                             UINT8_C(226), UINT8_C(255), UINT8_C( 52), UINT8_C(164)),
      simde_x_mm512_set_epu8(UINT8_C( 60), UINT8_C(216), UINT8_C( 36), UINT8_C(217),
                             UINT8_C(176), UINT8_C(146), UINT8_C( 14), UINT8_C(195),
                             UINT8_C(217), UINT8_C(186), UINT8_C(140), UINT8_C(157),
                             UINT8_C(174), UINT8_C(143), UINT8_C(136), UINT8_C(140),
                             UINT8_C(198), UINT8_C( 18), UINT8_C( 72), UINT8_C( 23),
                             UINT8_C(139), UINT8_C(151), UINT8_C( 83), UINT8_C(  3),
                             UINT8_C(152), UINT8_C( 34), UINT8_C( 72), UINT8_C(223),
                             UINT8_C( 84), UINT8_C(166), UINT8_C(140), UINT8_C(210),
                             UINT8_C(238), UINT8_C( 96), UINT8_C(210), UINT8_C(147),
                             UINT8_C(153), UINT8_C(238), UINT8_C(217), UINT8_C( 67),
                             UINT8_C(118), UINT8_C( 12), UINT8_C(237), UINT8_C(171),
                             UINT8_C( 23), UINT8_C( 75), UINT8_C(178), UINT8_C(118),
                             UINT8_C(128), UINT8_C( 11), UINT8_C(225), UINT8_C(116),
                             UINT8_C(179), UINT8_C( 97), UINT8_C( 87), UINT8_C( 53),
                             UINT8_C(223), UINT8_C( 37), UINT8_C( 28), UINT8_C( 24),
                             UINT8_C(153), UINT8_C( 99), UINT8_C(181), UINT8_C( 41)),
      simde_x_mm512_set_epu8(UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(225), UINT8_C(161), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C( 13), UINT8_C(167), UINT8_C(  0),
                             UINT8_C( 21), UINT8_C(  0), UINT8_C(183), UINT8_C(146),
                             UINT8_C(178), UINT8_C( 50), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(173), UINT8_C(124), UINT8_C( 99),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(105), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(177), UINT8_C(117), UINT8_C(  0)) },
    { UINT64_C(            74372392),
      simde_x_mm512_set_epu8(UINT8_C( 19), UINT8_C(169), UINT8_C( 42), UINT8_C(146),
                             UINT8_C( 68), UINT8_C( 97), UINT8_C(131), UINT8_C( 75),
                             UINT8_C( 30), UINT8_C(202), UINT8_C(218), UINT8_C(236),
                             UINT8_C(160), UINT8_C( 84), UINT8_C(108), UINT8_C( 24),
                             UINT8_C(202), UINT8_C(230), UINT8_C(131), UINT8_C(203),
                             UINT8_C( 48), UINT8_C(178), UINT8_C(160), UINT8_C( 82),
                             UINT8_C(240), UINT8_C(188), UINT8_C(191), UINT8_C( 28),
                             UINT8_C(174), UINT8_C(140), UINT8_C(119), UINT8_C(143),
                             UINT8_C(102), UINT8_C( 90), UINT8_C( 86), UINT8_C(242),
                             UINT8_C(207), UINT8_C( 71), UINT8_C(  2), UINT8_C( 28),
                             UINT8_C(194), UINT8_C( 53), UINT8_C(214), UINT8_C(158),
                             UINT8_C( 11), UINT8_C( 81), UINT8_C( 46), UINT8_C( 73),
                             UINT8_C(250), UINT8_C(127), UINT8_C(146), UINT8_C(248),
                             UINT8_C(106), UINT8_C( 95), UINT8_C(130), UINT8_C(129),
                             UINT8_C(153), UINT8_C(235), UINT8_C(236), UINT8_C(185),
                             UINT8_C(106), UINT8_C( 23), UINT8_C(205), UINT8_C(209)),
      simde_x_mm512_set_epu8(UINT8_C(221), UINT8_C(195), UINT8_C( 15), UINT8_C( 71),
                             UINT8_C(113), UINT8_C(109), UINT8_C( 91), UINT8_C(139),
                             UINT8_C(  0), UINT8_C(121), UINT8_C( 48), UINT8_C(109),
                             UINT8_C( 55), UINT8_C(125), UINT8_C(144), UINT8_C( 80),
                             UINT8_C( 48), UINT8_C( 40), UINT8_C( 32), UINT8_C(158),
                             UINT8_C( 64), UINT8_C(225), UINT8_C(246), UINT8_C(250),
                             UINT8_C(216), UINT8_C( 37), UINT8_C( 76), UINT8_C(205),
                             UINT8_C( 27), UINT8_C(254), UINT8_C(155), UINT8_C(246),
                             UINT8_C(218), UINT8_C( 69), UINT8_C(  1), UINT8_C(216),
                             UINT8_C(164), UINT8_C( 62), UINT8_C( 73), UINT8_C(202),
                             UINT8_C( 28), UINT8_C(155), UINT8_C(152), UINT8_C(139),
                             UINT8_C( 24), UINT8_C(201), UINT8_C( 82), UINT8_C(156),
                             UINT8_C(214), UINT8_C( 62), UINT8_C(143), UINT8_C(110),
                             UINT8_C(164), UINT8_C(127), UINT8_C(164), UINT8_C( 20),
                             UINT8_C(221), UINT8_C( 35), UINT8_C( 30), UINT8_C(170),
                             UINT8_C(120), UINT8_C( 91), UINT8_C(187), UINT8_C(207)),
      simde_x_mm512_set_epu8(UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C( 67), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(104), UINT8_C(183), UINT8_C(  0),
                             UINT8_C( 18), UINT8_C(141), UINT8_C( 64), UINT8_C(  0),
                             UINT8_C(232), UINT8_C( 95), UINT8_C(  0), UINT8_C(179),
                             UINT8_C(  0), UINT8_C(111), UINT8_C(  0), UINT8_C( 75),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(133), UINT8_C(  0),
                             UINT8_C(113), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0)) },
    { UINT64_C(          1704849946),
      simde_x_mm512_set_epu8(UINT8_C( 75), UINT8_C(130), UINT8_C(174), UINT8_C(185),
                             UINT8_C(240), UINT8_C(251), UINT8_C(233), UINT8_C(143),
                             UINT8_C(196), UINT8_C( 48), UINT8_C(196), UINT8_C( 72),
                             UINT8_C(201), UINT8_C(123), UINT8_C( 70), UINT8_C(237),
                             UINT8_C( 30), UINT8_C(225), UINT8_C(201), UINT8_C(186),
                             UINT8_C(  9), UINT8_C(202), UINT8_C( 73), UINT8_C(192),
                             UINT8_C( 82), UINT8_C(124), UINT8_C( 29), UINT8_C(  8),
                             UINT8_C( 64), UINT8_C( 66), UINT8_C(254), UINT8_C(144),
                             UINT8_C(122), UINT8_C(124), UINT8_C( 90), UINT8_C( 22),
                             UINT8_C(107), UINT8_C(236), UINT8_C( 37), UINT8_C(140),
                             UINT8_C(185), UINT8_C( 48), UINT8_C(255), UINT8_C(239),
                             UINT8_C(166), UINT8_C(  3), UINT8_C(222), UINT8_C( 36),
                             UINT8_C(239), UINT8_C(218), UINT8_C(100), UINT8_C(226),
                             UINT8_C(118), UINT8_C( 42), UINT8_C(231), UINT8_C(211),
                             UINT8_C(  4), UINT8_C(  8), UINT8_C( 53), UINT8_C( 84),
                             UINT8_C(136), UINT8_C( 61), UINT8_C( 90), UINT8_C(237)),
      simde_x_mm512_set_epu8(UINT8_C( 81), UINT8_C( 81), UINT8_C( 43), UINT8_C( 91),
                             UINT8_C(149), UINT8_C(240), UINT8_C( 71), UINT8_C(161),
                             UINT8_C(204), UINT8_C( 80), UINT8_C( 62), UINT8_C(128),
                             UINT8_C(178), UINT8_C( 60), UINT8_C( 92), UINT8_C( 64),
                             UINT8_C( 44), UINT8_C(188), UINT8_C(121), UINT8_C(108),
                             UINT8_C( 90), UINT8_C( 48), UINT8_C(  8), UINT8_C(192),
                             UINT8_C(189), UINT8_C(101), UINT8_C( 72), UINT8_C(114),
                             UINT8_C(232), UINT8_C(233), UINT8_C(205), UINT8_C(  5),
                             UINT8_C(117), UINT8_C( 79), UINT8_C( 29), UINT8_C(232),
                             UINT8_C( 51), UINT8_C(176), UINT8_C(226), UINT8_C(160),
                             UINT8_C(230), UINT8_C(138), UINT8_C( 64), UINT8_C(111),
                             UINT8_C(190), UINT8_C(200), UINT8_C(126), UINT8_C(168),
                             UINT8_C(222), UINT8_C(  5), UINT8_C(142), UINT8_C(  0),
                             UINT8_C( 60), UINT8_C( 23), UINT8_C(145), UINT8_C(197),
                             UINT8_C( 92), UINT8_C( 21), UINT8_C(182), UINT8_C( 99),
                             UINT8_C(234), UINT8_C(209), UINT8_C(134), UINT8_C( 50)),
      simde_x_mm512_set_epu8(UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(102), UINT8_C( 60), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(206), UINT8_C(  0), UINT8_C(150),
                             UINT8_C(208), UINT8_C(  0), UINT8_C(  0), UINT8_C(175),
                             UINT8_C(178), UINT8_C(102), UINT8_C(  0), UINT8_C(102),
                             UINT8_C(231), UINT8_C(112), UINT8_C(121), UINT8_C(113),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(188), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C( 92),
                             UINT8_C(185), UINT8_C(  0), UINT8_C(112), UINT8_C(  0)) },
    { UINT64_C(           616766838),
      simde_x_mm512_set_epu8(UINT8_C(180), UINT8_C(137), UINT8_C( 51), UINT8_C( 92),
                             UINT8_C(187), UINT8_C( 82), UINT8_C( 53), UINT8_C( 28),
                             UINT8_C(223), UINT8_C(152), UINT8_C(200), UINT8_C(193),
                             UINT8_C(225), UINT8_C(154), UINT8_C(231), UINT8_C( 61),
                             UINT8_C(162), UINT8_C( 56), UINT8_C(127), UINT8_C(187),
                             UINT8_C(196), UINT8_C(180), UINT8_C(126), UINT8_C( 42),
                             UINT8_C(219), UINT8_C(  5), UINT8_C(113), UINT8_C(138),
                             UINT8_C(204), UINT8_C(253), UINT8_C(215), UINT8_C(247),
                             UINT8_C(235), UINT8_C( 43), UINT8_C(234), UINT8_C( 33),
                             UINT8_C(112), UINT8_C(108), UINT8_C(220), UINT8_C( 90),
                             UINT8_C(144), UINT8_C(181), UINT8_C( 55), UINT8_C( 53),
                             UINT8_C( 64), UINT8_C(203), UINT8_C(190), UINT8_C(189),
                             UINT8_C(102), UINT8_C(244), UINT8_C( 66), UINT8_C(205),
                             UINT8_C( 39), UINT8_C(196), UINT8_C(165), UINT8_C(215),
                             UINT8_C(172), UINT8_C( 65), UINT8_C( 68), UINT8_C(204),
                             UINT8_C( 53), UINT8_C( 34), UINT8_C( 78), UINT8_C(127)),
      simde_x_mm512_set_epu8(UINT8_C(141), UINT8_C(142), UINT8_C(201), UINT8_C(183),
                             UINT8_C( 28), UINT8_C(210), UINT8_C( 48), UINT8_C(119),
                             UINT8_C(143), UINT8_C( 53), UINT8_C(224), UINT8_C( 96),
                             UINT8_C(218), UINT8_C(201), UINT8_C(253), UINT8_C(241),
                             UINT8_C( 77), UINT8_C(249), UINT8_C( 74), UINT8_C( 43),
                             UINT8_C(181), UINT8_C(113), UINT8_C(189), UINT8_C(106),
                             UINT8_C( 54), UINT8_C( 32), UINT8_C(202), UINT8_C( 67),
                             UINT8_C(214), UINT8_C( 23), UINT8_C(167), UINT8_C( 40),
                             UINT8_C(139), UINT8_C( 52), UINT8_C( 60), UINT8_C( 38),
                             UINT8_C( 95), UINT8_C( 19), UINT8_C(138), UINT8_C(217),
                             UINT8_C(209), UINT8_C( 61), UINT8_C( 63), UINT8_C(128),
                             UINT8_C(163), UINT8_C( 56), UINT8_C(251), UINT8_C(135),
                             UINT8_C( 69), UINT8_C(144), UINT8_C(129), UINT8_C(103),
                             UINT8_C(244), UINT8_C( 97), UINT8_C(191), UINT8_C( 58),
                             UINT8_C(119), UINT8_C( 19), UINT8_C(105), UINT8_C(174),
                             UINT8_C(180), UINT8_C( 41), UINT8_C(251), UINT8_C(155)),
      simde_x_mm512_set_epu8(UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(147), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C( 64), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(177), UINT8_C(121), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(221), UINT8_C(162),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(154),
                             UINT8_C(142), UINT8_C(147), UINT8_C(  0), UINT8_C(137),
                             UINT8_C(  0), UINT8_C( 42), UINT8_C( 87), UINT8_C(189),
                             UINT8_C(  0), UINT8_C( 38), UINT8_C(165), UINT8_C(  0)) },
    { UINT64_C(           771922964),
      simde_x_mm512_set_epu8(UINT8_C( 84), UINT8_C(193), UINT8_C(196), UINT8_C(188),
                             UINT8_C( 28), UINT8_C( 14), UINT8_C(183), UINT8_C( 63),
                             UINT8_C(195), UINT8_C( 17), UINT8_C( 60), UINT8_C(196),
                             UINT8_C(140), UINT8_C(189), UINT8_C(109), UINT8_C( 63),
                             UINT8_C( 42), UINT8_C(192), UINT8_C(240), UINT8_C(166),
                             UINT8_C( 14), UINT8_C(224), UINT8_C(252), UINT8_C( 17),
                             UINT8_C( 46), UINT8_C(184), UINT8_C(253), UINT8_C( 54),
                             UINT8_C( 94), UINT8_C( 75), UINT8_C(123), UINT8_C(145),
                             UINT8_C(160), UINT8_C(164), UINT8_C(123), UINT8_C(216),
                             UINT8_C(170), UINT8_C(112), UINT8_C(140), UINT8_C( 56),
                             UINT8_C( 30), UINT8_C(182), UINT8_C(108), UINT8_C( 63),
                             UINT8_C( 54), UINT8_C( 68), UINT8_C( 21), UINT8_C( 50),
                             UINT8_C( 82), UINT8_C( 10), UINT8_C(167), UINT8_C(177),
                             UINT8_C(210), UINT8_C(  2), UINT8_C( 48), UINT8_C( 73),
                             UINT8_C(153), UINT8_C( 42), UINT8_C( 43), UINT8_C( 19),
                             UINT8_C( 82), UINT8_C(112), UINT8_C(146), UINT8_C( 77)),
      simde_x_mm512_set_epu8(UINT8_C(117), UINT8_C( 61), UINT8_C(219), UINT8_C(166),
                             UINT8_C(101), UINT8_C(146), UINT8_C(252), UINT8_C(220),
                             UINT8_C(111), UINT8_C(  7), UINT8_C(233), UINT8_C( 32),
                             UINT8_C(239), UINT8_C(243), UINT8_C(204), UINT8_C(249),
                             UINT8_C(179), UINT8_C(241), UINT8_C(226), UINT8_C(120),
                             UINT8_C(244), UINT8_C(118), UINT8_C(248), UINT8_C(141),
                             UINT8_C(179), UINT8_C(252), UINT8_C(219), UINT8_C( 58),
                             UINT8_C( 62), UINT8_C(244), UINT8_C(181), UINT8_C( 77),
                             UINT8_C( 48), UINT8_C(136), UINT8_C(150), UINT8_C( 74),
                             UINT8_C( 87), UINT8_C(176), UINT8_C(194), UINT8_C( 45),
                             UINT8_C(190), UINT8_C(213), UINT8_C( 70), UINT8_C( 70),
                             UINT8_C(177), UINT8_C(254), UINT8_C(160), UINT8_C( 78),
                             UINT8_C(253), UINT8_C(131), UINT8_C(202), UINT8_C(108),
                             UINT8_C(174), UINT8_C(186), UINT8_C(172), UINT8_C(193),
                             UINT8_C(162), UINT8_C(235), UINT8_C(165), UINT8_C(158),
                             UINT8_C(140), UINT8_C(172), UINT8_C(251), UINT8_C(116)),
      simde_x_mm512_set_epu8(UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(137), UINT8_C(  0),
                             UINT8_C(129), UINT8_C(144), UINT8_C(167), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C( 91), UINT8_C(  0),
                             UINT8_C(168), UINT8_C(  0), UINT8_C(  0), UINT8_C(143),
                             UINT8_C(192), UINT8_C( 94), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C( 89),
                             UINT8_C(  0), UINT8_C(142), UINT8_C(  0), UINT8_C(  0)) },
    { UINT64_C(            97696573),
      simde_x_mm512_set_epu8(UINT8_C( 56), UINT8_C(233), UINT8_C(161), UINT8_C( 70),
                             UINT8_C( 29), UINT8_C(119), UINT8_C(231), UINT8_C(252),
                             UINT8_C(132), UINT8_C(198), UINT8_C( 18), UINT8_C(195),
                             UINT8_C( 88), UINT8_C(114), UINT8_C(173), UINT8_C( 54),
                             UINT8_C( 75), UINT8_C(  3), UINT8_C(214), UINT8_C(  2),
                             UINT8_C(139), UINT8_C(186), UINT8_C( 99), UINT8_C(154),
                             UINT8_C(177), UINT8_C(145), UINT8_C(140), UINT8_C(170),
                             UINT8_C(124), UINT8_C( 32), UINT8_C(208), UINT8_C(227),
                             UINT8_C( 14), UINT8_C( 57), UINT8_C( 96), UINT8_C(190),
                             UINT8_C(123), UINT8_C(184), UINT8_C( 51), UINT8_C( 34),
                             UINT8_C(239), UINT8_C( 21), UINT8_C(170), UINT8_C(146),
                             UINT8_C(232), UINT8_C(  0), UINT8_C(180), UINT8_C( 80),
                             UINT8_C( 72), UINT8_C(231), UINT8_C(149), UINT8_C(142),
                             UINT8_C(142), UINT8_C( 86), UINT8_C( 39), UINT8_C(243),
                             UINT8_C( 33), UINT8_C(235), UINT8_C( 93), UINT8_C(129),
                             UINT8_C( 46), UINT8_C(131), UINT8_C(184), UINT8_C(105)),
      simde_x_mm512_set_epu8(UINT8_C(188), UINT8_C(104), UINT8_C(150), UINT8_C( 91),
                             UINT8_C(223), UINT8_C( 10), UINT8_C(154), UINT8_C(110),
                             UINT8_C(234), UINT8_C(193), UINT8_C( 58), UINT8_C(132),
                             UINT8_C( 18), UINT8_C(225), UINT8_C( 95), UINT8_C(  7),
                             UINT8_C(253), UINT8_C( 41), UINT8_C(230), UINT8_C(186),
                             UINT8_C(  9), UINT8_C( 18), UINT8_C(163), UINT8_C( 56),
                             UINT8_C( 96), UINT8_C(249), UINT8_C( 80), UINT8_C( 62),
                             UINT8_C(194), UINT8_C( 89), UINT8_C(163), UINT8_C(133),
                             UINT8_C( 35), UINT8_C(148), UINT8_C(177), UINT8_C( 29),
                             UINT8_C(195), UINT8_C(169), UINT8_C( 29), UINT8_C( 99),
                             UINT8_C(232), UINT8_C( 69), UINT8_C( 58), UINT8_C(168),
                             UINT8_C(144), UINT8_C(242), UINT8_C(220), UINT8_C(  1),
                             UINT8_C( 48), UINT8_C(123), UINT8_C( 36), UINT8_C(240),
                             UINT8_C( 56), UINT8_C(103), UINT8_C(183), UINT8_C(  7),
                             UINT8_C(134), UINT8_C(138), UINT8_C(158), UINT8_C(199),
                             UINT8_C( 65), UINT8_C( 92), UINT8_C(182), UINT8_C(118)),
      simde_x_mm512_set_epu8(UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(177), UINT8_C(  0), UINT8_C( 67),
                             UINT8_C(236), UINT8_C( 45), UINT8_C(  0), UINT8_C(157),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(200), UINT8_C(  0),
                             UINT8_C( 60), UINT8_C(  0), UINT8_C( 93), UINT8_C(191),
                             UINT8_C( 99), UINT8_C(  0), UINT8_C(111), UINT8_C(125),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(126), UINT8_C(164),
                             UINT8_C( 56), UINT8_C(112), UINT8_C(  0), UINT8_C(112)) }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])); i++) {
    simde__m512i r = simde_mm512_maskz_avg_epu8(test_vec[i].k, test_vec[i].a, test_vec[i].b);
    simde_assert_m512i_u8(r, ==, test_vec[i].r);
  }

  return 0;
}

static int
test_simde_mm512_avg_epu16(SIMDE_MUNIT_TEST_ARGS) {
  const struct {
    simde__m512i a;
    simde__m512i b;
    simde__m512i r;
  } test_vec[8] = {
    { simde_x_mm512_set_epu16(UINT16_C( 13922), UINT16_C( 36897), UINT16_C( 58180), UINT16_C( 11516),
                              UINT16_C( 48259), UINT16_C(  5769), UINT16_C( 28390), UINT16_C( 29726),
                              UINT16_C( 60808), UINT16_C( 38778), UINT16_C( 21386), UINT16_C( 37563),
                              UINT16_C( 21427), UINT16_C( 42840), UINT16_C( 63576), UINT16_C( 25988),
                              UINT16_C( 52004), UINT16_C( 13742), UINT16_C( 20065), UINT16_C( 31945),
                              UINT16_C(  3305), UINT16_C( 50297), UINT16_C( 19714), UINT16_C( 48635),
                              UINT16_C( 64641), UINT16_C(  9835), UINT16_C( 33507), UINT16_C( 40606),
                              UINT16_C( 49930), UINT16_C( 25911), UINT16_C( 16490), UINT16_C( 30266)),
      simde_x_mm512_set_epu16(UINT16_C( 35675), UINT16_C(  3257), UINT16_C( 12418), UINT16_C( 59056),
                              UINT16_C( 54292), UINT16_C( 28377), UINT16_C( 47802), UINT16_C( 33906),
                              UINT16_C( 48379), UINT16_C( 57830), UINT16_C( 42348), UINT16_C(  4361),
                              UINT16_C( 62947), UINT16_C( 32240), UINT16_C( 12123), UINT16_C(   903),
                              UINT16_C( 62311), UINT16_C( 39097), UINT16_C( 12552), UINT16_C( 17043),
                              UINT16_C( 12967), UINT16_C( 14694), UINT16_C( 36399), UINT16_C( 44335),
                              UINT16_C( 44269), UINT16_C( 14847), UINT16_C( 26083), UINT16_C( 50887),
                              UINT16_C(  6575), UINT16_C( 58796), UINT16_C( 53958), UINT16_C( 55190)),
      simde_x_mm512_set_epu16(UINT16_C( 24799), UINT16_C( 20077), UINT16_C( 35299), UINT16_C( 35286),
                              UINT16_C( 51276), UINT16_C( 17073), UINT16_C( 38096), UINT16_C( 31816),
                              UINT16_C( 54594), UINT16_C( 48304), UINT16_C( 31867), UINT16_C( 20962),
                              UINT16_C( 42187), UINT16_C( 37540), UINT16_C( 37850), UINT16_C( 13446),
                              UINT16_C( 57158), UINT16_C( 26420), UINT16_C( 16309), UINT16_C( 24494),
                              UINT16_C(  8136), UINT16_C( 32496), UINT16_C( 28057), UINT16_C( 46485),
                              UINT16_C( 54455), UINT16_C( 12341), UINT16_C( 29795), UINT16_C( 45747),
                              UINT16_C( 28253), UINT16_C( 42354), UINT16_C( 35224), UINT16_C( 42728)) },
    { simde_x_mm512_set_epu16(UINT16_C( 53467), UINT16_C( 14812), UINT16_C(  1601), UINT16_C(  5446),
                              UINT16_C( 10821), UINT16_C( 52555), UINT16_C( 11613), UINT16_C( 32262),
                              UINT16_C( 44594), UINT16_C(  4573), UINT16_C( 55679), UINT16_C( 28536),
                              UINT16_C( 33684), UINT16_C( 36248), UINT16_C( 37000), UINT16_C( 16957),
                              UINT16_C( 33904), UINT16_C(  7320), UINT16_C( 32743), UINT16_C( 28065),
                              UINT16_C( 40454), UINT16_C( 54701), UINT16_C( 30387), UINT16_C( 20402),
                              UINT16_C( 12012), UINT16_C( 12600), UINT16_C( 40321), UINT16_C( 11976),
                              UINT16_C( 22914), UINT16_C( 48119), UINT16_C( 54567), UINT16_C( 37518)),
      simde_x_mm512_set_epu16(UINT16_C( 19683), UINT16_C( 49281), UINT16_C( 58394), UINT16_C( 42390),
                              UINT16_C( 28448), UINT16_C(  2882), UINT16_C( 16746), UINT16_C( 53644),
                              UINT16_C( 16898), UINT16_C( 40318), UINT16_C( 16648), UINT16_C( 14647),
                              UINT16_C( 38440), UINT16_C( 42038), UINT16_C( 24217), UINT16_C( 60044),
                              UINT16_C( 11584), UINT16_C( 35025), UINT16_C( 26069), UINT16_C( 37885),
                              UINT16_C( 14708), UINT16_C( 24663), UINT16_C( 44110), UINT16_C( 40062),
                              UINT16_C(   918), UINT16_C( 34061), UINT16_C( 57874), UINT16_C( 27338),
                              UINT16_C( 24412), UINT16_C( 15314), UINT16_C( 35927), UINT16_C( 54580)),
      simde_x_mm512_set_epu16(UINT16_C( 36575), UINT16_C( 32047), UINT16_C( 29998), UINT16_C( 23918),
                              UINT16_C( 19635), UINT16_C( 27719), UINT16_C( 14180), UINT16_C( 42953),
                              UINT16_C( 30746), UINT16_C( 22446), UINT16_C( 36164), UINT16_C( 21592),
                              UINT16_C( 36062), UINT16_C( 39143), UINT16_C( 30609), UINT16_C( 38501),
                              UINT16_C( 22744), UINT16_C( 21173), UINT16_C( 29406), UINT16_C( 32975),
                              UINT16_C( 27581), UINT16_C( 39682), UINT16_C( 37249), UINT16_C( 30232),
                              UINT16_C(  6465), UINT16_C( 23331), UINT16_C( 49098), UINT16_C( 19657),
                              UINT16_C( 23663), UINT16_C( 31717), UINT16_C( 45247), UINT16_C( 46049)) },
    { simde_x_mm512_set_epu16(UINT16_C(  2926), UINT16_C( 37218), UINT16_C( 49262), UINT16_C( 41266),
                              UINT16_C( 64616), UINT16_C( 47887), UINT16_C( 47046), UINT16_C( 20233),
                              UINT16_C( 17531), UINT16_C( 35216), UINT16_C( 26970), UINT16_C( 22110),
                              UINT16_C( 23885), UINT16_C( 49160), UINT16_C( 11289), UINT16_C( 22415),
                              UINT16_C( 57944), UINT16_C( 39676), UINT16_C( 14246), UINT16_C( 36547),
                              UINT16_C( 43442), UINT16_C( 52571), UINT16_C( 16838), UINT16_C( 32565),
                              UINT16_C( 62744), UINT16_C( 45552), UINT16_C( 50968), UINT16_C( 36716),
                              UINT16_C( 10154), UINT16_C( 41950), UINT16_C( 14496), UINT16_C( 51322)),
      simde_x_mm512_set_epu16(UINT16_C( 14640), UINT16_C( 63580), UINT16_C( 14746), UINT16_C( 21373),
                              UINT16_C(  2714), UINT16_C( 18543), UINT16_C( 17198), UINT16_C( 32202),
                              UINT16_C( 11581), UINT16_C( 13480), UINT16_C( 54288), UINT16_C(  9603),
                              UINT16_C( 12378), UINT16_C( 53993), UINT16_C( 37890), UINT16_C(  2622),
                              UINT16_C( 22964), UINT16_C( 24086), UINT16_C( 65101), UINT16_C(   151),
                              UINT16_C( 54310), UINT16_C( 27341), UINT16_C( 18591), UINT16_C( 57907),
                              UINT16_C( 13730), UINT16_C( 48472), UINT16_C( 10888), UINT16_C( 26832),
                              UINT16_C( 39665), UINT16_C( 48015), UINT16_C( 40287), UINT16_C(  7521)),
      simde_x_mm512_set_epu16(UINT16_C(  8783), UINT16_C( 50399), UINT16_C( 32004), UINT16_C( 31320),
                              UINT16_C( 33665), UINT16_C( 33215), UINT16_C( 32122), UINT16_C( 26218),
                              UINT16_C( 14556), UINT16_C( 24348), UINT16_C( 40629), UINT16_C( 15857),
                              UINT16_C( 18132), UINT16_C( 51577), UINT16_C( 24590), UINT16_C( 12519),
                              UINT16_C( 40454), UINT16_C( 31881), UINT16_C( 39674), UINT16_C( 18349),
                              UINT16_C( 48876), UINT16_C( 39956), UINT16_C( 17715), UINT16_C( 45236),
                              UINT16_C( 38237), UINT16_C( 47012), UINT16_C( 30928), UINT16_C( 31774),
                              UINT16_C( 24910), UINT16_C( 44983), UINT16_C( 27392), UINT16_C( 29422)) },
    { simde_x_mm512_set_epu16(UINT16_C( 33359), UINT16_C( 20997), UINT16_C( 60535), UINT16_C(  6477),
                              UINT16_C( 35687), UINT16_C( 52277), UINT16_C( 18001), UINT16_C(  9114),
                              UINT16_C( 58688), UINT16_C( 24195), UINT16_C( 55556), UINT16_C( 26572),
                              UINT16_C( 13614), UINT16_C( 31611), UINT16_C( 64483), UINT16_C( 39184),
                              UINT16_C( 20423), UINT16_C(  4017), UINT16_C( 21263), UINT16_C(  9687),
                              UINT16_C( 45713), UINT16_C( 61493), UINT16_C( 29891), UINT16_C( 26099),
                              UINT16_C( 34397), UINT16_C( 16487), UINT16_C( 18770), UINT16_C( 48421),
                              UINT16_C( 51774), UINT16_C( 40289), UINT16_C( 36358), UINT16_C(  9752)),
      simde_x_mm512_set_epu16(UINT16_C( 14685), UINT16_C( 36894), UINT16_C(  3039), UINT16_C( 14211),
                              UINT16_C(  7600), UINT16_C( 13396), UINT16_C( 20271), UINT16_C( 32796),
                              UINT16_C( 18819), UINT16_C( 35329), UINT16_C( 25198), UINT16_C( 53928),
                              UINT16_C( 53351), UINT16_C( 38714), UINT16_C( 38160), UINT16_C( 28969),
                              UINT16_C( 51469), UINT16_C( 54246), UINT16_C( 53402), UINT16_C( 12671),
                              UINT16_C( 23815), UINT16_C( 34869), UINT16_C(  4959), UINT16_C( 48021),
                              UINT16_C(   161), UINT16_C( 58452), UINT16_C( 21609), UINT16_C( 23057),
                              UINT16_C(   951), UINT16_C( 33560), UINT16_C( 51461), UINT16_C( 32848)),
      simde_x_mm512_set_epu16(UINT16_C( 24022), UINT16_C( 28946), UINT16_C( 31787), UINT16_C( 10344),
                              UINT16_C( 21644), UINT16_C( 32837), UINT16_C( 19136), UINT16_C( 20955),
                              UINT16_C( 38754), UINT16_C( 29762), UINT16_C( 40377), UINT16_C( 40250),
                              UINT16_C( 33483), UINT16_C( 35163), UINT16_C( 51322), UINT16_C( 34077),
                              UINT16_C( 35946), UINT16_C( 29132), UINT16_C( 37333), UINT16_C( 11179),
                              UINT16_C( 34764), UINT16_C( 48181), UINT16_C( 17425), UINT16_C( 37060),
                              UINT16_C( 17279), UINT16_C( 37470), UINT16_C( 20190), UINT16_C( 35739),
                              UINT16_C( 26363), UINT16_C( 36925), UINT16_C( 43910), UINT16_C( 21300)) },
    { simde_x_mm512_set_epu16(UINT16_C( 16482), UINT16_C( 29865), UINT16_C( 43161), UINT16_C( 49292),
                              UINT16_C( 20253), UINT16_C( 46312), UINT16_C( 22868), UINT16_C( 35970),
                              UINT16_C( 27832), UINT16_C( 29779), UINT16_C( 41321), UINT16_C(  4471),
                              UINT16_C(   101), UINT16_C( 26727), UINT16_C( 57916), UINT16_C(  6017),
                              UINT16_C( 36275), UINT16_C( 22385), UINT16_C( 64475), UINT16_C( 27511),
                              UINT16_C( 18089), UINT16_C(  2907), UINT16_C(  6044), UINT16_C( 25380),
                              UINT16_C( 39450), UINT16_C(  6056), UINT16_C(  3173), UINT16_C( 48508),
                              UINT16_C( 39476), UINT16_C( 34432), UINT16_C( 54613), UINT16_C( 48593)),
      simde_x_mm512_set_epu16(UINT16_C(  5403), UINT16_C( 14767), UINT16_C( 48931), UINT16_C( 19205),
                              UINT16_C( 43050), UINT16_C( 50911), UINT16_C( 61409), UINT16_C( 58117),
                              UINT16_C( 21956), UINT16_C( 47259), UINT16_C( 18797), UINT16_C( 33639),
                              UINT16_C( 33691), UINT16_C( 26950), UINT16_C( 42098), UINT16_C( 29396),
                              UINT16_C( 40226), UINT16_C( 56570), UINT16_C( 65251), UINT16_C( 61481),
                              UINT16_C( 53274), UINT16_C( 56708), UINT16_C( 31154), UINT16_C( 56119),
                              UINT16_C( 11598), UINT16_C( 59701), UINT16_C( 22444), UINT16_C( 31379),
                              UINT16_C( 47987), UINT16_C(  5886), UINT16_C(  2522), UINT16_C( 57558)),
      simde_x_mm512_set_epu16(UINT16_C( 10943), UINT16_C( 22316), UINT16_C( 46046), UINT16_C( 34249),
                              UINT16_C( 31652), UINT16_C( 48612), UINT16_C( 42139), UINT16_C( 47044),
                              UINT16_C( 24894), UINT16_C( 38519), UINT16_C( 30059), UINT16_C( 19055),
                              UINT16_C( 16896), UINT16_C( 26839), UINT16_C( 50007), UINT16_C( 17707),
                              UINT16_C( 38251), UINT16_C( 39478), UINT16_C( 64863), UINT16_C( 44496),
                              UINT16_C( 35682), UINT16_C( 29808), UINT16_C( 18599), UINT16_C( 40750),
                              UINT16_C( 25524), UINT16_C( 32879), UINT16_C( 12809), UINT16_C( 39944),
                              UINT16_C( 43732), UINT16_C( 20159), UINT16_C( 28568), UINT16_C( 53076)) },
    { simde_x_mm512_set_epu16(UINT16_C( 34893), UINT16_C( 23679), UINT16_C( 64034), UINT16_C( 46251),
                              UINT16_C(  8048), UINT16_C( 41654), UINT16_C( 61576), UINT16_C( 24661),
                              UINT16_C( 10548), UINT16_C( 15307), UINT16_C( 54631), UINT16_C( 56752),
                              UINT16_C( 25346), UINT16_C(  5558), UINT16_C(  1968), UINT16_C( 32109),
                              UINT16_C( 59890), UINT16_C(  1389), UINT16_C( 18928), UINT16_C( 44824),
                              UINT16_C( 11367), UINT16_C( 52264), UINT16_C( 20085), UINT16_C( 56744),
                              UINT16_C( 49674), UINT16_C(  4067), UINT16_C(  3569), UINT16_C( 23831),
                              UINT16_C(  8020), UINT16_C( 56140), UINT16_C( 13343), UINT16_C(  5815)),
      simde_x_mm512_set_epu16(UINT16_C(    70), UINT16_C( 49524), UINT16_C(  2389), UINT16_C( 48794),
                              UINT16_C(  9656), UINT16_C( 49515), UINT16_C( 20459), UINT16_C(  8573),
                              UINT16_C( 28524), UINT16_C( 25506), UINT16_C( 45011), UINT16_C( 20391),
                              UINT16_C( 42585), UINT16_C(  5514), UINT16_C(  3945), UINT16_C( 49101),
                              UINT16_C(  8826), UINT16_C( 53647), UINT16_C( 55458), UINT16_C( 61374),
                              UINT16_C( 54518), UINT16_C( 64462), UINT16_C( 15696), UINT16_C( 38749),
                              UINT16_C( 14471), UINT16_C( 43272), UINT16_C( 48962), UINT16_C( 15384),
                              UINT16_C( 23964), UINT16_C(  8219), UINT16_C( 12498), UINT16_C( 59146)),
      simde_x_mm512_set_epu16(UINT16_C( 17482), UINT16_C( 36602), UINT16_C( 33212), UINT16_C( 47523),
                              UINT16_C(  8852), UINT16_C( 45585), UINT16_C( 41018), UINT16_C( 16617),
                              UINT16_C( 19536), UINT16_C( 20407), UINT16_C( 49821), UINT16_C( 38572),
                              UINT16_C( 33966), UINT16_C(  5536), UINT16_C(  2957), UINT16_C( 40605),
                              UINT16_C( 34358), UINT16_C( 27518), UINT16_C( 37193), UINT16_C( 53099),
                              UINT16_C( 32943), UINT16_C( 58363), UINT16_C( 17891), UINT16_C( 47747),
                              UINT16_C( 32073), UINT16_C( 23670), UINT16_C( 26266), UINT16_C( 19608),
                              UINT16_C( 15992), UINT16_C( 32180), UINT16_C( 12921), UINT16_C( 32481)) },
    { simde_x_mm512_set_epu16(UINT16_C( 60096), UINT16_C( 60141), UINT16_C(  1401), UINT16_C( 46103),
                              UINT16_C( 12472), UINT16_C( 53354), UINT16_C( 24302), UINT16_C( 31759),
                              UINT16_C( 31691), UINT16_C(  4110), UINT16_C( 33754), UINT16_C( 25522),
                              UINT16_C( 55741), UINT16_C( 54238), UINT16_C(  6937), UINT16_C( 14267),
                              UINT16_C(  6394), UINT16_C( 11471), UINT16_C( 36806), UINT16_C( 29444),
                              UINT16_C(  4686), UINT16_C( 24894), UINT16_C(  9912), UINT16_C( 55420),
                              UINT16_C( 39725), UINT16_C( 16932), UINT16_C(  1814), UINT16_C( 27150),
                              UINT16_C( 14089), UINT16_C( 26760), UINT16_C( 42881), UINT16_C(  1890)),
      simde_x_mm512_set_epu16(UINT16_C(  1052), UINT16_C( 45798), UINT16_C(  2128), UINT16_C( 35449),
                              UINT16_C( 36274), UINT16_C( 38472), UINT16_C( 30996), UINT16_C(  7411),
                              UINT16_C( 65433), UINT16_C( 20087), UINT16_C(  6070), UINT16_C( 34216),
                              UINT16_C( 38017), UINT16_C( 52174), UINT16_C(  6632), UINT16_C( 18268),
                              UINT16_C( 23199), UINT16_C( 50262), UINT16_C( 41833), UINT16_C( 43512),
                              UINT16_C( 43349), UINT16_C( 45458), UINT16_C( 19756), UINT16_C( 38464),
                              UINT16_C( 37153), UINT16_C( 41983), UINT16_C(  8534), UINT16_C(   930),
                              UINT16_C( 61899), UINT16_C(  3423), UINT16_C( 63286), UINT16_C( 18842)),
      simde_x_mm512_set_epu16(UINT16_C( 30574), UINT16_C( 52970), UINT16_C(  1765), UINT16_C( 40776),
                              UINT16_C( 24373), UINT16_C( 45913), UINT16_C( 27649), UINT16_C( 19585),
                              UINT16_C( 48562), UINT16_C( 12099), UINT16_C( 19912), UINT16_C( 29869),
                              UINT16_C( 46879), UINT16_C( 53206), UINT16_C(  6785), UINT16_C( 16268),
                              UINT16_C( 14797), UINT16_C( 30867), UINT16_C( 39320), UINT16_C( 36478),
                              UINT16_C( 24018), UINT16_C( 35176), UINT16_C( 14834), UINT16_C( 46942),
                              UINT16_C( 38439), UINT16_C( 29458), UINT16_C(  5174), UINT16_C( 14040),
                              UINT16_C( 37994), UINT16_C( 15092), UINT16_C( 53084), UINT16_C( 10366)) },
    { simde_x_mm512_set_epu16(UINT16_C( 21390), UINT16_C( 10972), UINT16_C(  9534), UINT16_C( 25326),
                              UINT16_C( 39196), UINT16_C( 52858), UINT16_C( 21878), UINT16_C( 44949),
                              UINT16_C( 56397), UINT16_C(  7489), UINT16_C( 51094), UINT16_C( 21965),
                              UINT16_C( 45995), UINT16_C( 12111), UINT16_C( 47805), UINT16_C(  1368),
                              UINT16_C( 47857), UINT16_C( 52094), UINT16_C( 29749), UINT16_C( 11216),
                              UINT16_C( 36270), UINT16_C( 43041), UINT16_C( 37100), UINT16_C( 23737),
                              UINT16_C( 49684), UINT16_C(  1618), UINT16_C(  4508), UINT16_C( 49414),
                              UINT16_C( 16652), UINT16_C( 21178), UINT16_C(  2342), UINT16_C( 41466)),
      simde_x_mm512_set_epu16(UINT16_C(  2029), UINT16_C( 56235), UINT16_C( 60520), UINT16_C( 21505),
                              UINT16_C( 57936), UINT16_C(  7393), UINT16_C( 48841), UINT16_C( 33423),
                              UINT16_C( 21974), UINT16_C( 41720), UINT16_C( 60540), UINT16_C( 41725),
                              UINT16_C( 29801), UINT16_C( 64766), UINT16_C( 10276), UINT16_C( 10419),
                              UINT16_C( 29113), UINT16_C(  9717), UINT16_C( 10502), UINT16_C( 53810),
                              UINT16_C( 21215), UINT16_C( 51746), UINT16_C( 31756), UINT16_C( 40043),
                              UINT16_C( 19421), UINT16_C( 27841), UINT16_C(  1136), UINT16_C( 29043),
                              UINT16_C( 64035), UINT16_C( 41226), UINT16_C( 38869), UINT16_C( 32769)),
      simde_x_mm512_set_epu16(UINT16_C( 11710), UINT16_C( 33604), UINT16_C( 35027), UINT16_C( 23416),
                              UINT16_C( 48566), UINT16_C( 30126), UINT16_C( 35360), UINT16_C( 39186),
                              UINT16_C( 39186), UINT16_C( 24605), UINT16_C( 55817), UINT16_C( 31845),
                              UINT16_C( 37898), UINT16_C( 38439), UINT16_C( 29041), UINT16_C(  5894),
                              UINT16_C( 38485), UINT16_C( 30906), UINT16_C( 20126), UINT16_C( 32513),
                              UINT16_C( 28743), UINT16_C( 47394), UINT16_C( 34428), UINT16_C( 31890),
                              UINT16_C( 34553), UINT16_C( 14730), UINT16_C(  2822), UINT16_C( 39229),
                              UINT16_C( 40344), UINT16_C( 31202), UINT16_C( 20606), UINT16_C( 37118)) }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])); i++) {
    simde__m512i r = simde_mm512_avg_epu16(test_vec[i].a, test_vec[i].b);
    simde_assert_m512i_u16(r, ==, test_vec[i].r);
  }

  return 0;
}

static int
test_simde_mm512_broadcastb_epi8(SIMDE_MUNIT_TEST_ARGS) {
  const struct {
    simde__m128i a;
    simde__m512i r;
  } test_vec[8] = {
    { simde_mm_set_epi8(INT8_C( -17), INT8_C(  88), INT8_C(-122), INT8_C(-119),
                        INT8_C( 111), INT8_C(  87), INT8_C( -76), INT8_C(  27),
                        INT8_C( -93), INT8_C(  -8), INT8_C( -17), INT8_C(  24),
                        INT8_C(  69), INT8_C( 116), INT8_C( -78), INT8_C(-124)),
      simde_mm512_set_epi8(INT8_C(-124), INT8_C(-124), INT8_C(-124), INT8_C(-124),
                           INT8_C(-124), INT8_C(-124), INT8_C(-124), INT8_C(-124),
                           INT8_C(-124), INT8_C(-124), INT8_C(-124), INT8_C(-124),
                           INT8_C(-124), INT8_C(-124), INT8_C(-124), INT8_C(-124),
                           INT8_C(-124), INT8_C(-124), INT8_C(-124), INT8_C(-124),
                           INT8_C(-124), INT8_C(-124), INT8_C(-124), INT8_C(-124),
                           INT8_C(-124), INT8_C(-124), INT8_C(-124), INT8_C(-124),
                           INT8_C(-124), INT8_C(-124), INT8_C(-124), INT8_C(-124),
                           INT8_C(-124), INT8_C(-124), INT8_C(-124), INT8_C(-124),
                           INT8_C(-124), INT8_C(-124), INT8_C(-124), INT8_C(-124),
                           INT8_C(-124), INT8_C(-124), INT8_C(-124), INT8_C(-124),
                           INT8_C(-124), INT8_C(-124), INT8_C(-124), INT8_C(-124),
                           INT8_C(-124), INT8_C(-124), INT8_C(-124), INT8_C(-124),
                           INT8_C(-124), INT8_C(-124), INT8_C(-124), INT8_C(-124),
                           INT8_C(-124), INT8_C(-124), INT8_C(-124), INT8_C(-124),
                           INT8_C(-124), INT8_C(-124), INT8_C(-124), INT8_C(-124)) },
    { simde_mm_set_epi8(INT8_C(  -5), INT8_C(-114), INT8_C( -86), INT8_C(  -2),
                        INT8_C(  33), INT8_C(  90), INT8_C( -50), INT8_C(  28),
                        INT8_C(  15), INT8_C(  12), INT8_C(  32), INT8_C(  54),
                        INT8_C( -15), INT8_C( -57), INT8_C(  36), INT8_C( -50)),
      simde_mm512_set_epi8(INT8_C( -50), INT8_C( -50), INT8_C( -50), INT8_C( -50),
                           INT8_C( -50), INT8_C( -50), INT8_C( -50), INT8_C( -50),
                           INT8_C( -50), INT8_C( -50), INT8_C( -50), INT8_C( -50),
                           INT8_C( -50), INT8_C( -50), INT8_C( -50), INT8_C( -50),
                           INT8_C( -50), INT8_C( -50), INT8_C( -50), INT8_C( -50),
                           INT8_C( -50), INT8_C( -50), INT8_C( -50), INT8_C( -50),
                           INT8_C( -50), INT8_C( -50), INT8_C( -50), INT8_C( -50),
                           INT8_C( -50), INT8_C( -50), INT8_C( -50), INT8_C( -50),
                           INT8_C( -50), INT8_C( -50), INT8_C( -50), INT8_C( -50),
                           INT8_C( -50), INT8_C( -50), INT8_C( -50), INT8_C( -50),
                           INT8_C( -50), INT8_C( -50), INT8_C( -50), INT8_C( -50),
                           INT8_C( -50), INT8_C( -50), INT8_C( -50), INT8_C( -50),
                           INT8_C( -50), INT8_C( -50), INT8_C( -50), INT8_C( -50),
                           INT8_C( -50), INT8_C( -50), INT8_C( -50), INT8_C( -50),
                           INT8_C( -50), INT8_C( -50), INT8_C( -50), INT8_C( -50),
                           INT8_C( -50), INT8_C( -50), INT8_C( -50), INT8_C( -50)) },
    { simde_mm_set_epi8(INT8_C( -49), INT8_C( -76), INT8_C( -62), INT8_C( 118),
                        INT8_C(  -4), INT8_C( -25), INT8_C( -58), INT8_C( 126),
                        INT8_C(-115), INT8_C( 126), INT8_C(-104), INT8_C( 127),
                        INT8_C(  15), INT8_C(  41), INT8_C(  68), INT8_C(  31)),
      simde_mm512_set_epi8(INT8_C(  31), INT8_C(  31), INT8_C(  31), INT8_C(  31),
                           INT8_C(  31), INT8_C(  31), INT8_C(  31), INT8_C(  31),
                           INT8_C(  31), INT8_C(  31), INT8_C(  31), INT8_C(  31),
                           INT8_C(  31), INT8_C(  31), INT8_C(  31), INT8_C(  31),
                           INT8_C(  31), INT8_C(  31), INT8_C(  31), INT8_C(  31),
                           INT8_C(  31), INT8_C(  31), INT8_C(  31), INT8_C(  31),
                           INT8_C(  31), INT8_C(  31), INT8_C(  31), INT8_C(  31),
                           INT8_C(  31), INT8_C(  31), INT8_C(  31), INT8_C(  31),
                           INT8_C(  31), INT8_C(  31), INT8_C(  31), INT8_C(  31),
                           INT8_C(  31), INT8_C(  31), INT8_C(  31), INT8_C(  31),
                           INT8_C(  31), INT8_C(  31), INT8_C(  31), INT8_C(  31),
                           INT8_C(  31), INT8_C(  31), INT8_C(  31), INT8_C(  31),
                           INT8_C(  31), INT8_C(  31), INT8_C(  31), INT8_C(  31),
                           INT8_C(  31), INT8_C(  31), INT8_C(  31), INT8_C(  31),
                           INT8_C(  31), INT8_C(  31), INT8_C(  31), INT8_C(  31),
                           INT8_C(  31), INT8_C(  31), INT8_C(  31), INT8_C(  31)) },
    { simde_mm_set_epi8(INT8_C( -30), INT8_C( -23), INT8_C( -42), INT8_C( -27),
                        INT8_C(-102), INT8_C(  -5), INT8_C( -87), INT8_C(  98),
                        INT8_C(  33), INT8_C(  73), INT8_C( 125), INT8_C( 120),
                        INT8_C( -70), INT8_C(  59), INT8_C( 124), INT8_C(  46)),
      simde_mm512_set_epi8(INT8_C(  46), INT8_C(  46), INT8_C(  46), INT8_C(  46),
                           INT8_C(  46), INT8_C(  46), INT8_C(  46), INT8_C(  46),
                           INT8_C(  46), INT8_C(  46), INT8_C(  46), INT8_C(  46),
                           INT8_C(  46), INT8_C(  46), INT8_C(  46), INT8_C(  46),
                           INT8_C(  46), INT8_C(  46), INT8_C(  46), INT8_C(  46),
                           INT8_C(  46), INT8_C(  46), INT8_C(  46), INT8_C(  46),
                           INT8_C(  46), INT8_C(  46), INT8_C(  46), INT8_C(  46),
                           INT8_C(  46), INT8_C(  46), INT8_C(  46), INT8_C(  46),
                           INT8_C(  46), INT8_C(  46), INT8_C(  46), INT8_C(  46),
                           INT8_C(  46), INT8_C(  46), INT8_C(  46), INT8_C(  46),
                           INT8_C(  46), INT8_C(  46), INT8_C(  46), INT8_C(  46),
                           INT8_C(  46), INT8_C(  46), INT8_C(  46), INT8_C(  46),
                           INT8_C(  46), INT8_C(  46), INT8_C(  46), INT8_C(  46),
                           INT8_C(  46), INT8_C(  46), INT8_C(  46), INT8_C(  46),
                           INT8_C(  46), INT8_C(  46), INT8_C(  46), INT8_C(  46),
                           INT8_C(  46), INT8_C(  46), INT8_C(  46), INT8_C(  46)) },
    { simde_mm_set_epi8(INT8_C( -18), INT8_C(  28), INT8_C( -19), INT8_C( -73),
                        INT8_C( -19), INT8_C(  67), INT8_C(  79), INT8_C( -45),
                        INT8_C(-124), INT8_C(  80), INT8_C(-101), INT8_C(-122),
                        INT8_C( -54), INT8_C(  30), INT8_C( -16), INT8_C(  55)),
      simde_mm512_set_epi8(INT8_C(  55), INT8_C(  55), INT8_C(  55), INT8_C(  55),
                           INT8_C(  55), INT8_C(  55), INT8_C(  55), INT8_C(  55),
                           INT8_C(  55), INT8_C(  55), INT8_C(  55), INT8_C(  55),
                           INT8_C(  55), INT8_C(  55), INT8_C(  55), INT8_C(  55),
                           INT8_C(  55), INT8_C(  55), INT8_C(  55), INT8_C(  55),
                           INT8_C(  55), INT8_C(  55), INT8_C(  55), INT8_C(  55),
                           INT8_C(  55), INT8_C(  55), INT8_C(  55), INT8_C(  55),
                           INT8_C(  55), INT8_C(  55), INT8_C(  55), INT8_C(  55),
                           INT8_C(  55), INT8_C(  55), INT8_C(  55), INT8_C(  55),
                           INT8_C(  55), INT8_C(  55), INT8_C(  55), INT8_C(  55),
                           INT8_C(  55), INT8_C(  55), INT8_C(  55), INT8_C(  55),
                           INT8_C(  55), INT8_C(  55), INT8_C(  55), INT8_C(  55),
                           INT8_C(  55), INT8_C(  55), INT8_C(  55), INT8_C(  55),
                           INT8_C(  55), INT8_C(  55), INT8_C(  55), INT8_C(  55),
                           INT8_C(  55), INT8_C(  55), INT8_C(  55), INT8_C(  55),
                           INT8_C(  55), INT8_C(  55), INT8_C(  55), INT8_C(  55)) },
    { simde_mm_set_epi8(INT8_C(   6), INT8_C(  -5), INT8_C(  37), INT8_C( -97),
                        INT8_C(  16), INT8_C(  -5), INT8_C( -18), INT8_C(  14),
                        INT8_C(-120), INT8_C( -59), INT8_C( -43), INT8_C( -97),
                        INT8_C( -71), INT8_C( -73), INT8_C( -73), INT8_C( -50)),
      simde_mm512_set_epi8(INT8_C( -50), INT8_C( -50), INT8_C( -50), INT8_C( -50),
                           INT8_C( -50), INT8_C( -50), INT8_C( -50), INT8_C( -50),
                           INT8_C( -50), INT8_C( -50), INT8_C( -50), INT8_C( -50),
                           INT8_C( -50), INT8_C( -50), INT8_C( -50), INT8_C( -50),
                           INT8_C( -50), INT8_C( -50), INT8_C( -50), INT8_C( -50),
                           INT8_C( -50), INT8_C( -50), INT8_C( -50), INT8_C( -50),
                           INT8_C( -50), INT8_C( -50), INT8_C( -50), INT8_C( -50),
                           INT8_C( -50), INT8_C( -50), INT8_C( -50), INT8_C( -50),
                           INT8_C( -50), INT8_C( -50), INT8_C( -50), INT8_C( -50),
                           INT8_C( -50), INT8_C( -50), INT8_C( -50), INT8_C( -50),
                           INT8_C( -50), INT8_C( -50), INT8_C( -50), INT8_C( -50),
                           INT8_C( -50), INT8_C( -50), INT8_C( -50), INT8_C( -50),
                           INT8_C( -50), INT8_C( -50), INT8_C( -50), INT8_C( -50),
                           INT8_C( -50), INT8_C( -50), INT8_C( -50), INT8_C( -50),
                           INT8_C( -50), INT8_C( -50), INT8_C( -50), INT8_C( -50),
                           INT8_C( -50), INT8_C( -50), INT8_C( -50), INT8_C( -50)) },
    { simde_mm_set_epi8(INT8_C( 119), INT8_C(  60), INT8_C(  63), INT8_C( -26),
                        INT8_C(  50), INT8_C(  56), INT8_C(  40), INT8_C(  -7),
                        INT8_C(  68), INT8_C( -11), INT8_C( -21), INT8_C( -77),
                        INT8_C(  56), INT8_C(-109), INT8_C(-118), INT8_C(-108)),
      simde_mm512_set_epi8(INT8_C(-108), INT8_C(-108), INT8_C(-108), INT8_C(-108),
                           INT8_C(-108), INT8_C(-108), INT8_C(-108), INT8_C(-108),
                           INT8_C(-108), INT8_C(-108), INT8_C(-108), INT8_C(-108),
                           INT8_C(-108), INT8_C(-108), INT8_C(-108), INT8_C(-108),
                           INT8_C(-108), INT8_C(-108), INT8_C(-108), INT8_C(-108),
                           INT8_C(-108), INT8_C(-108), INT8_C(-108), INT8_C(-108),
                           INT8_C(-108), INT8_C(-108), INT8_C(-108), INT8_C(-108),
                           INT8_C(-108), INT8_C(-108), INT8_C(-108), INT8_C(-108),
                           INT8_C(-108), INT8_C(-108), INT8_C(-108), INT8_C(-108),
                           INT8_C(-108), INT8_C(-108), INT8_C(-108), INT8_C(-108),
                           INT8_C(-108), INT8_C(-108), INT8_C(-108), INT8_C(-108),
                           INT8_C(-108), INT8_C(-108), INT8_C(-108), INT8_C(-108),
                           INT8_C(-108), INT8_C(-108), INT8_C(-108), INT8_C(-108),
                           INT8_C(-108), INT8_C(-108), INT8_C(-108), INT8_C(-108),
                           INT8_C(-108), INT8_C(-108), INT8_C(-108), INT8_C(-108),
                           INT8_C(-108), INT8_C(-108), INT8_C(-108), INT8_C(-108)) },
    { simde_mm_set_epi8(INT8_C(-112), INT8_C(  65), INT8_C(  26), INT8_C( -90),
                        INT8_C( -77), INT8_C(  72), INT8_C(   2), INT8_C(   4),
                        INT8_C( -52), INT8_C( -82), INT8_C( -18), INT8_C( -66),
                        INT8_C(-118), INT8_C( -10), INT8_C(  52), INT8_C( -40)),
      simde_mm512_set_epi8(INT8_C( -40), INT8_C( -40), INT8_C( -40), INT8_C( -40),
                           INT8_C( -40), INT8_C( -40), INT8_C( -40), INT8_C( -40),
                           INT8_C( -40), INT8_C( -40), INT8_C( -40), INT8_C( -40),
                           INT8_C( -40), INT8_C( -40), INT8_C( -40), INT8_C( -40),
                           INT8_C( -40), INT8_C( -40), INT8_C( -40), INT8_C( -40),
                           INT8_C( -40), INT8_C( -40), INT8_C( -40), INT8_C( -40),
                           INT8_C( -40), INT8_C( -40), INT8_C( -40), INT8_C( -40),
                           INT8_C( -40), INT8_C( -40), INT8_C( -40), INT8_C( -40),
                           INT8_C( -40), INT8_C( -40), INT8_C( -40), INT8_C( -40),
                           INT8_C( -40), INT8_C( -40), INT8_C( -40), INT8_C( -40),
                           INT8_C( -40), INT8_C( -40), INT8_C( -40), INT8_C( -40),
                           INT8_C( -40), INT8_C( -40), INT8_C( -40), INT8_C( -40),
                           INT8_C( -40), INT8_C( -40), INT8_C( -40), INT8_C( -40),
                           INT8_C( -40), INT8_C( -40), INT8_C( -40), INT8_C( -40),
                           INT8_C( -40), INT8_C( -40), INT8_C( -40), INT8_C( -40),
                           INT8_C( -40), INT8_C( -40), INT8_C( -40), INT8_C( -40)) }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])); i++) {
    simde__m512i r = simde_mm512_broadcastb_epi8(test_vec[i].a);
    simde_assert_m512i_i8(r, ==, test_vec[i].r);
  }

  return 0;
}

static int
test_simde_mm512_mask_broadcastb_epi8(SIMDE_MUNIT_TEST_ARGS) {
  const struct {
    simde__m512i src;
    simde__mmask64 k;
    simde__m128i a;
    simde__m512i r;
  } test_vec[8] = {
    { simde_mm512_set_epi8(INT8_C(  65), INT8_C( -68), INT8_C( 102), INT8_C(-122),
                           INT8_C(  40), INT8_C(  19), INT8_C(-111), INT8_C(   8),
                           INT8_C( -58), INT8_C(-120), INT8_C( 111), INT8_C(  10),
                           INT8_C( -54), INT8_C(-100), INT8_C(  36), INT8_C(  27),
                           INT8_C(-106), INT8_C(-123), INT8_C( 120), INT8_C(  43),
                           INT8_C( -31), INT8_C(   4), INT8_C(  10), INT8_C(  96),
                           INT8_C( -40), INT8_C(  23), INT8_C(  31), INT8_C(  73),
                           INT8_C( -51), INT8_C(  91), INT8_C(  68), INT8_C( -23),
                           INT8_C(-108), INT8_C(  52), INT8_C(  23), INT8_C( 115),
                           INT8_C(  -4), INT8_C(  24), INT8_C( 106), INT8_C( -92),
                           INT8_C( 126), INT8_C(  -6), INT8_C(  16), INT8_C( 102),
                           INT8_C( -47), INT8_C(-116), INT8_C(  -4), INT8_C(  33),
                           INT8_C( -25), INT8_C(-108), INT8_C(-115), INT8_C(-104),
                           INT8_C( -39), INT8_C(  49), INT8_C(  72), INT8_C(  44),
                           INT8_C( -17), INT8_C( -66), INT8_C( -61), INT8_C( -68),
                           INT8_C( 124), INT8_C(  20), INT8_C(  64), INT8_C( -49)),
      UINT64_C(          2970261907),
      simde_mm_set_epi8(INT8_C( -78), INT8_C( -60), INT8_C(-122), INT8_C( -66),
                        INT8_C(   8), INT8_C( -42), INT8_C(  44), INT8_C(  45),
                        INT8_C(  37), INT8_C(  -9), INT8_C( -14), INT8_C(  38),
                        INT8_C( -85), INT8_C(  35), INT8_C(   8), INT8_C(-127)),
      simde_mm512_set_epi8(INT8_C(  65), INT8_C( -68), INT8_C( 102), INT8_C(-122),
                           INT8_C(  40), INT8_C(  19), INT8_C(-111), INT8_C(   8),
                           INT8_C( -58), INT8_C(-120), INT8_C( 111), INT8_C(  10),
                           INT8_C( -54), INT8_C(-100), INT8_C(  36), INT8_C(  27),
                           INT8_C(-106), INT8_C(-123), INT8_C( 120), INT8_C(  43),
                           INT8_C( -31), INT8_C(   4), INT8_C(  10), INT8_C(  96),
                           INT8_C( -40), INT8_C(  23), INT8_C(  31), INT8_C(  73),
                           INT8_C( -51), INT8_C(  91), INT8_C(  68), INT8_C( -23),
                           INT8_C(-127), INT8_C(  52), INT8_C(-127), INT8_C(-127),
                           INT8_C(  -4), INT8_C(  24), INT8_C( 106), INT8_C(-127),
                           INT8_C( 126), INT8_C(  -6), INT8_C(  16), INT8_C( 102),
                           INT8_C(-127), INT8_C(-116), INT8_C(-127), INT8_C(  33),
                           INT8_C(-127), INT8_C(-108), INT8_C(-115), INT8_C(-127),
                           INT8_C(-127), INT8_C(  49), INT8_C(  72), INT8_C(-127),
                           INT8_C(-127), INT8_C( -66), INT8_C( -61), INT8_C(-127),
                           INT8_C( 124), INT8_C(  20), INT8_C(-127), INT8_C(-127)) },
    { simde_mm512_set_epi8(INT8_C( -76), INT8_C(  58), INT8_C(  70), INT8_C(-106),
                           INT8_C( 120), INT8_C(  72), INT8_C(  -4), INT8_C( -60),
                           INT8_C( 104), INT8_C( 101), INT8_C(  53), INT8_C(-121),
                           INT8_C( 102), INT8_C(-115), INT8_C(  90), INT8_C(  31),
                           INT8_C(  11), INT8_C(  68), INT8_C(  48), INT8_C(   4),
                           INT8_C(  55), INT8_C( -83), INT8_C(  75), INT8_C( -60),
                           INT8_C( -54), INT8_C(  57), INT8_C(  70), INT8_C(-114),
                           INT8_C(  51), INT8_C( -72), INT8_C( -71), INT8_C(  17),
                           INT8_C(  48), INT8_C(  40), INT8_C(-108), INT8_C( -12),
                           INT8_C( -11), INT8_C( -71), INT8_C(-114), INT8_C( -36),
                           INT8_C( -92), INT8_C( 101), INT8_C(  30), INT8_C(  10),
                           INT8_C(  43), INT8_C(-116), INT8_C( -45), INT8_C(-104),
                           INT8_C(  99), INT8_C( 108), INT8_C(  90), INT8_C(   7),
                           INT8_C( 112), INT8_C(  86), INT8_C(-125), INT8_C(  88),
                           INT8_C(  27), INT8_C(  40), INT8_C(  10), INT8_C(-105),
                           INT8_C(  76), INT8_C(-101), INT8_C(  87), INT8_C( 112)),
      UINT64_C(           458960523),
      simde_mm_set_epi8(INT8_C(  70), INT8_C( -73), INT8_C( -42), INT8_C( -19),
                        INT8_C( 110), INT8_C( -58), INT8_C(-117), INT8_C(-100),
                        INT8_C(  52), INT8_C( -63), INT8_C( -88), INT8_C( -55),
                        INT8_C(  90), INT8_C( -15), INT8_C( -11), INT8_C( -21)),
      simde_mm512_set_epi8(INT8_C( -76), INT8_C(  58), INT8_C(  70), INT8_C(-106),
                           INT8_C( 120), INT8_C(  72), INT8_C(  -4), INT8_C( -60),
                           INT8_C( 104), INT8_C( 101), INT8_C(  53), INT8_C(-121),
                           INT8_C( 102), INT8_C(-115), INT8_C(  90), INT8_C(  31),
                           INT8_C(  11), INT8_C(  68), INT8_C(  48), INT8_C(   4),
                           INT8_C(  55), INT8_C( -83), INT8_C(  75), INT8_C( -60),
                           INT8_C( -54), INT8_C(  57), INT8_C(  70), INT8_C(-114),
                           INT8_C(  51), INT8_C( -72), INT8_C( -71), INT8_C(  17),
                           INT8_C(  48), INT8_C(  40), INT8_C(-108), INT8_C( -21),
                           INT8_C( -21), INT8_C( -71), INT8_C( -21), INT8_C( -21),
                           INT8_C( -92), INT8_C( -21), INT8_C(  30), INT8_C( -21),
                           INT8_C( -21), INT8_C(-116), INT8_C( -21), INT8_C( -21),
                           INT8_C(  99), INT8_C( 108), INT8_C( -21), INT8_C(   7),
                           INT8_C( -21), INT8_C( -21), INT8_C( -21), INT8_C(  88),
                           INT8_C( -21), INT8_C(  40), INT8_C(  10), INT8_C(-105),
                           INT8_C( -21), INT8_C(-101), INT8_C( -21), INT8_C( -21)) },
    { simde_mm512_set_epi8(INT8_C( -65), INT8_C(  -9), INT8_C( -93), INT8_C(-113),
                           INT8_C( -10), INT8_C(  74), INT8_C(  39), INT8_C(  57),
                           INT8_C(  91), INT8_C( -48), INT8_C(  11), INT8_C( -15),
                           INT8_C(  21), INT8_C( -88), INT8_C(  91), INT8_C(  87),
                           INT8_C(-120), INT8_C(-105), INT8_C( -47), INT8_C(  85),
                           INT8_C( -98), INT8_C(  22), INT8_C(-124), INT8_C(-124),
                           INT8_C(   2), INT8_C(-104), INT8_C(  27), INT8_C(  96),
                           INT8_C( -89), INT8_C(  31), INT8_C(  20), INT8_C(  31),
                           INT8_C( -95), INT8_C(  13), INT8_C(  37), INT8_C(  31),
                           INT8_C( -72), INT8_C(  83), INT8_C(  94), INT8_C(  52),
                           INT8_C(  41), INT8_C(  25), INT8_C( -42), INT8_C(-109),
                           INT8_C(  31), INT8_C(  88), INT8_C( -71), INT8_C( -89),
                           INT8_C( 103), INT8_C( -85), INT8_C( -29), INT8_C(  86),
                           INT8_C(  71), INT8_C(  28), INT8_C( -23), INT8_C(  28),
                           INT8_C( -53), INT8_C( -82), INT8_C(  58), INT8_C( -12),
                           INT8_C(  63), INT8_C(  39), INT8_C( -32), INT8_C( -94)),
      UINT64_C(          1058428392),
      simde_mm_set_epi8(INT8_C(  85), INT8_C( -11), INT8_C( -21), INT8_C(  66),
                        INT8_C(  72), INT8_C(  -7), INT8_C( -18), INT8_C(-121),
                        INT8_C(  56), INT8_C(  51), INT8_C( 101), INT8_C(  91),
                        INT8_C( -85), INT8_C( -32), INT8_C( -40), INT8_C( -81)),
      simde_mm512_set_epi8(INT8_C( -65), INT8_C(  -9), INT8_C( -93), INT8_C(-113),
                           INT8_C( -10), INT8_C(  74), INT8_C(  39), INT8_C(  57),
                           INT8_C(  91), INT8_C( -48), INT8_C(  11), INT8_C( -15),
                           INT8_C(  21), INT8_C( -88), INT8_C(  91), INT8_C(  87),
                           INT8_C(-120), INT8_C(-105), INT8_C( -47), INT8_C(  85),
                           INT8_C( -98), INT8_C(  22), INT8_C(-124), INT8_C(-124),
                           INT8_C(   2), INT8_C(-104), INT8_C(  27), INT8_C(  96),
                           INT8_C( -89), INT8_C(  31), INT8_C(  20), INT8_C(  31),
                           INT8_C( -95), INT8_C(  13), INT8_C( -81), INT8_C( -81),
                           INT8_C( -81), INT8_C( -81), INT8_C( -81), INT8_C( -81),
                           INT8_C(  41), INT8_C(  25), INT8_C( -42), INT8_C( -81),
                           INT8_C(  31), INT8_C( -81), INT8_C( -81), INT8_C( -89),
                           INT8_C( 103), INT8_C( -81), INT8_C( -29), INT8_C( -81),
                           INT8_C(  71), INT8_C( -81), INT8_C( -23), INT8_C( -81),
                           INT8_C( -81), INT8_C( -81), INT8_C( -81), INT8_C( -12),
                           INT8_C( -81), INT8_C(  39), INT8_C( -32), INT8_C( -94)) },
    { simde_mm512_set_epi8(INT8_C(  85), INT8_C(  18), INT8_C(-117), INT8_C( -50),
                           INT8_C(  -8), INT8_C( 126), INT8_C( 103), INT8_C( -42),
                           INT8_C( 107), INT8_C( -60), INT8_C( -85), INT8_C( 123),
                           INT8_C( -11), INT8_C(  41), INT8_C(  98), INT8_C( 115),
                           INT8_C(  14), INT8_C(  34), INT8_C(  89), INT8_C( 101),
                           INT8_C(  39), INT8_C(  26), INT8_C( 121), INT8_C(  70),
                           INT8_C( -20), INT8_C( -34), INT8_C( -11), INT8_C(  72),
                           INT8_C(   8), INT8_C( -24), INT8_C(-104), INT8_C(  61),
                           INT8_C(-108), INT8_C( -43), INT8_C( 102), INT8_C( 100),
                           INT8_C( -29), INT8_C( -21), INT8_C(  70), INT8_C( -28),
                           INT8_C( -21), INT8_C( -82), INT8_C( -18), INT8_C(   9),
                           INT8_C(  94), INT8_C( -32), INT8_C(  97), INT8_C( -86),
                           INT8_C(  87), INT8_C(  62), INT8_C(-118), INT8_C(  17),
                           INT8_C(  18), INT8_C(-126), INT8_C(  74), INT8_C( -83),
                           INT8_C( -46), INT8_C(-103), INT8_C( -21), INT8_C( 108),
                           INT8_C( -58), INT8_C(-126), INT8_C( -28), INT8_C(-112)),
      UINT64_C(           923153287),
      simde_mm_set_epi8(INT8_C(  73), INT8_C( -73), INT8_C( -11), INT8_C(  36),
                        INT8_C( -17), INT8_C(  70), INT8_C(-102), INT8_C(-111),
                        INT8_C(  27), INT8_C( -97), INT8_C(  -6), INT8_C(  -7),
                        INT8_C(  28), INT8_C( -52), INT8_C( -54), INT8_C( -50)),
      simde_mm512_set_epi8(INT8_C(  85), INT8_C(  18), INT8_C(-117), INT8_C( -50),
                           INT8_C(  -8), INT8_C( 126), INT8_C( 103), INT8_C( -42),
                           INT8_C( 107), INT8_C( -60), INT8_C( -85), INT8_C( 123),
                           INT8_C( -11), INT8_C(  41), INT8_C(  98), INT8_C( 115),
                           INT8_C(  14), INT8_C(  34), INT8_C(  89), INT8_C( 101),
                           INT8_C(  39), INT8_C(  26), INT8_C( 121), INT8_C(  70),
                           INT8_C( -20), INT8_C( -34), INT8_C( -11), INT8_C(  72),
                           INT8_C(   8), INT8_C( -24), INT8_C(-104), INT8_C(  61),
                           INT8_C(-108), INT8_C( -43), INT8_C( -50), INT8_C( -50),
                           INT8_C( -29), INT8_C( -50), INT8_C( -50), INT8_C( -50),
                           INT8_C( -21), INT8_C( -82), INT8_C( -18), INT8_C(   9),
                           INT8_C(  94), INT8_C( -50), INT8_C( -50), INT8_C( -86),
                           INT8_C(  87), INT8_C(  62), INT8_C( -50), INT8_C( -50),
                           INT8_C(  18), INT8_C(-126), INT8_C( -50), INT8_C( -50),
                           INT8_C( -50), INT8_C(-103), INT8_C( -21), INT8_C( 108),
                           INT8_C( -58), INT8_C( -50), INT8_C( -50), INT8_C( -50)) },
    { simde_mm512_set_epi8(INT8_C(  67), INT8_C(-107), INT8_C(  82), INT8_C(  55),
                           INT8_C(  64), INT8_C(  72), INT8_C( -53), INT8_C(  66),
                           INT8_C( -50), INT8_C( 103), INT8_C( -13), INT8_C(  78),
                           INT8_C(  15), INT8_C(  32), INT8_C(  76), INT8_C(  78),
                           INT8_C(  28), INT8_C( -98), INT8_C(-128), INT8_C(  80),
                           INT8_C( 106), INT8_C( -45), INT8_C(  79), INT8_C( 116),
                           INT8_C(  23), INT8_C(  31), INT8_C( 117), INT8_C( -12),
                           INT8_C( -59), INT8_C( -16), INT8_C(  98), INT8_C( -49),
                           INT8_C( 116), INT8_C( -82), INT8_C(  92), INT8_C(   1),
                           INT8_C(  30), INT8_C(-100), INT8_C(  61), INT8_C( -14),
                           INT8_C(  26), INT8_C( -40), INT8_C( -78), INT8_C( -85),
                           INT8_C( -24), INT8_C( -47), INT8_C( -93), INT8_C(  -1),
                           INT8_C(  21), INT8_C(  82), INT8_C( 119), INT8_C(  64),
                           INT8_C(  74), INT8_C( -53), INT8_C(  58), INT8_C(  33),
                           INT8_C(  14), INT8_C( 114), INT8_C(  35), INT8_C( 109),
                           INT8_C( -74), INT8_C( -59), INT8_C( -81), INT8_C(  16)),
      UINT64_C(           594368556),
      simde_mm_set_epi8(INT8_C(  26), INT8_C( -78), INT8_C(  32), INT8_C(  10),
                        INT8_C(-126), INT8_C(  64), INT8_C(  35), INT8_C( -54),
                        INT8_C( -42), INT8_C( -70), INT8_C( 114), INT8_C( 111),
                        INT8_C( 111), INT8_C(  11), INT8_C( 104), INT8_C(  39)),
      simde_mm512_set_epi8(INT8_C(  67), INT8_C(-107), INT8_C(  82), INT8_C(  55),
                           INT8_C(  64), INT8_C(  72), INT8_C( -53), INT8_C(  66),
                           INT8_C( -50), INT8_C( 103), INT8_C( -13), INT8_C(  78),
                           INT8_C(  15), INT8_C(  32), INT8_C(  76), INT8_C(  78),
                           INT8_C(  28), INT8_C( -98), INT8_C(-128), INT8_C(  80),
                           INT8_C( 106), INT8_C( -45), INT8_C(  79), INT8_C( 116),
                           INT8_C(  23), INT8_C(  31), INT8_C( 117), INT8_C( -12),
                           INT8_C( -59), INT8_C( -16), INT8_C(  98), INT8_C( -49),
                           INT8_C( 116), INT8_C( -82), INT8_C(  39), INT8_C(   1),
                           INT8_C(  30), INT8_C(-100), INT8_C(  39), INT8_C(  39),
                           INT8_C(  26), INT8_C(  39), INT8_C(  39), INT8_C( -85),
                           INT8_C(  39), INT8_C(  39), INT8_C( -93), INT8_C(  39),
                           INT8_C(  21), INT8_C(  39), INT8_C( 119), INT8_C(  39),
                           INT8_C(  39), INT8_C( -53), INT8_C(  58), INT8_C(  33),
                           INT8_C(  14), INT8_C( 114), INT8_C(  39), INT8_C( 109),
                           INT8_C(  39), INT8_C(  39), INT8_C( -81), INT8_C(  16)) },
    { simde_mm512_set_epi8(INT8_C( 124), INT8_C(  71), INT8_C(-128), INT8_C( 110),
                           INT8_C(-123), INT8_C( -14), INT8_C( 123), INT8_C( -42),
                           INT8_C(  94), INT8_C(  60), INT8_C( 116), INT8_C( -89),
                           INT8_C(  73), INT8_C( -61), INT8_C(  -3), INT8_C(-114),
                           INT8_C( -92), INT8_C( -78), INT8_C(  90), INT8_C(  44),
                           INT8_C( -84), INT8_C( -33), INT8_C( 116), INT8_C(  -6),
                           INT8_C( -44), INT8_C( 126), INT8_C( -26), INT8_C(  80),
                           INT8_C( -91), INT8_C(-125), INT8_C(  72), INT8_C(  -8),
                           INT8_C( -16), INT8_C(  95), INT8_C( -25), INT8_C( -16),
                           INT8_C( -52), INT8_C( 116), INT8_C( -23), INT8_C(-102),
                           INT8_C( 119), INT8_C( -76), INT8_C(  48), INT8_C(  26),
                           INT8_C(-128), INT8_C(  43), INT8_C(  99), INT8_C( -34),
                           INT8_C(-103), INT8_C( -40), INT8_C(  47), INT8_C(-112),
                           INT8_C(-117), INT8_C( 111), INT8_C(-126), INT8_C(-115),
                           INT8_C(  65), INT8_C( -55), INT8_C(  49), INT8_C(  37),
                           INT8_C(-110), INT8_C(-124), INT8_C( 126), INT8_C(  -2)),
      UINT64_C(          1610616610),
      simde_mm_set_epi8(INT8_C( -95), INT8_C(  29), INT8_C( -58), INT8_C( -87),
                        INT8_C(  73), INT8_C(  12), INT8_C( -29), INT8_C(  41),
                        INT8_C( -96), INT8_C( 122), INT8_C( -95), INT8_C( -33),
                        INT8_C(-128), INT8_C(   2), INT8_C( 115), INT8_C( 108)),
      simde_mm512_set_epi8(INT8_C( 124), INT8_C(  71), INT8_C(-128), INT8_C( 110),
                           INT8_C(-123), INT8_C( -14), INT8_C( 123), INT8_C( -42),
                           INT8_C(  94), INT8_C(  60), INT8_C( 116), INT8_C( -89),
                           INT8_C(  73), INT8_C( -61), INT8_C(  -3), INT8_C(-114),
                           INT8_C( -92), INT8_C( -78), INT8_C(  90), INT8_C(  44),
                           INT8_C( -84), INT8_C( -33), INT8_C( 116), INT8_C(  -6),
                           INT8_C( -44), INT8_C( 126), INT8_C( -26), INT8_C(  80),
                           INT8_C( -91), INT8_C(-125), INT8_C(  72), INT8_C(  -8),
                           INT8_C( -16), INT8_C( 108), INT8_C( 108), INT8_C( -16),
                           INT8_C( -52), INT8_C( 116), INT8_C( -23), INT8_C(-102),
                           INT8_C( 119), INT8_C( -76), INT8_C(  48), INT8_C(  26),
                           INT8_C(-128), INT8_C(  43), INT8_C(  99), INT8_C( -34),
                           INT8_C(-103), INT8_C( -40), INT8_C(  47), INT8_C(-112),
                           INT8_C( 108), INT8_C( 108), INT8_C( 108), INT8_C( 108),
                           INT8_C(  65), INT8_C( -55), INT8_C( 108), INT8_C(  37),
                           INT8_C(-110), INT8_C(-124), INT8_C( 108), INT8_C(  -2)) },
    { simde_mm512_set_epi8(INT8_C(  73), INT8_C( -95), INT8_C( -44), INT8_C( 123),
                           INT8_C( -34), INT8_C(-122), INT8_C( 105), INT8_C( -63),
                           INT8_C( -13), INT8_C( -78), INT8_C(  -7), INT8_C(  88),
                           INT8_C(-101), INT8_C(  60), INT8_C(  29), INT8_C( -15),
                           INT8_C(  87), INT8_C( -77), INT8_C(  65), INT8_C(  71),
                           INT8_C( 113), INT8_C(-124), INT8_C( -41), INT8_C( -18),
                           INT8_C(  37), INT8_C( -20), INT8_C( 112), INT8_C(  70),
                           INT8_C(  36), INT8_C( -80), INT8_C( 122), INT8_C( -28),
                           INT8_C( -45), INT8_C(-113), INT8_C(  68), INT8_C(  23),
                           INT8_C(  84), INT8_C(  56), INT8_C( -44), INT8_C( -61),
                           INT8_C( -78), INT8_C(   6), INT8_C(-108), INT8_C(  73),
                           INT8_C( -22), INT8_C( -71), INT8_C(   1), INT8_C(   7),
                           INT8_C(  47), INT8_C(  18), INT8_C(-127), INT8_C( 127),
                           INT8_C( -16), INT8_C( -48), INT8_C( -39), INT8_C( 106),
                           INT8_C(  27), INT8_C(  40), INT8_C( -58), INT8_C( -56),
                           INT8_C( -27), INT8_C(  17), INT8_C(  29), INT8_C( -46)),
      UINT64_C(          2168160586),
      simde_mm_set_epi8(INT8_C(  45), INT8_C(  89), INT8_C( -40), INT8_C(  94),
                        INT8_C( -55), INT8_C( -34), INT8_C(-119), INT8_C(-109),
                        INT8_C(   3), INT8_C(-117), INT8_C(-101), INT8_C(  63),
                        INT8_C( 122), INT8_C(  -4), INT8_C(-100), INT8_C( -84)),
      simde_mm512_set_epi8(INT8_C(  73), INT8_C( -95), INT8_C( -44), INT8_C( 123),
                           INT8_C( -34), INT8_C(-122), INT8_C( 105), INT8_C( -63),
                           INT8_C( -13), INT8_C( -78), INT8_C(  -7), INT8_C(  88),
                           INT8_C(-101), INT8_C(  60), INT8_C(  29), INT8_C( -15),
                           INT8_C(  87), INT8_C( -77), INT8_C(  65), INT8_C(  71),
                           INT8_C( 113), INT8_C(-124), INT8_C( -41), INT8_C( -18),
                           INT8_C(  37), INT8_C( -20), INT8_C( 112), INT8_C(  70),
                           INT8_C(  36), INT8_C( -80), INT8_C( 122), INT8_C( -28),
                           INT8_C( -84), INT8_C(-113), INT8_C(  68), INT8_C(  23),
                           INT8_C(  84), INT8_C(  56), INT8_C( -44), INT8_C( -84),
                           INT8_C( -78), INT8_C(   6), INT8_C( -84), INT8_C( -84),
                           INT8_C( -84), INT8_C( -71), INT8_C( -84), INT8_C( -84),
                           INT8_C( -84), INT8_C(  18), INT8_C(-127), INT8_C( 127),
                           INT8_C( -16), INT8_C( -48), INT8_C( -39), INT8_C( -84),
                           INT8_C(  27), INT8_C( -84), INT8_C( -58), INT8_C( -56),
                           INT8_C( -84), INT8_C(  17), INT8_C( -84), INT8_C( -46)) },
    { simde_mm512_set_epi8(INT8_C(  38), INT8_C( -12), INT8_C( -37), INT8_C(  58),
                           INT8_C(  89), INT8_C(-127), INT8_C( -11), INT8_C(  26),
                           INT8_C( -29), INT8_C(-122), INT8_C(  86), INT8_C(  69),
                           INT8_C(  63), INT8_C(  74), INT8_C(  90), INT8_C(  88),
                           INT8_C( -75), INT8_C( -43), INT8_C(  36), INT8_C(  61),
                           INT8_C( -19), INT8_C(  27), INT8_C(-123), INT8_C(  78),
                           INT8_C(  67), INT8_C(  58), INT8_C( -32), INT8_C(  42),
                           INT8_C(  25), INT8_C( -26), INT8_C( 122), INT8_C(-100),
                           INT8_C(-107), INT8_C( -53), INT8_C(-114), INT8_C(  63),
                           INT8_C(-100), INT8_C(  53), INT8_C( -32), INT8_C( -39),
                           INT8_C( -75), INT8_C(-119), INT8_C( -67), INT8_C(  96),
                           INT8_C(  -6), INT8_C( -22), INT8_C( -12), INT8_C(  19),
                           INT8_C( -51), INT8_C(  42), INT8_C(  39), INT8_C(-124),
                           INT8_C(  38), INT8_C( -95), INT8_C(-119), INT8_C(  -9),
                           INT8_C(  94), INT8_C( -51), INT8_C(   1), INT8_C( -64),
                           INT8_C( -67), INT8_C(-127), INT8_C( -33), INT8_C(  75)),
      UINT64_C(          3579095368),
      simde_mm_set_epi8(INT8_C( -71), INT8_C(-112), INT8_C(-122), INT8_C( -13),
                        INT8_C(-109), INT8_C(  21), INT8_C(  27), INT8_C(-109),
                        INT8_C(  55), INT8_C(   9), INT8_C( 117), INT8_C( -28),
                        INT8_C( -58), INT8_C(  -1), INT8_C(   3), INT8_C( -34)),
      simde_mm512_set_epi8(INT8_C(  38), INT8_C( -12), INT8_C( -37), INT8_C(  58),
                           INT8_C(  89), INT8_C(-127), INT8_C( -11), INT8_C(  26),
                           INT8_C( -29), INT8_C(-122), INT8_C(  86), INT8_C(  69),
                           INT8_C(  63), INT8_C(  74), INT8_C(  90), INT8_C(  88),
                           INT8_C( -75), INT8_C( -43), INT8_C(  36), INT8_C(  61),
                           INT8_C( -19), INT8_C(  27), INT8_C(-123), INT8_C(  78),
                           INT8_C(  67), INT8_C(  58), INT8_C( -32), INT8_C(  42),
                           INT8_C(  25), INT8_C( -26), INT8_C( 122), INT8_C(-100),
                           INT8_C( -34), INT8_C( -34), INT8_C(-114), INT8_C( -34),
                           INT8_C(-100), INT8_C( -34), INT8_C( -32), INT8_C( -34),
                           INT8_C( -75), INT8_C( -34), INT8_C( -67), INT8_C( -34),
                           INT8_C(  -6), INT8_C( -34), INT8_C( -12), INT8_C(  19),
                           INT8_C( -34), INT8_C(  42), INT8_C( -34), INT8_C(-124),
                           INT8_C( -34), INT8_C( -95), INT8_C(-119), INT8_C( -34),
                           INT8_C(  94), INT8_C( -34), INT8_C(   1), INT8_C( -64),
                           INT8_C( -34), INT8_C(-127), INT8_C( -33), INT8_C(  75)) }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])); i++) {
    simde__m512i r = simde_mm512_mask_broadcastb_epi8(test_vec[i].src, test_vec[i].k, test_vec[i].a);
    simde_assert_m512i_i8(r, ==, test_vec[i].r);
  }

  return 0;
}

static int
test_simde_mm512_maskz_broadcastb_epi8(SIMDE_MUNIT_TEST_ARGS) {
  const struct {
    simde__mmask64 k;
    simde__m128i a;
    simde__m512i r;
  } test_vec[8] = {
    { UINT64_C(          2081702095),
      simde_mm_set_epi8(INT8_C( 126), INT8_C(  -6), INT8_C(  16), INT8_C( 102),
                        INT8_C( -47), INT8_C(-116), INT8_C(  -4), INT8_C(  33),
                        INT8_C( -25), INT8_C(-108), INT8_C(-115), INT8_C(-104),
                        INT8_C( -39), INT8_C(  49), INT8_C(  72), INT8_C(  44)),
      simde_mm512_set_epi8(INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(  44), INT8_C(  44), INT8_C(  44),
                           INT8_C(  44), INT8_C(  44), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(  44),
                           INT8_C(   0), INT8_C(  44), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(  44), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(  44), INT8_C(  44), INT8_C(   0), INT8_C(   0),
                           INT8_C(  44), INT8_C(  44), INT8_C(  44), INT8_C(  44)) },
    { UINT64_C(          4229458596),
      simde_mm_set_epi8(INT8_C(-106), INT8_C(-123), INT8_C( 120), INT8_C(  43),
                        INT8_C( -31), INT8_C(   4), INT8_C(  10), INT8_C(  96),
                        INT8_C( -40), INT8_C(  23), INT8_C(  31), INT8_C(  73),
                        INT8_C( -51), INT8_C(  91), INT8_C(  68), INT8_C( -23)),
      simde_mm512_set_epi8(INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C( -23), INT8_C( -23), INT8_C( -23), INT8_C( -23),
                           INT8_C( -23), INT8_C( -23), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C( -23),
                           INT8_C( -23), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C( -23), INT8_C( -23), INT8_C(   0),
                           INT8_C( -23), INT8_C(   0), INT8_C( -23), INT8_C(   0),
                           INT8_C( -23), INT8_C(   0), INT8_C( -23), INT8_C(   0),
                           INT8_C(   0), INT8_C( -23), INT8_C(   0), INT8_C(   0)) },
    { UINT64_C(          3399230491),
      simde_mm_set_epi8(INT8_C( -40), INT8_C( -29), INT8_C(  78), INT8_C(  94),
                        INT8_C( -79), INT8_C(  10), INT8_C(-103), INT8_C(-109),
                        INT8_C(  65), INT8_C( -68), INT8_C( 102), INT8_C(-122),
                        INT8_C(  40), INT8_C(  19), INT8_C(-111), INT8_C(   8)),
      simde_mm512_set_epi8(INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   8), INT8_C(   8), INT8_C(   0), INT8_C(   0),
                           INT8_C(   8), INT8_C(   0), INT8_C(   8), INT8_C(   0),
                           INT8_C(   8), INT8_C(   0), INT8_C(   0), INT8_C(   8),
                           INT8_C(   8), INT8_C(   8), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   8), INT8_C(   0),
                           INT8_C(   0), INT8_C(   8), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   8),
                           INT8_C(   8), INT8_C(   0), INT8_C(   8), INT8_C(   8)) },
    { UINT64_C(          2871199873),
      simde_mm_set_epi8(INT8_C(  27), INT8_C(  40), INT8_C(  10), INT8_C(-105),
                        INT8_C(  76), INT8_C(-101), INT8_C(  87), INT8_C( 112),
                        INT8_C( -78), INT8_C( -60), INT8_C(-122), INT8_C( -66),
                        INT8_C(   8), INT8_C( -42), INT8_C(  44), INT8_C(  45)),
      simde_mm512_set_epi8(INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(  45), INT8_C(   0), INT8_C(  45), INT8_C(   0),
                           INT8_C(  45), INT8_C(   0), INT8_C(  45), INT8_C(  45),
                           INT8_C(   0), INT8_C(   0), INT8_C(  45), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(  45), INT8_C(  45),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(  45), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(  45), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(  45)) },
    { UINT64_C(          1884717912),
      simde_mm_set_epi8(INT8_C(  48), INT8_C(  40), INT8_C(-108), INT8_C( -12),
                        INT8_C( -11), INT8_C( -71), INT8_C(-114), INT8_C( -36),
                        INT8_C( -92), INT8_C( 101), INT8_C(  30), INT8_C(  10),
                        INT8_C(  43), INT8_C(-116), INT8_C( -45), INT8_C(-104)),
      simde_mm512_set_epi8(INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(-104), INT8_C(-104), INT8_C(-104),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(-104), INT8_C(   0), INT8_C(-104),
                           INT8_C(   0), INT8_C(-104), INT8_C(-104), INT8_C(   0),
                           INT8_C(-104), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(-104), INT8_C(-104),
                           INT8_C(   0), INT8_C(-104), INT8_C(   0), INT8_C(-104),
                           INT8_C(-104), INT8_C(   0), INT8_C(   0), INT8_C(   0)) },
    { UINT64_C(           867744017),
      simde_mm_set_epi8(INT8_C( 104), INT8_C( 101), INT8_C(  53), INT8_C(-121),
                        INT8_C( 102), INT8_C(-115), INT8_C(  90), INT8_C(  31),
                        INT8_C(  11), INT8_C(  68), INT8_C(  48), INT8_C(   4),
                        INT8_C(  55), INT8_C( -83), INT8_C(  75), INT8_C( -60)),
      simde_mm512_set_epi8(INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C( -60), INT8_C( -60),
                           INT8_C(   0), INT8_C(   0), INT8_C( -60), INT8_C( -60),
                           INT8_C( -60), INT8_C(   0), INT8_C( -60), INT8_C( -60),
                           INT8_C( -60), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C( -60), INT8_C(   0), INT8_C( -60), INT8_C( -60),
                           INT8_C( -60), INT8_C(   0), INT8_C(   0), INT8_C( -60),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C( -60),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C( -60)) },
    { UINT64_C(          2018049220),
      simde_mm_set_epi8(INT8_C(  52), INT8_C( -63), INT8_C( -88), INT8_C( -55),
                        INT8_C(  90), INT8_C( -15), INT8_C( -11), INT8_C( -21),
                        INT8_C( 100), INT8_C( -84), INT8_C( -92), INT8_C( -78),
                        INT8_C(  27), INT8_C(  91), INT8_C(  46), INT8_C(-117)),
      simde_mm512_set_epi8(INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(-117), INT8_C(-117), INT8_C(-117),
                           INT8_C(-117), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(-117), INT8_C(   0), INT8_C(   0),
                           INT8_C(-117), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(-117), INT8_C(-117), INT8_C(-117), INT8_C(-117),
                           INT8_C(-117), INT8_C(-117), INT8_C(   0), INT8_C(   0),
                           INT8_C(-117), INT8_C(-117), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(-117), INT8_C(   0), INT8_C(   0)) },
    { UINT64_C(          1858505628),
      simde_mm_set_epi8(INT8_C( 103), INT8_C( -85), INT8_C( -29), INT8_C(  86),
                        INT8_C(  71), INT8_C(  28), INT8_C( -23), INT8_C(  28),
                        INT8_C( -53), INT8_C( -82), INT8_C(  58), INT8_C( -12),
                        INT8_C(  63), INT8_C(  39), INT8_C( -32), INT8_C( -94)),
      simde_mm512_set_epi8(INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C( -94), INT8_C( -94), INT8_C(   0),
                           INT8_C( -94), INT8_C( -94), INT8_C( -94), INT8_C(   0),
                           INT8_C( -94), INT8_C( -94), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C( -94), INT8_C( -94), INT8_C(   0),
                           INT8_C( -94), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C( -94), INT8_C(   0), INT8_C( -94), INT8_C( -94),
                           INT8_C( -94), INT8_C(   0), INT8_C(   0), INT8_C( -94),
                           INT8_C( -94), INT8_C( -94), INT8_C(   0), INT8_C(   0)) }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])); i++) {
    simde__m512i r = simde_mm512_maskz_broadcastb_epi8(test_vec[i].k, test_vec[i].a);
    simde_assert_m512i_i8(r, ==, test_vec[i].r);
  }

  return 0;
}

static int
test_simde_mm512_broadcastw_epi16(SIMDE_MUNIT_TEST_ARGS) {
  const struct {
    simde__m128i a;
    simde__m512i r;
  } test_vec[8] = {
    { simde_mm_set_epi16(INT16_C( -4264), INT16_C(-31095), INT16_C( 28503), INT16_C(-19429),
                         INT16_C(-23560), INT16_C( -4328), INT16_C( 17780), INT16_C(-19836)),
      simde_mm512_set_epi16(INT16_C(-19836), INT16_C(-19836), INT16_C(-19836), INT16_C(-19836),
                            INT16_C(-19836), INT16_C(-19836), INT16_C(-19836), INT16_C(-19836),
                            INT16_C(-19836), INT16_C(-19836), INT16_C(-19836), INT16_C(-19836),
                            INT16_C(-19836), INT16_C(-19836), INT16_C(-19836), INT16_C(-19836),
                            INT16_C(-19836), INT16_C(-19836), INT16_C(-19836), INT16_C(-19836),
                            INT16_C(-19836), INT16_C(-19836), INT16_C(-19836), INT16_C(-19836),
                            INT16_C(-19836), INT16_C(-19836), INT16_C(-19836), INT16_C(-19836),
                            INT16_C(-19836), INT16_C(-19836), INT16_C(-19836), INT16_C(-19836)) },
    { simde_mm_set_epi16(INT16_C( -1138), INT16_C(-21762), INT16_C(  8538), INT16_C(-12772),
                         INT16_C(  3852), INT16_C(  8246), INT16_C( -3641), INT16_C(  9422)),
      simde_mm512_set_epi16(INT16_C(  9422), INT16_C(  9422), INT16_C(  9422), INT16_C(  9422),
                            INT16_C(  9422), INT16_C(  9422), INT16_C(  9422), INT16_C(  9422),
                            INT16_C(  9422), INT16_C(  9422), INT16_C(  9422), INT16_C(  9422),
                            INT16_C(  9422), INT16_C(  9422), INT16_C(  9422), INT16_C(  9422),
                            INT16_C(  9422), INT16_C(  9422), INT16_C(  9422), INT16_C(  9422),
                            INT16_C(  9422), INT16_C(  9422), INT16_C(  9422), INT16_C(  9422),
                            INT16_C(  9422), INT16_C(  9422), INT16_C(  9422), INT16_C(  9422),
                            INT16_C(  9422), INT16_C(  9422), INT16_C(  9422), INT16_C(  9422)) },
    { simde_mm_set_epi16(INT16_C(-12364), INT16_C(-15754), INT16_C(  -793), INT16_C(-14722),
                         INT16_C(-29314), INT16_C(-26497), INT16_C(  3881), INT16_C( 17439)),
      simde_mm512_set_epi16(INT16_C( 17439), INT16_C( 17439), INT16_C( 17439), INT16_C( 17439),
                            INT16_C( 17439), INT16_C( 17439), INT16_C( 17439), INT16_C( 17439),
                            INT16_C( 17439), INT16_C( 17439), INT16_C( 17439), INT16_C( 17439),
                            INT16_C( 17439), INT16_C( 17439), INT16_C( 17439), INT16_C( 17439),
                            INT16_C( 17439), INT16_C( 17439), INT16_C( 17439), INT16_C( 17439),
                            INT16_C( 17439), INT16_C( 17439), INT16_C( 17439), INT16_C( 17439),
                            INT16_C( 17439), INT16_C( 17439), INT16_C( 17439), INT16_C( 17439),
                            INT16_C( 17439), INT16_C( 17439), INT16_C( 17439), INT16_C( 17439)) },
    { simde_mm_set_epi16(INT16_C( -7447), INT16_C(-10523), INT16_C(-25861), INT16_C(-22174),
                         INT16_C(  8521), INT16_C( 32120), INT16_C(-17861), INT16_C( 31790)),
      simde_mm512_set_epi16(INT16_C( 31790), INT16_C( 31790), INT16_C( 31790), INT16_C( 31790),
                            INT16_C( 31790), INT16_C( 31790), INT16_C( 31790), INT16_C( 31790),
                            INT16_C( 31790), INT16_C( 31790), INT16_C( 31790), INT16_C( 31790),
                            INT16_C( 31790), INT16_C( 31790), INT16_C( 31790), INT16_C( 31790),
                            INT16_C( 31790), INT16_C( 31790), INT16_C( 31790), INT16_C( 31790),
                            INT16_C( 31790), INT16_C( 31790), INT16_C( 31790), INT16_C( 31790),
                            INT16_C( 31790), INT16_C( 31790), INT16_C( 31790), INT16_C( 31790),
                            INT16_C( 31790), INT16_C( 31790), INT16_C( 31790), INT16_C( 31790)) },
    { simde_mm_set_epi16(INT16_C( -4580), INT16_C( -4681), INT16_C( -4797), INT16_C( 20435),
                         INT16_C(-31664), INT16_C(-25722), INT16_C(-13794), INT16_C( -4041)),
      simde_mm512_set_epi16(INT16_C( -4041), INT16_C( -4041), INT16_C( -4041), INT16_C( -4041),
                            INT16_C( -4041), INT16_C( -4041), INT16_C( -4041), INT16_C( -4041),
                            INT16_C( -4041), INT16_C( -4041), INT16_C( -4041), INT16_C( -4041),
                            INT16_C( -4041), INT16_C( -4041), INT16_C( -4041), INT16_C( -4041),
                            INT16_C( -4041), INT16_C( -4041), INT16_C( -4041), INT16_C( -4041),
                            INT16_C( -4041), INT16_C( -4041), INT16_C( -4041), INT16_C( -4041),
                            INT16_C( -4041), INT16_C( -4041), INT16_C( -4041), INT16_C( -4041),
                            INT16_C( -4041), INT16_C( -4041), INT16_C( -4041), INT16_C( -4041)) },
    { simde_mm_set_epi16(INT16_C(  1787), INT16_C(  9631), INT16_C(  4347), INT16_C( -4594),
                         INT16_C(-30523), INT16_C(-10849), INT16_C(-17993), INT16_C(-18482)),
      simde_mm512_set_epi16(INT16_C(-18482), INT16_C(-18482), INT16_C(-18482), INT16_C(-18482),
                            INT16_C(-18482), INT16_C(-18482), INT16_C(-18482), INT16_C(-18482),
                            INT16_C(-18482), INT16_C(-18482), INT16_C(-18482), INT16_C(-18482),
                            INT16_C(-18482), INT16_C(-18482), INT16_C(-18482), INT16_C(-18482),
                            INT16_C(-18482), INT16_C(-18482), INT16_C(-18482), INT16_C(-18482),
                            INT16_C(-18482), INT16_C(-18482), INT16_C(-18482), INT16_C(-18482),
                            INT16_C(-18482), INT16_C(-18482), INT16_C(-18482), INT16_C(-18482),
                            INT16_C(-18482), INT16_C(-18482), INT16_C(-18482), INT16_C(-18482)) },
    { simde_mm_set_epi16(INT16_C( 30524), INT16_C( 16358), INT16_C( 12856), INT16_C( 10489),
                         INT16_C( 17653), INT16_C( -5197), INT16_C( 14483), INT16_C(-30060)),
      simde_mm512_set_epi16(INT16_C(-30060), INT16_C(-30060), INT16_C(-30060), INT16_C(-30060),
                            INT16_C(-30060), INT16_C(-30060), INT16_C(-30060), INT16_C(-30060),
                            INT16_C(-30060), INT16_C(-30060), INT16_C(-30060), INT16_C(-30060),
                            INT16_C(-30060), INT16_C(-30060), INT16_C(-30060), INT16_C(-30060),
                            INT16_C(-30060), INT16_C(-30060), INT16_C(-30060), INT16_C(-30060),
                            INT16_C(-30060), INT16_C(-30060), INT16_C(-30060), INT16_C(-30060),
                            INT16_C(-30060), INT16_C(-30060), INT16_C(-30060), INT16_C(-30060),
                            INT16_C(-30060), INT16_C(-30060), INT16_C(-30060), INT16_C(-30060)) },
    { simde_mm_set_epi16(INT16_C(-28607), INT16_C(  6822), INT16_C(-19640), INT16_C(   516),
                         INT16_C(-13138), INT16_C( -4418), INT16_C(-29962), INT16_C( 13528)),
      simde_mm512_set_epi16(INT16_C( 13528), INT16_C( 13528), INT16_C( 13528), INT16_C( 13528),
                            INT16_C( 13528), INT16_C( 13528), INT16_C( 13528), INT16_C( 13528),
                            INT16_C( 13528), INT16_C( 13528), INT16_C( 13528), INT16_C( 13528),
                            INT16_C( 13528), INT16_C( 13528), INT16_C( 13528), INT16_C( 13528),
                            INT16_C( 13528), INT16_C( 13528), INT16_C( 13528), INT16_C( 13528),
                            INT16_C( 13528), INT16_C( 13528), INT16_C( 13528), INT16_C( 13528),
                            INT16_C( 13528), INT16_C( 13528), INT16_C( 13528), INT16_C( 13528),
                            INT16_C( 13528), INT16_C( 13528), INT16_C( 13528), INT16_C( 13528)) }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])); i++) {
    simde__m512i r = simde_mm512_broadcastw_epi16(test_vec[i].a);
    simde_assert_m512i_i16(r, ==, test_vec[i].r);
  }

  return 0;
}

static int
test_simde_mm512_shuffle_epi8(SIMDE_MUNIT_TEST_ARGS) {
  const struct {
    simde__m512i a;
    simde__m512i b;
    simde__m512i r;
  } test_vec[8] = {
    { simde_mm512_set_epi8(INT8_C(  56), INT8_C( -94), INT8_C( -41), INT8_C( -59),
                           INT8_C(  40), INT8_C(  78), INT8_C(  93), INT8_C( 107),
                           INT8_C( -47), INT8_C(  66), INT8_C(  -8), INT8_C( -52),
                           INT8_C(  50), INT8_C(  78), INT8_C(  13), INT8_C(  26),
                           INT8_C( -33), INT8_C( 120), INT8_C(  67), INT8_C( -12),
                           INT8_C(  80), INT8_C(  88), INT8_C( -65), INT8_C(  49),
                           INT8_C(  28), INT8_C(  96), INT8_C( -99), INT8_C(-119),
                           INT8_C( 126), INT8_C(  24), INT8_C(  35), INT8_C(  11),
                           INT8_C( -43), INT8_C( -24), INT8_C(   1), INT8_C( -61),
                           INT8_C( 101), INT8_C(   5), INT8_C(  67), INT8_C( -42),
                           INT8_C( -46), INT8_C(-115), INT8_C(-105), INT8_C( -92),
                           INT8_C(  -3), INT8_C( -44), INT8_C(  13), INT8_C( -36),
                           INT8_C( 110), INT8_C( -38), INT8_C( -48), INT8_C(  36),
                           INT8_C( 117), INT8_C( -59), INT8_C( 109), INT8_C( -27),
                           INT8_C( -62), INT8_C(  98), INT8_C(-121), INT8_C(-108),
                           INT8_C(  -7), INT8_C(-112), INT8_C( -52), INT8_C( -84)),
      simde_mm512_set_epi8(INT8_C(  34), INT8_C(  34), INT8_C( -71), INT8_C( -63),
                           INT8_C( -34), INT8_C(-128), INT8_C( 113), INT8_C( -72),
                           INT8_C(  86), INT8_C( -73), INT8_C( -43), INT8_C(  95),
                           INT8_C(   3), INT8_C(  13), INT8_C(  19), INT8_C(  -1),
                           INT8_C( -54), INT8_C( 114), INT8_C(  27), INT8_C( -30),
                           INT8_C(  52), INT8_C( -54), INT8_C(  78), INT8_C(  23),
                           INT8_C(  71), INT8_C(  87), INT8_C( 107), INT8_C( -27),
                           INT8_C( -35), INT8_C(-122), INT8_C(  40), INT8_C(  55),
                           INT8_C(  -2), INT8_C(  40), INT8_C( -63), INT8_C(  85),
                           INT8_C( -25), INT8_C( -93), INT8_C(  25), INT8_C(  70),
                           INT8_C( 117), INT8_C(  66), INT8_C( -79), INT8_C(  57),
                           INT8_C(-115), INT8_C( -27), INT8_C(  59), INT8_C(  25),
                           INT8_C(  -6), INT8_C(  42), INT8_C( -27), INT8_C( -34),
                           INT8_C( -16), INT8_C(   5), INT8_C( -55), INT8_C(  74),
                           INT8_C( -29), INT8_C(  77), INT8_C( -17), INT8_C(  16),
                           INT8_C( -98), INT8_C( -38), INT8_C( 116), INT8_C( -56)),
      simde_mm512_set_epi8(INT8_C(  78), INT8_C(  78), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(  13), INT8_C(   0),
                           INT8_C(  66), INT8_C(   0), INT8_C(   0), INT8_C(  56),
                           INT8_C(  50), INT8_C( -41), INT8_C(  50), INT8_C(   0),
                           INT8_C(   0), INT8_C(  24), INT8_C(  80), INT8_C(   0),
                           INT8_C(-119), INT8_C(   0), INT8_C( 120), INT8_C(  28),
                           INT8_C(  28), INT8_C(  28), INT8_C(  80), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(  49), INT8_C(  28),
                           INT8_C(   0), INT8_C( -42), INT8_C(   0), INT8_C(-105),
                           INT8_C(   0), INT8_C(   0), INT8_C(  67), INT8_C(-115),
                           INT8_C(-105), INT8_C( -44), INT8_C(   0), INT8_C(  67),
                           INT8_C(   0), INT8_C(   0), INT8_C( 101), INT8_C(  67),
                           INT8_C(   0), INT8_C( -59), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(-121), INT8_C(   0), INT8_C( -59),
                           INT8_C(   0), INT8_C( -48), INT8_C(   0), INT8_C( -84),
                           INT8_C(   0), INT8_C(   0), INT8_C(-108), INT8_C(   0)) },
    { simde_mm512_set_epi8(INT8_C( -75), INT8_C(-123), INT8_C( -44), INT8_C( -97),
                           INT8_C(  61), INT8_C(-112), INT8_C( 109), INT8_C(  27),
                           INT8_C(  -9), INT8_C( -31), INT8_C(-111), INT8_C( -59),
                           INT8_C(  94), INT8_C( 110), INT8_C(  31), INT8_C(  50),
                           INT8_C( -86), INT8_C(  24), INT8_C(  91), INT8_C(-105),
                           INT8_C(  39), INT8_C(  25), INT8_C( -65), INT8_C(  69),
                           INT8_C( -59), INT8_C( -57), INT8_C( -98), INT8_C(  26),
                           INT8_C( -35), INT8_C(  -2), INT8_C( 114), INT8_C( -51),
                           INT8_C( -16), INT8_C( 101), INT8_C( -92), INT8_C(  65),
                           INT8_C( -88), INT8_C(  19), INT8_C(-102), INT8_C( -51),
                           INT8_C( -94), INT8_C( -30), INT8_C(  60), INT8_C(  -9),
                           INT8_C(   4), INT8_C( -93), INT8_C( 110), INT8_C(-102),
                           INT8_C( 109), INT8_C(   1), INT8_C( 113), INT8_C( 114),
                           INT8_C( 100), INT8_C(  80), INT8_C(  18), INT8_C(  -7),
                           INT8_C( -87), INT8_C(   0), INT8_C( -55), INT8_C(  37),
                           INT8_C(  13), INT8_C(  86), INT8_C(-114), INT8_C(-125)),
      simde_mm512_set_epi8(INT8_C(  18), INT8_C(  11), INT8_C(  73), INT8_C(  57),
                           INT8_C( -54), INT8_C(   9), INT8_C(  69), INT8_C( -45),
                           INT8_C(  71), INT8_C(  -6), INT8_C( -68), INT8_C(  -8),
                           INT8_C(  14), INT8_C( -27), INT8_C(  84), INT8_C( -90),
                           INT8_C( -10), INT8_C( -81), INT8_C(  77), INT8_C(-113),
                           INT8_C(  32), INT8_C(  17), INT8_C(  62), INT8_C( -18),
                           INT8_C( 124), INT8_C( -42), INT8_C( -52), INT8_C(-109),
                           INT8_C( -19), INT8_C(  30), INT8_C( -51), INT8_C(-111),
                           INT8_C( 100), INT8_C(  63), INT8_C( -80), INT8_C(-126),
                           INT8_C(   3), INT8_C( 119), INT8_C(  38), INT8_C( -44),
                           INT8_C( -48), INT8_C( -43), INT8_C(   6), INT8_C(-113),
                           INT8_C(  -5), INT8_C( -18), INT8_C(  58), INT8_C(  77),
                           INT8_C( -49), INT8_C(-107), INT8_C( -77), INT8_C( 119),
                           INT8_C(  -6), INT8_C(  92), INT8_C(-122), INT8_C(  43),
                           INT8_C(  85), INT8_C(-111), INT8_C( -15), INT8_C(  90),
                           INT8_C(-104), INT8_C(  31), INT8_C(  -4), INT8_C(  57)),
      simde_mm512_set_epi8(INT8_C( 110), INT8_C(  61), INT8_C( 109), INT8_C( 109),
                           INT8_C(   0), INT8_C( 109), INT8_C(-111), INT8_C(   0),
                           INT8_C(  -9), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(-123), INT8_C(   0), INT8_C( -59), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(  91), INT8_C(   0),
                           INT8_C( -51), INT8_C( 114), INT8_C(  24), INT8_C(   0),
                           INT8_C(-105), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(  24), INT8_C(   0), INT8_C(   0),
                           INT8_C(  -9), INT8_C( -16), INT8_C(   0), INT8_C(   0),
                           INT8_C(   4), INT8_C( -94), INT8_C( -30), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C( -30), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(  19), INT8_C( -92),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C( -87),
                           INT8_C(   0), INT8_C( 114), INT8_C(   0), INT8_C( 100),
                           INT8_C( -55), INT8_C(   0), INT8_C(   0), INT8_C(  80),
                           INT8_C(   0), INT8_C( 109), INT8_C(   0), INT8_C(  18)) },
    { simde_mm512_set_epi8(INT8_C( -54), INT8_C(  53), INT8_C(  35), INT8_C(  51),
                           INT8_C(  24), INT8_C( 100), INT8_C(  80), INT8_C(   7),
                           INT8_C(  54), INT8_C( 114), INT8_C( -42), INT8_C(  -2),
                           INT8_C(  18), INT8_C( 100), INT8_C(  26), INT8_C( -68),
                           INT8_C(  82), INT8_C( -30), INT8_C(  -4), INT8_C( 110),
                           INT8_C(  24), INT8_C(  88), INT8_C(-100), INT8_C(-120),
                           INT8_C( -17), INT8_C(-109), INT8_C(  92), INT8_C(-105),
                           INT8_C( -20), INT8_C(  34), INT8_C(  98), INT8_C( -17),
                           INT8_C(   2), INT8_C(   6), INT8_C(  37), INT8_C( -85),
                           INT8_C( 118), INT8_C(  28), INT8_C(  34), INT8_C( 117),
                           INT8_C(  77), INT8_C( -32), INT8_C(  25), INT8_C( -74),
                           INT8_C(  93), INT8_C(-108), INT8_C(   3), INT8_C( -90),
                           INT8_C(  13), INT8_C( -29), INT8_C( -88), INT8_C( 116),
                           INT8_C(  14), INT8_C( -29), INT8_C(  30), INT8_C( -26),
                           INT8_C(-115), INT8_C( -36), INT8_C(  94), INT8_C(-125),
                           INT8_C( 118), INT8_C( 125), INT8_C( -91), INT8_C(  31)),
      simde_mm512_set_epi8(INT8_C( -74), INT8_C( -13), INT8_C( -87), INT8_C( -10),
                           INT8_C(  21), INT8_C(  49), INT8_C( -64), INT8_C(  52),
                           INT8_C( -97), INT8_C(-103), INT8_C(-127), INT8_C(  53),
                           INT8_C(  99), INT8_C(  80), INT8_C(  55), INT8_C( 111),
                           INT8_C(  61), INT8_C( -93), INT8_C( -87), INT8_C(  81),
                           INT8_C( 108), INT8_C(  89), INT8_C(  63), INT8_C(-109),
                           INT8_C( -47), INT8_C( -32), INT8_C( 105), INT8_C(  91),
                           INT8_C(  88), INT8_C(  85), INT8_C( -96), INT8_C(  88),
                           INT8_C( -85), INT8_C(   3), INT8_C( 124), INT8_C( -33),
                           INT8_C( -21), INT8_C(  -7), INT8_C( -31), INT8_C(-126),
                           INT8_C(   3), INT8_C( -17), INT8_C(  40), INT8_C(   5),
                           INT8_C( 126), INT8_C( -60), INT8_C( -91), INT8_C(-112),
                           INT8_C(  88), INT8_C(  11), INT8_C( 100), INT8_C( 114),
                           INT8_C( 112), INT8_C( -53), INT8_C(  89), INT8_C(  78),
                           INT8_C( 115), INT8_C( 117), INT8_C( -33), INT8_C(  14),
                           INT8_C( -42), INT8_C( -15), INT8_C(  80), INT8_C( -46)),
      simde_mm512_set_epi8(INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C( -42), INT8_C(  26), INT8_C(   0), INT8_C(  -2),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C( -42),
                           INT8_C(  18), INT8_C( -68), INT8_C(  54), INT8_C( -54),
                           INT8_C(  -4), INT8_C(   0), INT8_C(   0), INT8_C(  98),
                           INT8_C( 110), INT8_C(-100), INT8_C(  82), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(-100), INT8_C(  24),
                           INT8_C(-120), INT8_C(  92), INT8_C(   0), INT8_C(-120),
                           INT8_C(   0), INT8_C(  93), INT8_C( -85), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(  93), INT8_C(   0), INT8_C( 117), INT8_C(  25),
                           INT8_C(   6), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C( -26), INT8_C(  14), INT8_C(-125), INT8_C( 125),
                           INT8_C(  31), INT8_C(   0), INT8_C(  30), INT8_C( -29),
                           INT8_C( 118), INT8_C(  94), INT8_C(   0), INT8_C( -29),
                           INT8_C(   0), INT8_C(   0), INT8_C(  31), INT8_C(   0)) },
    { simde_mm512_set_epi8(INT8_C(-109), INT8_C(  14), INT8_C( -91), INT8_C( -44),
                           INT8_C(  79), INT8_C(  -4), INT8_C(  88), INT8_C(  49),
                           INT8_C( -95), INT8_C( -92), INT8_C(-116), INT8_C(   8),
                           INT8_C(  25), INT8_C(  30), INT8_C( -55), INT8_C(-120),
                           INT8_C( -58), INT8_C( -84), INT8_C(  99), INT8_C( -92),
                           INT8_C( -29), INT8_C( -47), INT8_C(  42), INT8_C( -56),
                           INT8_C( 109), INT8_C( -71), INT8_C( -73), INT8_C( -30),
                           INT8_C( -15), INT8_C(-106), INT8_C( -91), INT8_C( -57),
                           INT8_C(  51), INT8_C(  -8), INT8_C(  55), INT8_C(  36),
                           INT8_C( -55), INT8_C(-103), INT8_C(  51), INT8_C( -28),
                           INT8_C(  70), INT8_C( 114), INT8_C(  -3), INT8_C(  49),
                           INT8_C(  23), INT8_C( -28), INT8_C( -87), INT8_C(  57),
                           INT8_C(  28), INT8_C( -12), INT8_C( -51), INT8_C(  37),
                           INT8_C(  29), INT8_C( -58), INT8_C( -69), INT8_C(  30),
                           INT8_C(  43), INT8_C( -65), INT8_C(  -2), INT8_C( -83),
                           INT8_C( -27), INT8_C(-122), INT8_C(  77), INT8_C(  47)),
      simde_mm512_set_epi8(INT8_C(-116), INT8_C(-127), INT8_C( -95), INT8_C( -97),
                           INT8_C( -78), INT8_C( -53), INT8_C( -36), INT8_C(  62),
                           INT8_C(  63), INT8_C(  28), INT8_C( -37), INT8_C(  40),
                           INT8_C( -14), INT8_C(   2), INT8_C( -65), INT8_C( -67),
                           INT8_C(  79), INT8_C(  51), INT8_C( -51), INT8_C( -64),
                           INT8_C( -40), INT8_C(-102), INT8_C(-107), INT8_C(  82),
                           INT8_C(  20), INT8_C(  54), INT8_C(  66), INT8_C(   7),
                           INT8_C(  33), INT8_C( 108), INT8_C( -88), INT8_C(  69),
                           INT8_C(  98), INT8_C(  43), INT8_C(  25), INT8_C(  58),
                           INT8_C( 117), INT8_C( -34), INT8_C( -70), INT8_C(   3),
                           INT8_C(   1), INT8_C( 100), INT8_C(   3), INT8_C(  14),
                           INT8_C( 117), INT8_C( -91), INT8_C( -89), INT8_C(  66),
                           INT8_C(  32), INT8_C( -35), INT8_C( 104), INT8_C(  65),
                           INT8_C(-100), INT8_C(  27), INT8_C(  42), INT8_C(  91),
                           INT8_C( -47), INT8_C(  39), INT8_C( -65), INT8_C(-124),
                           INT8_C( -84), INT8_C( -95), INT8_C( -46), INT8_C(-113)),
      simde_mm512_set_epi8(INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(  14),
                           INT8_C(-109), INT8_C( -44), INT8_C(   0), INT8_C(  49),
                           INT8_C(   0), INT8_C(  30), INT8_C(   0), INT8_C(   0),
                           INT8_C( -58), INT8_C( -15), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(-106),
                           INT8_C( -30), INT8_C( -71), INT8_C(-106), INT8_C( 109),
                           INT8_C( -91), INT8_C( -92), INT8_C(   0), INT8_C( -73),
                           INT8_C( -28), INT8_C( -55), INT8_C(  51), INT8_C(-103),
                           INT8_C(  -3), INT8_C(   0), INT8_C(   0), INT8_C(  23),
                           INT8_C( -87), INT8_C(  49), INT8_C(  23), INT8_C(  -8),
                           INT8_C(  -3), INT8_C(   0), INT8_C(   0), INT8_C( -28),
                           INT8_C(  47), INT8_C(   0), INT8_C(  30), INT8_C(  77),
                           INT8_C(   0), INT8_C(  29), INT8_C( -58), INT8_C(  29),
                           INT8_C(   0), INT8_C(  43), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0)) },
    { simde_mm512_set_epi8(INT8_C(-119), INT8_C(  55), INT8_C( -13), INT8_C(-118),
                           INT8_C(   5), INT8_C(  14), INT8_C(-103), INT8_C(  58),
                           INT8_C( 109), INT8_C(-113), INT8_C( -44), INT8_C( 126),
                           INT8_C(  70), INT8_C(-126), INT8_C(  24), INT8_C(-117),
                           INT8_C(  80), INT8_C(  25), INT8_C(  64), INT8_C( -89),
                           INT8_C(  60), INT8_C(   5), INT8_C(-119), INT8_C( -29),
                           INT8_C( -95), INT8_C( -26), INT8_C(  25), INT8_C( -65),
                           INT8_C( -81), INT8_C( -84), INT8_C(  46), INT8_C(  62),
                           INT8_C( -25), INT8_C(-116), INT8_C(-126), INT8_C(-103),
                           INT8_C( 126), INT8_C( -39), INT8_C( 111), INT8_C( -10),
                           INT8_C( -48), INT8_C( 122), INT8_C( -86), INT8_C( -25),
                           INT8_C(  35), INT8_C(  -4), INT8_C(  -7), INT8_C(  76),
                           INT8_C(-116), INT8_C(   1), INT8_C( 126), INT8_C( -30),
                           INT8_C( -11), INT8_C(  82), INT8_C(  81), INT8_C(  27),
                           INT8_C( -15), INT8_C( -14), INT8_C(  56), INT8_C(  60),
                           INT8_C( -29), INT8_C( -65), INT8_C( -35), INT8_C(  21)),
      simde_mm512_set_epi8(INT8_C( 125), INT8_C( -43), INT8_C( -42), INT8_C( -51),
                           INT8_C( -36), INT8_C(  38), INT8_C(  42), INT8_C(  18),
                           INT8_C(  24), INT8_C( -25), INT8_C(  19), INT8_C(  15),
                           INT8_C(-119), INT8_C(-124), INT8_C( 104), INT8_C( -93),
                           INT8_C(  22), INT8_C( -16), INT8_C(  31), INT8_C( 116),
                           INT8_C( -99), INT8_C(  45), INT8_C( -54), INT8_C(  50),
                           INT8_C( -72), INT8_C(-107), INT8_C(  48), INT8_C( 118),
                           INT8_C( -68), INT8_C( -15), INT8_C(-108), INT8_C( -29),
                           INT8_C( 118), INT8_C(  96), INT8_C( -51), INT8_C( 107),
                           INT8_C( -23), INT8_C( -97), INT8_C(  -6), INT8_C(  91),
                           INT8_C( -57), INT8_C( -67), INT8_C(-105), INT8_C(  68),
                           INT8_C( -50), INT8_C(  16), INT8_C( -86), INT8_C(   6),
                           INT8_C(  55), INT8_C(-118), INT8_C( 112), INT8_C( 125),
                           INT8_C(  92), INT8_C(  91), INT8_C( -27), INT8_C(  53),
                           INT8_C(  28), INT8_C( -66), INT8_C( -69), INT8_C(-117),
                           INT8_C( -30), INT8_C(-106), INT8_C(   1), INT8_C(  95)),
      simde_mm512_set_epi8(INT8_C( -13), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(-113), INT8_C(  14), INT8_C(-126),
                           INT8_C(  58), INT8_C(   0), INT8_C(  70), INT8_C(-119),
                           INT8_C(   0), INT8_C(   0), INT8_C(  58), INT8_C(   0),
                           INT8_C( -26), INT8_C(   0), INT8_C(  80), INT8_C( -65),
                           INT8_C(   0), INT8_C(  64), INT8_C(   0), INT8_C( -84),
                           INT8_C(   0), INT8_C(   0), INT8_C(  62), INT8_C( -26),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C( 122), INT8_C(  76), INT8_C(   0), INT8_C( 126),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C( 126),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C( -25),
                           INT8_C(   0), INT8_C(  76), INT8_C(   0), INT8_C( 122),
                           INT8_C( -15), INT8_C(   0), INT8_C(  21), INT8_C( 126),
                           INT8_C( -30), INT8_C( -11), INT8_C(   0), INT8_C(  56),
                           INT8_C( -30), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C( -35), INT8_C(-116)) },
    { simde_mm512_set_epi8(INT8_C(  18), INT8_C(-124), INT8_C(  -6), INT8_C( -41),
                           INT8_C(-109), INT8_C(  19), INT8_C(  47), INT8_C(  73),
                           INT8_C( -58), INT8_C( -50), INT8_C(  73), INT8_C( 110),
                           INT8_C(  56), INT8_C( -30), INT8_C( -79), INT8_C( 123),
                           INT8_C(  77), INT8_C(  62), INT8_C( -28), INT8_C(  45),
                           INT8_C( -95), INT8_C(  12), INT8_C(  53), INT8_C(  75),
                           INT8_C(  66), INT8_C( -89), INT8_C(  46), INT8_C( -47),
                           INT8_C(   6), INT8_C(   4), INT8_C( 112), INT8_C( -34),
                           INT8_C( 121), INT8_C(  -3), INT8_C(-102), INT8_C(-115),
                           INT8_C( -12), INT8_C(  80), INT8_C(   3), INT8_C(  56),
                           INT8_C(  85), INT8_C( -43), INT8_C( -93), INT8_C(  34),
                           INT8_C( -58), INT8_C(-101), INT8_C(  51), INT8_C(   1),
                           INT8_C( -18), INT8_C( -90), INT8_C( -71), INT8_C(  74),
                           INT8_C(  -5), INT8_C(-113), INT8_C(  71), INT8_C(  61),
                           INT8_C(  92), INT8_C(  73), INT8_C( 116), INT8_C( 110),
                           INT8_C(-117), INT8_C(  96), INT8_C( -77), INT8_C(  45)),
      simde_mm512_set_epi8(INT8_C(  52), INT8_C( -84), INT8_C( 103), INT8_C(-105),
                           INT8_C( -57), INT8_C(  17), INT8_C(-110), INT8_C(-113),
                           INT8_C(  56), INT8_C( 125), INT8_C(  56), INT8_C( -88),
                           INT8_C( -31), INT8_C( 119), INT8_C( -86), INT8_C( 114),
                           INT8_C( -85), INT8_C(  14), INT8_C(  60), INT8_C(  84),
                           INT8_C( -61), INT8_C(-111), INT8_C(  74), INT8_C( 113),
                           INT8_C(  13), INT8_C( -89), INT8_C(-114), INT8_C( -79),
                           INT8_C( -34), INT8_C( -73), INT8_C(  -9), INT8_C(-108),
                           INT8_C(  93), INT8_C( -78), INT8_C(  -1), INT8_C(-102),
                           INT8_C(  12), INT8_C( 117), INT8_C(  80), INT8_C(  44),
                           INT8_C(  29), INT8_C(  18), INT8_C(  91), INT8_C( -23),
                           INT8_C( 110), INT8_C(-126), INT8_C( -71), INT8_C(  65),
                           INT8_C( -76), INT8_C(  85), INT8_C(  93), INT8_C( -86),
                           INT8_C(-123), INT8_C(-115), INT8_C(-105), INT8_C(  75),
                           INT8_C(  45), INT8_C(  22), INT8_C(  73), INT8_C(  74),
                           INT8_C( 107), INT8_C( -60), INT8_C( -28), INT8_C( -57)),
      simde_mm512_set_epi8(INT8_C( 110), INT8_C(   0), INT8_C( -58), INT8_C(   0),
                           INT8_C(   0), INT8_C( -79), INT8_C(   0), INT8_C(   0),
                           INT8_C(  73), INT8_C(  -6), INT8_C(  73), INT8_C(   0),
                           INT8_C(   0), INT8_C( -58), INT8_C(   0), INT8_C( -30),
                           INT8_C(   0), INT8_C(  62), INT8_C(  45), INT8_C( -47),
                           INT8_C(   0), INT8_C(   0), INT8_C(  12), INT8_C( 112),
                           INT8_C( -28), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(-102), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(-115), INT8_C( -93), INT8_C(   1), INT8_C(-115),
                           INT8_C(-102), INT8_C(-101), INT8_C( -12), INT8_C(   0),
                           INT8_C(  -3), INT8_C(   0), INT8_C(   0), INT8_C(  51),
                           INT8_C(   0), INT8_C( 116), INT8_C( -71), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(  -5),
                           INT8_C( -71), INT8_C(  73), INT8_C(  71), INT8_C(-113),
                           INT8_C(  -5), INT8_C(   0), INT8_C(   0), INT8_C(   0)) },
    { simde_mm512_set_epi8(INT8_C(   4), INT8_C( -30), INT8_C( -68), INT8_C(  57),
                           INT8_C(  73), INT8_C(  25), INT8_C( -45), INT8_C( 112),
                           INT8_C(  41), INT8_C(  41), INT8_C( -56), INT8_C( -93),
                           INT8_C(  29), INT8_C(  99), INT8_C(  15), INT8_C( 122),
                           INT8_C(  74), INT8_C(   0), INT8_C(  89), INT8_C(  61),
                           INT8_C( 124), INT8_C(  36), INT8_C( -87), INT8_C( -25),
                           INT8_C(  42), INT8_C(-125), INT8_C( -87), INT8_C(  69),
                           INT8_C(  81), INT8_C(   4), INT8_C(  55), INT8_C( 107),
                           INT8_C(   0), INT8_C(  -7), INT8_C(  37), INT8_C( -15),
                           INT8_C( 117), INT8_C(   9), INT8_C( -27), INT8_C(  11),
                           INT8_C(  16), INT8_C(  87), INT8_C( 119), INT8_C(-107),
                           INT8_C( -22), INT8_C(  27), INT8_C( -86), INT8_C( -63),
                           INT8_C(  90), INT8_C( -44), INT8_C(-113), INT8_C(-126),
                           INT8_C( -75), INT8_C(  67), INT8_C(  88), INT8_C( 105),
                           INT8_C(  80), INT8_C(   7), INT8_C(  66), INT8_C( 126),
                           INT8_C(  17), INT8_C( -20), INT8_C( -91), INT8_C( -99)),
      simde_mm512_set_epi8(INT8_C( 123), INT8_C( 117), INT8_C(  18), INT8_C(   2),
                           INT8_C(-105), INT8_C( -51), INT8_C(  -9), INT8_C(  72),
                           INT8_C(  69), INT8_C(-116), INT8_C(  95), INT8_C(-110),
                           INT8_C( -32), INT8_C( 110), INT8_C(  -8), INT8_C(  85),
                           INT8_C( -41), INT8_C(  80), INT8_C( -44), INT8_C( 110),
                           INT8_C( -28), INT8_C( 116), INT8_C(  41), INT8_C( -31),
                           INT8_C(  12), INT8_C(  40), INT8_C(   5), INT8_C(   1),
                           INT8_C( -14), INT8_C(  66), INT8_C( -95), INT8_C( 106),
                           INT8_C(  66), INT8_C( -91), INT8_C( -20), INT8_C(-109),
                           INT8_C( -46), INT8_C(  41), INT8_C(  82), INT8_C( -61),
                           INT8_C(   2), INT8_C(   3), INT8_C(  62), INT8_C( -90),
                           INT8_C(  99), INT8_C( -54), INT8_C( -28), INT8_C( -21),
                           INT8_C( 126), INT8_C( 115), INT8_C( -46), INT8_C(  76),
                           INT8_C( -43), INT8_C(  46), INT8_C( 107), INT8_C(  75),
                           INT8_C( -93), INT8_C(  67), INT8_C( -37), INT8_C(   4),
                           INT8_C(-127), INT8_C( -50), INT8_C( -26), INT8_C(  99)),
      simde_mm512_set_epi8(INT8_C(  73), INT8_C( -56), INT8_C(  99), INT8_C(  99),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C( 112),
                           INT8_C( -56), INT8_C(   0), INT8_C(   4), INT8_C(   0),
                           INT8_C(   0), INT8_C( -30), INT8_C(   0), INT8_C( -56),
                           INT8_C(   0), INT8_C( 107), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(  69), INT8_C( -87), INT8_C(   0),
                           INT8_C(  61), INT8_C( -25), INT8_C( -87), INT8_C(  55),
                           INT8_C(   0), INT8_C(   4), INT8_C(   0), INT8_C(  36),
                           INT8_C(  27), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C( -27), INT8_C(  27), INT8_C(   0),
                           INT8_C(  27), INT8_C( -22), INT8_C(  -7), INT8_C(   0),
                           INT8_C( -22), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C( -44), INT8_C(  17), INT8_C(   0), INT8_C(-126),
                           INT8_C(   0), INT8_C( -44), INT8_C( -75), INT8_C( -75),
                           INT8_C(   0), INT8_C(  17), INT8_C(   0), INT8_C( 126),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(  17)) },
    { simde_mm512_set_epi8(INT8_C(  56), INT8_C(  24), INT8_C( -33), INT8_C(  82),
                           INT8_C(  72), INT8_C(  63), INT8_C(-114), INT8_C(  14),
                           INT8_C(   2), INT8_C(  71), INT8_C( -31), INT8_C( -46),
                           INT8_C(  64), INT8_C( -11), INT8_C(  35), INT8_C(  -7),
                           INT8_C( -78), INT8_C( 125), INT8_C( -28), INT8_C( -59),
                           INT8_C(   6), INT8_C(-127), INT8_C(  34), INT8_C(  64),
                           INT8_C(  88), INT8_C( -88), INT8_C(  70), INT8_C( -90),
                           INT8_C(  47), INT8_C( -21), INT8_C(-104), INT8_C( -27),
                           INT8_C( -16), INT8_C( -29), INT8_C(  51), INT8_C(-116),
                           INT8_C( -87), INT8_C(  91), INT8_C(-106), INT8_C(  -3),
                           INT8_C( -55), INT8_C( -15), INT8_C(-109), INT8_C(-108),
                           INT8_C( -41), INT8_C(  79), INT8_C(  54), INT8_C(  68),
                           INT8_C( -51), INT8_C(-108), INT8_C( -83), INT8_C( 104),
                           INT8_C(  18), INT8_C(-128), INT8_C( -75), INT8_C( -12),
                           INT8_C(  56), INT8_C(-104), INT8_C(  56), INT8_C(  47),
                           INT8_C( -30), INT8_C( -15), INT8_C(-115), INT8_C(  88)),
      simde_mm512_set_epi8(INT8_C( 107), INT8_C( 125), INT8_C(-111), INT8_C( -89),
                           INT8_C(  -9), INT8_C( 122), INT8_C(  -2), INT8_C( -26),
                           INT8_C(-100), INT8_C(  80), INT8_C(  89), INT8_C(  38),
                           INT8_C(  95), INT8_C( -82), INT8_C( -66), INT8_C( 108),
                           INT8_C( 104), INT8_C( -20), INT8_C(  72), INT8_C( -82),
                           INT8_C(  23), INT8_C( -45), INT8_C( -20), INT8_C(   8),
                           INT8_C(  -2), INT8_C( -77), INT8_C(-112), INT8_C( 102),
                           INT8_C(  83), INT8_C(  80), INT8_C(  56), INT8_C( -53),
                           INT8_C( -83), INT8_C( -86), INT8_C(  15), INT8_C(  30),
                           INT8_C( -92), INT8_C(  -2), INT8_C(  42), INT8_C( -79),
                           INT8_C( 108), INT8_C(  44), INT8_C(  17), INT8_C(  83),
                           INT8_C( -49), INT8_C( -44), INT8_C( -42), INT8_C( -54),
                           INT8_C(-127), INT8_C(  12), INT8_C(  88), INT8_C(-118),
                           INT8_C( -23), INT8_C( -69), INT8_C( -23), INT8_C( -36),
                           INT8_C( -23), INT8_C( -80), INT8_C(  33), INT8_C(  82),
                           INT8_C( -43), INT8_C( -91), INT8_C( -36), INT8_C( -56)),
      simde_mm512_set_epi8(INT8_C(  72), INT8_C( -33), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(  63), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(  -7), INT8_C(-114), INT8_C(  71),
                           INT8_C(  56), INT8_C(   0), INT8_C(   0), INT8_C(  82),
                           INT8_C(  64), INT8_C(   0), INT8_C(  64), INT8_C(   0),
                           INT8_C(  88), INT8_C(   0), INT8_C(   0), INT8_C(  64),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C( -88),
                           INT8_C(  47), INT8_C( -27), INT8_C(  64), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C( -16), INT8_C( -29),
                           INT8_C(   0), INT8_C(   0), INT8_C(  91), INT8_C(   0),
                           INT8_C(-116), INT8_C(-116), INT8_C(  54), INT8_C( -41),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C( 104), INT8_C( -12), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(-115), INT8_C( -15),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0)) },
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])); i++) {
    simde__m512i r = simde_mm512_shuffle_epi8(test_vec[i].a, test_vec[i].b);
    simde_assert_m512i_i8(r, ==, test_vec[i].r);
  }

  return 0;
}

static int
test_simde_mm512_mask_shuffle_epi8(SIMDE_MUNIT_TEST_ARGS) {
  const struct {
    simde__m512i src;
    simde__mmask64 k;
    simde__m512i a;
    simde__m512i b;
    simde__m512i r;
  } test_vec[8] = {
    { simde_mm512_set_epi8(INT8_C(  92), INT8_C( 116), INT8_C( -78), INT8_C( -19),
                           INT8_C( -73), INT8_C(  22), INT8_C( -66), INT8_C( -29),
                           INT8_C(  55), INT8_C(  78), INT8_C( -45), INT8_C(-119),
                           INT8_C(  30), INT8_C( -29), INT8_C( -23), INT8_C(  89),
                           INT8_C(  15), INT8_C( 119), INT8_C( -88), INT8_C( 109),
                           INT8_C( -16), INT8_C( -10), INT8_C(   0), INT8_C( -18),
                           INT8_C(   1), INT8_C( 116), INT8_C(  62), INT8_C( -73),
                           INT8_C(-122), INT8_C(   0), INT8_C( 111), INT8_C(  95),
                           INT8_C( -20), INT8_C(   3), INT8_C( 122), INT8_C(-121),
                           INT8_C(  13), INT8_C(  25), INT8_C( -35), INT8_C(-127),
                           INT8_C(  82), INT8_C(  90), INT8_C(  53), INT8_C( 123),
                           INT8_C(  73), INT8_C( 108), INT8_C( -18), INT8_C(  15),
                           INT8_C(  81), INT8_C( -27), INT8_C( 102), INT8_C( 118),
                           INT8_C(  39), INT8_C( -77), INT8_C(  45), INT8_C(  81),
                           INT8_C( -17), INT8_C( -28), INT8_C(  67), INT8_C(-118),
                           INT8_C(  79), INT8_C(-113), INT8_C(-122), INT8_C( 124)),
      UINT64_C(10224647434006242820),
      simde_mm512_set_epi8(INT8_C(  68), INT8_C(-108), INT8_C(-121), INT8_C(-115),
                           INT8_C( -59), INT8_C( -78), INT8_C(-111), INT8_C(  56),
                           INT8_C(   9), INT8_C(-121), INT8_C( 120), INT8_C( -36),
                           INT8_C(  36), INT8_C(-103), INT8_C(-104), INT8_C(  25),
                           INT8_C(-111), INT8_C( -63), INT8_C( -35), INT8_C(-120),
                           INT8_C(  28), INT8_C( -44), INT8_C( -26), INT8_C( -86),
                           INT8_C( -13), INT8_C(  53), INT8_C( -88), INT8_C(-107),
                           INT8_C(  68), INT8_C(  42), INT8_C(-118), INT8_C( 111),
                           INT8_C(  54), INT8_C( -58), INT8_C( -13), INT8_C(  27),
                           INT8_C(  23), INT8_C(  41), INT8_C(-119), INT8_C(  44),
                           INT8_C(   7), INT8_C(-120), INT8_C(  32), INT8_C( -43),
                           INT8_C( 114), INT8_C( -72), INT8_C(  73), INT8_C( -96),
                           INT8_C(  96), INT8_C( 110), INT8_C( -81), INT8_C( -76),
                           INT8_C( 103), INT8_C(-100), INT8_C( -22), INT8_C(  18),
                           INT8_C( 115), INT8_C(  54), INT8_C( -40), INT8_C( 125),
                           INT8_C( 110), INT8_C(  31), INT8_C(  51), INT8_C(-104)),
      simde_mm512_set_epi8(INT8_C( -14), INT8_C(  85), INT8_C( -80), INT8_C(  80),
                           INT8_C(  48), INT8_C(  93), INT8_C(  79), INT8_C( 127),
                           INT8_C(  16), INT8_C(  41), INT8_C(  54), INT8_C(-116),
                           INT8_C(  17), INT8_C(  42), INT8_C( -86), INT8_C(  38),
                           INT8_C(-118), INT8_C( -56), INT8_C(  60), INT8_C(  19),
                           INT8_C(-100), INT8_C(-107), INT8_C( 105), INT8_C( -76),
                           INT8_C(  10), INT8_C(  -9), INT8_C( -12), INT8_C( -56),
                           INT8_C( -71), INT8_C(  96), INT8_C(   6), INT8_C(  24),
                           INT8_C(  69), INT8_C(  73), INT8_C( -27), INT8_C(   3),
                           INT8_C( -95), INT8_C(  50), INT8_C( -67), INT8_C( -39),
                           INT8_C(  97), INT8_C(  62), INT8_C( 101), INT8_C(  56),
                           INT8_C( -79), INT8_C(  83), INT8_C( -99), INT8_C( -56),
                           INT8_C( -17), INT8_C( -56), INT8_C(  -8), INT8_C( -16),
                           INT8_C(  84), INT8_C( -95), INT8_C( -73), INT8_C(  54),
                           INT8_C( 125), INT8_C(  85), INT8_C(  78), INT8_C( -65),
                           INT8_C(   4), INT8_C( 113), INT8_C( -16), INT8_C( -53)),
      simde_mm512_set_epi8(INT8_C(   0), INT8_C( 116), INT8_C( -78), INT8_C( -19),
                           INT8_C(  25), INT8_C(-121), INT8_C( -66), INT8_C(  68),
                           INT8_C(  25), INT8_C(-111), INT8_C(-121), INT8_C(-119),
                           INT8_C(  30), INT8_C( -78), INT8_C( -23), INT8_C(-121),
                           INT8_C(  15), INT8_C( 119), INT8_C(-120), INT8_C(  68),
                           INT8_C(   0), INT8_C(   0), INT8_C( -26), INT8_C( -18),
                           INT8_C( -44), INT8_C( 116), INT8_C(   0), INT8_C( -73),
                           INT8_C(   0), INT8_C(   0), INT8_C(  53), INT8_C( -86),
                           INT8_C( -20), INT8_C(   3), INT8_C(   0), INT8_C( 114),
                           INT8_C(  13), INT8_C(  25), INT8_C( -35), INT8_C(   0),
                           INT8_C(  73), INT8_C(  90), INT8_C(  53), INT8_C( 123),
                           INT8_C(   0), INT8_C( 114), INT8_C( -18), INT8_C(   0),
                           INT8_C(  81), INT8_C( -27), INT8_C(   0), INT8_C( 118),
                           INT8_C(  39), INT8_C(   0), INT8_C(   0), INT8_C(  81),
                           INT8_C( -17), INT8_C( -28), INT8_C(  67), INT8_C(-118),
                           INT8_C(  79), INT8_C(  51), INT8_C(-122), INT8_C( 124)) },
    { simde_mm512_set_epi8(INT8_C(-123), INT8_C(-100), INT8_C( -39), INT8_C( -44),
                           INT8_C(  22), INT8_C( 112), INT8_C(  16), INT8_C(  15),
                           INT8_C(-104), INT8_C(-102), INT8_C( 102), INT8_C( -95),
                           INT8_C(  69), INT8_C(  13), INT8_C( -21), INT8_C(  45),
                           INT8_C(  62), INT8_C(-120), INT8_C(-111), INT8_C(  32),
                           INT8_C(-107), INT8_C( -30), INT8_C(  99), INT8_C( -64),
                           INT8_C(   8), INT8_C( -42), INT8_C(  81), INT8_C( -34),
                           INT8_C( -46), INT8_C(  26), INT8_C(  31), INT8_C(  -2),
                           INT8_C(  68), INT8_C(  -7), INT8_C( -71), INT8_C(  46),
                           INT8_C( -21), INT8_C( -73), INT8_C(  21), INT8_C(  83),
                           INT8_C(-108), INT8_C( -97), INT8_C( -69), INT8_C(  73),
                           INT8_C(  57), INT8_C( -37), INT8_C(  21), INT8_C(  82),
                           INT8_C(-119), INT8_C(-126), INT8_C( 126), INT8_C(  91),
                           INT8_C( 115), INT8_C(  31), INT8_C( -79), INT8_C(  28),
                           INT8_C(-106), INT8_C( -18), INT8_C(  65), INT8_C(-104),
                           INT8_C(  81), INT8_C(  38), INT8_C( -84), INT8_C(  -2)),
      UINT64_C( 4597426592773770833),
      simde_mm512_set_epi8(INT8_C(  74), INT8_C(  72), INT8_C(  -4), INT8_C(  28),
                           INT8_C(-115), INT8_C(  93), INT8_C( 102), INT8_C(  44),
                           INT8_C(-103), INT8_C( -29), INT8_C( -50), INT8_C(  48),
                           INT8_C( -96), INT8_C( -50), INT8_C(  46), INT8_C( -65),
                           INT8_C(   4), INT8_C(  43), INT8_C( -75), INT8_C(  97),
                           INT8_C( -26), INT8_C(-103), INT8_C(  71), INT8_C(-107),
                           INT8_C(  91), INT8_C(  45), INT8_C( -11), INT8_C(  47),
                           INT8_C(  29), INT8_C(  25), INT8_C(  26), INT8_C(  -9),
                           INT8_C(  10), INT8_C(  36), INT8_C( -79), INT8_C( -53),
                           INT8_C(  41), INT8_C(   1), INT8_C( -23), INT8_C( -63),
                           INT8_C(-127), INT8_C(  68), INT8_C(  48), INT8_C(  36),
                           INT8_C(  89), INT8_C(-112), INT8_C( -31), INT8_C( 120),
                           INT8_C(  35), INT8_C(  62), INT8_C( -21), INT8_C(-114),
                           INT8_C(-104), INT8_C(  57), INT8_C(  42), INT8_C(-111),
                           INT8_C(  94), INT8_C( -63), INT8_C(  -9), INT8_C(  64),
                           INT8_C( -65), INT8_C(  -2), INT8_C( 110), INT8_C(  -8)),
      simde_mm512_set_epi8(INT8_C(  44), INT8_C( -92), INT8_C( -31), INT8_C(  26),
                           INT8_C( -99), INT8_C( -53), INT8_C( 117), INT8_C(  18),
                           INT8_C( -63), INT8_C(  45), INT8_C(  12), INT8_C(  24),
                           INT8_C(-108), INT8_C(  18), INT8_C( -60), INT8_C(  28),
                           INT8_C(  50), INT8_C( -11), INT8_C( -68), INT8_C( -31),
                           INT8_C( 105), INT8_C(-106), INT8_C(  98), INT8_C(  51),
                           INT8_C(  58), INT8_C( 103), INT8_C( 111), INT8_C(-127),
                           INT8_C(  68), INT8_C( -56), INT8_C( 124), INT8_C(-119),
                           INT8_C(  74), INT8_C( -62), INT8_C(-116), INT8_C(  37),
                           INT8_C( -12), INT8_C( 114), INT8_C(   0), INT8_C(  61),
                           INT8_C( 103), INT8_C(  -4), INT8_C(-105), INT8_C( -68),
                           INT8_C(  39), INT8_C(-100), INT8_C( -93), INT8_C(  11),
                           INT8_C( -80), INT8_C( -19), INT8_C( -22), INT8_C( -39),
                           INT8_C( 127), INT8_C( -38), INT8_C(-125), INT8_C(-111),
                           INT8_C(  84), INT8_C( -96), INT8_C(  87), INT8_C( -22),
                           INT8_C(  -5), INT8_C(  -3), INT8_C(-127), INT8_C(  41)),
      simde_mm512_set_epi8(INT8_C(-123), INT8_C(-100), INT8_C(   0), INT8_C(  93),
                           INT8_C(   0), INT8_C(   0), INT8_C( -50), INT8_C( -50),
                           INT8_C(   0), INT8_C(  -4), INT8_C( 102), INT8_C( -95),
                           INT8_C(   0), INT8_C( -50), INT8_C( -21), INT8_C(  28),
                           INT8_C(  62), INT8_C(   0), INT8_C(-111), INT8_C(   0),
                           INT8_C(-107), INT8_C(   0), INT8_C(  25), INT8_C(  29),
                           INT8_C(   8), INT8_C( -42), INT8_C(   4), INT8_C( -34),
                           INT8_C( -46), INT8_C(  26), INT8_C(  31), INT8_C(  -2),
                           INT8_C(   1), INT8_C(  -7), INT8_C(   0), INT8_C(  48),
                           INT8_C(   0), INT8_C(-112), INT8_C( 120), INT8_C( -79),
                           INT8_C(-108), INT8_C( -97), INT8_C(   0), INT8_C(   0),
                           INT8_C(  57), INT8_C(   0), INT8_C(   0), INT8_C(  41),
                           INT8_C(-119), INT8_C(-126), INT8_C( 126), INT8_C(  91),
                           INT8_C(  35), INT8_C(   0), INT8_C(   0), INT8_C(  28),
                           INT8_C(-106), INT8_C(   0), INT8_C(  65), INT8_C(   0),
                           INT8_C(  81), INT8_C(  38), INT8_C( -84), INT8_C(  42)) },
    { simde_mm512_set_epi8(INT8_C( -30), INT8_C( -37), INT8_C(  51), INT8_C( -36),
                           INT8_C(   8), INT8_C(  52), INT8_C(  97), INT8_C( 123),
                           INT8_C( -49), INT8_C(-124), INT8_C(  95), INT8_C( -83),
                           INT8_C(  70), INT8_C( -50), INT8_C( -61), INT8_C(  25),
                           INT8_C( -97), INT8_C(  28), INT8_C( -58), INT8_C(  11),
                           INT8_C( -14), INT8_C( 126), INT8_C(  81), INT8_C(  45),
                           INT8_C( -23), INT8_C( 120), INT8_C( -83), INT8_C( -16),
                           INT8_C(   7), INT8_C(  51), INT8_C( -57), INT8_C( -50),
                           INT8_C( -21), INT8_C(  98), INT8_C(  88), INT8_C(   0),
                           INT8_C( -66), INT8_C(   3), INT8_C( 124), INT8_C(-113),
                           INT8_C(  50), INT8_C(  88), INT8_C( -85), INT8_C( -93),
                           INT8_C( -44), INT8_C( -13), INT8_C( -94), INT8_C(  17),
                           INT8_C(  -2), INT8_C(  79), INT8_C(-116), INT8_C(  43),
                           INT8_C( -77), INT8_C(-125), INT8_C( -23), INT8_C(-120),
                           INT8_C(  96), INT8_C( -64), INT8_C( -23), INT8_C( -46),
                           INT8_C( -29), INT8_C( -71), INT8_C(  71), INT8_C(  90)),
      UINT64_C(12627002542648829104),
      simde_mm512_set_epi8(INT8_C(  56), INT8_C( -45), INT8_C(-108), INT8_C( -19),
                           INT8_C(-124), INT8_C( -27), INT8_C(  22), INT8_C( 126),
                           INT8_C(-106), INT8_C( -68), INT8_C( -60), INT8_C(   8),
                           INT8_C(  60), INT8_C(  93), INT8_C( -33), INT8_C( -27),
                           INT8_C(  -7), INT8_C(  27), INT8_C(-122), INT8_C( -38),
                           INT8_C(  23), INT8_C(   6), INT8_C(  45), INT8_C( -21),
                           INT8_C( -23), INT8_C(-101), INT8_C( 116), INT8_C( 127),
                           INT8_C(  96), INT8_C(  40), INT8_C( -97), INT8_C(  40),
                           INT8_C(  86), INT8_C( -44), INT8_C(  70), INT8_C( -71),
                           INT8_C(  62), INT8_C( -21), INT8_C(  66), INT8_C(  68),
                           INT8_C( -87), INT8_C( -61), INT8_C(  48), INT8_C( -70),
                           INT8_C(  18), INT8_C( -78), INT8_C( -98), INT8_C( 117),
                           INT8_C(  74), INT8_C(  32), INT8_C(  93), INT8_C( 125),
                           INT8_C( -47), INT8_C( -60), INT8_C( -86), INT8_C( 117),
                           INT8_C( 122), INT8_C( -54), INT8_C(  50), INT8_C( 123),
                           INT8_C( -31), INT8_C( -74), INT8_C( -64), INT8_C(  54)),
      simde_mm512_set_epi8(INT8_C( 115), INT8_C(  51), INT8_C( -91), INT8_C(  56),
                           INT8_C(  64), INT8_C( -39), INT8_C(-119), INT8_C( -28),
                           INT8_C( -54), INT8_C(  28), INT8_C(  54), INT8_C(  -8),
                           INT8_C( -54), INT8_C(-128), INT8_C( -28), INT8_C( -71),
                           INT8_C( 107), INT8_C( -66), INT8_C(-114), INT8_C( -88),
                           INT8_C(  34), INT8_C( -83), INT8_C( -21), INT8_C( -64),
                           INT8_C( 121), INT8_C( -20), INT8_C( -89), INT8_C( -94),
                           INT8_C( 112), INT8_C( -27), INT8_C(  81), INT8_C( -54),
                           INT8_C( -64), INT8_C(-114), INT8_C(  48), INT8_C( -89),
                           INT8_C( -61), INT8_C(  26), INT8_C(  43), INT8_C(  29),
                           INT8_C(   0), INT8_C(  64), INT8_C( 123), INT8_C( -67),
                           INT8_C(  15), INT8_C( 120), INT8_C(  36), INT8_C(  40),
                           INT8_C( 106), INT8_C(-118), INT8_C(-108), INT8_C( -58),
                           INT8_C(  26), INT8_C(-111), INT8_C(  63), INT8_C( -98),
                           INT8_C( -13), INT8_C( -12), INT8_C(-124), INT8_C(  96),
                           INT8_C( -13), INT8_C( -98), INT8_C(  99), INT8_C( -13)),
      simde_mm512_set_epi8(INT8_C(  60), INT8_C( -37), INT8_C(   0), INT8_C( -36),
                           INT8_C( -27), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C( -49), INT8_C(-124), INT8_C( -68), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C( -61), INT8_C(  25),
                           INT8_C( -97), INT8_C(  28), INT8_C( -58), INT8_C(   0),
                           INT8_C(  40), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(  45), INT8_C(   0), INT8_C(   0), INT8_C( -16),
                           INT8_C(  40), INT8_C(  51), INT8_C( -57), INT8_C(   0),
                           INT8_C( -21), INT8_C(   0), INT8_C( 117), INT8_C(   0),
                           INT8_C(   0), INT8_C( -21), INT8_C( 124), INT8_C(-113),
                           INT8_C( 117), INT8_C(  88), INT8_C( -85), INT8_C( -93),
                           INT8_C(  86), INT8_C( -13), INT8_C( -94), INT8_C(  68),
                           INT8_C( -60), INT8_C(  79), INT8_C(   0), INT8_C(  43),
                           INT8_C( -77), INT8_C(   0), INT8_C( -23), INT8_C(-120),
                           INT8_C(   0), INT8_C( -64), INT8_C(   0), INT8_C(  54),
                           INT8_C( -29), INT8_C( -71), INT8_C(  71), INT8_C(  90)) },
    { simde_mm512_set_epi8(INT8_C(  72), INT8_C(  45), INT8_C( 120), INT8_C(  -5),
                           INT8_C(-109), INT8_C(  62), INT8_C(  17), INT8_C(  31),
                           INT8_C( -30), INT8_C( -58), INT8_C(  56), INT8_C(  21),
                           INT8_C(  72), INT8_C( -74), INT8_C( -40), INT8_C( 120),
                           INT8_C(  95), INT8_C( 108), INT8_C(  32), INT8_C(  64),
                           INT8_C(-128), INT8_C( 102), INT8_C( -21), INT8_C(  28),
                           INT8_C( 105), INT8_C(  52), INT8_C(  85), INT8_C(-104),
                           INT8_C(  57), INT8_C( -31), INT8_C( -38), INT8_C(-124),
                           INT8_C(-107), INT8_C(  -2), INT8_C(  55), INT8_C(  46),
                           INT8_C( -71), INT8_C(  77), INT8_C(  18), INT8_C(  70),
                           INT8_C(  89), INT8_C( 125), INT8_C( -42), INT8_C(-125),
                           INT8_C( 121), INT8_C( -11), INT8_C( -69), INT8_C( -59),
                           INT8_C( -53), INT8_C(  34), INT8_C(   9), INT8_C(  64),
                           INT8_C( -61), INT8_C( -25), INT8_C(-115), INT8_C( 100),
                           INT8_C(  65), INT8_C(   8), INT8_C(  69), INT8_C(  -8),
                           INT8_C( -15), INT8_C( -51), INT8_C(   1), INT8_C(  90)),
      UINT64_C(14515151237088493607),
      simde_mm512_set_epi8(INT8_C( -26), INT8_C(  -9), INT8_C(  66), INT8_C(   1),
                           INT8_C( -13), INT8_C(  60), INT8_C(-119), INT8_C( -83),
                           INT8_C(-122), INT8_C( -64), INT8_C( -83), INT8_C( -74),
                           INT8_C( 119), INT8_C(  -8), INT8_C(  12), INT8_C( 113),
                           INT8_C( -12), INT8_C( -84), INT8_C(   6), INT8_C(  69),
                           INT8_C(   2), INT8_C( -75), INT8_C( -34), INT8_C(-126),
                           INT8_C(   3), INT8_C(-128), INT8_C(  -9), INT8_C(  24),
                           INT8_C(  11), INT8_C( -94), INT8_C( -32), INT8_C( 110),
                           INT8_C(  33), INT8_C( -24), INT8_C( 125), INT8_C(  35),
                           INT8_C(-103), INT8_C( -48), INT8_C( -22), INT8_C(  38),
                           INT8_C( -81), INT8_C(   9), INT8_C( -11), INT8_C(-124),
                           INT8_C(  71), INT8_C(  31), INT8_C( -42), INT8_C(  93),
                           INT8_C(  67), INT8_C(  45), INT8_C(  51), INT8_C( -92),
                           INT8_C( 126), INT8_C( 108), INT8_C(-123), INT8_C( -71),
                           INT8_C( 113), INT8_C(  32), INT8_C(  71), INT8_C(  55),
                           INT8_C( -26), INT8_C(  82), INT8_C( -81), INT8_C( -20)),
      simde_mm512_set_epi8(INT8_C(-125), INT8_C( 121), INT8_C(-128), INT8_C( 103),
                           INT8_C(   0), INT8_C( 101), INT8_C( -41), INT8_C(  89),
                           INT8_C( -83), INT8_C( -65), INT8_C(   9), INT8_C(  -7),
                           INT8_C( -63), INT8_C(  13), INT8_C( 105), INT8_C(  92),
                           INT8_C( -18), INT8_C( -21), INT8_C(-102), INT8_C(-114),
                           INT8_C(  74), INT8_C( 121), INT8_C( -45), INT8_C(  52),
                           INT8_C( -63), INT8_C( -93), INT8_C(  98), INT8_C( 106),
                           INT8_C(-109), INT8_C( -47), INT8_C(  37), INT8_C(  70),
                           INT8_C( 100), INT8_C( 121), INT8_C(  18), INT8_C(  28),
                           INT8_C(-117), INT8_C( 107), INT8_C(   3), INT8_C( -62),
                           INT8_C(  42), INT8_C(  72), INT8_C(  91), INT8_C(  86),
                           INT8_C( -72), INT8_C(   9), INT8_C( -80), INT8_C( 118),
                           INT8_C( 122), INT8_C(-108), INT8_C( -70), INT8_C( -63),
                           INT8_C(  56), INT8_C(  71), INT8_C( -14), INT8_C(  49),
                           INT8_C( -73), INT8_C(  53), INT8_C( -29), INT8_C(   3),
                           INT8_C( -73), INT8_C(  43), INT8_C( -22), INT8_C(  85)),
      simde_mm512_set_epi8(INT8_C(   0), INT8_C(-119), INT8_C( 120), INT8_C(  -5),
                           INT8_C( 113), INT8_C(  62), INT8_C(  17), INT8_C(-119),
                           INT8_C( -30), INT8_C(   0), INT8_C(-119), INT8_C(   0),
                           INT8_C(  72), INT8_C( -74), INT8_C( -40), INT8_C( 120),
                           INT8_C(  95), INT8_C( 108), INT8_C(   0), INT8_C(  64),
                           INT8_C( -75), INT8_C( -34), INT8_C( -21), INT8_C(  24),
                           INT8_C( 105), INT8_C(  52), INT8_C( -94), INT8_C(-104),
                           INT8_C(  57), INT8_C(   0), INT8_C( -38), INT8_C(-128),
                           INT8_C(-107), INT8_C( -22), INT8_C(  55), INT8_C(  46),
                           INT8_C( -71), INT8_C(  77), INT8_C(  71), INT8_C(   0),
                           INT8_C( -48), INT8_C( 125), INT8_C(-103), INT8_C(   9),
                           INT8_C(   0), INT8_C( -11), INT8_C(   0), INT8_C(   9),
                           INT8_C( -53), INT8_C(   0), INT8_C(   9), INT8_C(  64),
                           INT8_C( -61), INT8_C( -25), INT8_C(-115), INT8_C( 100),
                           INT8_C(  65), INT8_C(   8), INT8_C(   0), INT8_C(  -8),
                           INT8_C( -15), INT8_C( 126), INT8_C(   0), INT8_C(  71)) },
    { simde_mm512_set_epi8(INT8_C( -47), INT8_C(  84), INT8_C(-126), INT8_C( -64),
                           INT8_C(  14), INT8_C(  11), INT8_C(  37), INT8_C( -23),
                           INT8_C(  67), INT8_C( 124), INT8_C(  58), INT8_C( -94),
                           INT8_C(  30), INT8_C( -33), INT8_C(  70), INT8_C( -24),
                           INT8_C(  38), INT8_C( -97), INT8_C( -56), INT8_C( -60),
                           INT8_C( -59), INT8_C(  65), INT8_C( -74), INT8_C(  45),
                           INT8_C( -11), INT8_C(  55), INT8_C( -82), INT8_C(  12),
                           INT8_C( 106), INT8_C(  22), INT8_C(-124), INT8_C(  -4),
                           INT8_C(   2), INT8_C( -81), INT8_C(  14), INT8_C(  90),
                           INT8_C(-100), INT8_C(-122), INT8_C( -35), INT8_C(  81),
                           INT8_C( -14), INT8_C( -42), INT8_C( 125), INT8_C(-125),
                           INT8_C( -57), INT8_C(  90), INT8_C(  -9), INT8_C(  63),
                           INT8_C(  53), INT8_C(  77), INT8_C(  63), INT8_C( -84),
                           INT8_C(  27), INT8_C(  22), INT8_C(   3), INT8_C( -37),
                           INT8_C(  65), INT8_C( 118), INT8_C(-126), INT8_C(  97),
                           INT8_C( 109), INT8_C(   7), INT8_C(-114), INT8_C( -75)),
      UINT64_C( 8707623543556880126),
      simde_mm512_set_epi8(INT8_C(  84), INT8_C( -71), INT8_C(   8), INT8_C(  12),
                           INT8_C( -11), INT8_C( -76), INT8_C(  62), INT8_C(  93),
                           INT8_C( -75), INT8_C( -77), INT8_C( -84), INT8_C(-108),
                           INT8_C( -35), INT8_C(  14), INT8_C( -60), INT8_C(  18),
                           INT8_C(  23), INT8_C( -60), INT8_C( -63), INT8_C(-114),
                           INT8_C( -55), INT8_C(  75), INT8_C( -99), INT8_C( -55),
                           INT8_C(  58), INT8_C(  76), INT8_C(-102), INT8_C(-118),
                           INT8_C( -30), INT8_C(  39), INT8_C( 119), INT8_C(  85),
                           INT8_C(  -8), INT8_C( -72), INT8_C( -60), INT8_C( -94),
                           INT8_C(-112), INT8_C( 119), INT8_C( 124), INT8_C(  76),
                           INT8_C( -42), INT8_C(-124), INT8_C(  54), INT8_C(  74),
                           INT8_C( -92), INT8_C(  99), INT8_C(  79), INT8_C(  -3),
                           INT8_C(  61), INT8_C( -89), INT8_C(  84), INT8_C( -94),
                           INT8_C(  31), INT8_C(-116), INT8_C( -67), INT8_C(-102),
                           INT8_C( -72), INT8_C( -91), INT8_C(-105), INT8_C(-108),
                           INT8_C( -44), INT8_C(  74), INT8_C( -28), INT8_C( 124)),
      simde_mm512_set_epi8(INT8_C(   1), INT8_C(  75), INT8_C(  21), INT8_C( -36),
                           INT8_C(-126), INT8_C( 122), INT8_C(  71), INT8_C(  76),
                           INT8_C(  28), INT8_C( -56), INT8_C(  32), INT8_C( 101),
                           INT8_C(-107), INT8_C(-111), INT8_C( -88), INT8_C( -19),
                           INT8_C( -77), INT8_C(  19), INT8_C( -21), INT8_C(-111),
                           INT8_C( -68), INT8_C(  82), INT8_C(-118), INT8_C( -76),
                           INT8_C(  47), INT8_C( 127), INT8_C(  62), INT8_C( -16),
                           INT8_C(  10), INT8_C( -14), INT8_C(-100), INT8_C(  86),
                           INT8_C(  29), INT8_C( 107), INT8_C(  56), INT8_C(  21),
                           INT8_C(  24), INT8_C(  68), INT8_C( -96), INT8_C(  64),
                           INT8_C(  48), INT8_C(  13), INT8_C( -83), INT8_C(   4),
                           INT8_C(  -3), INT8_C( -64), INT8_C(  17), INT8_C(-115),
                           INT8_C(  21), INT8_C( 108), INT8_C( 125), INT8_C( -60),
                           INT8_C( -72), INT8_C(  74), INT8_C(  -5), INT8_C( -58),
                           INT8_C( -41), INT8_C(  22), INT8_C(-115), INT8_C( 102),
                           INT8_C(  59), INT8_C( -80), INT8_C( -15), INT8_C( -63)),
      simde_mm512_set_epi8(INT8_C( -47), INT8_C( -11), INT8_C( -84), INT8_C(   0),
                           INT8_C(   0), INT8_C(  11), INT8_C(  37), INT8_C( -23),
                           INT8_C(  12), INT8_C(   0), INT8_C(  58), INT8_C( -84),
                           INT8_C(  30), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C( -97), INT8_C(   0), INT8_C(   0),
                           INT8_C( -59), INT8_C(  65), INT8_C( -74), INT8_C(   0),
                           INT8_C( -11), INT8_C(  23), INT8_C( -60), INT8_C(   0),
                           INT8_C(  75), INT8_C(  22), INT8_C(   0), INT8_C(  -4),
                           INT8_C(   2), INT8_C(-112), INT8_C(  14), INT8_C(  54),
                           INT8_C(-100), INT8_C(  74), INT8_C(   0), INT8_C(  -3),
                           INT8_C(  -3), INT8_C( -42), INT8_C( 125), INT8_C(-125),
                           INT8_C(   0), INT8_C(  90), INT8_C(  -9), INT8_C(   0),
                           INT8_C(  53), INT8_C(  77), INT8_C(  84), INT8_C(   0),
                           INT8_C(  27), INT8_C(-116), INT8_C(   0), INT8_C( -37),
                           INT8_C(   0), INT8_C( -91), INT8_C(   0), INT8_C( -91),
                           INT8_C(  31), INT8_C(   0), INT8_C(   0), INT8_C( -75)) },
    { simde_mm512_set_epi8(INT8_C( -64), INT8_C( -53), INT8_C( -42), INT8_C( 126),
                           INT8_C(  67), INT8_C(  50), INT8_C( -18), INT8_C(  76),
                           INT8_C( -19), INT8_C( 123), INT8_C( -87), INT8_C( 106),
                           INT8_C( -74), INT8_C(  44), INT8_C( 117), INT8_C( 103),
                           INT8_C(  81), INT8_C( 122), INT8_C(  56), INT8_C( -10),
                           INT8_C(  67), INT8_C(  79), INT8_C(  83), INT8_C( -38),
                           INT8_C( -13), INT8_C(  43), INT8_C(  27), INT8_C( -97),
                           INT8_C( 102), INT8_C( 126), INT8_C(  38), INT8_C( -62),
                           INT8_C( -24), INT8_C( 117), INT8_C( -38), INT8_C( -93),
                           INT8_C( -58), INT8_C(-124), INT8_C( -75), INT8_C(  10),
                           INT8_C(  18), INT8_C( -74), INT8_C(  14), INT8_C(  36),
                           INT8_C(  -7), INT8_C( 113), INT8_C(  40), INT8_C(  48),
                           INT8_C(-107), INT8_C( -34), INT8_C( -75), INT8_C(  85),
                           INT8_C( -35), INT8_C(-116), INT8_C(  65), INT8_C( -21),
                           INT8_C(  15), INT8_C(   3), INT8_C(  45), INT8_C(  21),
                           INT8_C(  72), INT8_C(  93), INT8_C( 108), INT8_C( 125)),
      UINT64_C(12576710173448868104),
      simde_mm512_set_epi8(INT8_C(  90), INT8_C( -38), INT8_C( -98), INT8_C( -70),
                           INT8_C(-108), INT8_C(  20), INT8_C(  43), INT8_C(-128),
                           INT8_C(  77), INT8_C( 108), INT8_C(  53), INT8_C(  82),
                           INT8_C( -50), INT8_C(  52), INT8_C(  56), INT8_C(  58),
                           INT8_C(-120), INT8_C( -43), INT8_C( 114), INT8_C(  93),
                           INT8_C( -44), INT8_C( -15), INT8_C(  38), INT8_C( -17),
                           INT8_C(-110), INT8_C(-123), INT8_C( -39), INT8_C( 114),
                           INT8_C(  51), INT8_C(-115), INT8_C( -74), INT8_C(  43),
                           INT8_C(  41), INT8_C( -36), INT8_C(  19), INT8_C(  69),
                           INT8_C(  60), INT8_C( -53), INT8_C( 112), INT8_C( 108),
                           INT8_C(   8), INT8_C(  46), INT8_C( -35), INT8_C(  26),
                           INT8_C(  11), INT8_C(  42), INT8_C(  47), INT8_C(  59),
                           INT8_C( -57), INT8_C(  94), INT8_C(-125), INT8_C(-124),
                           INT8_C(  36), INT8_C(  57), INT8_C(  68), INT8_C( -52),
                           INT8_C(  39), INT8_C(  50), INT8_C( -48), INT8_C(  94),
                           INT8_C(  53), INT8_C(  11), INT8_C(  29), INT8_C(  65)),
      simde_mm512_set_epi8(INT8_C(-107), INT8_C( 120), INT8_C( -58), INT8_C( 107),
                           INT8_C( -32), INT8_C( -32), INT8_C(  88), INT8_C( -43),
                           INT8_C(  31), INT8_C( -32), INT8_C( -64), INT8_C(  27),
                           INT8_C(  82), INT8_C( -90), INT8_C( -54), INT8_C( -84),
                           INT8_C( -30), INT8_C(  63), INT8_C(  24), INT8_C(  81),
                           INT8_C(  -8), INT8_C(   9), INT8_C( -35), INT8_C(-101),
                           INT8_C(  83), INT8_C( 107), INT8_C( -47), INT8_C( -56),
                           INT8_C(  57), INT8_C( -88), INT8_C(-115), INT8_C( -20),
                           INT8_C(  58), INT8_C(  75), INT8_C(  56), INT8_C(  93),
                           INT8_C(  49), INT8_C(  43), INT8_C( 108), INT8_C( 118),
                           INT8_C( -79), INT8_C( 112), INT8_C(  44), INT8_C(-112),
                           INT8_C( -52), INT8_C(  10), INT8_C(  28), INT8_C( -86),
                           INT8_C(  65), INT8_C(  62), INT8_C(  86), INT8_C(-107),
                           INT8_C(  24), INT8_C( -55), INT8_C(  54), INT8_C(-110),
                           INT8_C( -33), INT8_C( 110), INT8_C(-116), INT8_C( -39),
                           INT8_C(  39), INT8_C(-112), INT8_C(  64), INT8_C(  43)),
      simde_mm512_set_epi8(INT8_C(   0), INT8_C( -53), INT8_C(   0), INT8_C( 126),
                           INT8_C(   0), INT8_C(   0), INT8_C(-128), INT8_C(  76),
                           INT8_C(  90), INT8_C( 123), INT8_C( -87), INT8_C( 106),
                           INT8_C(  52), INT8_C(  44), INT8_C( 117), INT8_C(   0),
                           INT8_C(  81), INT8_C(-120), INT8_C( -17), INT8_C( -74),
                           INT8_C(  67), INT8_C(  79), INT8_C(   0), INT8_C(   0),
                           INT8_C( -13), INT8_C( -44), INT8_C(  27), INT8_C( -97),
                           INT8_C( 102), INT8_C(   0), INT8_C(  38), INT8_C( -62),
                           INT8_C( -53), INT8_C( 117), INT8_C( 108), INT8_C(  19),
                           INT8_C(  47), INT8_C(-124), INT8_C(  69), INT8_C(  46),
                           INT8_C(  18), INT8_C(  59), INT8_C(  69), INT8_C(   0),
                           INT8_C(  -7), INT8_C( -53), INT8_C(  69), INT8_C(  48),
                           INT8_C(-107), INT8_C( -34), INT8_C( -75), INT8_C(   0),
                           INT8_C( -35), INT8_C(-116), INT8_C(  65), INT8_C(   0),
                           INT8_C(  15), INT8_C(   3), INT8_C(  45), INT8_C(  21),
                           INT8_C(  39), INT8_C(  93), INT8_C( 108), INT8_C( 125)) },
    { simde_mm512_set_epi8(INT8_C(-103), INT8_C(-124), INT8_C(  13), INT8_C( -80),
                           INT8_C( -32), INT8_C( 123), INT8_C( 115), INT8_C( -49),
                           INT8_C( 113), INT8_C( -51), INT8_C( 119), INT8_C( -67),
                           INT8_C( -21), INT8_C(  19), INT8_C( -12), INT8_C(  29),
                           INT8_C(  91), INT8_C( -64), INT8_C(  88), INT8_C(-105),
                           INT8_C(  24), INT8_C(  31), INT8_C(  77), INT8_C(  92),
                           INT8_C( -85), INT8_C(  48), INT8_C(-113), INT8_C(-114),
                           INT8_C(  16), INT8_C(  18), INT8_C( -44), INT8_C( -66),
                           INT8_C(  25), INT8_C(-105), INT8_C(-100), INT8_C( -91),
                           INT8_C(  26), INT8_C(-123), INT8_C( -33), INT8_C( -37),
                           INT8_C(  63), INT8_C(  13), INT8_C(-124), INT8_C(  41),
                           INT8_C(-104), INT8_C( -59), INT8_C(  -2), INT8_C( -54),
                           INT8_C(  73), INT8_C(   3), INT8_C( -18), INT8_C(  10),
                           INT8_C(  19), INT8_C(  58), INT8_C( -12), INT8_C( -75),
                           INT8_C( -88), INT8_C(  59), INT8_C( 104), INT8_C( -40),
                           INT8_C( -82), INT8_C(  42), INT8_C( -73), INT8_C( -94)),
      UINT64_C( 2633789449456316803),
      simde_mm512_set_epi8(INT8_C( 118), INT8_C(  44), INT8_C( -14), INT8_C(  84),
                           INT8_C( -69), INT8_C( -48), INT8_C(  40), INT8_C(  86),
                           INT8_C(  -1), INT8_C( 121), INT8_C( -40), INT8_C(  44),
                           INT8_C(  -1), INT8_C(  38), INT8_C( -44), INT8_C(  38),
                           INT8_C(  93), INT8_C(-107), INT8_C(  -4), INT8_C( -61),
                           INT8_C( -52), INT8_C(  22), INT8_C( -54), INT8_C(-125),
                           INT8_C( -29), INT8_C(  25), INT8_C( -77), INT8_C( -68),
                           INT8_C(   9), INT8_C( -35), INT8_C( -11), INT8_C(  53),
                           INT8_C(  28), INT8_C(  61), INT8_C( -35), INT8_C(-106),
                           INT8_C( -46), INT8_C( 121), INT8_C(-102), INT8_C( 121),
                           INT8_C( -54), INT8_C( -60), INT8_C(   7), INT8_C(   2),
                           INT8_C(-119), INT8_C( 111), INT8_C( -20), INT8_C( -58),
                           INT8_C( -98), INT8_C(  83), INT8_C(  32), INT8_C( -49),
                           INT8_C( -11), INT8_C(  48), INT8_C(  92), INT8_C(  47),
                           INT8_C( -38), INT8_C(  11), INT8_C(  26), INT8_C(  90),
                           INT8_C(  -5), INT8_C(  73), INT8_C(  45), INT8_C(  -2)),
      simde_mm512_set_epi8(INT8_C( -31), INT8_C( 126), INT8_C(-118), INT8_C( -57),
                           INT8_C(-126), INT8_C(  29), INT8_C( 101), INT8_C( -15),
                           INT8_C( -61), INT8_C( 118), INT8_C( 102), INT8_C(  12),
                           INT8_C( -59), INT8_C( -41), INT8_C( -60), INT8_C(  46),
                           INT8_C(  63), INT8_C(  78), INT8_C(  87), INT8_C(  18),
                           INT8_C(  18), INT8_C(  32), INT8_C( -26), INT8_C(  -6),
                           INT8_C( -20), INT8_C(-123), INT8_C(  99), INT8_C(  65),
                           INT8_C(  13), INT8_C(  25), INT8_C( 108), INT8_C(-121),
                           INT8_C(  42), INT8_C(   0), INT8_C( 104), INT8_C( -17),
                           INT8_C( 111), INT8_C(-110), INT8_C( -39), INT8_C( 125),
                           INT8_C( -50), INT8_C( -47), INT8_C(  30), INT8_C(  92),
                           INT8_C(  19), INT8_C(  -8), INT8_C(-120), INT8_C( 127),
                           INT8_C( -49), INT8_C(  23), INT8_C(  16), INT8_C( -64),
                           INT8_C( -79), INT8_C( 116), INT8_C(  -5), INT8_C( -50),
                           INT8_C(  32), INT8_C(  22), INT8_C( -42), INT8_C(  -3),
                           INT8_C(  30), INT8_C(  64), INT8_C(  96), INT8_C( -66)),
      simde_mm512_set_epi8(INT8_C(-103), INT8_C(-124), INT8_C(   0), INT8_C( -80),
                           INT8_C( -32), INT8_C( -14), INT8_C( 115), INT8_C( -49),
                           INT8_C(   0), INT8_C( -51), INT8_C( 119), INT8_C( -67),
                           INT8_C(   0), INT8_C(   0), INT8_C( -12), INT8_C(  44),
                           INT8_C(  91), INT8_C( -64), INT8_C(  88), INT8_C( -35),
                           INT8_C( -35), INT8_C(  31), INT8_C(  77), INT8_C(   0),
                           INT8_C(   0), INT8_C(  48), INT8_C(-113), INT8_C(-114),
                           INT8_C(  -4), INT8_C( -54), INT8_C( -44), INT8_C( -66),
                           INT8_C( 121), INT8_C( -58), INT8_C(-100), INT8_C( -91),
                           INT8_C(  26), INT8_C(   0), INT8_C( -33), INT8_C( -37),
                           INT8_C(  63), INT8_C(  13), INT8_C(-124), INT8_C(  41),
                           INT8_C(-104), INT8_C( -59), INT8_C(   0), INT8_C(  28),
                           INT8_C(   0), INT8_C( -38), INT8_C(  -2), INT8_C(   0),
                           INT8_C(  19), INT8_C(  58), INT8_C( -12), INT8_C(   0),
                           INT8_C(  -2), INT8_C(  59), INT8_C( 104), INT8_C( -40),
                           INT8_C( -82), INT8_C(  42), INT8_C(  -2), INT8_C(   0)) },
    { simde_mm512_set_epi8(INT8_C( 117), INT8_C(  69), INT8_C( 121), INT8_C( -45),
                           INT8_C(  30), INT8_C( -73), INT8_C(   2), INT8_C( -40),
                           INT8_C(  95), INT8_C(  -3), INT8_C(  16), INT8_C( -78),
                           INT8_C(-128), INT8_C( -41), INT8_C( -66), INT8_C(  66),
                           INT8_C(  93), INT8_C( -32), INT8_C( -50), INT8_C(  -2),
                           INT8_C( -61), INT8_C(  29), INT8_C( -88), INT8_C(-118),
                           INT8_C( -27), INT8_C(  42), INT8_C(  78), INT8_C( -46),
                           INT8_C( -79), INT8_C(  38), INT8_C( -75), INT8_C(  14),
                           INT8_C(-118), INT8_C(-114), INT8_C(-120), INT8_C(  42),
                           INT8_C(   4), INT8_C(  79), INT8_C( -84), INT8_C(-110),
                           INT8_C(   0), INT8_C(  85), INT8_C( -20), INT8_C(  61),
                           INT8_C(  40), INT8_C( -75), INT8_C(  69), INT8_C( -99),
                           INT8_C(  73), INT8_C( -34), INT8_C( -14), INT8_C(  72),
                           INT8_C( 101), INT8_C(  96), INT8_C(-114), INT8_C(-124),
                           INT8_C( -87), INT8_C(  43), INT8_C(-118), INT8_C( 114),
                           INT8_C( -88), INT8_C(   8), INT8_C( -52), INT8_C(  75)),
      UINT64_C(14890918166471265655),
      simde_mm512_set_epi8(INT8_C( -56), INT8_C( -70), INT8_C(  66), INT8_C(-111),
                           INT8_C( -69), INT8_C(  15), INT8_C( -82), INT8_C( -12),
                           INT8_C( -89), INT8_C(  37), INT8_C(  80), INT8_C( 120),
                           INT8_C( -83), INT8_C(-120), INT8_C(  95), INT8_C(  21),
                           INT8_C(  91), INT8_C( -97), INT8_C( -72), INT8_C(  42),
                           INT8_C(  22), INT8_C( -70), INT8_C(  71), INT8_C( -78),
                           INT8_C(  -5), INT8_C(  52), INT8_C( -22), INT8_C( -34),
                           INT8_C(  16), INT8_C(  92), INT8_C(  91), INT8_C( -72),
                           INT8_C(   3), INT8_C( -31), INT8_C( -95), INT8_C( -56),
                           INT8_C( -50), INT8_C(  68), INT8_C( -24), INT8_C( -50),
                           INT8_C(  94), INT8_C(  67), INT8_C( 108), INT8_C(-118),
                           INT8_C( -65), INT8_C(  31), INT8_C(  70), INT8_C( 108),
                           INT8_C( -66), INT8_C( 107), INT8_C( -85), INT8_C(  38),
                           INT8_C(   2), INT8_C(  32), INT8_C(  56), INT8_C(  66),
                           INT8_C(  -2), INT8_C( -74), INT8_C( 112), INT8_C(  10),
                           INT8_C(  64), INT8_C( 100), INT8_C( -55), INT8_C(  83)),
      simde_mm512_set_epi8(INT8_C( -69), INT8_C( -45), INT8_C(  23), INT8_C(  70),
                           INT8_C(  22), INT8_C( 113), INT8_C(  75), INT8_C(-117),
                           INT8_C(  69), INT8_C( -74), INT8_C(  40), INT8_C( -39),
                           INT8_C( -51), INT8_C( -91), INT8_C(  25), INT8_C(  -4),
                           INT8_C( -12), INT8_C( -13), INT8_C( -77), INT8_C(  75),
                           INT8_C(-116), INT8_C( -36), INT8_C(  38), INT8_C( -52),
                           INT8_C(  13), INT8_C( -52), INT8_C(-100), INT8_C( -46),
                           INT8_C(  13), INT8_C(  83), INT8_C( -94), INT8_C( 102),
                           INT8_C( 116), INT8_C( -60), INT8_C(  44), INT8_C(  -7),
                           INT8_C( 104), INT8_C( -50), INT8_C( -30), INT8_C(  17),
                           INT8_C(  13), INT8_C(-107), INT8_C( 111), INT8_C( -13),
                           INT8_C(  17), INT8_C( -45), INT8_C( -31), INT8_C(  76),
                           INT8_C(-102), INT8_C( -71), INT8_C( 116), INT8_C(  72),
                           INT8_C( -11), INT8_C( -97), INT8_C(  93), INT8_C(  48),
                           INT8_C( -75), INT8_C( -90), INT8_C( -10), INT8_C( -78),
                           INT8_C(  -8), INT8_C( -10), INT8_C(  48), INT8_C( -11)),
      simde_mm512_set_epi8(INT8_C(   0), INT8_C(   0), INT8_C( 121), INT8_C( -45),
                           INT8_C(  37), INT8_C(  95), INT8_C( -69), INT8_C( -40),
                           INT8_C(  80), INT8_C(  -3), INT8_C( -12), INT8_C( -78),
                           INT8_C(-128), INT8_C(   0), INT8_C( -82), INT8_C(   0),
                           INT8_C(  93), INT8_C( -32), INT8_C(   0), INT8_C(  -2),
                           INT8_C(   0), INT8_C(  29), INT8_C(  52), INT8_C(   0),
                           INT8_C( -27), INT8_C(  42), INT8_C(   0), INT8_C( -46),
                           INT8_C( -72), INT8_C(  16), INT8_C( -75), INT8_C(  52),
                           INT8_C(-118), INT8_C(   0), INT8_C(-120), INT8_C(  42),
                           INT8_C( -50), INT8_C(  79), INT8_C(   0), INT8_C(  70),
                           INT8_C( -95), INT8_C(   0), INT8_C(   3), INT8_C(  61),
                           INT8_C(  70), INT8_C(   0), INT8_C(   0), INT8_C( -99),
                           INT8_C(  73), INT8_C(   0), INT8_C( -14), INT8_C(  72),
                           INT8_C(   0), INT8_C(   0), INT8_C(-114), INT8_C(  83),
                           INT8_C( -87), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C( -88), INT8_C(   0), INT8_C(  83), INT8_C(   0)) },
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])); i++) {
    simde__m512i r = simde_mm512_mask_shuffle_epi8(test_vec[i].src, test_vec[i].k, test_vec[i].a, test_vec[i].b);
    simde_assert_m512i_i8(r, ==, test_vec[i].r);
  }

  return 0;
}

static int
test_simde_mm512_maskz_shuffle_epi8(SIMDE_MUNIT_TEST_ARGS) {
  const struct {
    simde__mmask64 k;
    simde__m512i a;
    simde__m512i b;
    simde__m512i r;
  } test_vec[8] = {
    { UINT64_C(17286015531074160252),
      simde_mm512_set_epi8(INT8_C(-115), INT8_C( -27), INT8_C(  62), INT8_C( -85),
                           INT8_C(  49), INT8_C(-115), INT8_C(  38), INT8_C(   4),
                           INT8_C(  92), INT8_C( 116), INT8_C( -78), INT8_C( -19),
                           INT8_C( -73), INT8_C(  22), INT8_C( -66), INT8_C( -29),
                           INT8_C(  55), INT8_C(  78), INT8_C( -45), INT8_C(-119),
                           INT8_C(  30), INT8_C( -29), INT8_C( -23), INT8_C(  89),
                           INT8_C(  15), INT8_C( 119), INT8_C( -88), INT8_C( 109),
                           INT8_C( -16), INT8_C( -10), INT8_C(   0), INT8_C( -18),
                           INT8_C(   1), INT8_C( 116), INT8_C(  62), INT8_C( -73),
                           INT8_C(-122), INT8_C(   0), INT8_C( 111), INT8_C(  95),
                           INT8_C( -20), INT8_C(   3), INT8_C( 122), INT8_C(-121),
                           INT8_C(  13), INT8_C(  25), INT8_C( -35), INT8_C(-127),
                           INT8_C(  82), INT8_C(  90), INT8_C(  53), INT8_C( 123),
                           INT8_C(  73), INT8_C( 108), INT8_C( -18), INT8_C(  15),
                           INT8_C(  81), INT8_C( -27), INT8_C( 102), INT8_C( 118),
                           INT8_C(  39), INT8_C( -77), INT8_C(  45), INT8_C(  81)),
      simde_mm512_set_epi8(INT8_C(  68), INT8_C(-108), INT8_C(-121), INT8_C(-115),
                           INT8_C( -59), INT8_C( -78), INT8_C(-111), INT8_C(  56),
                           INT8_C(   9), INT8_C(-121), INT8_C( 120), INT8_C( -36),
                           INT8_C(  36), INT8_C(-103), INT8_C(-104), INT8_C(  25),
                           INT8_C(-111), INT8_C( -63), INT8_C( -35), INT8_C(-120),
                           INT8_C(  28), INT8_C( -44), INT8_C( -26), INT8_C( -86),
                           INT8_C( -13), INT8_C(  53), INT8_C( -88), INT8_C(-107),
                           INT8_C(  68), INT8_C(  42), INT8_C(-118), INT8_C( 111),
                           INT8_C(  54), INT8_C( -58), INT8_C( -13), INT8_C(  27),
                           INT8_C(  23), INT8_C(  41), INT8_C(-119), INT8_C(  44),
                           INT8_C(   7), INT8_C(-120), INT8_C(  32), INT8_C( -43),
                           INT8_C( 114), INT8_C( -72), INT8_C(  73), INT8_C( -96),
                           INT8_C(  96), INT8_C( 110), INT8_C( -81), INT8_C( -76),
                           INT8_C( 103), INT8_C(-100), INT8_C( -22), INT8_C(  18),
                           INT8_C( 115), INT8_C(  54), INT8_C( -40), INT8_C( 125),
                           INT8_C( 110), INT8_C(  31), INT8_C(  51), INT8_C(-104)),
      simde_mm512_set_epi8(INT8_C( -19), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   4),
                           INT8_C(  38), INT8_C(   0), INT8_C(   4), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C( 109), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C( -20), INT8_C( 111), INT8_C(   0), INT8_C( -73),
                           INT8_C( -20), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(  25), INT8_C(   0), INT8_C( 111), INT8_C(   0),
                           INT8_C(  81), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C( -27), INT8_C(   0), INT8_C(  53),
                           INT8_C(  90), INT8_C(  82), INT8_C(   0), INT8_C(   0)) },
    { UINT64_C( 9031211210081693899),
      simde_mm512_set_epi8(INT8_C(-106), INT8_C( -18), INT8_C(  65), INT8_C(-104),
                           INT8_C(  81), INT8_C(  38), INT8_C( -84), INT8_C(  -2),
                           INT8_C( -14), INT8_C(  85), INT8_C( -80), INT8_C(  80),
                           INT8_C(  48), INT8_C(  93), INT8_C(  79), INT8_C( 127),
                           INT8_C(  16), INT8_C(  41), INT8_C(  54), INT8_C(-116),
                           INT8_C(  17), INT8_C(  42), INT8_C( -86), INT8_C(  38),
                           INT8_C(-118), INT8_C( -56), INT8_C(  60), INT8_C(  19),
                           INT8_C(-100), INT8_C(-107), INT8_C( 105), INT8_C( -76),
                           INT8_C(  10), INT8_C(  -9), INT8_C( -12), INT8_C( -56),
                           INT8_C( -71), INT8_C(  96), INT8_C(   6), INT8_C(  24),
                           INT8_C(  69), INT8_C(  73), INT8_C( -27), INT8_C(   3),
                           INT8_C( -95), INT8_C(  50), INT8_C( -67), INT8_C( -39),
                           INT8_C(  97), INT8_C(  62), INT8_C( 101), INT8_C(  56),
                           INT8_C( -79), INT8_C(  83), INT8_C( -99), INT8_C( -56),
                           INT8_C( -17), INT8_C( -56), INT8_C(  -8), INT8_C( -16),
                           INT8_C(  84), INT8_C( -95), INT8_C( -73), INT8_C(  54)),
      simde_mm512_set_epi8(INT8_C(  63), INT8_C( -51), INT8_C(  87), INT8_C(  32),
                           INT8_C( -65), INT8_C(  55), INT8_C(  14), INT8_C(  81),
                           INT8_C(-123), INT8_C(-100), INT8_C( -39), INT8_C( -44),
                           INT8_C(  22), INT8_C( 112), INT8_C(  16), INT8_C(  15),
                           INT8_C(-104), INT8_C(-102), INT8_C( 102), INT8_C( -95),
                           INT8_C(  69), INT8_C(  13), INT8_C( -21), INT8_C(  45),
                           INT8_C(  62), INT8_C(-120), INT8_C(-111), INT8_C(  32),
                           INT8_C(-107), INT8_C( -30), INT8_C(  99), INT8_C( -64),
                           INT8_C(   8), INT8_C( -42), INT8_C(  81), INT8_C( -34),
                           INT8_C( -46), INT8_C(  26), INT8_C(  31), INT8_C(  -2),
                           INT8_C(  68), INT8_C(  -7), INT8_C( -71), INT8_C(  46),
                           INT8_C( -21), INT8_C( -73), INT8_C(  21), INT8_C(  83),
                           INT8_C(-108), INT8_C( -97), INT8_C( -69), INT8_C(  73),
                           INT8_C(  57), INT8_C( -37), INT8_C(  21), INT8_C(  82),
                           INT8_C(-119), INT8_C(-126), INT8_C( 126), INT8_C(  91),
                           INT8_C( 115), INT8_C(  31), INT8_C( -79), INT8_C(  28)),
      simde_mm512_set_epi8(INT8_C(   0), INT8_C(   0), INT8_C( -14), INT8_C( 127),
                           INT8_C(   0), INT8_C( -14), INT8_C(   0), INT8_C(  79),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C( 127), INT8_C(   0), INT8_C(-106),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(  60), INT8_C(  54), INT8_C(   0), INT8_C(   0),
                           INT8_C(  41), INT8_C(   0), INT8_C(   0), INT8_C( -76),
                           INT8_C(   0), INT8_C(   0), INT8_C(-100), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(  96), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(  -9),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C( -95),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C( -99),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(  84), INT8_C(   0), INT8_C(   0), INT8_C(  56)) },
    { UINT64_C( 6828010367541473016),
      simde_mm512_set_epi8(INT8_C(  84), INT8_C( -96), INT8_C(  87), INT8_C( -22),
                           INT8_C(  -5), INT8_C(  -3), INT8_C(-127), INT8_C(  41),
                           INT8_C(  74), INT8_C(  72), INT8_C(  -4), INT8_C(  28),
                           INT8_C(-115), INT8_C(  93), INT8_C( 102), INT8_C(  44),
                           INT8_C(-103), INT8_C( -29), INT8_C( -50), INT8_C(  48),
                           INT8_C( -96), INT8_C( -50), INT8_C(  46), INT8_C( -65),
                           INT8_C(   4), INT8_C(  43), INT8_C( -75), INT8_C(  97),
                           INT8_C( -26), INT8_C(-103), INT8_C(  71), INT8_C(-107),
                           INT8_C(  91), INT8_C(  45), INT8_C( -11), INT8_C(  47),
                           INT8_C(  29), INT8_C(  25), INT8_C(  26), INT8_C(  -9),
                           INT8_C(  10), INT8_C(  36), INT8_C( -79), INT8_C( -53),
                           INT8_C(  41), INT8_C(   1), INT8_C( -23), INT8_C( -63),
                           INT8_C(-127), INT8_C(  68), INT8_C(  48), INT8_C(  36),
                           INT8_C(  89), INT8_C(-112), INT8_C( -31), INT8_C( 120),
                           INT8_C(  35), INT8_C(  62), INT8_C( -21), INT8_C(-114),
                           INT8_C(-104), INT8_C(  57), INT8_C(  42), INT8_C(-111)),
      simde_mm512_set_epi8(INT8_C(  96), INT8_C( -64), INT8_C( -23), INT8_C( -46),
                           INT8_C( -29), INT8_C( -71), INT8_C(  71), INT8_C(  90),
                           INT8_C(  44), INT8_C( -92), INT8_C( -31), INT8_C(  26),
                           INT8_C( -99), INT8_C( -53), INT8_C( 117), INT8_C(  18),
                           INT8_C( -63), INT8_C(  45), INT8_C(  12), INT8_C(  24),
                           INT8_C(-108), INT8_C(  18), INT8_C( -60), INT8_C(  28),
                           INT8_C(  50), INT8_C( -11), INT8_C( -68), INT8_C( -31),
                           INT8_C( 105), INT8_C(-106), INT8_C(  98), INT8_C(  51),
                           INT8_C(  58), INT8_C( 103), INT8_C( 111), INT8_C(-127),
                           INT8_C(  68), INT8_C( -56), INT8_C( 124), INT8_C(-119),
                           INT8_C(  74), INT8_C( -62), INT8_C(-116), INT8_C(  37),
                           INT8_C( -12), INT8_C( 114), INT8_C(   0), INT8_C(  61),
                           INT8_C( 103), INT8_C(  -4), INT8_C(-105), INT8_C( -68),
                           INT8_C(  39), INT8_C(-100), INT8_C( -93), INT8_C(  11),
                           INT8_C( -80), INT8_C( -19), INT8_C( -22), INT8_C( -39),
                           INT8_C( 127), INT8_C( -38), INT8_C(-125), INT8_C(-111)),
      simde_mm512_set_epi8(INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(  74), INT8_C(   0),
                           INT8_C( -22), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(  93),
                           INT8_C(   0), INT8_C( -50), INT8_C(  48), INT8_C( -65),
                           INT8_C(   0), INT8_C(-103), INT8_C(   0), INT8_C(  48),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(  25), INT8_C(   0), INT8_C(  91), INT8_C(   0),
                           INT8_C( -53), INT8_C(   0), INT8_C(  47), INT8_C(   0),
                           INT8_C(  25), INT8_C(   0), INT8_C(   0), INT8_C( -79),
                           INT8_C(   0), INT8_C(   1), INT8_C( -63), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(  35), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(-127), INT8_C(   0), INT8_C(   0), INT8_C(   0)) },
    { UINT64_C(18325019528117086600),
      simde_mm512_set_epi8(INT8_C( 122), INT8_C( -54), INT8_C(  50), INT8_C( 123),
                           INT8_C( -31), INT8_C( -74), INT8_C( -64), INT8_C(  54),
                           INT8_C( -81), INT8_C(  60), INT8_C(  31), INT8_C( -23),
                           INT8_C( 108), INT8_C(-119), INT8_C( -92), INT8_C( -80),
                           INT8_C( -30), INT8_C( -37), INT8_C(  51), INT8_C( -36),
                           INT8_C(   8), INT8_C(  52), INT8_C(  97), INT8_C( 123),
                           INT8_C( -49), INT8_C(-124), INT8_C(  95), INT8_C( -83),
                           INT8_C(  70), INT8_C( -50), INT8_C( -61), INT8_C(  25),
                           INT8_C( -97), INT8_C(  28), INT8_C( -58), INT8_C(  11),
                           INT8_C( -14), INT8_C( 126), INT8_C(  81), INT8_C(  45),
                           INT8_C( -23), INT8_C( 120), INT8_C( -83), INT8_C( -16),
                           INT8_C(   7), INT8_C(  51), INT8_C( -57), INT8_C( -50),
                           INT8_C( -21), INT8_C(  98), INT8_C(  88), INT8_C(   0),
                           INT8_C( -66), INT8_C(   3), INT8_C( 124), INT8_C(-113),
                           INT8_C(  50), INT8_C(  88), INT8_C( -85), INT8_C( -93),
                           INT8_C( -44), INT8_C( -13), INT8_C( -94), INT8_C(  17)),
      simde_mm512_set_epi8(INT8_C( -13), INT8_C( -12), INT8_C(-124), INT8_C(  96),
                           INT8_C( -13), INT8_C( -98), INT8_C(  99), INT8_C( -13),
                           INT8_C(  56), INT8_C( -45), INT8_C(-108), INT8_C( -19),
                           INT8_C(-124), INT8_C( -27), INT8_C(  22), INT8_C( 126),
                           INT8_C(-106), INT8_C( -68), INT8_C( -60), INT8_C(   8),
                           INT8_C(  60), INT8_C(  93), INT8_C( -33), INT8_C( -27),
                           INT8_C(  -7), INT8_C(  27), INT8_C(-122), INT8_C( -38),
                           INT8_C(  23), INT8_C(   6), INT8_C(  45), INT8_C( -21),
                           INT8_C( -23), INT8_C(-101), INT8_C( 116), INT8_C( 127),
                           INT8_C(  96), INT8_C(  40), INT8_C( -97), INT8_C(  40),
                           INT8_C(  86), INT8_C( -44), INT8_C(  70), INT8_C( -71),
                           INT8_C(  62), INT8_C( -21), INT8_C(  66), INT8_C(  68),
                           INT8_C( -87), INT8_C( -61), INT8_C(  48), INT8_C( -70),
                           INT8_C(  18), INT8_C( -78), INT8_C( -98), INT8_C( 117),
                           INT8_C(  74), INT8_C(  32), INT8_C(  93), INT8_C( 125),
                           INT8_C( -47), INT8_C( -60), INT8_C( -86), INT8_C( 117)),
      simde_mm512_set_epi8(INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C( -80),
                           INT8_C(   0), INT8_C(   0), INT8_C( 108), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(  60), INT8_C( -54),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C( -36), INT8_C(  51), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C( -49), INT8_C(   0), INT8_C(  51), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C( -16), INT8_C( -97),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(  45),
                           INT8_C( 120), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(  51), INT8_C( -16),
                           INT8_C(   0), INT8_C(   0), INT8_C(  17), INT8_C(   0),
                           INT8_C( -13), INT8_C(   0), INT8_C(   0), INT8_C( -85),
                           INT8_C(   3), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0)) },
    { UINT64_C( 7677112093376593822),
      simde_mm512_set_epi8(INT8_C( -53), INT8_C(  34), INT8_C(   9), INT8_C(  64),
                           INT8_C( -61), INT8_C( -25), INT8_C(-115), INT8_C( 100),
                           INT8_C(  65), INT8_C(   8), INT8_C(  69), INT8_C(  -8),
                           INT8_C( -15), INT8_C( -51), INT8_C(   1), INT8_C(  90),
                           INT8_C( 115), INT8_C(  51), INT8_C( -91), INT8_C(  56),
                           INT8_C(  64), INT8_C( -39), INT8_C(-119), INT8_C( -28),
                           INT8_C( -54), INT8_C(  28), INT8_C(  54), INT8_C(  -8),
                           INT8_C( -54), INT8_C(-128), INT8_C( -28), INT8_C( -71),
                           INT8_C( 107), INT8_C( -66), INT8_C(-114), INT8_C( -88),
                           INT8_C(  34), INT8_C( -83), INT8_C( -21), INT8_C( -64),
                           INT8_C( 121), INT8_C( -20), INT8_C( -89), INT8_C( -94),
                           INT8_C( 112), INT8_C( -27), INT8_C(  81), INT8_C( -54),
                           INT8_C( -64), INT8_C(-114), INT8_C(  48), INT8_C( -89),
                           INT8_C( -61), INT8_C(  26), INT8_C(  43), INT8_C(  29),
                           INT8_C(   0), INT8_C(  64), INT8_C( 123), INT8_C( -67),
                           INT8_C(  15), INT8_C( 120), INT8_C(  36), INT8_C(  40)),
      simde_mm512_set_epi8(INT8_C( 113), INT8_C(  32), INT8_C(  71), INT8_C(  55),
                           INT8_C( -26), INT8_C(  82), INT8_C( -81), INT8_C( -20),
                           INT8_C( -55), INT8_C( 112), INT8_C(  45), INT8_C(  37),
                           INT8_C(  67), INT8_C( -69), INT8_C(  64), INT8_C(  39),
                           INT8_C(  72), INT8_C(  45), INT8_C( 120), INT8_C(  -5),
                           INT8_C(-109), INT8_C(  62), INT8_C(  17), INT8_C(  31),
                           INT8_C( -30), INT8_C( -58), INT8_C(  56), INT8_C(  21),
                           INT8_C(  72), INT8_C( -74), INT8_C( -40), INT8_C( 120),
                           INT8_C(  95), INT8_C( 108), INT8_C(  32), INT8_C(  64),
                           INT8_C(-128), INT8_C( 102), INT8_C( -21), INT8_C(  28),
                           INT8_C( 105), INT8_C(  52), INT8_C(  85), INT8_C(-104),
                           INT8_C(  57), INT8_C( -31), INT8_C( -38), INT8_C(-124),
                           INT8_C(-107), INT8_C(  -2), INT8_C(  55), INT8_C(  46),
                           INT8_C( -71), INT8_C(  77), INT8_C(  18), INT8_C(  70),
                           INT8_C(  89), INT8_C( 125), INT8_C( -42), INT8_C(-125),
                           INT8_C( 121), INT8_C( -11), INT8_C( -69), INT8_C( -59)),
      simde_mm512_set_epi8(INT8_C(   0), INT8_C(  90), INT8_C(  65), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C( -15), INT8_C(   0), INT8_C(  90), INT8_C(   0),
                           INT8_C( -28), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(  51), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C( -54),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C( -21), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(-114),
                           INT8_C(   0), INT8_C(  48), INT8_C( 120), INT8_C(  64),
                           INT8_C(  43), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(  43), INT8_C(   0), INT8_C(   0), INT8_C(   0)) },
    { UINT64_C( 4840581956081845689),
      simde_mm512_set_epi8(INT8_C( 122), INT8_C(-108), INT8_C( -70), INT8_C( -63),
                           INT8_C(  56), INT8_C(  71), INT8_C( -14), INT8_C(  49),
                           INT8_C( -73), INT8_C(  53), INT8_C( -29), INT8_C(   3),
                           INT8_C( -73), INT8_C(  43), INT8_C( -22), INT8_C(  85),
                           INT8_C( -26), INT8_C(  -9), INT8_C(  66), INT8_C(   1),
                           INT8_C( -13), INT8_C(  60), INT8_C(-119), INT8_C( -83),
                           INT8_C(-122), INT8_C( -64), INT8_C( -83), INT8_C( -74),
                           INT8_C( 119), INT8_C(  -8), INT8_C(  12), INT8_C( 113),
                           INT8_C( -12), INT8_C( -84), INT8_C(   6), INT8_C(  69),
                           INT8_C(   2), INT8_C( -75), INT8_C( -34), INT8_C(-126),
                           INT8_C(   3), INT8_C(-128), INT8_C(  -9), INT8_C(  24),
                           INT8_C(  11), INT8_C( -94), INT8_C( -32), INT8_C( 110),
                           INT8_C(  33), INT8_C( -24), INT8_C( 125), INT8_C(  35),
                           INT8_C(-103), INT8_C( -48), INT8_C( -22), INT8_C(  38),
                           INT8_C( -81), INT8_C(   9), INT8_C( -11), INT8_C(-124),
                           INT8_C(  71), INT8_C(  31), INT8_C( -42), INT8_C(  93)),
      simde_mm512_set_epi8(INT8_C(  53), INT8_C(  77), INT8_C(  63), INT8_C( -84),
                           INT8_C(  27), INT8_C(  22), INT8_C(   3), INT8_C( -37),
                           INT8_C(  65), INT8_C( 118), INT8_C(-126), INT8_C(  97),
                           INT8_C( 109), INT8_C(   7), INT8_C(-114), INT8_C( -75),
                           INT8_C(-125), INT8_C( 121), INT8_C(-128), INT8_C( 103),
                           INT8_C(   0), INT8_C( 101), INT8_C( -41), INT8_C(  89),
                           INT8_C( -83), INT8_C( -65), INT8_C(   9), INT8_C(  -7),
                           INT8_C( -63), INT8_C(  13), INT8_C( 105), INT8_C(  92),
                           INT8_C( -18), INT8_C( -21), INT8_C(-102), INT8_C(-114),
                           INT8_C(  74), INT8_C( 121), INT8_C( -45), INT8_C(  52),
                           INT8_C( -63), INT8_C( -93), INT8_C(  98), INT8_C( 106),
                           INT8_C(-109), INT8_C( -47), INT8_C(  37), INT8_C(  70),
                           INT8_C( 100), INT8_C( 121), INT8_C(  18), INT8_C(  28),
                           INT8_C(-117), INT8_C( 107), INT8_C(   3), INT8_C( -62),
                           INT8_C(  42), INT8_C(  72), INT8_C(  91), INT8_C(  86),
                           INT8_C( -72), INT8_C(   9), INT8_C( -80), INT8_C( 118)),
      simde_mm512_set_epi8(INT8_C(   0), INT8_C( -70), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C( -73), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C( -70), INT8_C( -73), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(-122),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(-119),
                           INT8_C(   0), INT8_C(   0), INT8_C(-119), INT8_C(   0),
                           INT8_C(   0), INT8_C(  66), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C( -75), INT8_C( -34), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C( -94), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(-124), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(-103), INT8_C(   0), INT8_C(   0),
                           INT8_C( -48), INT8_C(   0), INT8_C(-103), INT8_C(   9),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   9)) },
    { UINT64_C(17498311407133456191),
      simde_mm512_set_epi8(INT8_C(  61), INT8_C( -89), INT8_C(  84), INT8_C( -94),
                           INT8_C(  31), INT8_C(-116), INT8_C( -67), INT8_C(-102),
                           INT8_C( -72), INT8_C( -91), INT8_C(-105), INT8_C(-108),
                           INT8_C( -44), INT8_C(  74), INT8_C( -28), INT8_C( 124),
                           INT8_C( 120), INT8_C( -41), INT8_C( -79), INT8_C( 122),
                           INT8_C(  87), INT8_C(-119), INT8_C(  54), INT8_C(  -2),
                           INT8_C( -47), INT8_C(  84), INT8_C(-126), INT8_C( -64),
                           INT8_C(  14), INT8_C(  11), INT8_C(  37), INT8_C( -23),
                           INT8_C(  67), INT8_C( 124), INT8_C(  58), INT8_C( -94),
                           INT8_C(  30), INT8_C( -33), INT8_C(  70), INT8_C( -24),
                           INT8_C(  38), INT8_C( -97), INT8_C( -56), INT8_C( -60),
                           INT8_C( -59), INT8_C(  65), INT8_C( -74), INT8_C(  45),
                           INT8_C( -11), INT8_C(  55), INT8_C( -82), INT8_C(  12),
                           INT8_C( 106), INT8_C(  22), INT8_C(-124), INT8_C(  -4),
                           INT8_C(   2), INT8_C( -81), INT8_C(  14), INT8_C(  90),
                           INT8_C(-100), INT8_C(-122), INT8_C( -35), INT8_C(  81)),
      simde_mm512_set_epi8(INT8_C(  21), INT8_C( 108), INT8_C( 125), INT8_C( -60),
                           INT8_C( -72), INT8_C(  74), INT8_C(  -5), INT8_C( -58),
                           INT8_C( -41), INT8_C(  22), INT8_C(-115), INT8_C( 102),
                           INT8_C(  59), INT8_C( -80), INT8_C( -15), INT8_C( -63),
                           INT8_C(  84), INT8_C( -71), INT8_C(   8), INT8_C(  12),
                           INT8_C( -11), INT8_C( -76), INT8_C(  62), INT8_C(  93),
                           INT8_C( -75), INT8_C( -77), INT8_C( -84), INT8_C(-108),
                           INT8_C( -35), INT8_C(  14), INT8_C( -60), INT8_C(  18),
                           INT8_C(  23), INT8_C( -60), INT8_C( -63), INT8_C(-114),
                           INT8_C( -55), INT8_C(  75), INT8_C( -99), INT8_C( -55),
                           INT8_C(  58), INT8_C(  76), INT8_C(-102), INT8_C(-118),
                           INT8_C( -30), INT8_C(  39), INT8_C( 119), INT8_C(  85),
                           INT8_C(  -8), INT8_C( -72), INT8_C( -60), INT8_C( -94),
                           INT8_C(-112), INT8_C( 119), INT8_C( 124), INT8_C(  76),
                           INT8_C( -42), INT8_C(-124), INT8_C(  54), INT8_C(  74),
                           INT8_C( -92), INT8_C(  99), INT8_C(  79), INT8_C(  -3)),
      simde_mm512_set_epi8(INT8_C(-105), INT8_C( -94), INT8_C(  84), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C( -91), INT8_C(   0), INT8_C( -91),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(  -2), INT8_C( 122),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C( -79),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(  11),
                           INT8_C(  38), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(  30), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C( -94), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(  38), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   2), INT8_C(  12), INT8_C(  12),
                           INT8_C(   0), INT8_C(   0), INT8_C( -81), INT8_C(  22),
                           INT8_C(   0), INT8_C(-100), INT8_C( -11), INT8_C(   0)) },
    { UINT64_C( 3462613925466476941),
      simde_mm512_set_epi8(INT8_C(  18), INT8_C( -74), INT8_C(  14), INT8_C(  36),
                           INT8_C(  -7), INT8_C( 113), INT8_C(  40), INT8_C(  48),
                           INT8_C(-107), INT8_C( -34), INT8_C( -75), INT8_C(  85),
                           INT8_C( -35), INT8_C(-116), INT8_C(  65), INT8_C( -21),
                           INT8_C(  15), INT8_C(   3), INT8_C(  45), INT8_C(  21),
                           INT8_C(  72), INT8_C(  93), INT8_C( 108), INT8_C( 125),
                           INT8_C(   1), INT8_C(  75), INT8_C(  21), INT8_C( -36),
                           INT8_C(-126), INT8_C( 122), INT8_C(  71), INT8_C(  76),
                           INT8_C(  28), INT8_C( -56), INT8_C(  32), INT8_C( 101),
                           INT8_C(-107), INT8_C(-111), INT8_C( -88), INT8_C( -19),
                           INT8_C( -77), INT8_C(  19), INT8_C( -21), INT8_C(-111),
                           INT8_C( -68), INT8_C(  82), INT8_C(-118), INT8_C( -76),
                           INT8_C(  47), INT8_C( 127), INT8_C(  62), INT8_C( -16),
                           INT8_C(  10), INT8_C( -14), INT8_C(-100), INT8_C(  86),
                           INT8_C(  29), INT8_C( 107), INT8_C(  56), INT8_C(  21),
                           INT8_C(  24), INT8_C(  68), INT8_C( -96), INT8_C(  64)),
      simde_mm512_set_epi8(INT8_C( -57), INT8_C(  94), INT8_C(-125), INT8_C(-124),
                           INT8_C(  36), INT8_C(  57), INT8_C(  68), INT8_C( -52),
                           INT8_C(  39), INT8_C(  50), INT8_C( -48), INT8_C(  94),
                           INT8_C(  53), INT8_C(  11), INT8_C(  29), INT8_C(  65),
                           INT8_C( -82), INT8_C(-119), INT8_C( 115), INT8_C(  68),
                           INT8_C( -69), INT8_C( 118), INT8_C(  17), INT8_C(   8),
                           INT8_C( -64), INT8_C( -53), INT8_C( -42), INT8_C( 126),
                           INT8_C(  67), INT8_C(  50), INT8_C( -18), INT8_C(  76),
                           INT8_C( -19), INT8_C( 123), INT8_C( -87), INT8_C( 106),
                           INT8_C( -74), INT8_C(  44), INT8_C( 117), INT8_C( 103),
                           INT8_C(  81), INT8_C( 122), INT8_C(  56), INT8_C( -10),
                           INT8_C(  67), INT8_C(  79), INT8_C(  83), INT8_C( -38),
                           INT8_C( -13), INT8_C(  43), INT8_C(  27), INT8_C( -97),
                           INT8_C( 102), INT8_C( 126), INT8_C(  38), INT8_C( -62),
                           INT8_C( -24), INT8_C( 117), INT8_C( -38), INT8_C( -93),
                           INT8_C( -58), INT8_C(-124), INT8_C( -75), INT8_C(  10)),
      simde_mm512_set_epi8(INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C( -75), INT8_C(  -7), INT8_C(   0), INT8_C(  65),
                           INT8_C(   0), INT8_C(   0), INT8_C(-126), INT8_C(   0),
                           INT8_C(   0), INT8_C(  75), INT8_C(   0), INT8_C( 125),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C( 122), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(-107), INT8_C(   0), INT8_C(-111),
                           INT8_C(   0), INT8_C( 101), INT8_C(   0), INT8_C( -77),
                           INT8_C(-118), INT8_C(-111), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C( -14)) },
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])); i++) {
    simde__m512i r = simde_mm512_maskz_shuffle_epi8(test_vec[i].k, test_vec[i].a, test_vec[i].b);
    simde_assert_m512i_i8(r, ==, test_vec[i].r);
  }

  return 0;
}

static int
test_simde_mm512_cmpeq_epi8_mask(SIMDE_MUNIT_TEST_ARGS) {
  const struct {
    simde__m512i   a;
    simde__m512i   b;
    simde__mmask64 r;
  } test_vec[8] = {
    { simde_mm512_set_epi8(INT8_C(  73), INT8_C(  68), INT8_C( -71), INT8_C( -32),
                           INT8_C( 100), INT8_C( 125), INT8_C(  89), INT8_C(  95),
                           INT8_C( -23), INT8_C(  76), INT8_C(  84), INT8_C( -43),
                           INT8_C(  86), INT8_C(  29), INT8_C(  64), INT8_C(  30),
                           INT8_C( -17), INT8_C( -61), INT8_C( 115), INT8_C( -53),
                           INT8_C(-100), INT8_C( 104), INT8_C( 111), INT8_C( -59),
                           INT8_C( -31), INT8_C(  20), INT8_C(  31), INT8_C(-121),
                           INT8_C(  90), INT8_C(  18), INT8_C(   6), INT8_C(  39),
                           INT8_C(  15), INT8_C(  62), INT8_C(  39), INT8_C( -25),
                           INT8_C(  60), INT8_C( 110), INT8_C(  45), INT8_C( 113),
                           INT8_C(  81), INT8_C(  78), INT8_C( -53), INT8_C(  11),
                           INT8_C( -27), INT8_C(-113), INT8_C(  -3), INT8_C(  14),
                           INT8_C( 109), INT8_C(  43), INT8_C( -54), INT8_C( 111),
                           INT8_C( -91), INT8_C( -21), INT8_C( 102), INT8_C(   8),
                           INT8_C( -41), INT8_C( -47), INT8_C( -90), INT8_C(   3),
                           INT8_C(  18), INT8_C(  32), INT8_C(  89), INT8_C( -62)),
      simde_mm512_set_epi8(INT8_C(  73), INT8_C(  68), INT8_C( -71), INT8_C( -46),
                           INT8_C(  72), INT8_C(  42), INT8_C(  65), INT8_C( -27),
                           INT8_C( -37), INT8_C(  76), INT8_C(  84), INT8_C( -95),
                           INT8_C( -29), INT8_C(  29), INT8_C(  64), INT8_C(  75),
                           INT8_C( -17), INT8_C( -61), INT8_C(  76), INT8_C(  88),
                           INT8_C(-100), INT8_C( -91), INT8_C( 111), INT8_C( -59),
                           INT8_C( -31), INT8_C( -17), INT8_C(  31), INT8_C(  68),
                           INT8_C(  90), INT8_C(  18), INT8_C(-110), INT8_C(  39),
                           INT8_C(  15), INT8_C(  62), INT8_C(  24), INT8_C( -25),
                           INT8_C(  80), INT8_C( 122), INT8_C( 103), INT8_C(-115),
                           INT8_C(  81), INT8_C(  24), INT8_C(  32), INT8_C(  82),
                           INT8_C( -27), INT8_C( 105), INT8_C(  -3), INT8_C(  14),
                           INT8_C( 109), INT8_C(  43), INT8_C( -54), INT8_C(-121),
                           INT8_C( -91), INT8_C(-124), INT8_C( 102), INT8_C(  46),
                           INT8_C( -41), INT8_C( 101), INT8_C(  51), INT8_C(   3),
                           INT8_C(  18), INT8_C(  32), INT8_C( -12), INT8_C( -62)),
      UINT64_C(0xe066cbadd08bea9d) },
    { simde_mm512_set_epi8(INT8_C( -84), INT8_C(-108), INT8_C(  13), INT8_C( -97),
                           INT8_C( -34), INT8_C(  27), INT8_C( 124), INT8_C(-120),
                           INT8_C(   3), INT8_C(  26), INT8_C(  43), INT8_C( -96),
                           INT8_C( -63), INT8_C(  49), INT8_C( 127), INT8_C(   0),
                           INT8_C( -20), INT8_C( -31), INT8_C( 125), INT8_C(  14),
                           INT8_C( -53), INT8_C( -87), INT8_C( 115), INT8_C( -20),
                           INT8_C( -93), INT8_C(  70), INT8_C(  29), INT8_C( -90),
                           INT8_C( 105), INT8_C( -54), INT8_C(  96), INT8_C(-106),
                           INT8_C(  94), INT8_C( -52), INT8_C( -50), INT8_C( -79),
                           INT8_C( -54), INT8_C(  78), INT8_C(  17), INT8_C(  81),
                           INT8_C(  35), INT8_C( 120), INT8_C(  47), INT8_C( -25),
                           INT8_C( 110), INT8_C(  55), INT8_C(  40), INT8_C( -31),
                           INT8_C(  93), INT8_C( -23), INT8_C(   4), INT8_C(  45),
                           INT8_C(  59), INT8_C( -33), INT8_C( 124), INT8_C( -52),
                           INT8_C(  42), INT8_C( -14), INT8_C(-119), INT8_C(  88),
                           INT8_C( -38), INT8_C( -31), INT8_C(-113), INT8_C(  33)),
      simde_mm512_set_epi8(INT8_C(  25), INT8_C(-108), INT8_C(  13), INT8_C( -97),
                           INT8_C( -34), INT8_C( 119), INT8_C( 122), INT8_C(  82),
                           INT8_C(   3), INT8_C(-111), INT8_C(  60), INT8_C( -96),
                           INT8_C(  26), INT8_C(   3), INT8_C(  -7), INT8_C(  -8),
                           INT8_C(  94), INT8_C( -31), INT8_C( -71), INT8_C(  14),
                           INT8_C(-105), INT8_C( -87), INT8_C( 115), INT8_C( -68),
                           INT8_C( -93), INT8_C(  70), INT8_C( -47), INT8_C(-106),
                           INT8_C( 105), INT8_C( -54), INT8_C(  96), INT8_C( 105),
                           INT8_C(  94), INT8_C(  84), INT8_C( -50), INT8_C( -79),
                           INT8_C( -54), INT8_C(  78), INT8_C(  17), INT8_C(  39),
                           INT8_C(  35), INT8_C( -87), INT8_C( -83), INT8_C( -25),
                           INT8_C( 110), INT8_C(   2), INT8_C( -90), INT8_C( -31),
                           INT8_C(  19), INT8_C( -23), INT8_C(   4), INT8_C(  16),
                           INT8_C(  59), INT8_C( -33), INT8_C( 124), INT8_C( 127),
                           INT8_C( -60), INT8_C( -14), INT8_C(-119), INT8_C(  88),
                           INT8_C( -38), INT8_C( 109), INT8_C(-113), INT8_C(  25)),
      UINT64_C(0x789056cebe996e7a) },
    { simde_mm512_set_epi8(INT8_C(  93), INT8_C( 110), INT8_C( 120), INT8_C(  25),
                           INT8_C( -37), INT8_C( -25), INT8_C( -34), INT8_C(-108),
                           INT8_C( -77), INT8_C(-114), INT8_C(  79), INT8_C( -50),
                           INT8_C( -94), INT8_C(  22), INT8_C( -28), INT8_C(-105),
                           INT8_C( 110), INT8_C(  29), INT8_C(  -9), INT8_C( -13),
                           INT8_C( -71), INT8_C( 107), INT8_C(-115), INT8_C(  86),
                           INT8_C(-127), INT8_C(-100), INT8_C(   1), INT8_C(  21),
                           INT8_C( -55), INT8_C( -85), INT8_C( -55), INT8_C( -81),
                           INT8_C( -41), INT8_C(  39), INT8_C(  18), INT8_C( -92),
                           INT8_C(  11), INT8_C( -32), INT8_C( -53), INT8_C(  38),
                           INT8_C( -49), INT8_C(-118), INT8_C(  20), INT8_C(  66),
                           INT8_C(-106), INT8_C(-109), INT8_C(  45), INT8_C( -24),
                           INT8_C( -47), INT8_C(  95), INT8_C(  50), INT8_C( 105),
                           INT8_C(  58), INT8_C(  25), INT8_C( -53), INT8_C( -61),
                           INT8_C( -90), INT8_C(  92), INT8_C(  83), INT8_C( 120),
                           INT8_C( 107), INT8_C( -72), INT8_C(   3), INT8_C(  -1)),
      simde_mm512_set_epi8(INT8_C(  93), INT8_C( 110), INT8_C( 120), INT8_C( -75),
                           INT8_C( -37), INT8_C( -25), INT8_C(  14), INT8_C(-108),
                           INT8_C(   5), INT8_C(-114), INT8_C(  79), INT8_C(  57),
                           INT8_C( -94), INT8_C(  22), INT8_C(   4), INT8_C(   3),
                           INT8_C(  66), INT8_C(  29), INT8_C(  -9), INT8_C(  20),
                           INT8_C(  93), INT8_C( 107), INT8_C(   6), INT8_C(  86),
                           INT8_C(  84), INT8_C(-100), INT8_C(  81), INT8_C(  21),
                           INT8_C( 117), INT8_C(  22), INT8_C( -55), INT8_C( -81),
                           INT8_C( -41), INT8_C( -17), INT8_C(  19), INT8_C( 106),
                           INT8_C( 114), INT8_C( -32), INT8_C(  98), INT8_C( -16),
                           INT8_C( -49), INT8_C(-118), INT8_C(  20), INT8_C(  66),
                           INT8_C(-106), INT8_C(-109), INT8_C(  97), INT8_C(  29),
                           INT8_C( -47), INT8_C( -47), INT8_C(  50), INT8_C(-111),
                           INT8_C(  58), INT8_C( 115), INT8_C( -53), INT8_C(  93),
                           INT8_C( -90), INT8_C( -27), INT8_C(  41), INT8_C( 120),
                           INT8_C( 119), INT8_C(  86), INT8_C( -36), INT8_C(  -1)),
      UINT64_C(0xed6c655384fcaa91) },
    { simde_mm512_set_epi8(INT8_C(  10), INT8_C(  75), INT8_C(  91), INT8_C( -99),
                           INT8_C( -88), INT8_C(  99), INT8_C( -86), INT8_C(  96),
                           INT8_C(  14), INT8_C(  -1), INT8_C(  14), INT8_C( 100),
                           INT8_C(-114), INT8_C(  63), INT8_C(  68), INT8_C(-113),
                           INT8_C( -59), INT8_C( -42), INT8_C( -14), INT8_C(-111),
                           INT8_C(   6), INT8_C(  68), INT8_C(  11), INT8_C(-108),
                           INT8_C( -62), INT8_C(  87), INT8_C( -72), INT8_C( -23),
                           INT8_C(  78), INT8_C( -18), INT8_C( -36), INT8_C(  -6),
                           INT8_C( -68), INT8_C(-115), INT8_C( -24), INT8_C( 127),
                           INT8_C( -36), INT8_C(  21), INT8_C(  38), INT8_C(-106),
                           INT8_C(  33), INT8_C( -66), INT8_C(-121), INT8_C(  36),
                           INT8_C(  24), INT8_C(  61), INT8_C(  66), INT8_C(  20),
                           INT8_C(  63), INT8_C( -18), INT8_C(  11), INT8_C(-103),
                           INT8_C( -19), INT8_C( -42), INT8_C( -69), INT8_C(  53),
                           INT8_C( -40), INT8_C( 112), INT8_C(   8), INT8_C( -69),
                           INT8_C(-102), INT8_C(  62), INT8_C(  85), INT8_C(  62)),
      simde_mm512_set_epi8(INT8_C(  10), INT8_C(  75), INT8_C( -74), INT8_C( -47),
                           INT8_C( -88), INT8_C(  99), INT8_C( -86), INT8_C(-128),
                           INT8_C(  94), INT8_C(  -1), INT8_C(  99), INT8_C( 100),
                           INT8_C( -25), INT8_C(   7), INT8_C(  59), INT8_C(-113),
                           INT8_C( 119), INT8_C( -42), INT8_C( -14), INT8_C(  79),
                           INT8_C(   4), INT8_C(-111), INT8_C(  11), INT8_C(  80),
                           INT8_C( -78), INT8_C(  87), INT8_C( -72), INT8_C(-111),
                           INT8_C( -95), INT8_C( -18), INT8_C( -36), INT8_C( -40),
                           INT8_C( -68), INT8_C(-115), INT8_C( -24), INT8_C( -50),
                           INT8_C( -36), INT8_C(  10), INT8_C(  47), INT8_C(  62),
                           INT8_C( -15), INT8_C( -66), INT8_C(-122), INT8_C(  36),
                           INT8_C( -22), INT8_C(  61), INT8_C( -11), INT8_C(  20),
                           INT8_C(  63), INT8_C(  82), INT8_C(-113), INT8_C(-103),
                           INT8_C( -19), INT8_C( -42), INT8_C( -69), INT8_C(  53),
                           INT8_C( -40), INT8_C( 112), INT8_C(   8), INT8_C( -69),
                           INT8_C(-102), INT8_C(  23), INT8_C(  85), INT8_C(  62)),
      UINT64_C(0xce516266e8559ffb) },
    { simde_mm512_set_epi8(INT8_C(  -7), INT8_C(   2), INT8_C(-111), INT8_C(  64),
                           INT8_C(-100), INT8_C(  87), INT8_C( 100), INT8_C( -30),
                           INT8_C( -39), INT8_C( -38), INT8_C( 121), INT8_C(  55),
                           INT8_C( -64), INT8_C(  81), INT8_C(  -3), INT8_C(  79),
                           INT8_C( -41), INT8_C( 118), INT8_C( -37), INT8_C( -34),
                           INT8_C( -13), INT8_C(  63), INT8_C(  26), INT8_C( -81),
                           INT8_C(  90), INT8_C(  43), INT8_C( -31), INT8_C( -17),
                           INT8_C(-100), INT8_C( -71), INT8_C(-104), INT8_C( -66),
                           INT8_C( -94), INT8_C( -89), INT8_C( 100), INT8_C(  36),
                           INT8_C(  17), INT8_C( 116), INT8_C( -30), INT8_C(  16),
                           INT8_C( 110), INT8_C(  98), INT8_C(  11), INT8_C( -42),
                           INT8_C( -78), INT8_C( -68), INT8_C( -26), INT8_C( -35),
                           INT8_C(  12), INT8_C( -40), INT8_C( -27), INT8_C( -40),
                           INT8_C(-102), INT8_C(-109), INT8_C(  39), INT8_C(  29),
                           INT8_C(  21), INT8_C(   9), INT8_C(  49), INT8_C( -13),
                           INT8_C( -49), INT8_C(   7), INT8_C(  91), INT8_C(  15)),
      simde_mm512_set_epi8(INT8_C(  78), INT8_C(   2), INT8_C( -91), INT8_C(  64),
                           INT8_C(-100), INT8_C(  41), INT8_C( -34), INT8_C( -46),
                           INT8_C( -39), INT8_C(  31), INT8_C(  13), INT8_C(  55),
                           INT8_C( -42), INT8_C(  33), INT8_C(  -3), INT8_C(  79),
                           INT8_C( -41), INT8_C( 118), INT8_C( -37), INT8_C(  90),
                           INT8_C( -13), INT8_C(  63), INT8_C(  51), INT8_C( -81),
                           INT8_C(  90), INT8_C(  43), INT8_C( -31), INT8_C(-112),
                           INT8_C(-100), INT8_C(  41), INT8_C(-104), INT8_C( -66),
                           INT8_C( -94), INT8_C( -89), INT8_C( -85), INT8_C(-109),
                           INT8_C( 113), INT8_C( 116), INT8_C( 100), INT8_C(  16),
                           INT8_C(   5), INT8_C( -50), INT8_C( -51), INT8_C( -42),
                           INT8_C( -95), INT8_C( -68), INT8_C( -26), INT8_C( -35),
                           INT8_C( -73), INT8_C(  71), INT8_C(  65), INT8_C( -40),
                           INT8_C(-102), INT8_C(   7), INT8_C(  94), INT8_C(  29),
                           INT8_C(  65), INT8_C(   9), INT8_C(  49), INT8_C( -13),
                           INT8_C( -33), INT8_C(   7), INT8_C(-101), INT8_C(  15)),
      UINT64_C(0x5893edebc5171975) },
    { simde_mm512_set_epi8(INT8_C( -34), INT8_C( -12), INT8_C( 105), INT8_C(-124),
                           INT8_C( -33), INT8_C( -79), INT8_C(  -6), INT8_C(  54),
                           INT8_C(  81), INT8_C( -11), INT8_C(  67), INT8_C(  63),
                           INT8_C( 103), INT8_C( 119), INT8_C( -89), INT8_C(  40),
                           INT8_C(   8), INT8_C( -38), INT8_C(  71), INT8_C(  66),
                           INT8_C(-106), INT8_C( -45), INT8_C(  18), INT8_C( 100),
                           INT8_C( 122), INT8_C(  93), INT8_C( -42), INT8_C(   5),
                           INT8_C( -39), INT8_C(  37), INT8_C( -70), INT8_C(  13),
                           INT8_C(  99), INT8_C( -57), INT8_C( -88), INT8_C( -36),
                           INT8_C(-103), INT8_C(  25), INT8_C(  94), INT8_C(-107),
                           INT8_C( -32), INT8_C( -12), INT8_C( -14), INT8_C(  32),
                           INT8_C( -38), INT8_C(  10), INT8_C(  89), INT8_C( -69),
                           INT8_C(  -8), INT8_C(  69), INT8_C( -20), INT8_C(-122),
                           INT8_C( -75), INT8_C( -71), INT8_C(   3), INT8_C( 102),
                           INT8_C( 119), INT8_C( -58), INT8_C( -49), INT8_C(  80),
                           INT8_C( -15), INT8_C( -97), INT8_C(  45), INT8_C(  96)),
      simde_mm512_set_epi8(INT8_C( -34), INT8_C( -12), INT8_C(  81), INT8_C(-115),
                           INT8_C( -33), INT8_C( -79), INT8_C(-117), INT8_C( -34),
                           INT8_C(  81), INT8_C( -11), INT8_C( -63), INT8_C( -61),
                           INT8_C(  53), INT8_C( 119), INT8_C(  26), INT8_C(  40),
                           INT8_C(   8), INT8_C( -38), INT8_C(  25), INT8_C( -23),
                           INT8_C( -16), INT8_C( -45), INT8_C( -64), INT8_C( 100),
                           INT8_C(  91), INT8_C(  93), INT8_C( -42), INT8_C(   5),
                           INT8_C(  81), INT8_C( -76), INT8_C( -70), INT8_C(  13),
                           INT8_C(  26), INT8_C( -57), INT8_C( -88), INT8_C( -64),
                           INT8_C( -68), INT8_C( -91), INT8_C(-123), INT8_C(  38),
                           INT8_C( -32), INT8_C(  29), INT8_C(  82), INT8_C(  54),
                           INT8_C(-107), INT8_C(  10), INT8_C(  89), INT8_C(  28),
                           INT8_C( -27), INT8_C(  41), INT8_C( -20), INT8_C(-122),
                           INT8_C( -75), INT8_C( -71), INT8_C(   3), INT8_C( -30),
                           INT8_C(  97), INT8_C(  18), INT8_C( -90), INT8_C( 107),
                           INT8_C(  99), INT8_C(  10), INT8_C(  45), INT8_C(  96)),
      UINT64_C(0xccc5c57360863e03) },
    { simde_mm512_set_epi8(INT8_C(  48), INT8_C(  94), INT8_C( 112), INT8_C(-107),
                           INT8_C( -34), INT8_C( -86), INT8_C(  65), INT8_C(  92),
                           INT8_C(  97), INT8_C( -99), INT8_C(  28), INT8_C(  47),
                           INT8_C(-117), INT8_C( -22), INT8_C(-111), INT8_C( -67),
                           INT8_C( 113), INT8_C(-107), INT8_C( -23), INT8_C(  77),
                           INT8_C(  60), INT8_C( 104), INT8_C(-116), INT8_C( -86),
                           INT8_C(-113), INT8_C( -79), INT8_C( -64), INT8_C( -15),
                           INT8_C(-123), INT8_C(  99), INT8_C(  25), INT8_C(  27),
                           INT8_C( -40), INT8_C( 126), INT8_C( -66), INT8_C( -45),
                           INT8_C(  57), INT8_C( -30), INT8_C( -12), INT8_C(  16),
                           INT8_C( 122), INT8_C( 124), INT8_C( -75), INT8_C(  50),
                           INT8_C(  -6), INT8_C(  41), INT8_C( -47), INT8_C(  -3),
                           INT8_C(  29), INT8_C( -20), INT8_C( -45), INT8_C( -46),
                           INT8_C( -45), INT8_C( -14), INT8_C(  99), INT8_C(  84),
                           INT8_C( -62), INT8_C( -99), INT8_C(-104), INT8_C( -78),
                           INT8_C( 106), INT8_C(-117), INT8_C( -94), INT8_C(   3)),
      simde_mm512_set_epi8(INT8_C( -88), INT8_C( -74), INT8_C(   2), INT8_C( -83),
                           INT8_C(-112), INT8_C( -91), INT8_C(  65), INT8_C(  92),
                           INT8_C(  97), INT8_C(  52), INT8_C(  28), INT8_C( -65),
                           INT8_C(-117), INT8_C( -90), INT8_C(-111), INT8_C( -67),
                           INT8_C( 113), INT8_C(  16), INT8_C(-124), INT8_C(  77),
                           INT8_C(  60), INT8_C( -64), INT8_C(-116), INT8_C( -89),
                           INT8_C(  -7), INT8_C( -79), INT8_C(  46), INT8_C( 114),
                           INT8_C(-107), INT8_C(  99), INT8_C( -79), INT8_C(  80),
                           INT8_C( -40), INT8_C( -81), INT8_C( -66), INT8_C( -45),
                           INT8_C(  57), INT8_C( -30), INT8_C(  66), INT8_C(  71),
                           INT8_C( 122), INT8_C(  95), INT8_C( -43), INT8_C(  50),
                           INT8_C(  -6), INT8_C(  41), INT8_C( -47), INT8_C(  95),
                           INT8_C(   5), INT8_C( -20), INT8_C( -45), INT8_C(-118),
                           INT8_C(  70), INT8_C(  81), INT8_C(   0), INT8_C(  84),
                           INT8_C( -62), INT8_C(-101), INT8_C(  13), INT8_C(  33),
                           INT8_C(-104), INT8_C(-117), INT8_C( -11), INT8_C(  20)),
      UINT64_C(0x3ab9a44bc9e6184) },
    { simde_mm512_set_epi8(INT8_C(  67), INT8_C(  34), INT8_C( -33), INT8_C(  31),
                           INT8_C(-128), INT8_C(  55), INT8_C(  93), INT8_C(  58),
                           INT8_C(  57), INT8_C( 104), INT8_C(-110), INT8_C(  59),
                           INT8_C(  55), INT8_C(  33), INT8_C(-122), INT8_C(  69),
                           INT8_C(  57), INT8_C(  30), INT8_C( -13), INT8_C( -65),
                           INT8_C( -22), INT8_C(-100), INT8_C(  18), INT8_C( -65),
                           INT8_C( -60), INT8_C(-105), INT8_C(  27), INT8_C( -71),
                           INT8_C(  52), INT8_C(  12), INT8_C(  -4), INT8_C(  64),
                           INT8_C(  20), INT8_C(  51), INT8_C(  87), INT8_C(  43),
                           INT8_C(  26), INT8_C(   6), INT8_C( -66), INT8_C( -40),
                           INT8_C(  87), INT8_C(   1), INT8_C( -26), INT8_C(  92),
                           INT8_C( -33), INT8_C(   8), INT8_C(  42), INT8_C( -93),
                           INT8_C(  44), INT8_C( -55), INT8_C(-113), INT8_C( -43),
                           INT8_C(  32), INT8_C( 105), INT8_C( -27), INT8_C(  96),
                           INT8_C(  72), INT8_C(  48), INT8_C( -46), INT8_C(  24),
                           INT8_C( -10), INT8_C( -98), INT8_C( -56), INT8_C( -41)),
      simde_mm512_set_epi8(INT8_C(  67), INT8_C( -63), INT8_C( -33), INT8_C(  31),
                           INT8_C(-128), INT8_C(  55), INT8_C(  93), INT8_C(  -8),
                           INT8_C(  82), INT8_C( 104), INT8_C(-110), INT8_C(  59),
                           INT8_C(  55), INT8_C(   0), INT8_C( -25), INT8_C(  69),
                           INT8_C(  27), INT8_C(  30), INT8_C( -13), INT8_C( -65),
                           INT8_C(  -7), INT8_C( -28), INT8_C(  18), INT8_C( -65),
                           INT8_C(  67), INT8_C(  -3), INT8_C(  57), INT8_C( -68),
                           INT8_C(  52), INT8_C(  12), INT8_C(  -4), INT8_C(-128),
                           INT8_C(  20), INT8_C(  37), INT8_C(   9), INT8_C(  80),
                           INT8_C(  26), INT8_C(   6), INT8_C( -66), INT8_C(   9),
                           INT8_C( -98), INT8_C(   1), INT8_C( -26), INT8_C(  92),
                           INT8_C( -33), INT8_C(   8), INT8_C( -81), INT8_C( -93),
                           INT8_C( 116), INT8_C( -55), INT8_C(-113), INT8_C( -43),
                           INT8_C(  32), INT8_C( 105), INT8_C( -27), INT8_C(  37),
                           INT8_C(  72), INT8_C( -73), INT8_C( -19), INT8_C(  96),
                           INT8_C(  52), INT8_C( -98), INT8_C( -45), INT8_C( -41)),
      UINT64_C(0xbe79730e8e7d7e85) },
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])); i++) {
    simde__mmask64 r = simde_mm512_cmpeq_epi8_mask(test_vec[i].a, test_vec[i].b);
    simde_assert_mmask64(r, ==, test_vec[i].r);
  }

  return 0;
}

static int
test_simde_mm512_cmpge_epi8_mask(SIMDE_MUNIT_TEST_ARGS) {
  const struct {
    simde__m512i   a;
    simde__m512i   b;
    simde__mmask64 r;
  } test_vec[8] = {
    { simde_mm512_set_epi8(INT8_C(  92), INT8_C(-121), INT8_C( 120), INT8_C( -19),
                           INT8_C( -73), INT8_C(  22), INT8_C( -66), INT8_C( -29),
                           INT8_C(  55), INT8_C( -63), INT8_C( -45), INT8_C(-119),
                           INT8_C(  30), INT8_C( -29), INT8_C( -26), INT8_C(  89),
                           INT8_C( -13), INT8_C( 119), INT8_C( -88), INT8_C( 109),
                           INT8_C(  68), INT8_C( -10), INT8_C(   0), INT8_C( -18),
                           INT8_C(   1), INT8_C( 116), INT8_C( -13), INT8_C( -73),
                           INT8_C(-122), INT8_C(   0), INT8_C( 111), INT8_C(  95),
                           INT8_C( -20), INT8_C(   3), INT8_C( 122), INT8_C( -43),
                           INT8_C(  13), INT8_C(  25), INT8_C( -35), INT8_C(-127),
                           INT8_C(  82), INT8_C(  90), INT8_C(  53), INT8_C( 123),
                           INT8_C(  73), INT8_C( 108), INT8_C( -18), INT8_C(  15),
                           INT8_C( 115), INT8_C(  54), INT8_C( 102), INT8_C( 118),
                           INT8_C(  39), INT8_C( -77), INT8_C(  45), INT8_C(  81),
                           INT8_C( -17), INT8_C( -28), INT8_C(  67), INT8_C( -85),
                           INT8_C(  79), INT8_C(-113), INT8_C(-122), INT8_C( 124)),
      simde_mm512_set_epi8(INT8_C(   9), INT8_C(-121), INT8_C( 120), INT8_C( -36),
                           INT8_C(  36), INT8_C(-103), INT8_C(-104), INT8_C(  25),
                           INT8_C(-111), INT8_C( -63), INT8_C( -35), INT8_C(-120),
                           INT8_C(  28), INT8_C( -44), INT8_C( -26), INT8_C( -86),
                           INT8_C( -13), INT8_C(  53), INT8_C( -88), INT8_C(-107),
                           INT8_C(  68), INT8_C(  42), INT8_C(-118), INT8_C( 111),
                           INT8_C(  54), INT8_C( -58), INT8_C( -13), INT8_C(  27),
                           INT8_C(  23), INT8_C(  41), INT8_C(-119), INT8_C(  44),
                           INT8_C(   7), INT8_C(-120), INT8_C(  32), INT8_C( -43),
                           INT8_C( 114), INT8_C( -72), INT8_C(  73), INT8_C( -96),
                           INT8_C(  96), INT8_C( 110), INT8_C( -81), INT8_C( -76),
                           INT8_C( 103), INT8_C(-100), INT8_C( -22), INT8_C(  18),
                           INT8_C( 115), INT8_C(  54), INT8_C( -40), INT8_C( 125),
                           INT8_C( 110), INT8_C(  31), INT8_C(  51), INT8_C(-104),
                           INT8_C(-115), INT8_C( -27), INT8_C(  62), INT8_C( -85),
                           INT8_C(  49), INT8_C(-115), INT8_C(  38), INT8_C(   4)),
      UINT64_C(0xf6dffa637436e1bd) },
    { simde_mm512_set_epi8(INT8_C(  16), INT8_C(  41), INT8_C( 102), INT8_C( -95),
                           INT8_C(  17), INT8_C(  42), INT8_C( -86), INT8_C(  38),
                           INT8_C(  62), INT8_C( -56), INT8_C(  60), INT8_C(  19),
                           INT8_C(-100), INT8_C(-107), INT8_C( 105), INT8_C( -76),
                           INT8_C(  10), INT8_C(  -9), INT8_C( -12), INT8_C( -56),
                           INT8_C( -71), INT8_C(  96), INT8_C(  31), INT8_C(  24),
                           INT8_C(  68), INT8_C(  -7), INT8_C( -27), INT8_C(   3),
                           INT8_C( -21), INT8_C(  50), INT8_C( -67), INT8_C( -39),
                           INT8_C(-108), INT8_C(  62), INT8_C( 101), INT8_C(  56),
                           INT8_C( -79), INT8_C( -37), INT8_C( -99), INT8_C( -56),
                           INT8_C(-119), INT8_C( -56), INT8_C(  -8), INT8_C( -16),
                           INT8_C( 115), INT8_C( -95), INT8_C( -73), INT8_C(  54),
                           INT8_C( 125), INT8_C(  85), INT8_C(  78), INT8_C( -65),
                           INT8_C(   4), INT8_C(  38), INT8_C( -84), INT8_C( -53),
                           INT8_C(  68), INT8_C(-108), INT8_C(-121), INT8_C(-115),
                           INT8_C( -59), INT8_C( -78), INT8_C(-111), INT8_C(  56)),
      simde_mm512_set_epi8(INT8_C(-104), INT8_C(-102), INT8_C( 102), INT8_C( -95),
                           INT8_C(  69), INT8_C(  13), INT8_C( -21), INT8_C(  45),
                           INT8_C(  62), INT8_C(-120), INT8_C(-111), INT8_C(  32),
                           INT8_C(-107), INT8_C( -30), INT8_C(  99), INT8_C( -64),
                           INT8_C(   8), INT8_C( -42), INT8_C(  81), INT8_C( -34),
                           INT8_C( -46), INT8_C(  26), INT8_C(  31), INT8_C(  -2),
                           INT8_C(  68), INT8_C(  -7), INT8_C( -71), INT8_C(  46),
                           INT8_C( -21), INT8_C( -73), INT8_C(  21), INT8_C(  83),
                           INT8_C(-108), INT8_C( -97), INT8_C( -69), INT8_C(  73),
                           INT8_C(  57), INT8_C( -37), INT8_C(  21), INT8_C(  82),
                           INT8_C(-119), INT8_C(-126), INT8_C( 126), INT8_C(  91),
                           INT8_C( 115), INT8_C(  31), INT8_C( -79), INT8_C(  28),
                           INT8_C(-106), INT8_C( -18), INT8_C(  65), INT8_C(-104),
                           INT8_C(  81), INT8_C(  38), INT8_C( -84), INT8_C(  -2),
                           INT8_C( -14), INT8_C(  85), INT8_C( -80), INT8_C(  80),
                           INT8_C(  48), INT8_C(  93), INT8_C(  79), INT8_C( 127)),
      UINT64_C(0xf4eac7ece4cbf680) },
    { simde_mm512_set_epi8(INT8_C(  50), INT8_C(  43), INT8_C( -68), INT8_C(  97),
                           INT8_C( -26), INT8_C(-103), INT8_C(  71), INT8_C(-107),
                           INT8_C(  91), INT8_C(  45), INT8_C( -11), INT8_C(  47),
                           INT8_C(  29), INT8_C( -56), INT8_C(  26), INT8_C(  -9),
                           INT8_C(  10), INT8_C(  36), INT8_C(-116), INT8_C( -53),
                           INT8_C(  41), INT8_C(   1), INT8_C( -23), INT8_C(  61),
                           INT8_C(-127), INT8_C(  -4), INT8_C(  48), INT8_C( -68),
                           INT8_C(  89), INT8_C(-112), INT8_C( -31), INT8_C( 120),
                           INT8_C(  35), INT8_C(  62), INT8_C( -21), INT8_C(-114),
                           INT8_C(-104), INT8_C(  57), INT8_C(  42), INT8_C(-111),
                           INT8_C(  94), INT8_C( -63), INT8_C(  87), INT8_C(  64),
                           INT8_C( -65), INT8_C(  -2), INT8_C( 110), INT8_C(  -8),
                           INT8_C(  63), INT8_C( -51), INT8_C(  -4), INT8_C(  32),
                           INT8_C( -65), INT8_C(  55), INT8_C(  14), INT8_C(  81),
                           INT8_C(-123), INT8_C(-100), INT8_C( -39), INT8_C( -44),
                           INT8_C(  22), INT8_C( 112), INT8_C(  16), INT8_C(  15)),
      simde_mm512_set_epi8(INT8_C(  50), INT8_C( -11), INT8_C( -68), INT8_C( -31),
                           INT8_C( 105), INT8_C(-106), INT8_C(  98), INT8_C(  51),
                           INT8_C(  58), INT8_C( 103), INT8_C( 111), INT8_C(-127),
                           INT8_C(  68), INT8_C( -56), INT8_C( 124), INT8_C(-119),
                           INT8_C(  74), INT8_C( -62), INT8_C(-116), INT8_C(  37),
                           INT8_C( -12), INT8_C( 114), INT8_C(   0), INT8_C(  61),
                           INT8_C( 103), INT8_C(  -4), INT8_C(-105), INT8_C( -68),
                           INT8_C(  39), INT8_C(-100), INT8_C( -93), INT8_C(  11),
                           INT8_C( -80), INT8_C( -19), INT8_C( -22), INT8_C( -39),
                           INT8_C( 127), INT8_C( -38), INT8_C(-125), INT8_C(-111),
                           INT8_C(  84), INT8_C( -96), INT8_C(  87), INT8_C( -22),
                           INT8_C(  -5), INT8_C(  -3), INT8_C(-127), INT8_C(  41),
                           INT8_C(  74), INT8_C(  72), INT8_C(  -4), INT8_C(  28),
                           INT8_C(-115), INT8_C(  93), INT8_C( 102), INT8_C(  44),
                           INT8_C(-103), INT8_C( -29), INT8_C( -50), INT8_C(  48),
                           INT8_C( -96), INT8_C( -50), INT8_C(  46), INT8_C( -65)),
      UINT64_C(0xf495697be7f6392d) },
    { simde_mm512_set_epi8(INT8_C( -97), INT8_C(  28), INT8_C( -58), INT8_C(  11),
                           INT8_C( -14), INT8_C( 126), INT8_C(  81), INT8_C(  45),
                           INT8_C( -23), INT8_C( 120), INT8_C( -83), INT8_C( -16),
                           INT8_C(   7), INT8_C(  51), INT8_C( -57), INT8_C( -50),
                           INT8_C( -21), INT8_C(  98), INT8_C(  88), INT8_C(   0),
                           INT8_C( -66), INT8_C(   3), INT8_C( 124), INT8_C(-113),
                           INT8_C(  50), INT8_C(  32), INT8_C( -85), INT8_C( -93),
                           INT8_C( -44), INT8_C( -13), INT8_C( -94), INT8_C(  17),
                           INT8_C( 122), INT8_C(  79), INT8_C(-116), INT8_C(  43),
                           INT8_C( -77), INT8_C(-125), INT8_C( -23), INT8_C(-120),
                           INT8_C(  96), INT8_C( -64), INT8_C( -23), INT8_C( -46),
                           INT8_C( -29), INT8_C( -71), INT8_C(  71), INT8_C( -80),
                           INT8_C(  44), INT8_C( -92), INT8_C( -31), INT8_C(  26),
                           INT8_C(   8), INT8_C(  52), INT8_C( 117), INT8_C( 123),
                           INT8_C( -63), INT8_C(  45), INT8_C(  95), INT8_C(  24),
                           INT8_C(-108), INT8_C(  18), INT8_C( -60), INT8_C(  28)),
      simde_mm512_set_epi8(INT8_C( -23), INT8_C(-101), INT8_C( 116), INT8_C( 127),
                           INT8_C(  96), INT8_C(  40), INT8_C( -97), INT8_C(  40),
                           INT8_C(  86), INT8_C( -44), INT8_C(  70), INT8_C( -71),
                           INT8_C(  62), INT8_C( -21), INT8_C(  66), INT8_C(  68),
                           INT8_C( -87), INT8_C( -61), INT8_C(  48), INT8_C( -70),
                           INT8_C(  18), INT8_C( -78), INT8_C( -98), INT8_C( 117),
                           INT8_C(  74), INT8_C(  32), INT8_C(  93), INT8_C( 125),
                           INT8_C( -47), INT8_C( -60), INT8_C( -86), INT8_C( 117),
                           INT8_C( 122), INT8_C( -54), INT8_C(  50), INT8_C( 123),
                           INT8_C( -31), INT8_C( -74), INT8_C( -64), INT8_C(  54),
                           INT8_C( -81), INT8_C(  60), INT8_C(  31), INT8_C( -23),
                           INT8_C( 108), INT8_C(-119), INT8_C( -92), INT8_C( -80),
                           INT8_C( -30), INT8_C( -37), INT8_C(  51), INT8_C( -36),
                           INT8_C(   8), INT8_C(  52), INT8_C(  97), INT8_C( 123),
                           INT8_C( -49), INT8_C(-124), INT8_C(  95), INT8_C( -83),
                           INT8_C(  70), INT8_C( -50), INT8_C( -61), INT8_C(  25)),
      UINT64_C(0x4754f64cc2879f77) },
    { simde_mm512_set_epi8(INT8_C( 121), INT8_C( -20), INT8_C( -89), INT8_C( -94),
                           INT8_C( 112), INT8_C( -27), INT8_C(  81), INT8_C( -54),
                           INT8_C( -64), INT8_C(-114), INT8_C(  48), INT8_C( -89),
                           INT8_C( -61), INT8_C(  26), INT8_C(  43), INT8_C(  29),
                           INT8_C(   0), INT8_C( 125), INT8_C( -42), INT8_C( -67),
                           INT8_C(  15), INT8_C( 120), INT8_C(  36), INT8_C(  40),
                           INT8_C( -53), INT8_C(  34), INT8_C(-108), INT8_C( -58),
                           INT8_C(  26), INT8_C(-111), INT8_C(  63), INT8_C( -98),
                           INT8_C(  65), INT8_C(   8), INT8_C(-124), INT8_C(  96),
                           INT8_C( -13), INT8_C( -98), INT8_C(  99), INT8_C(  90),
                           INT8_C(  56), INT8_C( -45), INT8_C(-108), INT8_C( -19),
                           INT8_C(-124), INT8_C( -27), INT8_C(  22), INT8_C( 126),
                           INT8_C(-106), INT8_C( -68), INT8_C( -60), INT8_C(   8),
                           INT8_C( -54), INT8_C(  93), INT8_C( -33), INT8_C( -27),
                           INT8_C(  -7), INT8_C(  27), INT8_C(-122), INT8_C( -88),
                           INT8_C(  23), INT8_C(   6), INT8_C(  45), INT8_C( -21)),
      simde_mm512_set_epi8(INT8_C( 105), INT8_C(  52), INT8_C(  85), INT8_C(-104),
                           INT8_C(  57), INT8_C( -31), INT8_C( -38), INT8_C(-124),
                           INT8_C(-107), INT8_C(  -2), INT8_C(  55), INT8_C(  46),
                           INT8_C( -71), INT8_C(  77), INT8_C(  18), INT8_C(  70),
                           INT8_C(  89), INT8_C( 125), INT8_C( -42), INT8_C(-125),
                           INT8_C( 121), INT8_C( -11), INT8_C( -69), INT8_C( -59),
                           INT8_C( -53), INT8_C(  34), INT8_C(   9), INT8_C(  64),
                           INT8_C( -61), INT8_C( -25), INT8_C(-115), INT8_C( 100),
                           INT8_C(  65), INT8_C(   8), INT8_C(  69), INT8_C(  -8),
                           INT8_C( -15), INT8_C( -51), INT8_C(   1), INT8_C(  90),
                           INT8_C( 115), INT8_C(  51), INT8_C( -91), INT8_C(  56),
                           INT8_C(  64), INT8_C( -39), INT8_C(-119), INT8_C( -28),
                           INT8_C( -54), INT8_C(  28), INT8_C(  54), INT8_C(  -8),
                           INT8_C( -54), INT8_C(-128), INT8_C( -28), INT8_C( -71),
                           INT8_C( 107), INT8_C( -66), INT8_C(-114), INT8_C( -88),
                           INT8_C(  34), INT8_C( -83), INT8_C( -21), INT8_C( -64)),
      UINT64_C(0x9f8a77cadb071d57) },
    { simde_mm512_set_epi8(INT8_C(  33), INT8_C( 121), INT8_C( 125), INT8_C(  35),
                           INT8_C(-103), INT8_C( -48), INT8_C( -22), INT8_C(  38),
                           INT8_C( -81), INT8_C(   9), INT8_C( -11), INT8_C(-124),
                           INT8_C(  71), INT8_C(   9), INT8_C( -42), INT8_C( 118),
                           INT8_C(  67), INT8_C(  45), INT8_C(  51), INT8_C( -92),
                           INT8_C( 126), INT8_C( 108), INT8_C(-123), INT8_C( -71),
                           INT8_C( 113), INT8_C(  32), INT8_C(  71), INT8_C(   3),
                           INT8_C( -26), INT8_C(  82), INT8_C( -81), INT8_C( -20),
                           INT8_C( -55), INT8_C( 112), INT8_C(  66), INT8_C(  37),
                           INT8_C(  67), INT8_C( -69), INT8_C(  64), INT8_C(  39),
                           INT8_C(  72), INT8_C(  45), INT8_C( 120), INT8_C(  -5),
                           INT8_C(-109), INT8_C(  62), INT8_C(  17), INT8_C(  31),
                           INT8_C( -30), INT8_C( -58), INT8_C(  56), INT8_C(  21),
                           INT8_C(  72), INT8_C( -75), INT8_C( -34), INT8_C( 120),
                           INT8_C(  95), INT8_C( 108), INT8_C(  32), INT8_C(  64),
                           INT8_C(-128), INT8_C( 102), INT8_C( -21), INT8_C(  28)),
      simde_mm512_set_epi8(INT8_C( 100), INT8_C( 121), INT8_C(  18), INT8_C(  28),
                           INT8_C(-117), INT8_C( 107), INT8_C(   3), INT8_C( -62),
                           INT8_C(  42), INT8_C(  72), INT8_C(  91), INT8_C(  86),
                           INT8_C( -72), INT8_C(   9), INT8_C( -80), INT8_C( 118),
                           INT8_C( 122), INT8_C(-108), INT8_C( -70), INT8_C( -63),
                           INT8_C(  56), INT8_C(  71), INT8_C( -14), INT8_C(  49),
                           INT8_C( -73), INT8_C(  53), INT8_C( -29), INT8_C(   3),
                           INT8_C( -73), INT8_C(  43), INT8_C( -22), INT8_C(  85),
                           INT8_C( -26), INT8_C(  -9), INT8_C(  66), INT8_C(   1),
                           INT8_C( -13), INT8_C(  60), INT8_C(-119), INT8_C( -83),
                           INT8_C(-122), INT8_C( -64), INT8_C( -83), INT8_C( -74),
                           INT8_C( 119), INT8_C(  -8), INT8_C(  12), INT8_C( 113),
                           INT8_C( -12), INT8_C( -84), INT8_C(   6), INT8_C(  69),
                           INT8_C(   2), INT8_C( -75), INT8_C( -34), INT8_C(-126),
                           INT8_C(   3), INT8_C(-128), INT8_C(  -9), INT8_C(  24),
                           INT8_C(  11), INT8_C( -94), INT8_C( -32), INT8_C( 110)),
      UINT64_C(0x790f6cbc7bf66ff6) },
    { simde_mm512_set_epi8(INT8_C(   2), INT8_C( -81), INT8_C(  14), INT8_C(  90),
                           INT8_C(-100), INT8_C(-122), INT8_C( -35), INT8_C(  81),
                           INT8_C( -14), INT8_C( -42), INT8_C( 125), INT8_C(-125),
                           INT8_C( -57), INT8_C(  90), INT8_C(  -9), INT8_C(  63),
                           INT8_C(  53), INT8_C(  77), INT8_C(  63), INT8_C( -84),
                           INT8_C(  27), INT8_C(  22), INT8_C( -28), INT8_C( -37),
                           INT8_C(  65), INT8_C( 118), INT8_C(-126), INT8_C(  97),
                           INT8_C( 109), INT8_C(-119), INT8_C(-114), INT8_C( -75),
                           INT8_C(-125), INT8_C( 121), INT8_C(-128), INT8_C( 103),
                           INT8_C(   0), INT8_C( 101), INT8_C( -41), INT8_C(  89),
                           INT8_C(  67), INT8_C( -65), INT8_C(   9), INT8_C(  -7),
                           INT8_C( -63), INT8_C(  13), INT8_C( 105), INT8_C(  92),
                           INT8_C( -18), INT8_C( -21), INT8_C(-102), INT8_C(-114),
                           INT8_C(  74), INT8_C( 121), INT8_C( -45), INT8_C(  52),
                           INT8_C( -63), INT8_C( -93), INT8_C(  98), INT8_C( 106),
                           INT8_C(-109), INT8_C( -47), INT8_C(  37), INT8_C(  70)),
      simde_mm512_set_epi8(INT8_C( -42), INT8_C(-124), INT8_C(  54), INT8_C(  74),
                           INT8_C( -92), INT8_C(  99), INT8_C(  79), INT8_C(  -3),
                           INT8_C(  61), INT8_C( -89), INT8_C(  84), INT8_C( -94),
                           INT8_C(  31), INT8_C(-116), INT8_C( -67), INT8_C(-102),
                           INT8_C( -72), INT8_C( -91), INT8_C(-105), INT8_C(-108),
                           INT8_C( -44), INT8_C(  74), INT8_C( -28), INT8_C( 124),
                           INT8_C( 120), INT8_C( -41), INT8_C( -79), INT8_C( 122),
                           INT8_C(  87), INT8_C(-119), INT8_C(  54), INT8_C(  -2),
                           INT8_C( -47), INT8_C(  84), INT8_C(-126), INT8_C( -64),
                           INT8_C(  14), INT8_C(  11), INT8_C(  37), INT8_C( -23),
                           INT8_C(  67), INT8_C( 124), INT8_C(  58), INT8_C( -94),
                           INT8_C(  30), INT8_C( -33), INT8_C(  70), INT8_C( -24),
                           INT8_C(  38), INT8_C( -97), INT8_C( -56), INT8_C( -60),
                           INT8_C( -59), INT8_C(  65), INT8_C( -74), INT8_C(  45),
                           INT8_C( -11), INT8_C(  55), INT8_C( -82), INT8_C(  12),
                           INT8_C( 106), INT8_C(  22), INT8_C(-124), INT8_C(  -4)),
      UINT64_C(0xd167fa4c55974f33) },
    { simde_mm512_set_epi8(INT8_C(  18), INT8_C(  13), INT8_C(  14), INT8_C(   4),
                           INT8_C(  -3), INT8_C( -64), INT8_C(  17), INT8_C(-115),
                           INT8_C(  21), INT8_C( -34), INT8_C( 125), INT8_C( -60),
                           INT8_C( -72), INT8_C(  74), INT8_C(  -5), INT8_C( -21),
                           INT8_C( -41), INT8_C(  22), INT8_C(  45), INT8_C( 102),
                           INT8_C(  59), INT8_C( -80), INT8_C( -15), INT8_C( -63),
                           INT8_C(  84), INT8_C( -71), INT8_C(   8), INT8_C(  12),
                           INT8_C( -11), INT8_C( -76), INT8_C(  62), INT8_C(  93),
                           INT8_C( -75), INT8_C( -77), INT8_C( -84), INT8_C(-108),
                           INT8_C( -35), INT8_C(  14), INT8_C( -60), INT8_C(  18),
                           INT8_C(  23), INT8_C( -60), INT8_C( -63), INT8_C(-114),
                           INT8_C( -55), INT8_C(  75), INT8_C( -99), INT8_C( -55),
                           INT8_C(  58), INT8_C(  76), INT8_C(-102), INT8_C(-118),
                           INT8_C(  10), INT8_C(  39), INT8_C( 119), INT8_C(  85),
                           INT8_C(  -8), INT8_C( -72), INT8_C( -60), INT8_C( -94),
                           INT8_C(-112), INT8_C( 119), INT8_C( 124), INT8_C(  76)),
      simde_mm512_set_epi8(INT8_C(  18), INT8_C( -74), INT8_C(  14), INT8_C(  36),
                           INT8_C(  -7), INT8_C( 113), INT8_C(  40), INT8_C(  48),
                           INT8_C(-107), INT8_C( -34), INT8_C( -75), INT8_C(  85),
                           INT8_C( -35), INT8_C(-116), INT8_C(  65), INT8_C( -21),
                           INT8_C(  15), INT8_C(   3), INT8_C(  45), INT8_C(  21),
                           INT8_C(  72), INT8_C(  93), INT8_C( 108), INT8_C( 125),
                           INT8_C(   1), INT8_C(  75), INT8_C(  21), INT8_C( -36),
                           INT8_C(-126), INT8_C( 122), INT8_C(  71), INT8_C(  76),
                           INT8_C(  28), INT8_C( -56), INT8_C(  32), INT8_C( 101),
                           INT8_C(-107), INT8_C(-111), INT8_C( -88), INT8_C( -19),
                           INT8_C( -77), INT8_C(  19), INT8_C( -21), INT8_C(-111),
                           INT8_C( -68), INT8_C(  82), INT8_C(-118), INT8_C( -76),
                           INT8_C(  47), INT8_C( 127), INT8_C(  62), INT8_C( -16),
                           INT8_C(  10), INT8_C( -14), INT8_C(-100), INT8_C(  86),
                           INT8_C(  29), INT8_C( 107), INT8_C(  56), INT8_C(  21),
                           INT8_C(  24), INT8_C(  68), INT8_C( -96), INT8_C(  64)),
      UINT64_C(0xe8e570990f8b8e07) },
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])); i++) {
    simde__mmask64 r = simde_mm512_cmpge_epi8_mask(test_vec[i].a, test_vec[i].b);
    simde_assert_mmask64(r, ==, test_vec[i].r);
  }

  return 0;
}

static int
test_simde_mm512_cmpge_epu8_mask(SIMDE_MUNIT_TEST_ARGS) {
  const struct {
    simde__m512i   a;
    simde__m512i   b;
    simde__mmask64 r;
  } test_vec[8] = {
    { simde_x_mm512_set_epu8(UINT8_C( 92), UINT8_C(135), UINT8_C(120), UINT8_C(237),
                             UINT8_C(183), UINT8_C( 22), UINT8_C(190), UINT8_C(227),
                             UINT8_C( 55), UINT8_C(193), UINT8_C(211), UINT8_C(137),
                             UINT8_C( 30), UINT8_C(227), UINT8_C(230), UINT8_C( 89),
                             UINT8_C(243), UINT8_C(119), UINT8_C(168), UINT8_C(109),
                             UINT8_C( 68), UINT8_C(246), UINT8_C(  0), UINT8_C(238),
                             UINT8_C(  1), UINT8_C(116), UINT8_C(243), UINT8_C(183),
                             UINT8_C(134), UINT8_C(  0), UINT8_C(111), UINT8_C( 95),
                             UINT8_C(236), UINT8_C(  3), UINT8_C(122), UINT8_C(213),
                             UINT8_C( 13), UINT8_C( 25), UINT8_C(221), UINT8_C(129),
                             UINT8_C( 82), UINT8_C( 90), UINT8_C( 53), UINT8_C(123),
                             UINT8_C( 73), UINT8_C(108), UINT8_C(238), UINT8_C( 15),
                             UINT8_C(115), UINT8_C( 54), UINT8_C(102), UINT8_C(118),
                             UINT8_C( 39), UINT8_C(179), UINT8_C( 45), UINT8_C( 81),
                             UINT8_C(239), UINT8_C(228), UINT8_C( 67), UINT8_C(171),
                             UINT8_C( 79), UINT8_C(143), UINT8_C(134), UINT8_C(124)),
      simde_x_mm512_set_epu8(UINT8_C(  9), UINT8_C(135), UINT8_C(120), UINT8_C(220),
                             UINT8_C( 36), UINT8_C(153), UINT8_C(152), UINT8_C( 25),
                             UINT8_C(145), UINT8_C(193), UINT8_C(221), UINT8_C(136),
                             UINT8_C( 28), UINT8_C(212), UINT8_C(230), UINT8_C(170),
                             UINT8_C(243), UINT8_C( 53), UINT8_C(168), UINT8_C(149),
                             UINT8_C( 68), UINT8_C( 42), UINT8_C(138), UINT8_C(111),
                             UINT8_C( 54), UINT8_C(198), UINT8_C(243), UINT8_C( 27),
                             UINT8_C( 23), UINT8_C( 41), UINT8_C(137), UINT8_C( 44),
                             UINT8_C(  7), UINT8_C(136), UINT8_C( 32), UINT8_C(213),
                             UINT8_C(114), UINT8_C(184), UINT8_C( 73), UINT8_C(160),
                             UINT8_C( 96), UINT8_C(110), UINT8_C(175), UINT8_C(180),
                             UINT8_C(103), UINT8_C(156), UINT8_C(234), UINT8_C( 18),
                             UINT8_C(115), UINT8_C( 54), UINT8_C(216), UINT8_C(125),
                             UINT8_C(110), UINT8_C( 31), UINT8_C( 51), UINT8_C(152),
                             UINT8_C(141), UINT8_C(229), UINT8_C( 62), UINT8_C(171),
                             UINT8_C( 49), UINT8_C(141), UINT8_C( 38), UINT8_C(  4)),
      UINT64_C(0xfb5eed39b202c4bf) },
    { simde_x_mm512_set_epu8(UINT8_C( 16), UINT8_C( 41), UINT8_C(102), UINT8_C(161),
                             UINT8_C( 17), UINT8_C( 42), UINT8_C(170), UINT8_C( 38),
                             UINT8_C( 62), UINT8_C(200), UINT8_C( 60), UINT8_C( 19),
                             UINT8_C(156), UINT8_C(149), UINT8_C(105), UINT8_C(180),
                             UINT8_C( 10), UINT8_C(247), UINT8_C(244), UINT8_C(200),
                             UINT8_C(185), UINT8_C( 96), UINT8_C( 31), UINT8_C( 24),
                             UINT8_C( 68), UINT8_C(249), UINT8_C(229), UINT8_C(  3),
                             UINT8_C(235), UINT8_C( 50), UINT8_C(189), UINT8_C(217),
                             UINT8_C(148), UINT8_C( 62), UINT8_C(101), UINT8_C( 56),
                             UINT8_C(177), UINT8_C(219), UINT8_C(157), UINT8_C(200),
                             UINT8_C(137), UINT8_C(200), UINT8_C(248), UINT8_C(240),
                             UINT8_C(115), UINT8_C(161), UINT8_C(183), UINT8_C( 54),
                             UINT8_C(125), UINT8_C( 85), UINT8_C( 78), UINT8_C(191),
                             UINT8_C(  4), UINT8_C( 38), UINT8_C(172), UINT8_C(203),
                             UINT8_C( 68), UINT8_C(148), UINT8_C(135), UINT8_C(141),
                             UINT8_C(197), UINT8_C(178), UINT8_C(145), UINT8_C( 56)),
      simde_x_mm512_set_epu8(UINT8_C(152), UINT8_C(154), UINT8_C(102), UINT8_C(161),
                             UINT8_C( 69), UINT8_C( 13), UINT8_C(235), UINT8_C( 45),
                             UINT8_C( 62), UINT8_C(136), UINT8_C(145), UINT8_C( 32),
                             UINT8_C(149), UINT8_C(226), UINT8_C( 99), UINT8_C(192),
                             UINT8_C(  8), UINT8_C(214), UINT8_C( 81), UINT8_C(222),
                             UINT8_C(210), UINT8_C( 26), UINT8_C( 31), UINT8_C(254),
                             UINT8_C( 68), UINT8_C(249), UINT8_C(185), UINT8_C( 46),
                             UINT8_C(235), UINT8_C(183), UINT8_C( 21), UINT8_C( 83),
                             UINT8_C(148), UINT8_C(159), UINT8_C(187), UINT8_C( 73),
                             UINT8_C( 57), UINT8_C(219), UINT8_C( 21), UINT8_C( 82),
                             UINT8_C(137), UINT8_C(130), UINT8_C(126), UINT8_C( 91),
                             UINT8_C(115), UINT8_C( 31), UINT8_C(177), UINT8_C( 28),
                             UINT8_C(150), UINT8_C(238), UINT8_C( 65), UINT8_C(152),
                             UINT8_C( 81), UINT8_C( 38), UINT8_C(172), UINT8_C(254),
                             UINT8_C(242), UINT8_C( 85), UINT8_C(176), UINT8_C( 80),
                             UINT8_C( 48), UINT8_C( 93), UINT8_C( 79), UINT8_C(127)),
      UINT64_C(0x34cae6eb8fff365e) },
    { simde_x_mm512_set_epu8(UINT8_C( 50), UINT8_C( 43), UINT8_C(188), UINT8_C( 97),
                             UINT8_C(230), UINT8_C(153), UINT8_C( 71), UINT8_C(149),
                             UINT8_C( 91), UINT8_C( 45), UINT8_C(245), UINT8_C( 47),
                             UINT8_C( 29), UINT8_C(200), UINT8_C( 26), UINT8_C(247),
                             UINT8_C( 10), UINT8_C( 36), UINT8_C(140), UINT8_C(203),
                             UINT8_C( 41), UINT8_C(  1), UINT8_C(233), UINT8_C( 61),
                             UINT8_C(129), UINT8_C(252), UINT8_C( 48), UINT8_C(188),
                             UINT8_C( 89), UINT8_C(144), UINT8_C(225), UINT8_C(120),
                             UINT8_C( 35), UINT8_C( 62), UINT8_C(235), UINT8_C(142),
                             UINT8_C(152), UINT8_C( 57), UINT8_C( 42), UINT8_C(145),
                             UINT8_C( 94), UINT8_C(193), UINT8_C( 87), UINT8_C( 64),
                             UINT8_C(191), UINT8_C(254), UINT8_C(110), UINT8_C(248),
                             UINT8_C( 63), UINT8_C(205), UINT8_C(252), UINT8_C( 32),
                             UINT8_C(191), UINT8_C( 55), UINT8_C( 14), UINT8_C( 81),
                             UINT8_C(133), UINT8_C(156), UINT8_C(217), UINT8_C(212),
                             UINT8_C( 22), UINT8_C(112), UINT8_C( 16), UINT8_C( 15)),
      simde_x_mm512_set_epu8(UINT8_C( 50), UINT8_C(245), UINT8_C(188), UINT8_C(225),
                             UINT8_C(105), UINT8_C(150), UINT8_C( 98), UINT8_C( 51),
                             UINT8_C( 58), UINT8_C(103), UINT8_C(111), UINT8_C(129),
                             UINT8_C( 68), UINT8_C(200), UINT8_C(124), UINT8_C(137),
                             UINT8_C( 74), UINT8_C(194), UINT8_C(140), UINT8_C( 37),
                             UINT8_C(244), UINT8_C(114), UINT8_C(  0), UINT8_C( 61),
                             UINT8_C(103), UINT8_C(252), UINT8_C(151), UINT8_C(188),
                             UINT8_C( 39), UINT8_C(156), UINT8_C(163), UINT8_C( 11),
                             UINT8_C(176), UINT8_C(237), UINT8_C(234), UINT8_C(217),
                             UINT8_C(127), UINT8_C(218), UINT8_C(131), UINT8_C(145),
                             UINT8_C( 84), UINT8_C(160), UINT8_C( 87), UINT8_C(234),
                             UINT8_C(251), UINT8_C(253), UINT8_C(129), UINT8_C( 41),
                             UINT8_C( 74), UINT8_C( 72), UINT8_C(252), UINT8_C( 28),
                             UINT8_C(141), UINT8_C( 93), UINT8_C(102), UINT8_C( 44),
                             UINT8_C(153), UINT8_C(227), UINT8_C(206), UINT8_C( 48),
                             UINT8_C(160), UINT8_C(206), UINT8_C( 46), UINT8_C(191)),
      UINT64_C(0xada533db29e57930) },
    { simde_x_mm512_set_epu8(UINT8_C(159), UINT8_C( 28), UINT8_C(198), UINT8_C( 11),
                             UINT8_C(242), UINT8_C(126), UINT8_C( 81), UINT8_C( 45),
                             UINT8_C(233), UINT8_C(120), UINT8_C(173), UINT8_C(240),
                             UINT8_C(  7), UINT8_C( 51), UINT8_C(199), UINT8_C(206),
                             UINT8_C(235), UINT8_C( 98), UINT8_C( 88), UINT8_C(  0),
                             UINT8_C(190), UINT8_C(  3), UINT8_C(124), UINT8_C(143),
                             UINT8_C( 50), UINT8_C( 32), UINT8_C(171), UINT8_C(163),
                             UINT8_C(212), UINT8_C(243), UINT8_C(162), UINT8_C( 17),
                             UINT8_C(122), UINT8_C( 79), UINT8_C(140), UINT8_C( 43),
                             UINT8_C(179), UINT8_C(131), UINT8_C(233), UINT8_C(136),
                             UINT8_C( 96), UINT8_C(192), UINT8_C(233), UINT8_C(210),
                             UINT8_C(227), UINT8_C(185), UINT8_C( 71), UINT8_C(176),
                             UINT8_C( 44), UINT8_C(164), UINT8_C(225), UINT8_C( 26),
                             UINT8_C(  8), UINT8_C( 52), UINT8_C(117), UINT8_C(123),
                             UINT8_C(193), UINT8_C( 45), UINT8_C( 95), UINT8_C( 24),
                             UINT8_C(148), UINT8_C( 18), UINT8_C(196), UINT8_C( 28)),
      simde_x_mm512_set_epu8(UINT8_C(233), UINT8_C(155), UINT8_C(116), UINT8_C(127),
                             UINT8_C( 96), UINT8_C( 40), UINT8_C(159), UINT8_C( 40),
                             UINT8_C( 86), UINT8_C(212), UINT8_C( 70), UINT8_C(185),
                             UINT8_C( 62), UINT8_C(235), UINT8_C( 66), UINT8_C( 68),
                             UINT8_C(169), UINT8_C(195), UINT8_C( 48), UINT8_C(186),
                             UINT8_C( 18), UINT8_C(178), UINT8_C(158), UINT8_C(117),
                             UINT8_C( 74), UINT8_C( 32), UINT8_C( 93), UINT8_C(125),
                             UINT8_C(209), UINT8_C(196), UINT8_C(170), UINT8_C(117),
                             UINT8_C(122), UINT8_C(202), UINT8_C( 50), UINT8_C(123),
                             UINT8_C(225), UINT8_C(182), UINT8_C(192), UINT8_C( 54),
                             UINT8_C(175), UINT8_C( 60), UINT8_C( 31), UINT8_C(233),
                             UINT8_C(108), UINT8_C(137), UINT8_C(164), UINT8_C(176),
                             UINT8_C(226), UINT8_C(219), UINT8_C( 51), UINT8_C(220),
                             UINT8_C(  8), UINT8_C( 52), UINT8_C( 97), UINT8_C(123),
                             UINT8_C(207), UINT8_C(132), UINT8_C( 95), UINT8_C(173),
                             UINT8_C( 70), UINT8_C(206), UINT8_C(195), UINT8_C( 25)),
      UINT64_C(0x2db3a97ca36d2f2b) },
    { simde_x_mm512_set_epu8(UINT8_C(121), UINT8_C(236), UINT8_C(167), UINT8_C(162),
                             UINT8_C(112), UINT8_C(229), UINT8_C( 81), UINT8_C(202),
                             UINT8_C(192), UINT8_C(142), UINT8_C( 48), UINT8_C(167),
                             UINT8_C(195), UINT8_C( 26), UINT8_C( 43), UINT8_C( 29),
                             UINT8_C(  0), UINT8_C(125), UINT8_C(214), UINT8_C(189),
                             UINT8_C( 15), UINT8_C(120), UINT8_C( 36), UINT8_C( 40),
                             UINT8_C(203), UINT8_C( 34), UINT8_C(148), UINT8_C(198),
                             UINT8_C( 26), UINT8_C(145), UINT8_C( 63), UINT8_C(158),
                             UINT8_C( 65), UINT8_C(  8), UINT8_C(132), UINT8_C( 96),
                             UINT8_C(243), UINT8_C(158), UINT8_C( 99), UINT8_C( 90),
                             UINT8_C( 56), UINT8_C(211), UINT8_C(148), UINT8_C(237),
                             UINT8_C(132), UINT8_C(229), UINT8_C( 22), UINT8_C(126),
                             UINT8_C(150), UINT8_C(188), UINT8_C(196), UINT8_C(  8),
                             UINT8_C(202), UINT8_C( 93), UINT8_C(223), UINT8_C(229),
                             UINT8_C(249), UINT8_C( 27), UINT8_C(134), UINT8_C(168),
                             UINT8_C( 23), UINT8_C(  6), UINT8_C( 45), UINT8_C(235)),
      simde_x_mm512_set_epu8(UINT8_C(105), UINT8_C( 52), UINT8_C( 85), UINT8_C(152),
                             UINT8_C( 57), UINT8_C(225), UINT8_C(218), UINT8_C(132),
                             UINT8_C(149), UINT8_C(254), UINT8_C( 55), UINT8_C( 46),
                             UINT8_C(185), UINT8_C( 77), UINT8_C( 18), UINT8_C( 70),
                             UINT8_C( 89), UINT8_C(125), UINT8_C(214), UINT8_C(131),
                             UINT8_C(121), UINT8_C(245), UINT8_C(187), UINT8_C(197),
                             UINT8_C(203), UINT8_C( 34), UINT8_C(  9), UINT8_C( 64),
                             UINT8_C(195), UINT8_C(231), UINT8_C(141), UINT8_C(100),
                             UINT8_C( 65), UINT8_C(  8), UINT8_C( 69), UINT8_C(248),
                             UINT8_C(241), UINT8_C(205), UINT8_C(  1), UINT8_C( 90),
                             UINT8_C(115), UINT8_C( 51), UINT8_C(165), UINT8_C( 56),
                             UINT8_C( 64), UINT8_C(217), UINT8_C(137), UINT8_C(228),
                             UINT8_C(202), UINT8_C( 28), UINT8_C( 54), UINT8_C(248),
                             UINT8_C(202), UINT8_C(128), UINT8_C(228), UINT8_C(185),
                             UINT8_C(107), UINT8_C(190), UINT8_C(142), UINT8_C(168),
                             UINT8_C( 34), UINT8_C(173), UINT8_C(235), UINT8_C(192)),
      UINT64_C(0xfd9a70f1eb5c6991) },
    { simde_x_mm512_set_epu8(UINT8_C( 33), UINT8_C(121), UINT8_C(125), UINT8_C( 35),
                             UINT8_C(153), UINT8_C(208), UINT8_C(234), UINT8_C( 38),
                             UINT8_C(175), UINT8_C(  9), UINT8_C(245), UINT8_C(132),
                             UINT8_C( 71), UINT8_C(  9), UINT8_C(214), UINT8_C(118),
                             UINT8_C( 67), UINT8_C( 45), UINT8_C( 51), UINT8_C(164),
                             UINT8_C(126), UINT8_C(108), UINT8_C(133), UINT8_C(185),
                             UINT8_C(113), UINT8_C( 32), UINT8_C( 71), UINT8_C(  3),
                             UINT8_C(230), UINT8_C( 82), UINT8_C(175), UINT8_C(236),
                             UINT8_C(201), UINT8_C(112), UINT8_C( 66), UINT8_C( 37),
                             UINT8_C( 67), UINT8_C(187), UINT8_C( 64), UINT8_C( 39),
                             UINT8_C( 72), UINT8_C( 45), UINT8_C(120), UINT8_C(251),
                             UINT8_C(147), UINT8_C( 62), UINT8_C( 17), UINT8_C( 31),
                             UINT8_C(226), UINT8_C(198), UINT8_C( 56), UINT8_C( 21),
                             UINT8_C( 72), UINT8_C(181), UINT8_C(222), UINT8_C(120),
                             UINT8_C( 95), UINT8_C(108), UINT8_C( 32), UINT8_C( 64),
                             UINT8_C(128), UINT8_C(102), UINT8_C(235), UINT8_C( 28)),
      simde_x_mm512_set_epu8(UINT8_C(100), UINT8_C(121), UINT8_C( 18), UINT8_C( 28),
                             UINT8_C(139), UINT8_C(107), UINT8_C(  3), UINT8_C(194),
                             UINT8_C( 42), UINT8_C( 72), UINT8_C( 91), UINT8_C( 86),
                             UINT8_C(184), UINT8_C(  9), UINT8_C(176), UINT8_C(118),
                             UINT8_C(122), UINT8_C(148), UINT8_C(186), UINT8_C(193),
                             UINT8_C( 56), UINT8_C( 71), UINT8_C(242), UINT8_C( 49),
                             UINT8_C(183), UINT8_C( 53), UINT8_C(227), UINT8_C(  3),
                             UINT8_C(183), UINT8_C( 43), UINT8_C(234), UINT8_C( 85),
                             UINT8_C(230), UINT8_C(247), UINT8_C( 66), UINT8_C(  1),
                             UINT8_C(243), UINT8_C( 60), UINT8_C(137), UINT8_C(173),
                             UINT8_C(134), UINT8_C(192), UINT8_C(173), UINT8_C(182),
                             UINT8_C(119), UINT8_C(248), UINT8_C( 12), UINT8_C(113),
                             UINT8_C(244), UINT8_C(172), UINT8_C(  6), UINT8_C( 69),
                             UINT8_C(  2), UINT8_C(181), UINT8_C(222), UINT8_C(130),
                             UINT8_C(  3), UINT8_C(128), UINT8_C(247), UINT8_C( 24),
                             UINT8_C( 11), UINT8_C(162), UINT8_C(224), UINT8_C(110)),
      UINT64_C(0x7eb70d1d341a6e9a) },
    { simde_x_mm512_set_epu8(UINT8_C(  2), UINT8_C(175), UINT8_C( 14), UINT8_C( 90),
                             UINT8_C(156), UINT8_C(134), UINT8_C(221), UINT8_C( 81),
                             UINT8_C(242), UINT8_C(214), UINT8_C(125), UINT8_C(131),
                             UINT8_C(199), UINT8_C( 90), UINT8_C(247), UINT8_C( 63),
                             UINT8_C( 53), UINT8_C( 77), UINT8_C( 63), UINT8_C(172),
                             UINT8_C( 27), UINT8_C( 22), UINT8_C(228), UINT8_C(219),
                             UINT8_C( 65), UINT8_C(118), UINT8_C(130), UINT8_C( 97),
                             UINT8_C(109), UINT8_C(137), UINT8_C(142), UINT8_C(181),
                             UINT8_C(131), UINT8_C(121), UINT8_C(128), UINT8_C(103),
                             UINT8_C(  0), UINT8_C(101), UINT8_C(215), UINT8_C( 89),
                             UINT8_C( 67), UINT8_C(191), UINT8_C(  9), UINT8_C(249),
                             UINT8_C(193), UINT8_C( 13), UINT8_C(105), UINT8_C( 92),
                             UINT8_C(238), UINT8_C(235), UINT8_C(154), UINT8_C(142),
                             UINT8_C( 74), UINT8_C(121), UINT8_C(211), UINT8_C( 52),
                             UINT8_C(193), UINT8_C(163), UINT8_C( 98), UINT8_C(106),
                             UINT8_C(147), UINT8_C(209), UINT8_C( 37), UINT8_C( 70)),
      simde_x_mm512_set_epu8(UINT8_C(214), UINT8_C(132), UINT8_C( 54), UINT8_C( 74),
                             UINT8_C(164), UINT8_C( 99), UINT8_C( 79), UINT8_C(253),
                             UINT8_C( 61), UINT8_C(167), UINT8_C( 84), UINT8_C(162),
                             UINT8_C( 31), UINT8_C(140), UINT8_C(189), UINT8_C(154),
                             UINT8_C(184), UINT8_C(165), UINT8_C(151), UINT8_C(148),
                             UINT8_C(212), UINT8_C( 74), UINT8_C(228), UINT8_C(124),
                             UINT8_C(120), UINT8_C(215), UINT8_C(177), UINT8_C(122),
                             UINT8_C( 87), UINT8_C(137), UINT8_C( 54), UINT8_C(254),
                             UINT8_C(209), UINT8_C( 84), UINT8_C(130), UINT8_C(192),
                             UINT8_C( 14), UINT8_C( 11), UINT8_C( 37), UINT8_C(233),
                             UINT8_C( 67), UINT8_C(124), UINT8_C( 58), UINT8_C(162),
                             UINT8_C( 30), UINT8_C(223), UINT8_C( 70), UINT8_C(232),
                             UINT8_C( 38), UINT8_C(159), UINT8_C(200), UINT8_C(196),
                             UINT8_C(197), UINT8_C( 65), UINT8_C(182), UINT8_C( 45),
                             UINT8_C(245), UINT8_C( 55), UINT8_C(174), UINT8_C( 12),
                             UINT8_C(106), UINT8_C( 22), UINT8_C(132), UINT8_C(252)),
      UINT64_C(0x56ea130e46dac75c) },
    { simde_x_mm512_set_epu8(UINT8_C( 18), UINT8_C( 13), UINT8_C( 14), UINT8_C(  4),
                             UINT8_C(253), UINT8_C(192), UINT8_C( 17), UINT8_C(141),
                             UINT8_C( 21), UINT8_C(222), UINT8_C(125), UINT8_C(196),
                             UINT8_C(184), UINT8_C( 74), UINT8_C(251), UINT8_C(235),
                             UINT8_C(215), UINT8_C( 22), UINT8_C( 45), UINT8_C(102),
                             UINT8_C( 59), UINT8_C(176), UINT8_C(241), UINT8_C(193),
                             UINT8_C( 84), UINT8_C(185), UINT8_C(  8), UINT8_C( 12),
                             UINT8_C(245), UINT8_C(180), UINT8_C( 62), UINT8_C( 93),
                             UINT8_C(181), UINT8_C(179), UINT8_C(172), UINT8_C(148),
                             UINT8_C(221), UINT8_C( 14), UINT8_C(196), UINT8_C( 18),
                             UINT8_C( 23), UINT8_C(196), UINT8_C(193), UINT8_C(142),
                             UINT8_C(201), UINT8_C( 75), UINT8_C(157), UINT8_C(201),
                             UINT8_C( 58), UINT8_C( 76), UINT8_C(154), UINT8_C(138),
                             UINT8_C( 10), UINT8_C( 39), UINT8_C(119), UINT8_C( 85),
                             UINT8_C(248), UINT8_C(184), UINT8_C(196), UINT8_C(162),
                             UINT8_C(144), UINT8_C(119), UINT8_C(124), UINT8_C( 76)),
      simde_x_mm512_set_epu8(UINT8_C( 18), UINT8_C(182), UINT8_C( 14), UINT8_C( 36),
                             UINT8_C(249), UINT8_C(113), UINT8_C( 40), UINT8_C( 48),
                             UINT8_C(149), UINT8_C(222), UINT8_C(181), UINT8_C( 85),
                             UINT8_C(221), UINT8_C(140), UINT8_C( 65), UINT8_C(235),
                             UINT8_C( 15), UINT8_C(  3), UINT8_C( 45), UINT8_C( 21),
                             UINT8_C( 72), UINT8_C( 93), UINT8_C(108), UINT8_C(125),
                             UINT8_C(  1), UINT8_C( 75), UINT8_C( 21), UINT8_C(220),
                             UINT8_C(130), UINT8_C(122), UINT8_C( 71), UINT8_C( 76),
                             UINT8_C( 28), UINT8_C(200), UINT8_C( 32), UINT8_C(101),
                             UINT8_C(149), UINT8_C(145), UINT8_C(168), UINT8_C(237),
                             UINT8_C(179), UINT8_C( 19), UINT8_C(235), UINT8_C(145),
                             UINT8_C(188), UINT8_C( 82), UINT8_C(138), UINT8_C(180),
                             UINT8_C( 47), UINT8_C(127), UINT8_C( 62), UINT8_C(240),
                             UINT8_C( 10), UINT8_C(242), UINT8_C(156), UINT8_C( 86),
                             UINT8_C( 29), UINT8_C(107), UINT8_C( 56), UINT8_C( 21),
                             UINT8_C( 24), UINT8_C( 68), UINT8_C(160), UINT8_C( 64)),
      UINT64_C(0xad53f7cdba4ba8fd) },
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])); i++) {
    simde__mmask64 r = simde_mm512_cmpge_epu8_mask(test_vec[i].a, test_vec[i].b);
    simde_assert_mmask64(r, ==, test_vec[i].r);
   }

  return 0;
}

static int
test_simde_mm512_cmpgt_epi8_mask(SIMDE_MUNIT_TEST_ARGS) {
  const struct {
    simde__m512i   a;
    simde__m512i   b;
    simde__mmask64 r;
  } test_vec[8] = {
    { simde_mm512_set_epi8(INT8_C(  92), INT8_C(-121), INT8_C( 120), INT8_C( -19),
                           INT8_C( -73), INT8_C(  22), INT8_C( -66), INT8_C( -29),
                           INT8_C(  55), INT8_C( -63), INT8_C( -45), INT8_C(-119),
                           INT8_C(  30), INT8_C( -29), INT8_C( -26), INT8_C(  89),
                           INT8_C( -13), INT8_C( 119), INT8_C( -88), INT8_C( 109),
                           INT8_C(  68), INT8_C( -10), INT8_C(   0), INT8_C( -18),
                           INT8_C(   1), INT8_C( 116), INT8_C( -13), INT8_C( -73),
                           INT8_C(-122), INT8_C(   0), INT8_C( 111), INT8_C(  95),
                           INT8_C( -20), INT8_C(   3), INT8_C( 122), INT8_C( -43),
                           INT8_C(  13), INT8_C(  25), INT8_C( -35), INT8_C(-127),
                           INT8_C(  82), INT8_C(  90), INT8_C(  53), INT8_C( 123),
                           INT8_C(  73), INT8_C( 108), INT8_C( -18), INT8_C(  15),
                           INT8_C( 115), INT8_C(  54), INT8_C( 102), INT8_C( 118),
                           INT8_C(  39), INT8_C( -77), INT8_C(  45), INT8_C(  81),
                           INT8_C( -17), INT8_C( -28), INT8_C(  67), INT8_C( -85),
                           INT8_C(  79), INT8_C(-113), INT8_C(-122), INT8_C( 124)),
      simde_mm512_set_epi8(INT8_C(   9), INT8_C(-121), INT8_C( 120), INT8_C( -36),
                           INT8_C(  36), INT8_C(-103), INT8_C(-104), INT8_C(  25),
                           INT8_C(-111), INT8_C( -63), INT8_C( -35), INT8_C(-120),
                           INT8_C(  28), INT8_C( -44), INT8_C( -26), INT8_C( -86),
                           INT8_C( -13), INT8_C(  53), INT8_C( -88), INT8_C(-107),
                           INT8_C(  68), INT8_C(  42), INT8_C(-118), INT8_C( 111),
                           INT8_C(  54), INT8_C( -58), INT8_C( -13), INT8_C(  27),
                           INT8_C(  23), INT8_C(  41), INT8_C(-119), INT8_C(  44),
                           INT8_C(   7), INT8_C(-120), INT8_C(  32), INT8_C( -43),
                           INT8_C( 114), INT8_C( -72), INT8_C(  73), INT8_C( -96),
                           INT8_C(  96), INT8_C( 110), INT8_C( -81), INT8_C( -76),
                           INT8_C( 103), INT8_C(-100), INT8_C( -22), INT8_C(  18),
                           INT8_C( 115), INT8_C(  54), INT8_C( -40), INT8_C( 125),
                           INT8_C( 110), INT8_C(  31), INT8_C(  51), INT8_C(-104),
                           INT8_C(-115), INT8_C( -27), INT8_C(  62), INT8_C( -85),
                           INT8_C(  49), INT8_C(-115), INT8_C(  38), INT8_C(   4)),
      UINT64_C(0x969d5243643621ad) },
    { simde_mm512_set_epi8(INT8_C(  16), INT8_C(  41), INT8_C( 102), INT8_C( -95),
                           INT8_C(  17), INT8_C(  42), INT8_C( -86), INT8_C(  38),
                           INT8_C(  62), INT8_C( -56), INT8_C(  60), INT8_C(  19),
                           INT8_C(-100), INT8_C(-107), INT8_C( 105), INT8_C( -76),
                           INT8_C(  10), INT8_C(  -9), INT8_C( -12), INT8_C( -56),
                           INT8_C( -71), INT8_C(  96), INT8_C(  31), INT8_C(  24),
                           INT8_C(  68), INT8_C(  -7), INT8_C( -27), INT8_C(   3),
                           INT8_C( -21), INT8_C(  50), INT8_C( -67), INT8_C( -39),
                           INT8_C(-108), INT8_C(  62), INT8_C( 101), INT8_C(  56),
                           INT8_C( -79), INT8_C( -37), INT8_C( -99), INT8_C( -56),
                           INT8_C(-119), INT8_C( -56), INT8_C(  -8), INT8_C( -16),
                           INT8_C( 115), INT8_C( -95), INT8_C( -73), INT8_C(  54),
                           INT8_C( 125), INT8_C(  85), INT8_C(  78), INT8_C( -65),
                           INT8_C(   4), INT8_C(  38), INT8_C( -84), INT8_C( -53),
                           INT8_C(  68), INT8_C(-108), INT8_C(-121), INT8_C(-115),
                           INT8_C( -59), INT8_C( -78), INT8_C(-111), INT8_C(  56)),
      simde_mm512_set_epi8(INT8_C(-104), INT8_C(-102), INT8_C( 102), INT8_C( -95),
                           INT8_C(  69), INT8_C(  13), INT8_C( -21), INT8_C(  45),
                           INT8_C(  62), INT8_C(-120), INT8_C(-111), INT8_C(  32),
                           INT8_C(-107), INT8_C( -30), INT8_C(  99), INT8_C( -64),
                           INT8_C(   8), INT8_C( -42), INT8_C(  81), INT8_C( -34),
                           INT8_C( -46), INT8_C(  26), INT8_C(  31), INT8_C(  -2),
                           INT8_C(  68), INT8_C(  -7), INT8_C( -71), INT8_C(  46),
                           INT8_C( -21), INT8_C( -73), INT8_C(  21), INT8_C(  83),
                           INT8_C(-108), INT8_C( -97), INT8_C( -69), INT8_C(  73),
                           INT8_C(  57), INT8_C( -37), INT8_C(  21), INT8_C(  82),
                           INT8_C(-119), INT8_C(-126), INT8_C( 126), INT8_C(  91),
                           INT8_C( 115), INT8_C(  31), INT8_C( -79), INT8_C(  28),
                           INT8_C(-106), INT8_C( -18), INT8_C(  65), INT8_C(-104),
                           INT8_C(  81), INT8_C(  38), INT8_C( -84), INT8_C(  -2),
                           INT8_C( -14), INT8_C(  85), INT8_C( -80), INT8_C(  80),
                           INT8_C(  48), INT8_C(  93), INT8_C(  79), INT8_C( 127)),
      UINT64_C(0xc46ac5246043f080) },
    { simde_mm512_set_epi8(INT8_C(  50), INT8_C(  43), INT8_C( -68), INT8_C(  97),
                           INT8_C( -26), INT8_C(-103), INT8_C(  71), INT8_C(-107),
                           INT8_C(  91), INT8_C(  45), INT8_C( -11), INT8_C(  47),
                           INT8_C(  29), INT8_C( -56), INT8_C(  26), INT8_C(  -9),
                           INT8_C(  10), INT8_C(  36), INT8_C(-116), INT8_C( -53),
                           INT8_C(  41), INT8_C(   1), INT8_C( -23), INT8_C(  61),
                           INT8_C(-127), INT8_C(  -4), INT8_C(  48), INT8_C( -68),
                           INT8_C(  89), INT8_C(-112), INT8_C( -31), INT8_C( 120),
                           INT8_C(  35), INT8_C(  62), INT8_C( -21), INT8_C(-114),
                           INT8_C(-104), INT8_C(  57), INT8_C(  42), INT8_C(-111),
                           INT8_C(  94), INT8_C( -63), INT8_C(  87), INT8_C(  64),
                           INT8_C( -65), INT8_C(  -2), INT8_C( 110), INT8_C(  -8),
                           INT8_C(  63), INT8_C( -51), INT8_C(  -4), INT8_C(  32),
                           INT8_C( -65), INT8_C(  55), INT8_C(  14), INT8_C(  81),
                           INT8_C(-123), INT8_C(-100), INT8_C( -39), INT8_C( -44),
                           INT8_C(  22), INT8_C( 112), INT8_C(  16), INT8_C(  15)),
      simde_mm512_set_epi8(INT8_C(  50), INT8_C( -11), INT8_C( -68), INT8_C( -31),
                           INT8_C( 105), INT8_C(-106), INT8_C(  98), INT8_C(  51),
                           INT8_C(  58), INT8_C( 103), INT8_C( 111), INT8_C(-127),
                           INT8_C(  68), INT8_C( -56), INT8_C( 124), INT8_C(-119),
                           INT8_C(  74), INT8_C( -62), INT8_C(-116), INT8_C(  37),
                           INT8_C( -12), INT8_C( 114), INT8_C(   0), INT8_C(  61),
                           INT8_C( 103), INT8_C(  -4), INT8_C(-105), INT8_C( -68),
                           INT8_C(  39), INT8_C(-100), INT8_C( -93), INT8_C(  11),
                           INT8_C( -80), INT8_C( -19), INT8_C( -22), INT8_C( -39),
                           INT8_C( 127), INT8_C( -38), INT8_C(-125), INT8_C(-111),
                           INT8_C(  84), INT8_C( -96), INT8_C(  87), INT8_C( -22),
                           INT8_C(  -5), INT8_C(  -3), INT8_C(-127), INT8_C(  41),
                           INT8_C(  74), INT8_C(  72), INT8_C(  -4), INT8_C(  28),
                           INT8_C(-115), INT8_C(  93), INT8_C( 102), INT8_C(  44),
                           INT8_C(-103), INT8_C( -29), INT8_C( -50), INT8_C(  48),
                           INT8_C( -96), INT8_C( -50), INT8_C(  46), INT8_C( -65)),
      UINT64_C(0x5491482be6d6192d) },
    { simde_mm512_set_epi8(INT8_C( -97), INT8_C(  28), INT8_C( -58), INT8_C(  11),
                           INT8_C( -14), INT8_C( 126), INT8_C(  81), INT8_C(  45),
                           INT8_C( -23), INT8_C( 120), INT8_C( -83), INT8_C( -16),
                           INT8_C(   7), INT8_C(  51), INT8_C( -57), INT8_C( -50),
                           INT8_C( -21), INT8_C(  98), INT8_C(  88), INT8_C(   0),
                           INT8_C( -66), INT8_C(   3), INT8_C( 124), INT8_C(-113),
                           INT8_C(  50), INT8_C(  32), INT8_C( -85), INT8_C( -93),
                           INT8_C( -44), INT8_C( -13), INT8_C( -94), INT8_C(  17),
                           INT8_C( 122), INT8_C(  79), INT8_C(-116), INT8_C(  43),
                           INT8_C( -77), INT8_C(-125), INT8_C( -23), INT8_C(-120),
                           INT8_C(  96), INT8_C( -64), INT8_C( -23), INT8_C( -46),
                           INT8_C( -29), INT8_C( -71), INT8_C(  71), INT8_C( -80),
                           INT8_C(  44), INT8_C( -92), INT8_C( -31), INT8_C(  26),
                           INT8_C(   8), INT8_C(  52), INT8_C( 117), INT8_C( 123),
                           INT8_C( -63), INT8_C(  45), INT8_C(  95), INT8_C(  24),
                           INT8_C(-108), INT8_C(  18), INT8_C( -60), INT8_C(  28)),
      simde_mm512_set_epi8(INT8_C( -23), INT8_C(-101), INT8_C( 116), INT8_C( 127),
                           INT8_C(  96), INT8_C(  40), INT8_C( -97), INT8_C(  40),
                           INT8_C(  86), INT8_C( -44), INT8_C(  70), INT8_C( -71),
                           INT8_C(  62), INT8_C( -21), INT8_C(  66), INT8_C(  68),
                           INT8_C( -87), INT8_C( -61), INT8_C(  48), INT8_C( -70),
                           INT8_C(  18), INT8_C( -78), INT8_C( -98), INT8_C( 117),
                           INT8_C(  74), INT8_C(  32), INT8_C(  93), INT8_C( 125),
                           INT8_C( -47), INT8_C( -60), INT8_C( -86), INT8_C( 117),
                           INT8_C( 122), INT8_C( -54), INT8_C(  50), INT8_C( 123),
                           INT8_C( -31), INT8_C( -74), INT8_C( -64), INT8_C(  54),
                           INT8_C( -81), INT8_C(  60), INT8_C(  31), INT8_C( -23),
                           INT8_C( 108), INT8_C(-119), INT8_C( -92), INT8_C( -80),
                           INT8_C( -30), INT8_C( -37), INT8_C(  51), INT8_C( -36),
                           INT8_C(   8), INT8_C(  52), INT8_C(  97), INT8_C( 123),
                           INT8_C( -49), INT8_C(-124), INT8_C(  95), INT8_C( -83),
                           INT8_C(  70), INT8_C( -50), INT8_C( -61), INT8_C(  25)),
      UINT64_C(0x4754f60c42869257) },
    { simde_mm512_set_epi8(INT8_C( 121), INT8_C( -20), INT8_C( -89), INT8_C( -94),
                           INT8_C( 112), INT8_C( -27), INT8_C(  81), INT8_C( -54),
                           INT8_C( -64), INT8_C(-114), INT8_C(  48), INT8_C( -89),
                           INT8_C( -61), INT8_C(  26), INT8_C(  43), INT8_C(  29),
                           INT8_C(   0), INT8_C( 125), INT8_C( -42), INT8_C( -67),
                           INT8_C(  15), INT8_C( 120), INT8_C(  36), INT8_C(  40),
                           INT8_C( -53), INT8_C(  34), INT8_C(-108), INT8_C( -58),
                           INT8_C(  26), INT8_C(-111), INT8_C(  63), INT8_C( -98),
                           INT8_C(  65), INT8_C(   8), INT8_C(-124), INT8_C(  96),
                           INT8_C( -13), INT8_C( -98), INT8_C(  99), INT8_C(  90),
                           INT8_C(  56), INT8_C( -45), INT8_C(-108), INT8_C( -19),
                           INT8_C(-124), INT8_C( -27), INT8_C(  22), INT8_C( 126),
                           INT8_C(-106), INT8_C( -68), INT8_C( -60), INT8_C(   8),
                           INT8_C( -54), INT8_C(  93), INT8_C( -33), INT8_C( -27),
                           INT8_C(  -7), INT8_C(  27), INT8_C(-122), INT8_C( -88),
                           INT8_C(  23), INT8_C(   6), INT8_C(  45), INT8_C( -21)),
      simde_mm512_set_epi8(INT8_C( 105), INT8_C(  52), INT8_C(  85), INT8_C(-104),
                           INT8_C(  57), INT8_C( -31), INT8_C( -38), INT8_C(-124),
                           INT8_C(-107), INT8_C(  -2), INT8_C(  55), INT8_C(  46),
                           INT8_C( -71), INT8_C(  77), INT8_C(  18), INT8_C(  70),
                           INT8_C(  89), INT8_C( 125), INT8_C( -42), INT8_C(-125),
                           INT8_C( 121), INT8_C( -11), INT8_C( -69), INT8_C( -59),
                           INT8_C( -53), INT8_C(  34), INT8_C(   9), INT8_C(  64),
                           INT8_C( -61), INT8_C( -25), INT8_C(-115), INT8_C( 100),
                           INT8_C(  65), INT8_C(   8), INT8_C(  69), INT8_C(  -8),
                           INT8_C( -15), INT8_C( -51), INT8_C(   1), INT8_C(  90),
                           INT8_C( 115), INT8_C(  51), INT8_C( -91), INT8_C(  56),
                           INT8_C(  64), INT8_C( -39), INT8_C(-119), INT8_C( -28),
                           INT8_C( -54), INT8_C(  28), INT8_C(  54), INT8_C(  -8),
                           INT8_C( -54), INT8_C(-128), INT8_C( -28), INT8_C( -71),
                           INT8_C( 107), INT8_C( -66), INT8_C(-114), INT8_C( -88),
                           INT8_C(  34), INT8_C( -83), INT8_C( -21), INT8_C( -64)),
      UINT64_C(0x9f8a170a1a071547) },
    { simde_mm512_set_epi8(INT8_C(  33), INT8_C( 121), INT8_C( 125), INT8_C(  35),
                           INT8_C(-103), INT8_C( -48), INT8_C( -22), INT8_C(  38),
                           INT8_C( -81), INT8_C(   9), INT8_C( -11), INT8_C(-124),
                           INT8_C(  71), INT8_C(   9), INT8_C( -42), INT8_C( 118),
                           INT8_C(  67), INT8_C(  45), INT8_C(  51), INT8_C( -92),
                           INT8_C( 126), INT8_C( 108), INT8_C(-123), INT8_C( -71),
                           INT8_C( 113), INT8_C(  32), INT8_C(  71), INT8_C(   3),
                           INT8_C( -26), INT8_C(  82), INT8_C( -81), INT8_C( -20),
                           INT8_C( -55), INT8_C( 112), INT8_C(  66), INT8_C(  37),
                           INT8_C(  67), INT8_C( -69), INT8_C(  64), INT8_C(  39),
                           INT8_C(  72), INT8_C(  45), INT8_C( 120), INT8_C(  -5),
                           INT8_C(-109), INT8_C(  62), INT8_C(  17), INT8_C(  31),
                           INT8_C( -30), INT8_C( -58), INT8_C(  56), INT8_C(  21),
                           INT8_C(  72), INT8_C( -75), INT8_C( -34), INT8_C( 120),
                           INT8_C(  95), INT8_C( 108), INT8_C(  32), INT8_C(  64),
                           INT8_C(-128), INT8_C( 102), INT8_C( -21), INT8_C(  28)),
      simde_mm512_set_epi8(INT8_C( 100), INT8_C( 121), INT8_C(  18), INT8_C(  28),
                           INT8_C(-117), INT8_C( 107), INT8_C(   3), INT8_C( -62),
                           INT8_C(  42), INT8_C(  72), INT8_C(  91), INT8_C(  86),
                           INT8_C( -72), INT8_C(   9), INT8_C( -80), INT8_C( 118),
                           INT8_C( 122), INT8_C(-108), INT8_C( -70), INT8_C( -63),
                           INT8_C(  56), INT8_C(  71), INT8_C( -14), INT8_C(  49),
                           INT8_C( -73), INT8_C(  53), INT8_C( -29), INT8_C(   3),
                           INT8_C( -73), INT8_C(  43), INT8_C( -22), INT8_C(  85),
                           INT8_C( -26), INT8_C(  -9), INT8_C(  66), INT8_C(   1),
                           INT8_C( -13), INT8_C(  60), INT8_C(-119), INT8_C( -83),
                           INT8_C(-122), INT8_C( -64), INT8_C( -83), INT8_C( -74),
                           INT8_C( 119), INT8_C(  -8), INT8_C(  12), INT8_C( 113),
                           INT8_C( -12), INT8_C( -84), INT8_C(   6), INT8_C(  69),
                           INT8_C(   2), INT8_C( -75), INT8_C( -34), INT8_C(-126),
                           INT8_C(   3), INT8_C(-128), INT8_C(  -9), INT8_C(  24),
                           INT8_C(  11), INT8_C( -94), INT8_C( -32), INT8_C( 110)),
      UINT64_C(0x390a6cac5bf669f6) },
    { simde_mm512_set_epi8(INT8_C(   2), INT8_C( -81), INT8_C(  14), INT8_C(  90),
                           INT8_C(-100), INT8_C(-122), INT8_C( -35), INT8_C(  81),
                           INT8_C( -14), INT8_C( -42), INT8_C( 125), INT8_C(-125),
                           INT8_C( -57), INT8_C(  90), INT8_C(  -9), INT8_C(  63),
                           INT8_C(  53), INT8_C(  77), INT8_C(  63), INT8_C( -84),
                           INT8_C(  27), INT8_C(  22), INT8_C( -28), INT8_C( -37),
                           INT8_C(  65), INT8_C( 118), INT8_C(-126), INT8_C(  97),
                           INT8_C( 109), INT8_C(-119), INT8_C(-114), INT8_C( -75),
                           INT8_C(-125), INT8_C( 121), INT8_C(-128), INT8_C( 103),
                           INT8_C(   0), INT8_C( 101), INT8_C( -41), INT8_C(  89),
                           INT8_C(  67), INT8_C( -65), INT8_C(   9), INT8_C(  -7),
                           INT8_C( -63), INT8_C(  13), INT8_C( 105), INT8_C(  92),
                           INT8_C( -18), INT8_C( -21), INT8_C(-102), INT8_C(-114),
                           INT8_C(  74), INT8_C( 121), INT8_C( -45), INT8_C(  52),
                           INT8_C( -63), INT8_C( -93), INT8_C(  98), INT8_C( 106),
                           INT8_C(-109), INT8_C( -47), INT8_C(  37), INT8_C(  70)),
      simde_mm512_set_epi8(INT8_C( -42), INT8_C(-124), INT8_C(  54), INT8_C(  74),
                           INT8_C( -92), INT8_C(  99), INT8_C(  79), INT8_C(  -3),
                           INT8_C(  61), INT8_C( -89), INT8_C(  84), INT8_C( -94),
                           INT8_C(  31), INT8_C(-116), INT8_C( -67), INT8_C(-102),
                           INT8_C( -72), INT8_C( -91), INT8_C(-105), INT8_C(-108),
                           INT8_C( -44), INT8_C(  74), INT8_C( -28), INT8_C( 124),
                           INT8_C( 120), INT8_C( -41), INT8_C( -79), INT8_C( 122),
                           INT8_C(  87), INT8_C(-119), INT8_C(  54), INT8_C(  -2),
                           INT8_C( -47), INT8_C(  84), INT8_C(-126), INT8_C( -64),
                           INT8_C(  14), INT8_C(  11), INT8_C(  37), INT8_C( -23),
                           INT8_C(  67), INT8_C( 124), INT8_C(  58), INT8_C( -94),
                           INT8_C(  30), INT8_C( -33), INT8_C(  70), INT8_C( -24),
                           INT8_C(  38), INT8_C( -97), INT8_C( -56), INT8_C( -60),
                           INT8_C( -59), INT8_C(  65), INT8_C( -74), INT8_C(  45),
                           INT8_C( -11), INT8_C(  55), INT8_C( -82), INT8_C(  12),
                           INT8_C( 106), INT8_C(  22), INT8_C(-124), INT8_C(  -4)),
      UINT64_C(0xd167f84855174f33) },
    { simde_mm512_set_epi8(INT8_C(  18), INT8_C(  13), INT8_C(  14), INT8_C(   4),
                           INT8_C(  -3), INT8_C( -64), INT8_C(  17), INT8_C(-115),
                           INT8_C(  21), INT8_C( -34), INT8_C( 125), INT8_C( -60),
                           INT8_C( -72), INT8_C(  74), INT8_C(  -5), INT8_C( -21),
                           INT8_C( -41), INT8_C(  22), INT8_C(  45), INT8_C( 102),
                           INT8_C(  59), INT8_C( -80), INT8_C( -15), INT8_C( -63),
                           INT8_C(  84), INT8_C( -71), INT8_C(   8), INT8_C(  12),
                           INT8_C( -11), INT8_C( -76), INT8_C(  62), INT8_C(  93),
                           INT8_C( -75), INT8_C( -77), INT8_C( -84), INT8_C(-108),
                           INT8_C( -35), INT8_C(  14), INT8_C( -60), INT8_C(  18),
                           INT8_C(  23), INT8_C( -60), INT8_C( -63), INT8_C(-114),
                           INT8_C( -55), INT8_C(  75), INT8_C( -99), INT8_C( -55),
                           INT8_C(  58), INT8_C(  76), INT8_C(-102), INT8_C(-118),
                           INT8_C(  10), INT8_C(  39), INT8_C( 119), INT8_C(  85),
                           INT8_C(  -8), INT8_C( -72), INT8_C( -60), INT8_C( -94),
                           INT8_C(-112), INT8_C( 119), INT8_C( 124), INT8_C(  76)),
      simde_mm512_set_epi8(INT8_C(  18), INT8_C( -74), INT8_C(  14), INT8_C(  36),
                           INT8_C(  -7), INT8_C( 113), INT8_C(  40), INT8_C(  48),
                           INT8_C(-107), INT8_C( -34), INT8_C( -75), INT8_C(  85),
                           INT8_C( -35), INT8_C(-116), INT8_C(  65), INT8_C( -21),
                           INT8_C(  15), INT8_C(   3), INT8_C(  45), INT8_C(  21),
                           INT8_C(  72), INT8_C(  93), INT8_C( 108), INT8_C( 125),
                           INT8_C(   1), INT8_C(  75), INT8_C(  21), INT8_C( -36),
                           INT8_C(-126), INT8_C( 122), INT8_C(  71), INT8_C(  76),
                           INT8_C(  28), INT8_C( -56), INT8_C(  32), INT8_C( 101),
                           INT8_C(-107), INT8_C(-111), INT8_C( -88), INT8_C( -19),
                           INT8_C( -77), INT8_C(  19), INT8_C( -21), INT8_C(-111),
                           INT8_C( -68), INT8_C(  82), INT8_C(-118), INT8_C( -76),
                           INT8_C(  47), INT8_C( 127), INT8_C(  62), INT8_C( -16),
                           INT8_C(  10), INT8_C( -14), INT8_C(-100), INT8_C(  86),
                           INT8_C(  29), INT8_C( 107), INT8_C(  56), INT8_C(  21),
                           INT8_C(  24), INT8_C(  68), INT8_C( -96), INT8_C(  64)),
      UINT64_C(0x48a450990f8b8607) },
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])); i++) {
    simde__mmask64 r = simde_mm512_cmpgt_epi8_mask(test_vec[i].a, test_vec[i].b);
    simde_assert_mmask64(r, ==, test_vec[i].r);
   }

  return 0;
}

static int
test_simde_mm512_cmpgt_epu8_mask(SIMDE_MUNIT_TEST_ARGS) {
  const struct {
    simde__m512i   a;
    simde__m512i   b;
    simde__mmask64 r;
  } test_vec[8] = {
    { simde_x_mm512_set_epu8(UINT8_C( 92), UINT8_C(135), UINT8_C(120), UINT8_C(237),
                             UINT8_C(183), UINT8_C( 22), UINT8_C(190), UINT8_C(227),
                             UINT8_C( 55), UINT8_C(193), UINT8_C(211), UINT8_C(137),
                             UINT8_C( 30), UINT8_C(227), UINT8_C(230), UINT8_C( 89),
                             UINT8_C(243), UINT8_C(119), UINT8_C(168), UINT8_C(109),
                             UINT8_C( 68), UINT8_C(246), UINT8_C(  0), UINT8_C(238),
                             UINT8_C(  1), UINT8_C(116), UINT8_C(243), UINT8_C(183),
                             UINT8_C(134), UINT8_C(  0), UINT8_C(111), UINT8_C( 95),
                             UINT8_C(236), UINT8_C(  3), UINT8_C(122), UINT8_C(213),
                             UINT8_C( 13), UINT8_C( 25), UINT8_C(221), UINT8_C(129),
                             UINT8_C( 82), UINT8_C( 90), UINT8_C( 53), UINT8_C(123),
                             UINT8_C( 73), UINT8_C(108), UINT8_C(238), UINT8_C( 15),
                             UINT8_C(115), UINT8_C( 54), UINT8_C(102), UINT8_C(118),
                             UINT8_C( 39), UINT8_C(179), UINT8_C( 45), UINT8_C( 81),
                             UINT8_C(239), UINT8_C(228), UINT8_C( 67), UINT8_C(171),
                             UINT8_C( 79), UINT8_C(143), UINT8_C(134), UINT8_C(124)),
      simde_x_mm512_set_epu8(UINT8_C(  9), UINT8_C(135), UINT8_C(120), UINT8_C(220),
                             UINT8_C( 36), UINT8_C(153), UINT8_C(152), UINT8_C( 25),
                             UINT8_C(145), UINT8_C(193), UINT8_C(221), UINT8_C(136),
                             UINT8_C( 28), UINT8_C(212), UINT8_C(230), UINT8_C(170),
                             UINT8_C(243), UINT8_C( 53), UINT8_C(168), UINT8_C(149),
                             UINT8_C( 68), UINT8_C( 42), UINT8_C(138), UINT8_C(111),
                             UINT8_C( 54), UINT8_C(198), UINT8_C(243), UINT8_C( 27),
                             UINT8_C( 23), UINT8_C( 41), UINT8_C(137), UINT8_C( 44),
                             UINT8_C(  7), UINT8_C(136), UINT8_C( 32), UINT8_C(213),
                             UINT8_C(114), UINT8_C(184), UINT8_C( 73), UINT8_C(160),
                             UINT8_C( 96), UINT8_C(110), UINT8_C(175), UINT8_C(180),
                             UINT8_C(103), UINT8_C(156), UINT8_C(234), UINT8_C( 18),
                             UINT8_C(115), UINT8_C( 54), UINT8_C(216), UINT8_C(125),
                             UINT8_C(110), UINT8_C( 31), UINT8_C( 51), UINT8_C(152),
                             UINT8_C(141), UINT8_C(229), UINT8_C( 62), UINT8_C(171),
                             UINT8_C( 49), UINT8_C(141), UINT8_C( 38), UINT8_C(  4)),
      UINT64_C(0x9b1c4519a20204af) },
    { simde_x_mm512_set_epu8(UINT8_C( 16), UINT8_C( 41), UINT8_C(102), UINT8_C(161),
                             UINT8_C( 17), UINT8_C( 42), UINT8_C(170), UINT8_C( 38),
                             UINT8_C( 62), UINT8_C(200), UINT8_C( 60), UINT8_C( 19),
                             UINT8_C(156), UINT8_C(149), UINT8_C(105), UINT8_C(180),
                             UINT8_C( 10), UINT8_C(247), UINT8_C(244), UINT8_C(200),
                             UINT8_C(185), UINT8_C( 96), UINT8_C( 31), UINT8_C( 24),
                             UINT8_C( 68), UINT8_C(249), UINT8_C(229), UINT8_C(  3),
                             UINT8_C(235), UINT8_C( 50), UINT8_C(189), UINT8_C(217),
                             UINT8_C(148), UINT8_C( 62), UINT8_C(101), UINT8_C( 56),
                             UINT8_C(177), UINT8_C(219), UINT8_C(157), UINT8_C(200),
                             UINT8_C(137), UINT8_C(200), UINT8_C(248), UINT8_C(240),
                             UINT8_C(115), UINT8_C(161), UINT8_C(183), UINT8_C( 54),
                             UINT8_C(125), UINT8_C( 85), UINT8_C( 78), UINT8_C(191),
                             UINT8_C(  4), UINT8_C( 38), UINT8_C(172), UINT8_C(203),
                             UINT8_C( 68), UINT8_C(148), UINT8_C(135), UINT8_C(141),
                             UINT8_C(197), UINT8_C(178), UINT8_C(145), UINT8_C( 56)),
      simde_x_mm512_set_epu8(UINT8_C(152), UINT8_C(154), UINT8_C(102), UINT8_C(161),
                             UINT8_C( 69), UINT8_C( 13), UINT8_C(235), UINT8_C( 45),
                             UINT8_C( 62), UINT8_C(136), UINT8_C(145), UINT8_C( 32),
                             UINT8_C(149), UINT8_C(226), UINT8_C( 99), UINT8_C(192),
                             UINT8_C(  8), UINT8_C(214), UINT8_C( 81), UINT8_C(222),
                             UINT8_C(210), UINT8_C( 26), UINT8_C( 31), UINT8_C(254),
                             UINT8_C( 68), UINT8_C(249), UINT8_C(185), UINT8_C( 46),
                             UINT8_C(235), UINT8_C(183), UINT8_C( 21), UINT8_C( 83),
                             UINT8_C(148), UINT8_C(159), UINT8_C(187), UINT8_C( 73),
                             UINT8_C( 57), UINT8_C(219), UINT8_C( 21), UINT8_C( 82),
                             UINT8_C(137), UINT8_C(130), UINT8_C(126), UINT8_C( 91),
                             UINT8_C(115), UINT8_C( 31), UINT8_C(177), UINT8_C( 28),
                             UINT8_C(150), UINT8_C(238), UINT8_C( 65), UINT8_C(152),
                             UINT8_C( 81), UINT8_C( 38), UINT8_C(172), UINT8_C(254),
                             UINT8_C(242), UINT8_C( 85), UINT8_C(176), UINT8_C( 80),
                             UINT8_C( 48), UINT8_C( 93), UINT8_C( 79), UINT8_C(127)),
      UINT64_C(0x44ae4230b77305e) },
    { simde_x_mm512_set_epu8(UINT8_C( 50), UINT8_C( 43), UINT8_C(188), UINT8_C( 97),
                             UINT8_C(230), UINT8_C(153), UINT8_C( 71), UINT8_C(149),
                             UINT8_C( 91), UINT8_C( 45), UINT8_C(245), UINT8_C( 47),
                             UINT8_C( 29), UINT8_C(200), UINT8_C( 26), UINT8_C(247),
                             UINT8_C( 10), UINT8_C( 36), UINT8_C(140), UINT8_C(203),
                             UINT8_C( 41), UINT8_C(  1), UINT8_C(233), UINT8_C( 61),
                             UINT8_C(129), UINT8_C(252), UINT8_C( 48), UINT8_C(188),
                             UINT8_C( 89), UINT8_C(144), UINT8_C(225), UINT8_C(120),
                             UINT8_C( 35), UINT8_C( 62), UINT8_C(235), UINT8_C(142),
                             UINT8_C(152), UINT8_C( 57), UINT8_C( 42), UINT8_C(145),
                             UINT8_C( 94), UINT8_C(193), UINT8_C( 87), UINT8_C( 64),
                             UINT8_C(191), UINT8_C(254), UINT8_C(110), UINT8_C(248),
                             UINT8_C( 63), UINT8_C(205), UINT8_C(252), UINT8_C( 32),
                             UINT8_C(191), UINT8_C( 55), UINT8_C( 14), UINT8_C( 81),
                             UINT8_C(133), UINT8_C(156), UINT8_C(217), UINT8_C(212),
                             UINT8_C( 22), UINT8_C(112), UINT8_C( 16), UINT8_C( 15)),
      simde_x_mm512_set_epu8(UINT8_C( 50), UINT8_C(245), UINT8_C(188), UINT8_C(225),
                             UINT8_C(105), UINT8_C(150), UINT8_C( 98), UINT8_C( 51),
                             UINT8_C( 58), UINT8_C(103), UINT8_C(111), UINT8_C(129),
                             UINT8_C( 68), UINT8_C(200), UINT8_C(124), UINT8_C(137),
                             UINT8_C( 74), UINT8_C(194), UINT8_C(140), UINT8_C( 37),
                             UINT8_C(244), UINT8_C(114), UINT8_C(  0), UINT8_C( 61),
                             UINT8_C(103), UINT8_C(252), UINT8_C(151), UINT8_C(188),
                             UINT8_C( 39), UINT8_C(156), UINT8_C(163), UINT8_C( 11),
                             UINT8_C(176), UINT8_C(237), UINT8_C(234), UINT8_C(217),
                             UINT8_C(127), UINT8_C(218), UINT8_C(131), UINT8_C(145),
                             UINT8_C( 84), UINT8_C(160), UINT8_C( 87), UINT8_C(234),
                             UINT8_C(251), UINT8_C(253), UINT8_C(129), UINT8_C( 41),
                             UINT8_C( 74), UINT8_C( 72), UINT8_C(252), UINT8_C( 28),
                             UINT8_C(141), UINT8_C( 93), UINT8_C(102), UINT8_C( 44),
                             UINT8_C(153), UINT8_C(227), UINT8_C(206), UINT8_C( 48),
                             UINT8_C(160), UINT8_C(206), UINT8_C( 46), UINT8_C(191)),
      UINT64_C(0xda1128b28c55930) },
    { simde_x_mm512_set_epu8(UINT8_C(159), UINT8_C( 28), UINT8_C(198), UINT8_C( 11),
                             UINT8_C(242), UINT8_C(126), UINT8_C( 81), UINT8_C( 45),
                             UINT8_C(233), UINT8_C(120), UINT8_C(173), UINT8_C(240),
                             UINT8_C(  7), UINT8_C( 51), UINT8_C(199), UINT8_C(206),
                             UINT8_C(235), UINT8_C( 98), UINT8_C( 88), UINT8_C(  0),
                             UINT8_C(190), UINT8_C(  3), UINT8_C(124), UINT8_C(143),
                             UINT8_C( 50), UINT8_C( 32), UINT8_C(171), UINT8_C(163),
                             UINT8_C(212), UINT8_C(243), UINT8_C(162), UINT8_C( 17),
                             UINT8_C(122), UINT8_C( 79), UINT8_C(140), UINT8_C( 43),
                             UINT8_C(179), UINT8_C(131), UINT8_C(233), UINT8_C(136),
                             UINT8_C( 96), UINT8_C(192), UINT8_C(233), UINT8_C(210),
                             UINT8_C(227), UINT8_C(185), UINT8_C( 71), UINT8_C(176),
                             UINT8_C( 44), UINT8_C(164), UINT8_C(225), UINT8_C( 26),
                             UINT8_C(  8), UINT8_C( 52), UINT8_C(117), UINT8_C(123),
                             UINT8_C(193), UINT8_C( 45), UINT8_C( 95), UINT8_C( 24),
                             UINT8_C(148), UINT8_C( 18), UINT8_C(196), UINT8_C( 28)),
      simde_x_mm512_set_epu8(UINT8_C(233), UINT8_C(155), UINT8_C(116), UINT8_C(127),
                             UINT8_C( 96), UINT8_C( 40), UINT8_C(159), UINT8_C( 40),
                             UINT8_C( 86), UINT8_C(212), UINT8_C( 70), UINT8_C(185),
                             UINT8_C( 62), UINT8_C(235), UINT8_C( 66), UINT8_C( 68),
                             UINT8_C(169), UINT8_C(195), UINT8_C( 48), UINT8_C(186),
                             UINT8_C( 18), UINT8_C(178), UINT8_C(158), UINT8_C(117),
                             UINT8_C( 74), UINT8_C( 32), UINT8_C( 93), UINT8_C(125),
                             UINT8_C(209), UINT8_C(196), UINT8_C(170), UINT8_C(117),
                             UINT8_C(122), UINT8_C(202), UINT8_C( 50), UINT8_C(123),
                             UINT8_C(225), UINT8_C(182), UINT8_C(192), UINT8_C( 54),
                             UINT8_C(175), UINT8_C( 60), UINT8_C( 31), UINT8_C(233),
                             UINT8_C(108), UINT8_C(137), UINT8_C(164), UINT8_C(176),
                             UINT8_C(226), UINT8_C(219), UINT8_C( 51), UINT8_C(220),
                             UINT8_C(  8), UINT8_C( 52), UINT8_C( 97), UINT8_C(123),
                             UINT8_C(207), UINT8_C(132), UINT8_C( 95), UINT8_C(173),
                             UINT8_C( 70), UINT8_C(206), UINT8_C(195), UINT8_C( 25)),
      UINT64_C(0x2db3a93c236c220b) },
    { simde_x_mm512_set_epu8(UINT8_C(121), UINT8_C(236), UINT8_C(167), UINT8_C(162),
                             UINT8_C(112), UINT8_C(229), UINT8_C( 81), UINT8_C(202),
                             UINT8_C(192), UINT8_C(142), UINT8_C( 48), UINT8_C(167),
                             UINT8_C(195), UINT8_C( 26), UINT8_C( 43), UINT8_C( 29),
                             UINT8_C(  0), UINT8_C(125), UINT8_C(214), UINT8_C(189),
                             UINT8_C( 15), UINT8_C(120), UINT8_C( 36), UINT8_C( 40),
                             UINT8_C(203), UINT8_C( 34), UINT8_C(148), UINT8_C(198),
                             UINT8_C( 26), UINT8_C(145), UINT8_C( 63), UINT8_C(158),
                             UINT8_C( 65), UINT8_C(  8), UINT8_C(132), UINT8_C( 96),
                             UINT8_C(243), UINT8_C(158), UINT8_C( 99), UINT8_C( 90),
                             UINT8_C( 56), UINT8_C(211), UINT8_C(148), UINT8_C(237),
                             UINT8_C(132), UINT8_C(229), UINT8_C( 22), UINT8_C(126),
                             UINT8_C(150), UINT8_C(188), UINT8_C(196), UINT8_C(  8),
                             UINT8_C(202), UINT8_C( 93), UINT8_C(223), UINT8_C(229),
                             UINT8_C(249), UINT8_C( 27), UINT8_C(134), UINT8_C(168),
                             UINT8_C( 23), UINT8_C(  6), UINT8_C( 45), UINT8_C(235)),
      simde_x_mm512_set_epu8(UINT8_C(105), UINT8_C( 52), UINT8_C( 85), UINT8_C(152),
                             UINT8_C( 57), UINT8_C(225), UINT8_C(218), UINT8_C(132),
                             UINT8_C(149), UINT8_C(254), UINT8_C( 55), UINT8_C( 46),
                             UINT8_C(185), UINT8_C( 77), UINT8_C( 18), UINT8_C( 70),
                             UINT8_C( 89), UINT8_C(125), UINT8_C(214), UINT8_C(131),
                             UINT8_C(121), UINT8_C(245), UINT8_C(187), UINT8_C(197),
                             UINT8_C(203), UINT8_C( 34), UINT8_C(  9), UINT8_C( 64),
                             UINT8_C(195), UINT8_C(231), UINT8_C(141), UINT8_C(100),
                             UINT8_C( 65), UINT8_C(  8), UINT8_C( 69), UINT8_C(248),
                             UINT8_C(241), UINT8_C(205), UINT8_C(  1), UINT8_C( 90),
                             UINT8_C(115), UINT8_C( 51), UINT8_C(165), UINT8_C( 56),
                             UINT8_C( 64), UINT8_C(217), UINT8_C(137), UINT8_C(228),
                             UINT8_C(202), UINT8_C( 28), UINT8_C( 54), UINT8_C(248),
                             UINT8_C(202), UINT8_C(128), UINT8_C(228), UINT8_C(185),
                             UINT8_C(107), UINT8_C(190), UINT8_C(142), UINT8_C(168),
                             UINT8_C( 34), UINT8_C(173), UINT8_C(235), UINT8_C(192)),
      UINT64_C(0xfd9a10312a5c6181) },
    { simde_x_mm512_set_epu8(UINT8_C( 33), UINT8_C(121), UINT8_C(125), UINT8_C( 35),
                             UINT8_C(153), UINT8_C(208), UINT8_C(234), UINT8_C( 38),
                             UINT8_C(175), UINT8_C(  9), UINT8_C(245), UINT8_C(132),
                             UINT8_C( 71), UINT8_C(  9), UINT8_C(214), UINT8_C(118),
                             UINT8_C( 67), UINT8_C( 45), UINT8_C( 51), UINT8_C(164),
                             UINT8_C(126), UINT8_C(108), UINT8_C(133), UINT8_C(185),
                             UINT8_C(113), UINT8_C( 32), UINT8_C( 71), UINT8_C(  3),
                             UINT8_C(230), UINT8_C( 82), UINT8_C(175), UINT8_C(236),
                             UINT8_C(201), UINT8_C(112), UINT8_C( 66), UINT8_C( 37),
                             UINT8_C( 67), UINT8_C(187), UINT8_C( 64), UINT8_C( 39),
                             UINT8_C( 72), UINT8_C( 45), UINT8_C(120), UINT8_C(251),
                             UINT8_C(147), UINT8_C( 62), UINT8_C( 17), UINT8_C( 31),
                             UINT8_C(226), UINT8_C(198), UINT8_C( 56), UINT8_C( 21),
                             UINT8_C( 72), UINT8_C(181), UINT8_C(222), UINT8_C(120),
                             UINT8_C( 95), UINT8_C(108), UINT8_C( 32), UINT8_C( 64),
                             UINT8_C(128), UINT8_C(102), UINT8_C(235), UINT8_C( 28)),
      simde_x_mm512_set_epu8(UINT8_C(100), UINT8_C(121), UINT8_C( 18), UINT8_C( 28),
                             UINT8_C(139), UINT8_C(107), UINT8_C(  3), UINT8_C(194),
                             UINT8_C( 42), UINT8_C( 72), UINT8_C( 91), UINT8_C( 86),
                             UINT8_C(184), UINT8_C(  9), UINT8_C(176), UINT8_C(118),
                             UINT8_C(122), UINT8_C(148), UINT8_C(186), UINT8_C(193),
                             UINT8_C( 56), UINT8_C( 71), UINT8_C(242), UINT8_C( 49),
                             UINT8_C(183), UINT8_C( 53), UINT8_C(227), UINT8_C(  3),
                             UINT8_C(183), UINT8_C( 43), UINT8_C(234), UINT8_C( 85),
                             UINT8_C(230), UINT8_C(247), UINT8_C( 66), UINT8_C(  1),
                             UINT8_C(243), UINT8_C( 60), UINT8_C(137), UINT8_C(173),
                             UINT8_C(134), UINT8_C(192), UINT8_C(173), UINT8_C(182),
                             UINT8_C(119), UINT8_C(248), UINT8_C( 12), UINT8_C(113),
                             UINT8_C(244), UINT8_C(172), UINT8_C(  6), UINT8_C( 69),
                             UINT8_C(  2), UINT8_C(181), UINT8_C(222), UINT8_C(130),
                             UINT8_C(  3), UINT8_C(128), UINT8_C(247), UINT8_C( 24),
                             UINT8_C( 11), UINT8_C(162), UINT8_C(224), UINT8_C(110)),
      UINT64_C(0x3eb20d0d141a689a) },
    { simde_x_mm512_set_epu8(UINT8_C(  2), UINT8_C(175), UINT8_C( 14), UINT8_C( 90),
                             UINT8_C(156), UINT8_C(134), UINT8_C(221), UINT8_C( 81),
                             UINT8_C(242), UINT8_C(214), UINT8_C(125), UINT8_C(131),
                             UINT8_C(199), UINT8_C( 90), UINT8_C(247), UINT8_C( 63),
                             UINT8_C( 53), UINT8_C( 77), UINT8_C( 63), UINT8_C(172),
                             UINT8_C( 27), UINT8_C( 22), UINT8_C(228), UINT8_C(219),
                             UINT8_C( 65), UINT8_C(118), UINT8_C(130), UINT8_C( 97),
                             UINT8_C(109), UINT8_C(137), UINT8_C(142), UINT8_C(181),
                             UINT8_C(131), UINT8_C(121), UINT8_C(128), UINT8_C(103),
                             UINT8_C(  0), UINT8_C(101), UINT8_C(215), UINT8_C( 89),
                             UINT8_C( 67), UINT8_C(191), UINT8_C(  9), UINT8_C(249),
                             UINT8_C(193), UINT8_C( 13), UINT8_C(105), UINT8_C( 92),
                             UINT8_C(238), UINT8_C(235), UINT8_C(154), UINT8_C(142),
                             UINT8_C( 74), UINT8_C(121), UINT8_C(211), UINT8_C( 52),
                             UINT8_C(193), UINT8_C(163), UINT8_C( 98), UINT8_C(106),
                             UINT8_C(147), UINT8_C(209), UINT8_C( 37), UINT8_C( 70)),
      simde_x_mm512_set_epu8(UINT8_C(214), UINT8_C(132), UINT8_C( 54), UINT8_C( 74),
                             UINT8_C(164), UINT8_C( 99), UINT8_C( 79), UINT8_C(253),
                             UINT8_C( 61), UINT8_C(167), UINT8_C( 84), UINT8_C(162),
                             UINT8_C( 31), UINT8_C(140), UINT8_C(189), UINT8_C(154),
                             UINT8_C(184), UINT8_C(165), UINT8_C(151), UINT8_C(148),
                             UINT8_C(212), UINT8_C( 74), UINT8_C(228), UINT8_C(124),
                             UINT8_C(120), UINT8_C(215), UINT8_C(177), UINT8_C(122),
                             UINT8_C( 87), UINT8_C(137), UINT8_C( 54), UINT8_C(254),
                             UINT8_C(209), UINT8_C( 84), UINT8_C(130), UINT8_C(192),
                             UINT8_C( 14), UINT8_C( 11), UINT8_C( 37), UINT8_C(233),
                             UINT8_C( 67), UINT8_C(124), UINT8_C( 58), UINT8_C(162),
                             UINT8_C( 30), UINT8_C(223), UINT8_C( 70), UINT8_C(232),
                             UINT8_C( 38), UINT8_C(159), UINT8_C(200), UINT8_C(196),
                             UINT8_C(197), UINT8_C( 65), UINT8_C(182), UINT8_C( 45),
                             UINT8_C(245), UINT8_C( 55), UINT8_C(174), UINT8_C( 12),
                             UINT8_C(106), UINT8_C( 22), UINT8_C(132), UINT8_C(252)),
      UINT64_C(0x56ea110a465ac75c) },
    { simde_x_mm512_set_epu8(UINT8_C( 18), UINT8_C( 13), UINT8_C( 14), UINT8_C(  4),
                             UINT8_C(253), UINT8_C(192), UINT8_C( 17), UINT8_C(141),
                             UINT8_C( 21), UINT8_C(222), UINT8_C(125), UINT8_C(196),
                             UINT8_C(184), UINT8_C( 74), UINT8_C(251), UINT8_C(235),
                             UINT8_C(215), UINT8_C( 22), UINT8_C( 45), UINT8_C(102),
                             UINT8_C( 59), UINT8_C(176), UINT8_C(241), UINT8_C(193),
                             UINT8_C( 84), UINT8_C(185), UINT8_C(  8), UINT8_C( 12),
                             UINT8_C(245), UINT8_C(180), UINT8_C( 62), UINT8_C( 93),
                             UINT8_C(181), UINT8_C(179), UINT8_C(172), UINT8_C(148),
                             UINT8_C(221), UINT8_C( 14), UINT8_C(196), UINT8_C( 18),
                             UINT8_C( 23), UINT8_C(196), UINT8_C(193), UINT8_C(142),
                             UINT8_C(201), UINT8_C( 75), UINT8_C(157), UINT8_C(201),
                             UINT8_C( 58), UINT8_C( 76), UINT8_C(154), UINT8_C(138),
                             UINT8_C( 10), UINT8_C( 39), UINT8_C(119), UINT8_C( 85),
                             UINT8_C(248), UINT8_C(184), UINT8_C(196), UINT8_C(162),
                             UINT8_C(144), UINT8_C(119), UINT8_C(124), UINT8_C( 76)),
      simde_x_mm512_set_epu8(UINT8_C( 18), UINT8_C(182), UINT8_C( 14), UINT8_C( 36),
                             UINT8_C(249), UINT8_C(113), UINT8_C( 40), UINT8_C( 48),
                             UINT8_C(149), UINT8_C(222), UINT8_C(181), UINT8_C( 85),
                             UINT8_C(221), UINT8_C(140), UINT8_C( 65), UINT8_C(235),
                             UINT8_C( 15), UINT8_C(  3), UINT8_C( 45), UINT8_C( 21),
                             UINT8_C( 72), UINT8_C( 93), UINT8_C(108), UINT8_C(125),
                             UINT8_C(  1), UINT8_C( 75), UINT8_C( 21), UINT8_C(220),
                             UINT8_C(130), UINT8_C(122), UINT8_C( 71), UINT8_C( 76),
                             UINT8_C( 28), UINT8_C(200), UINT8_C( 32), UINT8_C(101),
                             UINT8_C(149), UINT8_C(145), UINT8_C(168), UINT8_C(237),
                             UINT8_C(179), UINT8_C( 19), UINT8_C(235), UINT8_C(145),
                             UINT8_C(188), UINT8_C( 82), UINT8_C(138), UINT8_C(180),
                             UINT8_C( 47), UINT8_C(127), UINT8_C( 62), UINT8_C(240),
                             UINT8_C( 10), UINT8_C(242), UINT8_C(156), UINT8_C( 86),
                             UINT8_C( 29), UINT8_C(107), UINT8_C( 56), UINT8_C( 21),
                             UINT8_C( 24), UINT8_C( 68), UINT8_C(160), UINT8_C( 64)),
      UINT64_C(0xd12d7cdba4ba0fd) },
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])); i++) {
    simde__mmask64 r = simde_mm512_cmpgt_epu8_mask(test_vec[i].a, test_vec[i].b);
    simde_assert_mmask64(r, ==, test_vec[i].r);
   }

  return 0;
}

static int
test_simde_mm512_cmple_epi8_mask(SIMDE_MUNIT_TEST_ARGS) {
  const struct {
    simde__m512i a;
    simde__m512i b;
    simde__mmask64 r;
  } test_vec[8] = {
    { simde_mm512_set_epi8(INT8_C(  52), INT8_C(   1), INT8_C(  13), INT8_C(  75),
                           INT8_C( -85), INT8_C(  72), INT8_C( -19), INT8_C( -45),
                           INT8_C(  -9), INT8_C(-112), INT8_C( -83), INT8_C( -75),
                           INT8_C( 108), INT8_C( -56), INT8_C(   1), INT8_C(  67),
                           INT8_C(-121), INT8_C( -80), INT8_C( -61), INT8_C( -21),
                           INT8_C(  32), INT8_C(  90), INT8_C(  18), INT8_C( -76),
                           INT8_C( -55), INT8_C(-120), INT8_C(  21), INT8_C(  67),
                           INT8_C( -90), INT8_C(  96), INT8_C(  54), INT8_C( 110),
                           INT8_C(  64), INT8_C(   8), INT8_C( -22), INT8_C(  94),
                           INT8_C(  52), INT8_C( -99), INT8_C(  -4), INT8_C( -84),
                           INT8_C(  -6), INT8_C( 125), INT8_C(  -1), INT8_C( -60),
                           INT8_C(  92), INT8_C(-113), INT8_C( -19), INT8_C(  84),
                           INT8_C( -51), INT8_C(  77), INT8_C(  43), INT8_C( -20),
                           INT8_C( -65), INT8_C( 126), INT8_C(  26), INT8_C( 119),
                           INT8_C( -48), INT8_C( -40), INT8_C(  25), INT8_C(-102),
                           INT8_C( -57), INT8_C( -51), INT8_C(  66), INT8_C(  22)),
      simde_mm512_set_epi8(INT8_C(  86), INT8_C(   9), INT8_C( -71), INT8_C( -90),
                           INT8_C(  18), INT8_C( -62), INT8_C( -33), INT8_C(-112),
                           INT8_C( -98), INT8_C( -84), INT8_C(-115), INT8_C(  15),
                           INT8_C( -33), INT8_C( -76), INT8_C(  61), INT8_C( -95),
                           INT8_C(-105), INT8_C( -60), INT8_C(  -6), INT8_C(-111),
                           INT8_C(  16), INT8_C(-119), INT8_C(  -8), INT8_C( 102),
                           INT8_C(-121), INT8_C(  65), INT8_C(  74), INT8_C( -15),
                           INT8_C( -75), INT8_C( 113), INT8_C(  12), INT8_C(  72),
                           INT8_C(  11), INT8_C( -99), INT8_C(-102), INT8_C(-120),
                           INT8_C(  85), INT8_C( -27), INT8_C(  50), INT8_C(  44),
                           INT8_C(  99), INT8_C(  97), INT8_C( -64), INT8_C(  17),
                           INT8_C( -71), INT8_C( 126), INT8_C( 120), INT8_C(  30),
                           INT8_C(  35), INT8_C( -80), INT8_C( -38), INT8_C( 107),
                           INT8_C(  58), INT8_C(   8), INT8_C( -10), INT8_C(   0),
                           INT8_C(-107), INT8_C( -88), INT8_C(-112), INT8_C(  12),
                           INT8_C(-116), INT8_C( -27), INT8_C( -98), INT8_C(-111)),
      UINT64_C(14434847609910106132) },
    { simde_mm512_set_epi8(INT8_C( 107), INT8_C(-116), INT8_C( 122), INT8_C( 102),
                           INT8_C( -58), INT8_C( 110), INT8_C( -59), INT8_C( -22),
                           INT8_C(  43), INT8_C(  28), INT8_C(  44), INT8_C( -42),
                           INT8_C(-114), INT8_C( -45), INT8_C( -97), INT8_C(  37),
                           INT8_C(-125), INT8_C(  89), INT8_C(-120), INT8_C( -47),
                           INT8_C( -37), INT8_C( -38), INT8_C( 100), INT8_C(  17),
                           INT8_C(  50), INT8_C( -37), INT8_C( -47), INT8_C(  89),
                           INT8_C(  20), INT8_C( -20), INT8_C( -62), INT8_C(-101),
                           INT8_C(  62), INT8_C( 121), INT8_C(-111), INT8_C(  -6),
                           INT8_C(   1), INT8_C(  18), INT8_C(  98), INT8_C(  82),
                           INT8_C( -13), INT8_C(  78), INT8_C(  -4), INT8_C(  14),
                           INT8_C( -66), INT8_C(  64), INT8_C( -67), INT8_C( 109),
                           INT8_C(  39), INT8_C(  91), INT8_C( -87), INT8_C(   9),
                           INT8_C( -93), INT8_C(-109), INT8_C(   6), INT8_C(  98),
                           INT8_C( 120), INT8_C( 124), INT8_C( 122), INT8_C( -19),
                           INT8_C( -77), INT8_C(  57), INT8_C( -96), INT8_C( 126)),
      simde_mm512_set_epi8(INT8_C( -21), INT8_C(-123), INT8_C( -78), INT8_C( -79),
                           INT8_C( -86), INT8_C(  25), INT8_C(-109), INT8_C(  -7),
                           INT8_C(  99), INT8_C( -40), INT8_C(  26), INT8_C(  97),
                           INT8_C(-125), INT8_C( 116), INT8_C( -95), INT8_C(  35),
                           INT8_C(   2), INT8_C(-112), INT8_C(  36), INT8_C( -92),
                           INT8_C(   3), INT8_C(-116), INT8_C( 114), INT8_C(-106),
                           INT8_C(  44), INT8_C(  56), INT8_C(  61), INT8_C( -40),
                           INT8_C(   0), INT8_C( 125), INT8_C(  -9), INT8_C(-122),
                           INT8_C( -60), INT8_C(  40), INT8_C( -45), INT8_C( -33),
                           INT8_C( -44), INT8_C( -46), INT8_C( -92), INT8_C( -73),
                           INT8_C( -80), INT8_C( 116), INT8_C( -97), INT8_C( -44),
                           INT8_C(-128), INT8_C(  96), INT8_C(  31), INT8_C(  65),
                           INT8_C(  78), INT8_C(-127), INT8_C(-104), INT8_C( -24),
                           INT8_C(  50), INT8_C(-106), INT8_C(  74), INT8_C( -36),
                           INT8_C( -78), INT8_C( -25), INT8_C(  74), INT8_C(  73),
                           INT8_C(-109), INT8_C(  66), INT8_C(  65), INT8_C( 122)),
      UINT64_C(114466196149407254) },
    { simde_mm512_set_epi8(INT8_C(-114), INT8_C( -20), INT8_C(  33), INT8_C(  85),
                           INT8_C( 122), INT8_C( -58), INT8_C(-110), INT8_C(  73),
                           INT8_C( -51), INT8_C(  77), INT8_C(  19), INT8_C(  55),
                           INT8_C(  58), INT8_C(-110), INT8_C(  71), INT8_C(-103),
                           INT8_C(   4), INT8_C(-105), INT8_C(  17), INT8_C( -19),
                           INT8_C( -69), INT8_C(  -9), INT8_C(  20), INT8_C( -70),
                           INT8_C( -64), INT8_C(  10), INT8_C(  85), INT8_C( 102),
                           INT8_C( -33), INT8_C(-106), INT8_C(-128), INT8_C(  35),
                           INT8_C( -69), INT8_C( -59), INT8_C( 120), INT8_C(-107),
                           INT8_C( 106), INT8_C( -82), INT8_C( -54), INT8_C(-116),
                           INT8_C(  23), INT8_C(   8), INT8_C(  -4), INT8_C( -91),
                           INT8_C( -73), INT8_C( -40), INT8_C( 102), INT8_C( -54),
                           INT8_C( -23), INT8_C( -80), INT8_C(-110), INT8_C( -39),
                           INT8_C(  63), INT8_C( 120), INT8_C(  11), INT8_C(  -6),
                           INT8_C( 120), INT8_C( -34), INT8_C( -31), INT8_C(-107),
                           INT8_C(  78), INT8_C( 119), INT8_C( -83), INT8_C(  34)),
      simde_mm512_set_epi8(INT8_C( -52), INT8_C( -70), INT8_C(  68), INT8_C( -91),
                           INT8_C(-105), INT8_C(-106), INT8_C( -66), INT8_C( -74),
                           INT8_C(  10), INT8_C(-101), INT8_C( -82), INT8_C(  74),
                           INT8_C(  61), INT8_C(-127), INT8_C(  33), INT8_C( -25),
                           INT8_C( -39), INT8_C(  43), INT8_C(  29), INT8_C(  72),
                           INT8_C( -22), INT8_C(  98), INT8_C( -15), INT8_C(  51),
                           INT8_C(-120), INT8_C( -23), INT8_C(   8), INT8_C(  42),
                           INT8_C(-125), INT8_C(  -3), INT8_C(  56), INT8_C( 103),
                           INT8_C(-111), INT8_C(  -5), INT8_C(  92), INT8_C( -35),
                           INT8_C( 109), INT8_C( -50), INT8_C( -47), INT8_C(-123),
                           INT8_C( 113), INT8_C( -13), INT8_C(  46), INT8_C(  -7),
                           INT8_C(  18), INT8_C(  70), INT8_C(  27), INT8_C( -34),
                           INT8_C( -89), INT8_C(  80), INT8_C(-101), INT8_C( -36),
                           INT8_C(  41), INT8_C( -84), INT8_C( -38), INT8_C( -38),
                           INT8_C(  67), INT8_C( -35), INT8_C(-125), INT8_C( -16),
                           INT8_C( -10), INT8_C(-121), INT8_C( -73), INT8_C(  -7)),
      UINT64_C(11716533376188772370) },
    { simde_mm512_set_epi8(INT8_C( -44), INT8_C(  33), INT8_C(-126), INT8_C( -76),
                           INT8_C(  95), INT8_C(  42), INT8_C( 112), INT8_C(-100),
                           INT8_C(-103), INT8_C( 126), INT8_C(-112), INT8_C( -76),
                           INT8_C(-105), INT8_C( -79), INT8_C( -40), INT8_C( -27),
                           INT8_C( -60), INT8_C( -42), INT8_C(-109), INT8_C( -31),
                           INT8_C( -68), INT8_C( -24), INT8_C( -70), INT8_C(  67),
                           INT8_C( -80), INT8_C(  19), INT8_C( -96), INT8_C(   2),
                           INT8_C( -54), INT8_C(  80), INT8_C(  72), INT8_C( -38),
                           INT8_C(  64), INT8_C( -70), INT8_C( -47), INT8_C( -13),
                           INT8_C(  21), INT8_C(  42), INT8_C(-120), INT8_C( -10),
                           INT8_C(  63), INT8_C( -33), INT8_C( -57), INT8_C( -57),
                           INT8_C( 116), INT8_C(  15), INT8_C( -51), INT8_C(  -6),
                           INT8_C( 122), INT8_C(  99), INT8_C(-128), INT8_C(  -5),
                           INT8_C( -25), INT8_C( 119), INT8_C( -74), INT8_C(  99),
                           INT8_C( -40), INT8_C( -57), INT8_C(  28), INT8_C( -42),
                           INT8_C(-120), INT8_C(  65), INT8_C( -45), INT8_C(-120)),
      simde_mm512_set_epi8(INT8_C(  -9), INT8_C(  84), INT8_C(  59), INT8_C(  71),
                           INT8_C(  13), INT8_C(  39), INT8_C( -79), INT8_C( -26),
                           INT8_C(  82), INT8_C( -47), INT8_C( -45), INT8_C(  29),
                           INT8_C( -91), INT8_C( -34), INT8_C(  79), INT8_C(-114),
                           INT8_C( -91), INT8_C(  13), INT8_C(  12), INT8_C( -60),
                           INT8_C( -44), INT8_C(-121), INT8_C(  70), INT8_C(  85),
                           INT8_C( -49), INT8_C(   2), INT8_C(  65), INT8_C(  20),
                           INT8_C(  84), INT8_C(  52), INT8_C( -41), INT8_C(  31),
                           INT8_C(  85), INT8_C(   5), INT8_C(-119), INT8_C( -80),
                           INT8_C(  55), INT8_C( 106), INT8_C( 104), INT8_C(-127),
                           INT8_C(  66), INT8_C(   9), INT8_C( -87), INT8_C(   1),
                           INT8_C(  62), INT8_C( -13), INT8_C( -95), INT8_C( 107),
                           INT8_C( -18), INT8_C(   9), INT8_C( -38), INT8_C( 114),
                           INT8_C(  -6), INT8_C(  83), INT8_C( -70), INT8_C( -62),
                           INT8_C( -54), INT8_C(  89), INT8_C( -72), INT8_C( -70),
                           INT8_C( -80), INT8_C( -23), INT8_C( -13), INT8_C( 125)),
      UINT64_C(17419478854498597451) },
    { simde_mm512_set_epi8(INT8_C(-122), INT8_C(  98), INT8_C( -61), INT8_C( -27),
                           INT8_C( -69), INT8_C( -73), INT8_C(  19), INT8_C( -42),
                           INT8_C( -94), INT8_C( -91), INT8_C(  70), INT8_C(  49),
                           INT8_C( -51), INT8_C( -48), INT8_C( -34), INT8_C( -19),
                           INT8_C(-122), INT8_C(  35), INT8_C( 100), INT8_C( -94),
                           INT8_C( -69), INT8_C(  64), INT8_C(  56), INT8_C( -16),
                           INT8_C(  95), INT8_C( -67), INT8_C( 120), INT8_C( -89),
                           INT8_C(  79), INT8_C(  34), INT8_C(-114), INT8_C( -60),
                           INT8_C(  60), INT8_C( -94), INT8_C( -73), INT8_C(-127),
                           INT8_C(  53), INT8_C( -21), INT8_C( -21), INT8_C(  93),
                           INT8_C( -84), INT8_C(  -3), INT8_C( -33), INT8_C(-100),
                           INT8_C( -51), INT8_C(  64), INT8_C( 122), INT8_C(  20),
                           INT8_C(  71), INT8_C(  31), INT8_C( 119), INT8_C( -31),
                           INT8_C( -54), INT8_C(-117), INT8_C(  16), INT8_C( -86),
                           INT8_C(  -2), INT8_C( -44), INT8_C(  18), INT8_C(  10),
                           INT8_C(  87), INT8_C( 126), INT8_C( 125), INT8_C(-118)),
      simde_mm512_set_epi8(INT8_C(  73), INT8_C( -43), INT8_C( -22), INT8_C(  17),
                           INT8_C(  58), INT8_C(-109), INT8_C( -46), INT8_C( -57),
                           INT8_C(  64), INT8_C( 101), INT8_C( 126), INT8_C( -55),
                           INT8_C(-126), INT8_C( 125), INT8_C(  63), INT8_C(  11),
                           INT8_C(  35), INT8_C(  47), INT8_C( -77), INT8_C( -22),
                           INT8_C( -98), INT8_C( -82), INT8_C( -84), INT8_C(-104),
                           INT8_C(  55), INT8_C( -26), INT8_C( -90), INT8_C( -11),
                           INT8_C(  51), INT8_C( 115), INT8_C(  98), INT8_C( -34),
                           INT8_C( -10), INT8_C(  39), INT8_C( 107), INT8_C(  53),
                           INT8_C( -20), INT8_C( 127), INT8_C(  -9), INT8_C(   9),
                           INT8_C(-101), INT8_C( -21), INT8_C( -30), INT8_C( -70),
                           INT8_C(-128), INT8_C(-115), INT8_C(-123), INT8_C( -73),
                           INT8_C( -77), INT8_C(  54), INT8_C( 113), INT8_C(  34),
                           INT8_C(  55), INT8_C( -74), INT8_C( -52), INT8_C(  17),
                           INT8_C(   5), INT8_C(-118), INT8_C( -68), INT8_C( 115),
                           INT8_C( 127), INT8_C(  35), INT8_C(  86), INT8_C(  24)),
      UINT64_C(13323847096662515097) },
    { simde_mm512_set_epi8(INT8_C(  37), INT8_C( -12), INT8_C( -32), INT8_C( 126),
                           INT8_C( -35), INT8_C(-101), INT8_C(  64), INT8_C( -71),
                           INT8_C( 102), INT8_C(  71), INT8_C( -15), INT8_C( -36),
                           INT8_C( -31), INT8_C( -15), INT8_C(   2), INT8_C( -32),
                           INT8_C(   7), INT8_C( -43), INT8_C( 119), INT8_C( -54),
                           INT8_C( -96), INT8_C(  -6), INT8_C(  62), INT8_C( 104),
                           INT8_C(  35), INT8_C(  37), INT8_C( 120), INT8_C(  -4),
                           INT8_C(  62), INT8_C(  54), INT8_C( -97), INT8_C(-103),
                           INT8_C(-115), INT8_C( -68), INT8_C( -94), INT8_C( -96),
                           INT8_C( -71), INT8_C( 108), INT8_C( 112), INT8_C(  21),
                           INT8_C( -60), INT8_C(-107), INT8_C(  13), INT8_C(  23),
                           INT8_C(  28), INT8_C(  94), INT8_C(-121), INT8_C(-105),
                           INT8_C( 117), INT8_C(  92), INT8_C(  -5), INT8_C( 102),
                           INT8_C( 113), INT8_C( -68), INT8_C( -73), INT8_C( -98),
                           INT8_C(-116), INT8_C(-108), INT8_C( 104), INT8_C( -94),
                           INT8_C( 123), INT8_C( -15), INT8_C( 105), INT8_C(  49)),
      simde_mm512_set_epi8(INT8_C(   5), INT8_C(  84), INT8_C(  11), INT8_C( -98),
                           INT8_C( -61), INT8_C( -19), INT8_C(  52), INT8_C(  -5),
                           INT8_C( -79), INT8_C(  45), INT8_C( -79), INT8_C( -17),
                           INT8_C( -45), INT8_C(  68), INT8_C(  30), INT8_C( -51),
                           INT8_C(-115), INT8_C(-100), INT8_C( -59), INT8_C( -64),
                           INT8_C(  94), INT8_C( -29), INT8_C( -94), INT8_C(  91),
                           INT8_C(-128), INT8_C( -59), INT8_C( -67), INT8_C( -23),
                           INT8_C(  61), INT8_C(-122), INT8_C(-120), INT8_C(-108),
                           INT8_C( -31), INT8_C( -12), INT8_C( -69), INT8_C(  83),
                           INT8_C( -41), INT8_C(-119), INT8_C(-114), INT8_C(  34),
                           INT8_C(  83), INT8_C( 109), INT8_C(-105), INT8_C( -73),
                           INT8_C(  94), INT8_C( -53), INT8_C(  17), INT8_C( 104),
                           INT8_C( -66), INT8_C(  76), INT8_C(-125), INT8_C( -11),
                           INT8_C(  91), INT8_C( -85), INT8_C( -13), INT8_C( -16),
                           INT8_C( -56), INT8_C(  83), INT8_C(  72), INT8_C(  80),
                           INT8_C(  38), INT8_C( -24), INT8_C(  28), INT8_C( 126)),
      UINT64_C(7284018247602209745) },
    { simde_mm512_set_epi8(INT8_C( -73), INT8_C(-128), INT8_C(  96), INT8_C( -55),
                           INT8_C( -66), INT8_C(  -7), INT8_C( -10), INT8_C(-120),
                           INT8_C( 107), INT8_C( -20), INT8_C( -32), INT8_C(   4),
                           INT8_C(-122), INT8_C(-121), INT8_C(  77), INT8_C(  72),
                           INT8_C(  24), INT8_C( -59), INT8_C(   5), INT8_C( -25),
                           INT8_C( -39), INT8_C( 100), INT8_C( -14), INT8_C(  62),
                           INT8_C( -76), INT8_C( -56), INT8_C( -35), INT8_C(  47),
                           INT8_C(  88), INT8_C(  70), INT8_C(  51), INT8_C(  15),
                           INT8_C(  65), INT8_C(  78), INT8_C( -75), INT8_C(  26),
                           INT8_C( -34), INT8_C( -87), INT8_C( -19), INT8_C( -93),
                           INT8_C(  -9), INT8_C( -97), INT8_C( 126), INT8_C( -61),
                           INT8_C( 126), INT8_C( 124), INT8_C( 103), INT8_C(-124),
                           INT8_C(  74), INT8_C( -95), INT8_C(  17), INT8_C( -78),
                           INT8_C(-110), INT8_C( -79), INT8_C(  39), INT8_C(  55),
                           INT8_C(  21), INT8_C(  70), INT8_C( -36), INT8_C( -25),
                           INT8_C(  -3), INT8_C( -83), INT8_C( -67), INT8_C(  -7)),
      simde_mm512_set_epi8(INT8_C( -94), INT8_C(   1), INT8_C(  32), INT8_C(   2),
                           INT8_C(-119), INT8_C(  91), INT8_C(-121), INT8_C(  50),
                           INT8_C( -99), INT8_C(   3), INT8_C(  73), INT8_C(  40),
                           INT8_C(-124), INT8_C( -23), INT8_C(  95), INT8_C( 102),
                           INT8_C(  41), INT8_C(  56), INT8_C(  70), INT8_C( 126),
                           INT8_C(  48), INT8_C( -42), INT8_C(  60), INT8_C(  88),
                           INT8_C(  38), INT8_C(  76), INT8_C(  -4), INT8_C(-121),
                           INT8_C( -33), INT8_C( 119), INT8_C(-103), INT8_C(   4),
                           INT8_C( 100), INT8_C(  93), INT8_C(  25), INT8_C(-105),
                           INT8_C(-113), INT8_C(  48), INT8_C( 102), INT8_C( -75),
                           INT8_C(  35), INT8_C(  24), INT8_C(  12), INT8_C(  10),
                           INT8_C(  -8), INT8_C(  18), INT8_C( -50), INT8_C(  14),
                           INT8_C( -72), INT8_C(  90), INT8_C( -35), INT8_C( 103),
                           INT8_C( -97), INT8_C( -75), INT8_C(  46), INT8_C( -43),
                           INT8_C( 101), INT8_C( -57), INT8_C(  37), INT8_C(  23),
                           INT8_C(-127), INT8_C(  86), INT8_C( -24), INT8_C( 104)),
      UINT64_C(6158667976012816055) },
    { simde_mm512_set_epi8(INT8_C(-100), INT8_C( -98), INT8_C( -42), INT8_C(  95),
                           INT8_C(  40), INT8_C(   8), INT8_C( 114), INT8_C(  23),
                           INT8_C( -26), INT8_C(-115), INT8_C(  79), INT8_C(  45),
                           INT8_C(  90), INT8_C( 114), INT8_C(   2), INT8_C( 107),
                           INT8_C( -80), INT8_C(  -3), INT8_C( -37), INT8_C( -87),
                           INT8_C( -51), INT8_C( -33), INT8_C( -48), INT8_C( -87),
                           INT8_C( -24), INT8_C( -52), INT8_C( 116), INT8_C( 127),
                           INT8_C(   3), INT8_C( 109), INT8_C(-127), INT8_C( -79),
                           INT8_C( -48), INT8_C(-121), INT8_C(  27), INT8_C(  17),
                           INT8_C(  52), INT8_C(-113), INT8_C( -21), INT8_C(  13),
                           INT8_C(-121), INT8_C( -96), INT8_C(  10), INT8_C(-116),
                           INT8_C(  62), INT8_C(  99), INT8_C(  21), INT8_C(  68),
                           INT8_C( -43), INT8_C( 107), INT8_C(  47), INT8_C( -18),
                           INT8_C( -46), INT8_C(-117), INT8_C(  83), INT8_C( -33),
                           INT8_C(  50), INT8_C(  26), INT8_C(   5), INT8_C(-102),
                           INT8_C( -62), INT8_C(-117), INT8_C(  11), INT8_C( -89)),
      simde_mm512_set_epi8(INT8_C(  -7), INT8_C(-107), INT8_C(-110), INT8_C(   3),
                           INT8_C( 123), INT8_C(  42), INT8_C(  35), INT8_C(-112),
                           INT8_C( -33), INT8_C( -27), INT8_C( -71), INT8_C(  60),
                           INT8_C(  28), INT8_C(-128), INT8_C( -61), INT8_C( -94),
                           INT8_C( -53), INT8_C(-120), INT8_C( -58), INT8_C(  86),
                           INT8_C(  54), INT8_C( -41), INT8_C( -24), INT8_C( -24),
                           INT8_C( -79), INT8_C(  97), INT8_C(  11), INT8_C(-106),
                           INT8_C(  -2), INT8_C( -80), INT8_C(  54), INT8_C(   5),
                           INT8_C(  37), INT8_C(  35), INT8_C( -99), INT8_C(-117),
                           INT8_C( -23), INT8_C(  93), INT8_C(  84), INT8_C(  64),
                           INT8_C(-111), INT8_C( -21), INT8_C( -43), INT8_C(  49),
                           INT8_C(   7), INT8_C( -32), INT8_C(  68), INT8_C( -29),
                           INT8_C( 119), INT8_C(  93), INT8_C( -20), INT8_C( -53),
                           INT8_C(  28), INT8_C( -11), INT8_C(  -1), INT8_C(  93),
                           INT8_C( -68), INT8_C( 100), INT8_C(  31), INT8_C(  98),
                           INT8_C(  78), INT8_C(  52), INT8_C(  -6), INT8_C(  -1)),
      UINT64_C(10110751878864342397) }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])); i++) {
    simde__mmask64 r = simde_mm512_cmple_epi8_mask(test_vec[i].a, test_vec[i].b);
    simde_assert_mmask64(r, ==, test_vec[i].r);
  }

  return 0;
}

static int
test_simde_mm512_cmple_epu8_mask(SIMDE_MUNIT_TEST_ARGS) {
  const struct {
    simde__m512i a;
    simde__m512i b;
    simde__mmask64 r;
  } test_vec[8] = {
    { simde_x_mm512_set_epu8(UINT8_C(212), UINT8_C( 13), UINT8_C( 31), UINT8_C(214),
                             UINT8_C(180), UINT8_C(244), UINT8_C( 71), UINT8_C( 63),
                             UINT8_C(225), UINT8_C(144), UINT8_C( 44), UINT8_C(106),
                             UINT8_C(204), UINT8_C( 63), UINT8_C(146), UINT8_C(179),
                             UINT8_C( 32), UINT8_C(164), UINT8_C(133), UINT8_C( 40),
                             UINT8_C(191), UINT8_C(127), UINT8_C(223), UINT8_C( 71),
                             UINT8_C(188), UINT8_C( 44), UINT8_C(171), UINT8_C( 22),
                             UINT8_C( 89), UINT8_C(241), UINT8_C( 98), UINT8_C(161),
                             UINT8_C(  5), UINT8_C(111), UINT8_C(103), UINT8_C(163),
                             UINT8_C(148), UINT8_C(182), UINT8_C( 53), UINT8_C(167),
                             UINT8_C(123), UINT8_C( 87), UINT8_C(248), UINT8_C( 30),
                             UINT8_C( 59), UINT8_C( 34), UINT8_C(228), UINT8_C(123),
                             UINT8_C( 19), UINT8_C(  1), UINT8_C(177), UINT8_C(191),
                             UINT8_C(228), UINT8_C(252), UINT8_C( 82), UINT8_C( 41),
                             UINT8_C(190), UINT8_C( 81), UINT8_C(126), UINT8_C(186),
                             UINT8_C(232), UINT8_C(220), UINT8_C(248), UINT8_C(  9)),
      simde_x_mm512_set_epu8(UINT8_C(156), UINT8_C(167), UINT8_C(182), UINT8_C(174),
                             UINT8_C( 59), UINT8_C( 33), UINT8_C(108), UINT8_C( 56),
                             UINT8_C(235), UINT8_C(112), UINT8_C( 57), UINT8_C(123),
                             UINT8_C(204), UINT8_C(222), UINT8_C(254), UINT8_C(219),
                             UINT8_C( 79), UINT8_C(226), UINT8_C(235), UINT8_C(225),
                             UINT8_C(225), UINT8_C(214), UINT8_C( 93), UINT8_C(110),
                             UINT8_C(130), UINT8_C(140), UINT8_C(  9), UINT8_C(197),
                             UINT8_C(196), UINT8_C(218), UINT8_C( 26), UINT8_C(172),
                             UINT8_C( 79), UINT8_C(211), UINT8_C(167), UINT8_C(175),
                             UINT8_C(117), UINT8_C(109), UINT8_C(123), UINT8_C( 61),
                             UINT8_C(201), UINT8_C(219), UINT8_C( 65), UINT8_C(225),
                             UINT8_C(169), UINT8_C(245), UINT8_C(163), UINT8_C(246),
                             UINT8_C( 72), UINT8_C(  0), UINT8_C(139), UINT8_C( 27),
                             UINT8_C(202), UINT8_C(250), UINT8_C(  9), UINT8_C( 85),
                             UINT8_C(  2), UINT8_C(226), UINT8_C( 89), UINT8_C( 13),
                             UINT8_C(200), UINT8_C(251), UINT8_C( 41), UINT8_C(231)),
      UINT64_C(7115684499037192517) },
    { simde_x_mm512_set_epu8(UINT8_C( 29), UINT8_C(222), UINT8_C(229), UINT8_C(138),
                             UINT8_C(180), UINT8_C(164), UINT8_C( 76), UINT8_C(245),
                             UINT8_C( 99), UINT8_C(226), UINT8_C(230), UINT8_C( 98),
                             UINT8_C(233), UINT8_C( 51), UINT8_C(144), UINT8_C(148),
                             UINT8_C( 54), UINT8_C( 78), UINT8_C(119), UINT8_C( 10),
                             UINT8_C(178), UINT8_C(149), UINT8_C(114), UINT8_C( 10),
                             UINT8_C(114), UINT8_C(229), UINT8_C(111), UINT8_C(217),
                             UINT8_C(221), UINT8_C(177), UINT8_C(132), UINT8_C(239),
                             UINT8_C( 37), UINT8_C( 97), UINT8_C( 39), UINT8_C(159),
                             UINT8_C(180), UINT8_C(171), UINT8_C(207), UINT8_C( 97),
                             UINT8_C( 34), UINT8_C( 28), UINT8_C(196), UINT8_C( 31),
                             UINT8_C(161), UINT8_C(176), UINT8_C(212), UINT8_C(150),
                             UINT8_C(127), UINT8_C( 96), UINT8_C(  8), UINT8_C(231),
                             UINT8_C(113), UINT8_C(244), UINT8_C(225), UINT8_C( 59),
                             UINT8_C(  8), UINT8_C(189), UINT8_C(180), UINT8_C(181),
                             UINT8_C( 17), UINT8_C(247), UINT8_C(253), UINT8_C(193)),
      simde_x_mm512_set_epu8(UINT8_C(139), UINT8_C(135), UINT8_C(125), UINT8_C(234),
                             UINT8_C(170), UINT8_C(118), UINT8_C(218), UINT8_C(127),
                             UINT8_C(224), UINT8_C( 87), UINT8_C(101), UINT8_C( 79),
                             UINT8_C(160), UINT8_C( 79), UINT8_C(171), UINT8_C(143),
                             UINT8_C(221), UINT8_C( 27), UINT8_C( 16), UINT8_C(105),
                             UINT8_C(233), UINT8_C(128), UINT8_C( 36), UINT8_C( 18),
                             UINT8_C( 43), UINT8_C(252), UINT8_C(123), UINT8_C(101),
                             UINT8_C( 69), UINT8_C( 20), UINT8_C(168), UINT8_C(248),
                             UINT8_C( 42), UINT8_C(112), UINT8_C( 32), UINT8_C(253),
                             UINT8_C( 41), UINT8_C( 94), UINT8_C(127), UINT8_C(246),
                             UINT8_C(224), UINT8_C( 59), UINT8_C(224), UINT8_C(111),
                             UINT8_C(208), UINT8_C( 14), UINT8_C(109), UINT8_C(170),
                             UINT8_C(202), UINT8_C(101), UINT8_C(232), UINT8_C( 20),
                             UINT8_C( 79), UINT8_C( 96), UINT8_C(249), UINT8_C(176),
                             UINT8_C(110), UINT8_C(169), UINT8_C( 85), UINT8_C( 81),
                             UINT8_C( 78), UINT8_C(  8), UINT8_C(191), UINT8_C( 88)),
      UINT64_C(10558295030420333448) },
    { simde_x_mm512_set_epu8(UINT8_C(179), UINT8_C(213), UINT8_C( 48), UINT8_C(187),
                             UINT8_C(164), UINT8_C(  7), UINT8_C( 91), UINT8_C(  4),
                             UINT8_C(102), UINT8_C(109), UINT8_C(177), UINT8_C(255),
                             UINT8_C(192), UINT8_C(222), UINT8_C(234), UINT8_C(134),
                             UINT8_C(145), UINT8_C(124), UINT8_C(251), UINT8_C(236),
                             UINT8_C(216), UINT8_C(105), UINT8_C(153), UINT8_C( 89),
                             UINT8_C( 43), UINT8_C( 64), UINT8_C(112), UINT8_C(212),
                             UINT8_C(140), UINT8_C( 39), UINT8_C( 85), UINT8_C(189),
                             UINT8_C(227), UINT8_C(172), UINT8_C(113), UINT8_C(242),
                             UINT8_C( 62), UINT8_C(140), UINT8_C(107), UINT8_C(240),
                             UINT8_C(230), UINT8_C(141), UINT8_C(154), UINT8_C(244),
                             UINT8_C(228), UINT8_C(222), UINT8_C(241), UINT8_C( 55),
                             UINT8_C( 62), UINT8_C(128), UINT8_C( 59), UINT8_C( 35),
                             UINT8_C(194), UINT8_C(240), UINT8_C(211), UINT8_C(214),
                             UINT8_C( 18), UINT8_C(149), UINT8_C(249), UINT8_C(119),
                             UINT8_C( 83), UINT8_C(223), UINT8_C(207), UINT8_C(164)),
      simde_x_mm512_set_epu8(UINT8_C( 54), UINT8_C(  3), UINT8_C(127), UINT8_C(243),
                             UINT8_C(233), UINT8_C( 35), UINT8_C(224), UINT8_C( 24),
                             UINT8_C(138), UINT8_C(223), UINT8_C(122), UINT8_C(117),
                             UINT8_C(242), UINT8_C(132), UINT8_C(185), UINT8_C( 60),
                             UINT8_C(130), UINT8_C( 34), UINT8_C(198), UINT8_C( 87),
                             UINT8_C(166), UINT8_C( 62), UINT8_C(236), UINT8_C(111),
                             UINT8_C(236), UINT8_C(148), UINT8_C( 23), UINT8_C(102),
                             UINT8_C(203), UINT8_C( 39), UINT8_C( 44), UINT8_C(229),
                             UINT8_C(165), UINT8_C( 64), UINT8_C(247), UINT8_C(232),
                             UINT8_C(252), UINT8_C( 14), UINT8_C(190), UINT8_C(210),
                             UINT8_C(114), UINT8_C( 77), UINT8_C(213), UINT8_C( 48),
                             UINT8_C(150), UINT8_C(192), UINT8_C(  7), UINT8_C( 60),
                             UINT8_C(243), UINT8_C(183), UINT8_C( 19), UINT8_C( 12),
                             UINT8_C( 82), UINT8_C(159), UINT8_C(244), UINT8_C( 58),
                             UINT8_C(100), UINT8_C(194), UINT8_C(140), UINT8_C(234),
                             UINT8_C( 26), UINT8_C( 79), UINT8_C(203), UINT8_C( 24)),
      UINT64_C(4595927599441625808) },
    { simde_x_mm512_set_epu8(UINT8_C( 20), UINT8_C(104), UINT8_C(252), UINT8_C( 18),
                             UINT8_C( 49), UINT8_C(100), UINT8_C(232), UINT8_C(164),
                             UINT8_C(213), UINT8_C(  4), UINT8_C(177), UINT8_C(161),
                             UINT8_C(177), UINT8_C(  3), UINT8_C(134), UINT8_C(175),
                             UINT8_C( 44), UINT8_C(123), UINT8_C(208), UINT8_C( 13),
                             UINT8_C(112), UINT8_C(152), UINT8_C(166), UINT8_C( 36),
                             UINT8_C(194), UINT8_C( 54), UINT8_C(139), UINT8_C(252),
                             UINT8_C(211), UINT8_C( 63), UINT8_C(  1), UINT8_C(193),
                             UINT8_C(192), UINT8_C( 71), UINT8_C( 33), UINT8_C(244),
                             UINT8_C(217), UINT8_C(149), UINT8_C(174), UINT8_C(175),
                             UINT8_C(183), UINT8_C( 89), UINT8_C(  4), UINT8_C(212),
                             UINT8_C(123), UINT8_C( 28), UINT8_C(107), UINT8_C( 62),
                             UINT8_C(181), UINT8_C(  4), UINT8_C(156), UINT8_C( 13),
                             UINT8_C( 99), UINT8_C(210), UINT8_C( 57), UINT8_C( 39),
                             UINT8_C( 59), UINT8_C( 79), UINT8_C( 89), UINT8_C(123),
                             UINT8_C( 82), UINT8_C(235), UINT8_C(217), UINT8_C(152)),
      simde_x_mm512_set_epu8(UINT8_C(150), UINT8_C(194), UINT8_C(117), UINT8_C( 49),
                             UINT8_C(221), UINT8_C(199), UINT8_C(212), UINT8_C(148),
                             UINT8_C( 85), UINT8_C( 59), UINT8_C(185), UINT8_C( 89),
                             UINT8_C(176), UINT8_C(174), UINT8_C(127), UINT8_C(134),
                             UINT8_C(249), UINT8_C(178), UINT8_C(114), UINT8_C(195),
                             UINT8_C(248), UINT8_C(153), UINT8_C( 86), UINT8_C(137),
                             UINT8_C( 78), UINT8_C(198), UINT8_C(186), UINT8_C(113),
                             UINT8_C(114), UINT8_C(213), UINT8_C(233), UINT8_C(100),
                             UINT8_C(115), UINT8_C( 27), UINT8_C(  6), UINT8_C(115),
                             UINT8_C( 71), UINT8_C(139), UINT8_C(249), UINT8_C(103),
                             UINT8_C(106), UINT8_C(242), UINT8_C( 15), UINT8_C(207),
                             UINT8_C( 82), UINT8_C(215), UINT8_C(153), UINT8_C(201),
                             UINT8_C(103), UINT8_C(101), UINT8_C(182), UINT8_C(195),
                             UINT8_C(233), UINT8_C( 35), UINT8_C(201), UINT8_C(188),
                             UINT8_C(248), UINT8_C(236), UINT8_C( 57), UINT8_C(212),
                             UINT8_C( 14), UINT8_C(200), UINT8_C( 28), UINT8_C(223)),
      UINT64_C(15881061616211950545) },
    { simde_x_mm512_set_epu8(UINT8_C( 75), UINT8_C(247), UINT8_C(  8), UINT8_C(191),
                             UINT8_C(201), UINT8_C(123), UINT8_C( 94), UINT8_C(179),
                             UINT8_C(244), UINT8_C(101), UINT8_C( 84), UINT8_C(235),
                             UINT8_C( 73), UINT8_C(217), UINT8_C(236), UINT8_C( 67),
                             UINT8_C(172), UINT8_C(176), UINT8_C( 63), UINT8_C( 10),
                             UINT8_C(  5), UINT8_C(236), UINT8_C(174), UINT8_C(220),
                             UINT8_C(206), UINT8_C(250), UINT8_C(153), UINT8_C(199),
                             UINT8_C(238), UINT8_C(212), UINT8_C(149), UINT8_C(133),
                             UINT8_C( 38), UINT8_C( 78), UINT8_C(150), UINT8_C(121),
                             UINT8_C(152), UINT8_C(118), UINT8_C(104), UINT8_C(114),
                             UINT8_C( 96), UINT8_C(108), UINT8_C( 94), UINT8_C(164),
                             UINT8_C(231), UINT8_C( 95), UINT8_C( 67), UINT8_C(157),
                             UINT8_C(160), UINT8_C( 73), UINT8_C(157), UINT8_C(140),
                             UINT8_C(130), UINT8_C(247), UINT8_C(150), UINT8_C(152),
                             UINT8_C(157), UINT8_C(232), UINT8_C( 29), UINT8_C(121),
                             UINT8_C(206), UINT8_C(156), UINT8_C(126), UINT8_C( 23)),
      simde_x_mm512_set_epu8(UINT8_C(100), UINT8_C( 83), UINT8_C( 54), UINT8_C( 71),
                             UINT8_C( 37), UINT8_C(  5), UINT8_C(116), UINT8_C( 23),
                             UINT8_C(202), UINT8_C( 63), UINT8_C( 69), UINT8_C(165),
                             UINT8_C( 74), UINT8_C(243), UINT8_C(197), UINT8_C(135),
                             UINT8_C( 54), UINT8_C(163), UINT8_C(231), UINT8_C(198),
                             UINT8_C(236), UINT8_C( 28), UINT8_C(182), UINT8_C(250),
                             UINT8_C(142), UINT8_C(142), UINT8_C(129), UINT8_C(112),
                             UINT8_C( 35), UINT8_C(210), UINT8_C(144), UINT8_C(254),
                             UINT8_C(152), UINT8_C(159), UINT8_C( 93), UINT8_C( 83),
                             UINT8_C(237), UINT8_C(179), UINT8_C(152), UINT8_C( 79),
                             UINT8_C(232), UINT8_C(160), UINT8_C(116), UINT8_C(255),
                             UINT8_C(123), UINT8_C(122), UINT8_C(140), UINT8_C(155),
                             UINT8_C(208), UINT8_C(117), UINT8_C(159), UINT8_C(124),
                             UINT8_C( 66), UINT8_C(106), UINT8_C( 14), UINT8_C(238),
                             UINT8_C( 20), UINT8_C(155), UINT8_C(176), UINT8_C( 29),
                             UINT8_C(190), UINT8_C(210), UINT8_C(118), UINT8_C(126)),
      UINT64_C(11677054287794856229) },
    { simde_x_mm512_set_epu8(UINT8_C(207), UINT8_C( 64), UINT8_C(105), UINT8_C(187),
                             UINT8_C(171), UINT8_C( 70), UINT8_C(149), UINT8_C(106),
                             UINT8_C(166), UINT8_C(121), UINT8_C(188), UINT8_C(223),
                             UINT8_C(179), UINT8_C(107), UINT8_C(221), UINT8_C(150),
                             UINT8_C(139), UINT8_C( 19), UINT8_C(235), UINT8_C( 53),
                             UINT8_C(220), UINT8_C( 58), UINT8_C(119), UINT8_C(117),
                             UINT8_C(168), UINT8_C( 70), UINT8_C(147), UINT8_C(215),
                             UINT8_C(204), UINT8_C(240), UINT8_C( 35), UINT8_C(179),
                             UINT8_C(220), UINT8_C(143), UINT8_C(187), UINT8_C( 63),
                             UINT8_C(203), UINT8_C(224), UINT8_C(132), UINT8_C( 76),
                             UINT8_C( 40), UINT8_C( 69), UINT8_C(  2), UINT8_C( 69),
                             UINT8_C( 77), UINT8_C( 42), UINT8_C( 24), UINT8_C(201),
                             UINT8_C( 19), UINT8_C(253), UINT8_C(249), UINT8_C(203),
                             UINT8_C( 23), UINT8_C(169), UINT8_C(207), UINT8_C(  8),
                             UINT8_C(208), UINT8_C(154), UINT8_C( 75), UINT8_C(165),
                             UINT8_C(  0), UINT8_C(121), UINT8_C( 35), UINT8_C( 83)),
      simde_x_mm512_set_epu8(UINT8_C(148), UINT8_C( 45), UINT8_C( 60), UINT8_C(121),
                             UINT8_C(136), UINT8_C(104), UINT8_C( 13), UINT8_C(217),
                             UINT8_C( 88), UINT8_C(183), UINT8_C(187), UINT8_C(143),
                             UINT8_C(198), UINT8_C(210), UINT8_C(145), UINT8_C(248),
                             UINT8_C( 52), UINT8_C( 10), UINT8_C(182), UINT8_C( 49),
                             UINT8_C( 78), UINT8_C( 50), UINT8_C( 27), UINT8_C( 82),
                             UINT8_C( 46), UINT8_C(154), UINT8_C( 72), UINT8_C(  7),
                             UINT8_C( 99), UINT8_C( 90), UINT8_C(196), UINT8_C(238),
                             UINT8_C(215), UINT8_C(157), UINT8_C(102), UINT8_C( 95),
                             UINT8_C(144), UINT8_C( 12), UINT8_C( 52), UINT8_C( 36),
                             UINT8_C( 87), UINT8_C( 93), UINT8_C( 55), UINT8_C( 68),
                             UINT8_C(113), UINT8_C( 27), UINT8_C(111), UINT8_C(201),
                             UINT8_C(130), UINT8_C( 33), UINT8_C(210), UINT8_C( 36),
                             UINT8_C( 59), UINT8_C(255), UINT8_C( 46), UINT8_C( 49),
                             UINT8_C( 22), UINT8_C(148), UINT8_C(144), UINT8_C(146),
                             UINT8_C(245), UINT8_C( 41), UINT8_C(198), UINT8_C(231)),
      UINT64_C(381961832516783403) },
    { simde_x_mm512_set_epu8(UINT8_C(235), UINT8_C( 63), UINT8_C(229), UINT8_C(216),
                             UINT8_C( 37), UINT8_C(222), UINT8_C( 30), UINT8_C( 44),
                             UINT8_C(158), UINT8_C(214), UINT8_C(245), UINT8_C( 16),
                             UINT8_C( 13), UINT8_C( 12), UINT8_C(141), UINT8_C(114),
                             UINT8_C(211), UINT8_C( 56), UINT8_C(106), UINT8_C( 90),
                             UINT8_C( 25), UINT8_C( 48), UINT8_C(151), UINT8_C(  2),
                             UINT8_C(239), UINT8_C(116), UINT8_C( 99), UINT8_C( 74),
                             UINT8_C(147), UINT8_C( 81), UINT8_C(180), UINT8_C(169),
                             UINT8_C(183), UINT8_C(247), UINT8_C(193), UINT8_C( 12),
                             UINT8_C(147), UINT8_C(164), UINT8_C(194), UINT8_C(196),
                             UINT8_C( 62), UINT8_C(138), UINT8_C(220), UINT8_C(182),
                             UINT8_C(122), UINT8_C(  2), UINT8_C(203), UINT8_C( 14),
                             UINT8_C( 82), UINT8_C(208), UINT8_C(210), UINT8_C( 59),
                             UINT8_C( 36), UINT8_C(151), UINT8_C( 18), UINT8_C( 92),
                             UINT8_C(134), UINT8_C(208), UINT8_C( 95), UINT8_C( 59),
                             UINT8_C(250), UINT8_C(  9), UINT8_C(199), UINT8_C(157)),
      simde_x_mm512_set_epu8(UINT8_C(138), UINT8_C(192), UINT8_C( 19), UINT8_C( 45),
                             UINT8_C(  2), UINT8_C( 30), UINT8_C(159), UINT8_C(195),
                             UINT8_C( 92), UINT8_C(244), UINT8_C(218), UINT8_C(152),
                             UINT8_C(238), UINT8_C(209), UINT8_C( 95), UINT8_C( 38),
                             UINT8_C( 76), UINT8_C( 25), UINT8_C(198), UINT8_C( 22),
                             UINT8_C(237), UINT8_C( 18), UINT8_C(148), UINT8_C(223),
                             UINT8_C( 99), UINT8_C(223), UINT8_C(112), UINT8_C(190),
                             UINT8_C( 45), UINT8_C( 13), UINT8_C( 32), UINT8_C(140),
                             UINT8_C(249), UINT8_C(183), UINT8_C(177), UINT8_C( 27),
                             UINT8_C( 27), UINT8_C(174), UINT8_C(110), UINT8_C( 62),
                             UINT8_C(140), UINT8_C(195), UINT8_C(157), UINT8_C(183),
                             UINT8_C( 81), UINT8_C( 92), UINT8_C( 28), UINT8_C( 99),
                             UINT8_C(115), UINT8_C( 41), UINT8_C(207), UINT8_C(220),
                             UINT8_C(170), UINT8_C( 70), UINT8_C(196), UINT8_C( 53),
                             UINT8_C( 45), UINT8_C(254), UINT8_C(177), UINT8_C(198),
                             UINT8_C( 26), UINT8_C(251), UINT8_C(201), UINT8_C(125)),
      UINT64_C(4853800061908654710) },
    { simde_x_mm512_set_epu8(UINT8_C( 39), UINT8_C(111), UINT8_C( 79), UINT8_C( 64),
                             UINT8_C(165), UINT8_C( 55), UINT8_C( 15), UINT8_C(251),
                             UINT8_C(155), UINT8_C(226), UINT8_C(102), UINT8_C( 27),
                             UINT8_C(173), UINT8_C(169), UINT8_C(205), UINT8_C( 72),
                             UINT8_C(187), UINT8_C(157), UINT8_C(143), UINT8_C( 48),
                             UINT8_C(145), UINT8_C(133), UINT8_C(221), UINT8_C(157),
                             UINT8_C(112), UINT8_C(228), UINT8_C(192), UINT8_C(246),
                             UINT8_C( 19), UINT8_C(154), UINT8_C(151), UINT8_C( 43),
                             UINT8_C( 18), UINT8_C( 33), UINT8_C(196), UINT8_C( 32),
                             UINT8_C(143), UINT8_C(197), UINT8_C( 77), UINT8_C( 35),
                             UINT8_C(108), UINT8_C( 21), UINT8_C(240), UINT8_C( 47),
                             UINT8_C( 44), UINT8_C(206), UINT8_C(103), UINT8_C(244),
                             UINT8_C(131), UINT8_C(178), UINT8_C(145), UINT8_C(  4),
                             UINT8_C(241), UINT8_C( 13), UINT8_C(185), UINT8_C( 72),
                             UINT8_C(226), UINT8_C( 93), UINT8_C(116), UINT8_C( 66),
                             UINT8_C(223), UINT8_C(186), UINT8_C(235), UINT8_C( 57)),
      simde_x_mm512_set_epu8(UINT8_C(137), UINT8_C(  6), UINT8_C( 38), UINT8_C(185),
                             UINT8_C(182), UINT8_C(134), UINT8_C( 54), UINT8_C( 21),
                             UINT8_C(101), UINT8_C( 51), UINT8_C(169), UINT8_C(214),
                             UINT8_C(204), UINT8_C( 43), UINT8_C( 15), UINT8_C(161),
                             UINT8_C(123), UINT8_C(201), UINT8_C(126), UINT8_C( 21),
                             UINT8_C(181), UINT8_C(113), UINT8_C(224), UINT8_C(235),
                             UINT8_C(112), UINT8_C( 81), UINT8_C( 97), UINT8_C(103),
                             UINT8_C( 63), UINT8_C( 88), UINT8_C(251), UINT8_C( 83),
                             UINT8_C( 37), UINT8_C( 52), UINT8_C(172), UINT8_C( 10),
                             UINT8_C(101), UINT8_C(146), UINT8_C(200), UINT8_C(167),
                             UINT8_C( 91), UINT8_C(136), UINT8_C(165), UINT8_C( 10),
                             UINT8_C( 46), UINT8_C(208), UINT8_C(176), UINT8_C(155),
                             UINT8_C(102), UINT8_C(231), UINT8_C( 88), UINT8_C(169),
                             UINT8_C( 36), UINT8_C(196), UINT8_C(172), UINT8_C(187),
                             UINT8_C(198), UINT8_C(153), UINT8_C(113), UINT8_C( 47),
                             UINT8_C(217), UINT8_C(143), UINT8_C(254), UINT8_C( 59)),
      UINT64_C(11401226995314349379) }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])); i++) {
    simde__mmask64 r = simde_mm512_cmple_epu8_mask(test_vec[i].a, test_vec[i].b);
    simde_assert_mmask64(r, ==, test_vec[i].r);
  }

  return 0;
}

static int
test_simde_mm512_cmplt_epi8_mask(SIMDE_MUNIT_TEST_ARGS) {
  const struct {
    simde__m512i a;
    simde__m512i b;
    simde__mmask64 r;
  } test_vec[8] = {
    { simde_mm512_set_epi8(INT8_C( -77), INT8_C( -25), INT8_C( -46), INT8_C(  46),
                           INT8_C(  13), INT8_C(   4), INT8_C( -85), INT8_C( -85),
                           INT8_C( -84), INT8_C( -54), INT8_C(  24), INT8_C(  27),
                           INT8_C(-115), INT8_C(  32), INT8_C( -88), INT8_C( -66),
                           INT8_C( 113), INT8_C( -86), INT8_C(  24), INT8_C(  39),
                           INT8_C( -74), INT8_C(  61), INT8_C( 110), INT8_C(  70),
                           INT8_C(  64), INT8_C(  85), INT8_C(-108), INT8_C(  -7),
                           INT8_C(-115), INT8_C( -79), INT8_C( -97), INT8_C( -25),
                           INT8_C( 108), INT8_C( -91), INT8_C(  98), INT8_C(  90),
                           INT8_C( -86), INT8_C(-115), INT8_C(  85), INT8_C( -77),
                           INT8_C( -94), INT8_C( -97), INT8_C( 118), INT8_C( -72),
                           INT8_C( -59), INT8_C(   1), INT8_C(   5), INT8_C(  40),
                           INT8_C( -51), INT8_C(-106), INT8_C( -27), INT8_C(-101),
                           INT8_C(  27), INT8_C( -43), INT8_C( -67), INT8_C(-118),
                           INT8_C(   9), INT8_C( -56), INT8_C(-102), INT8_C( -49),
                           INT8_C( -36), INT8_C(  56), INT8_C(  85), INT8_C(  82)),
      simde_mm512_set_epi8(INT8_C(  15), INT8_C( -44), INT8_C(  -4), INT8_C(  65),
                           INT8_C( 115), INT8_C(  75), INT8_C(-128), INT8_C( -29),
                           INT8_C( -41), INT8_C( -89), INT8_C( -75), INT8_C( -12),
                           INT8_C(   8), INT8_C( -18), INT8_C(   0), INT8_C(  50),
                           INT8_C( -20), INT8_C(  66), INT8_C(  59), INT8_C(  42),
                           INT8_C( 112), INT8_C(-128), INT8_C(  83), INT8_C(   7),
                           INT8_C(  66), INT8_C( -29), INT8_C( -70), INT8_C(  42),
                           INT8_C(-100), INT8_C(  85), INT8_C( -81), INT8_C( -93),
                           INT8_C(   9), INT8_C( -66), INT8_C( -12), INT8_C(  91),
                           INT8_C(  12), INT8_C(  45), INT8_C( 127), INT8_C(-123),
                           INT8_C( -53), INT8_C(  78), INT8_C(  39), INT8_C(-107),
                           INT8_C(   4), INT8_C( -32), INT8_C( -36), INT8_C(  -2),
                           INT8_C( -88), INT8_C(  39), INT8_C( -66), INT8_C( -14),
                           INT8_C( -93), INT8_C( -77), INT8_C( -69), INT8_C(   8),
                           INT8_C(-103), INT8_C( 105), INT8_C(  72), INT8_C(  -8),
                           INT8_C(  49), INT8_C(-104), INT8_C(  40), INT8_C(  17)),
      UINT64_C(13658143053960466808) },
    { simde_mm512_set_epi8(INT8_C(-103), INT8_C(  71), INT8_C(  97), INT8_C(  13),
                           INT8_C( -23), INT8_C(-103), INT8_C(-115), INT8_C(  49),
                           INT8_C(  20), INT8_C(  -2), INT8_C(  49), INT8_C(  20),
                           INT8_C( -48), INT8_C(  19), INT8_C(  36), INT8_C(   5),
                           INT8_C( 110), INT8_C( -17), INT8_C( -78), INT8_C( -81),
                           INT8_C( -87), INT8_C( -42), INT8_C( -90), INT8_C( -74),
                           INT8_C( -81), INT8_C( -59), INT8_C( -73), INT8_C( 101),
                           INT8_C( -93), INT8_C(  16), INT8_C(  54), INT8_C(-126),
                           INT8_C(  73), INT8_C(-113), INT8_C( -63), INT8_C(   0),
                           INT8_C(  -4), INT8_C( -98), INT8_C(  69), INT8_C( -82),
                           INT8_C(-103), INT8_C(-100), INT8_C( -26), INT8_C(   6),
                           INT8_C( -99), INT8_C(  22), INT8_C(   1), INT8_C(-119),
                           INT8_C(  62), INT8_C( -91), INT8_C( 126), INT8_C( -42),
                           INT8_C( -88), INT8_C( -10), INT8_C(  66), INT8_C(-108),
                           INT8_C(   4), INT8_C( -81), INT8_C(-101), INT8_C( -87),
                           INT8_C( -36), INT8_C( 114), INT8_C( 105), INT8_C(  70)),
      simde_mm512_set_epi8(INT8_C(-106), INT8_C( 118), INT8_C(-104), INT8_C(  91),
                           INT8_C(  22), INT8_C( -65), INT8_C(  99), INT8_C(  90),
                           INT8_C( -59), INT8_C( 121), INT8_C(  74), INT8_C(  82),
                           INT8_C(  17), INT8_C( -59), INT8_C(  19), INT8_C(-103),
                           INT8_C(  84), INT8_C(  62), INT8_C( 105), INT8_C( -37),
                           INT8_C( -29), INT8_C(-118), INT8_C(  43), INT8_C(  43),
                           INT8_C(  33), INT8_C(-102), INT8_C(  -5), INT8_C( -51),
                           INT8_C( -22), INT8_C(   3), INT8_C(  47), INT8_C( -50),
                           INT8_C( -25), INT8_C(  25), INT8_C( -33), INT8_C( -68),
                           INT8_C(  52), INT8_C( -60), INT8_C(  19), INT8_C(-103),
                           INT8_C(  71), INT8_C(  88), INT8_C(  82), INT8_C( -50),
                           INT8_C( -90), INT8_C(  -3), INT8_C( -25), INT8_C(  35),
                           INT8_C(-100), INT8_C( -67), INT8_C(  46), INT8_C(  77),
                           INT8_C( -70), INT8_C(   1), INT8_C(  82), INT8_C( 114),
                           INT8_C( -55), INT8_C(  11), INT8_C( -95), INT8_C( 111),
                           INT8_C(  48), INT8_C(  71), INT8_C(  90), INT8_C( -66)),
      UINT64_C(6879384398415355768) },
    { simde_mm512_set_epi8(INT8_C( -71), INT8_C( 111), INT8_C( -21), INT8_C(  61),
                           INT8_C(   5), INT8_C(  96), INT8_C(  81), INT8_C(   9),
                           INT8_C(-121), INT8_C(  39), INT8_C( -77), INT8_C( 111),
                           INT8_C( -66), INT8_C(  56), INT8_C( -30), INT8_C( -47),
                           INT8_C(  60), INT8_C( -59), INT8_C(  45), INT8_C(  86),
                           INT8_C( -57), INT8_C( -53), INT8_C( 106), INT8_C(  23),
                           INT8_C( -11), INT8_C(  82), INT8_C(  92), INT8_C( -19),
                           INT8_C(  64), INT8_C( 103), INT8_C( -89), INT8_C( -98),
                           INT8_C( -33), INT8_C(  99), INT8_C(  24), INT8_C(  46),
                           INT8_C(  12), INT8_C(  -4), INT8_C( -89), INT8_C( 107),
                           INT8_C( -35), INT8_C(  71), INT8_C(  43), INT8_C( 111),
                           INT8_C( -31), INT8_C( -90), INT8_C(  -5), INT8_C(  22),
                           INT8_C(  27), INT8_C( -27), INT8_C( -44), INT8_C( 119),
                           INT8_C( -73), INT8_C(  55), INT8_C(-108), INT8_C( -98),
                           INT8_C( 121), INT8_C(-114), INT8_C(  51), INT8_C(  28),
                           INT8_C(  69), INT8_C(  37), INT8_C(  17), INT8_C( -56)),
      simde_mm512_set_epi8(INT8_C( -65), INT8_C(  52), INT8_C(  -9), INT8_C(  14),
                           INT8_C(  23), INT8_C(-117), INT8_C( 110), INT8_C(  60),
                           INT8_C(  81), INT8_C(-125), INT8_C( 120), INT8_C(  71),
                           INT8_C( 100), INT8_C( -41), INT8_C( 116), INT8_C(-126),
                           INT8_C(-101), INT8_C(  34), INT8_C( -39), INT8_C(  84),
                           INT8_C( -70), INT8_C(-112), INT8_C(  -6), INT8_C( -59),
                           INT8_C(  82), INT8_C(  94), INT8_C(  76), INT8_C( 114),
                           INT8_C( 127), INT8_C( -86), INT8_C( -89), INT8_C(  93),
                           INT8_C(   1), INT8_C( 119), INT8_C( -87), INT8_C( -11),
                           INT8_C( -62), INT8_C( -56), INT8_C( -72), INT8_C( -84),
                           INT8_C(  46), INT8_C(  34), INT8_C( -72), INT8_C(-127),
                           INT8_C(  99), INT8_C( 102), INT8_C(  60), INT8_C(  57),
                           INT8_C( -62), INT8_C( -50), INT8_C( -30), INT8_C(  99),
                           INT8_C( -14), INT8_C(  93), INT8_C( -12), INT8_C(-120),
                           INT8_C( 126), INT8_C(   7), INT8_C(  84), INT8_C(  10),
                           INT8_C( -53), INT8_C( 100), INT8_C( 113), INT8_C( -25)),
      UINT64_C(12369770630542733031) },
    { simde_mm512_set_epi8(INT8_C(  56), INT8_C(  -4), INT8_C(  -4), INT8_C( -38),
                           INT8_C(  25), INT8_C( 103), INT8_C( -62), INT8_C(  92),
                           INT8_C(  31), INT8_C( -43), INT8_C( -18), INT8_C(  90),
                           INT8_C( -11), INT8_C(  80), INT8_C(-102), INT8_C( -32),
                           INT8_C( -48), INT8_C(  -4), INT8_C(-124), INT8_C(-111),
                           INT8_C( 122), INT8_C(  50), INT8_C(  20), INT8_C(  73),
                           INT8_C(  10), INT8_C( -61), INT8_C(  30), INT8_C(  39),
                           INT8_C(  47), INT8_C(  -1), INT8_C( -24), INT8_C(-123),
                           INT8_C(  91), INT8_C(   9), INT8_C( -27), INT8_C(  35),
                           INT8_C(   0), INT8_C( -62), INT8_C( -75), INT8_C( 104),
                           INT8_C(  44), INT8_C(  16), INT8_C(-126), INT8_C(  97),
                           INT8_C( -20), INT8_C( -56), INT8_C( -70), INT8_C( -25),
                           INT8_C(  96), INT8_C( 112), INT8_C( 102), INT8_C(   2),
                           INT8_C( -70), INT8_C( -47), INT8_C(  77), INT8_C( -51),
                           INT8_C( -63), INT8_C(  15), INT8_C( -89), INT8_C( -32),
                           INT8_C(  72), INT8_C( 102), INT8_C( -45), INT8_C(  80)),
      simde_mm512_set_epi8(INT8_C(  46), INT8_C( -69), INT8_C(  -3), INT8_C(   7),
                           INT8_C( -53), INT8_C( -75), INT8_C(-113), INT8_C(  66),
                           INT8_C(-117), INT8_C(  -4), INT8_C( -75), INT8_C(-100),
                           INT8_C( -10), INT8_C(-123), INT8_C( 108), INT8_C(  99),
                           INT8_C(  34), INT8_C(  28), INT8_C(  20), INT8_C(  -3),
                           INT8_C( -41), INT8_C(  37), INT8_C( 126), INT8_C(  37),
                           INT8_C(  86), INT8_C(-126), INT8_C(  57), INT8_C( -79),
                           INT8_C(-102), INT8_C( -22), INT8_C( -65), INT8_C( -86),
                           INT8_C( -13), INT8_C(  63), INT8_C( -35), INT8_C(  12),
                           INT8_C(  52), INT8_C( 115), INT8_C(  54), INT8_C(-115),
                           INT8_C(  85), INT8_C(-123), INT8_C(  -3), INT8_C( -67),
                           INT8_C(  75), INT8_C( -64), INT8_C(  52), INT8_C( 126),
                           INT8_C(  62), INT8_C( -88), INT8_C(  10), INT8_C(  75),
                           INT8_C( -91), INT8_C(  62), INT8_C(  97), INT8_C(  54),
                           INT8_C( -80), INT8_C( -98), INT8_C( -77), INT8_C(  80),
                           INT8_C(  14), INT8_C( 105), INT8_C( -43), INT8_C(  19)),
      UINT64_C(3480141911697332022) },
    { simde_mm512_set_epi8(INT8_C(  30), INT8_C(  13), INT8_C(  72), INT8_C( 124),
                           INT8_C(   6), INT8_C( -85), INT8_C( -61), INT8_C( -45),
                           INT8_C(-117), INT8_C(  64), INT8_C(-110), INT8_C(  -2),
                           INT8_C(  83), INT8_C(  64), INT8_C(  94), INT8_C(  33),
                           INT8_C(  87), INT8_C( -89), INT8_C( -85), INT8_C( -82),
                           INT8_C(  61), INT8_C( -90), INT8_C(  27), INT8_C(-115),
                           INT8_C( -84), INT8_C( -79), INT8_C( -56), INT8_C(  66),
                           INT8_C(  57), INT8_C(  48), INT8_C(  34), INT8_C(  90),
                           INT8_C(  51), INT8_C(  19), INT8_C( 105), INT8_C( -57),
                           INT8_C( -67), INT8_C(-104), INT8_C(   1), INT8_C(-128),
                           INT8_C(  95), INT8_C(  94), INT8_C( -45), INT8_C( -86),
                           INT8_C( 116), INT8_C(  95), INT8_C(  64), INT8_C(-106),
                           INT8_C(  32), INT8_C( -60), INT8_C(-105), INT8_C(  23),
                           INT8_C( 115), INT8_C( -71), INT8_C( -22), INT8_C( -60),
                           INT8_C( -51), INT8_C(  42), INT8_C( -96), INT8_C(  -3),
                           INT8_C(  39), INT8_C( -17), INT8_C(  55), INT8_C(-100)),
      simde_mm512_set_epi8(INT8_C(  33), INT8_C( -73), INT8_C(  56), INT8_C(-105),
                           INT8_C( 103), INT8_C(-109), INT8_C(  18), INT8_C( -30),
                           INT8_C(  97), INT8_C(  18), INT8_C( 119), INT8_C( -24),
                           INT8_C( 104), INT8_C(  64), INT8_C( -85), INT8_C( -21),
                           INT8_C(  18), INT8_C(-115), INT8_C(  98), INT8_C(  20),
                           INT8_C(  51), INT8_C(  30), INT8_C( -90), INT8_C( -24),
                           INT8_C( -99), INT8_C( -91), INT8_C(  11), INT8_C( -84),
                           INT8_C(  56), INT8_C(  98), INT8_C( -91), INT8_C( -93),
                           INT8_C(   0), INT8_C( 119), INT8_C( 113), INT8_C( 107),
                           INT8_C( 103), INT8_C(  96), INT8_C( -68), INT8_C(-127),
                           INT8_C( -84), INT8_C(  51), INT8_C( 103), INT8_C(  56),
                           INT8_C( -12), INT8_C(  53), INT8_C(  32), INT8_C(-117),
                           INT8_C( -90), INT8_C( -10), INT8_C(  29), INT8_C( 115),
                           INT8_C( 127), INT8_C(  10), INT8_C( -23), INT8_C( 108),
                           INT8_C(  92), INT8_C(  -2), INT8_C( -94), INT8_C(  83),
                           INT8_C( -55), INT8_C( 115), INT8_C( -67), INT8_C( -25)),
      UINT64_C(10063351798194798005) },
    { simde_mm512_set_epi8(INT8_C(  30), INT8_C( -62), INT8_C(  -2), INT8_C( 110),
                           INT8_C( -99), INT8_C(   0), INT8_C( 114), INT8_C(-101),
                           INT8_C( -98), INT8_C(-101), INT8_C( 110), INT8_C( 127),
                           INT8_C( -57), INT8_C( 112), INT8_C(   1), INT8_C( -68),
                           INT8_C( -53), INT8_C(  40), INT8_C(  60), INT8_C(  -7),
                           INT8_C( 119), INT8_C( -84), INT8_C(  59), INT8_C(  41),
                           INT8_C(  94), INT8_C(  56), INT8_C( -73), INT8_C(-113),
                           INT8_C(-101), INT8_C(  70), INT8_C(  -5), INT8_C(-102),
                           INT8_C( -24), INT8_C( -88), INT8_C( -82), INT8_C( -98),
                           INT8_C( 103), INT8_C( 114), INT8_C( -24), INT8_C(  -1),
                           INT8_C(  33), INT8_C( -48), INT8_C(  56), INT8_C( -37),
                           INT8_C( -82), INT8_C( 126), INT8_C(  -6), INT8_C( 117),
                           INT8_C(-112), INT8_C( -39), INT8_C(  59), INT8_C(  25),
                           INT8_C( -19), INT8_C(  35), INT8_C( -12), INT8_C( -23),
                           INT8_C(-128), INT8_C( -16), INT8_C( -33), INT8_C( -91),
                           INT8_C( -40), INT8_C( -21), INT8_C( -38), INT8_C(  79)),
      simde_mm512_set_epi8(INT8_C(  42), INT8_C( 118), INT8_C(  39), INT8_C(  16),
                           INT8_C(  45), INT8_C( -16), INT8_C(  38), INT8_C(  64),
                           INT8_C( -47), INT8_C(  99), INT8_C(  10), INT8_C( -26),
                           INT8_C( -31), INT8_C( -27), INT8_C(  -3), INT8_C( 108),
                           INT8_C( -96), INT8_C( -87), INT8_C( -84), INT8_C(   9),
                           INT8_C(  24), INT8_C(  14), INT8_C( 123), INT8_C( -80),
                           INT8_C(   1), INT8_C(  70), INT8_C(  95), INT8_C(   7),
                           INT8_C( -79), INT8_C( -64), INT8_C(  81), INT8_C( -84),
                           INT8_C(-123), INT8_C( -69), INT8_C( -73), INT8_C(  98),
                           INT8_C( -88), INT8_C( 100), INT8_C( -60), INT8_C( 125),
                           INT8_C(  62), INT8_C( -77), INT8_C(  32), INT8_C(  40),
                           INT8_C(  68), INT8_C(  75), INT8_C( 112), INT8_C(-128),
                           INT8_C( -18), INT8_C(  -3), INT8_C(   2), INT8_C(  28),
                           INT8_C( -88), INT8_C(  15), INT8_C( -42), INT8_C(  -1),
                           INT8_C(  10), INT8_C( -70), INT8_C( -90), INT8_C( -93),
                           INT8_C(  65), INT8_C( 119), INT8_C( 107), INT8_C(  29)),
      UINT64_C(16846020600598811022) },
    { simde_mm512_set_epi8(INT8_C(  21), INT8_C( 119), INT8_C(  54), INT8_C( -98),
                           INT8_C(-127), INT8_C(  24), INT8_C( -58), INT8_C(-124),
                           INT8_C(  58), INT8_C(   6), INT8_C(  90), INT8_C( -82),
                           INT8_C(  81), INT8_C(-114), INT8_C( -76), INT8_C( -79),
                           INT8_C(-107), INT8_C( 107), INT8_C( -44), INT8_C(  36),
                           INT8_C(  -3), INT8_C( -89), INT8_C( 118), INT8_C(-104),
                           INT8_C(  90), INT8_C( 122), INT8_C(   4), INT8_C(  68),
                           INT8_C(  34), INT8_C(  55), INT8_C(  65), INT8_C(  86),
                           INT8_C(  74), INT8_C( -50), INT8_C(-117), INT8_C(   7),
                           INT8_C(  11), INT8_C(  -4), INT8_C(  -3), INT8_C( 109),
                           INT8_C( -44), INT8_C( -96), INT8_C(  98), INT8_C(  87),
                           INT8_C( -59), INT8_C(  95), INT8_C( -16), INT8_C( -64),
                           INT8_C( -50), INT8_C(  -5), INT8_C( -97), INT8_C( -47),
                           INT8_C( -88), INT8_C(  77), INT8_C( -27), INT8_C( -13),
                           INT8_C( -76), INT8_C( -43), INT8_C( 104), INT8_C(  53),
                           INT8_C(   4), INT8_C( -45), INT8_C(  81), INT8_C( 115)),
      simde_mm512_set_epi8(INT8_C(  58), INT8_C(  41), INT8_C(  85), INT8_C( -51),
                           INT8_C(   1), INT8_C(  51), INT8_C(  56), INT8_C(-109),
                           INT8_C( 109), INT8_C( 112), INT8_C(  72), INT8_C( -55),
                           INT8_C( -35), INT8_C( -66), INT8_C( -30), INT8_C( -94),
                           INT8_C(  71), INT8_C(  55), INT8_C( 100), INT8_C(  34),
                           INT8_C(  17), INT8_C( 115), INT8_C( 127), INT8_C(  32),
                           INT8_C( 101), INT8_C(  91), INT8_C(  97), INT8_C( -40),
                           INT8_C(  45), INT8_C( -66), INT8_C( -66), INT8_C(  34),
                           INT8_C( -55), INT8_C(  18), INT8_C( -74), INT8_C(  -1),
                           INT8_C(  33), INT8_C( -59), INT8_C(  16), INT8_C( -80),
                           INT8_C(  -4), INT8_C(  84), INT8_C(  30), INT8_C( -62),
                           INT8_C(-115), INT8_C(  37), INT8_C(  41), INT8_C(  57),
                           INT8_C( -41), INT8_C( -67), INT8_C( -77), INT8_C(  48),
                           INT8_C( 113), INT8_C(  84), INT8_C(  44), INT8_C(  98),
                           INT8_C( -38), INT8_C(   2), INT8_C(-122), INT8_C( -26),
                           INT8_C(  77), INT8_C(  90), INT8_C(  30), INT8_C( 127)),
      UINT64_C(13823429244140896205) },
    { simde_mm512_set_epi8(INT8_C( -22), INT8_C( 124), INT8_C(  34), INT8_C( -16),
                           INT8_C(   8), INT8_C( 122), INT8_C(  46), INT8_C(-121),
                           INT8_C(  29), INT8_C(  20), INT8_C(  -3), INT8_C( -93),
                           INT8_C(  62), INT8_C( 115), INT8_C(  28), INT8_C( -90),
                           INT8_C(  27), INT8_C(  21), INT8_C( -60), INT8_C(  15),
                           INT8_C(  72), INT8_C(-113), INT8_C(   5), INT8_C( -77),
                           INT8_C(  42), INT8_C( -54), INT8_C( -42), INT8_C(-118),
                           INT8_C( -22), INT8_C(  63), INT8_C( -17), INT8_C( -10),
                           INT8_C( -67), INT8_C(  58), INT8_C( -23), INT8_C(-108),
                           INT8_C(-119), INT8_C( 102), INT8_C(  88), INT8_C( 112),
                           INT8_C(-126), INT8_C(-115), INT8_C(  -3), INT8_C(  -3),
                           INT8_C( 115), INT8_C( -28), INT8_C(  73), INT8_C(  86),
                           INT8_C(  27), INT8_C( -49), INT8_C(  40), INT8_C(   0),
                           INT8_C(  84), INT8_C(-105), INT8_C( -76), INT8_C( -85),
                           INT8_C(  88), INT8_C( 123), INT8_C(  42), INT8_C(  35),
                           INT8_C(  67), INT8_C( -90), INT8_C(  86), INT8_C( -23)),
      simde_mm512_set_epi8(INT8_C(-115), INT8_C(  -9), INT8_C(  73), INT8_C(  35),
                           INT8_C(-126), INT8_C(-117), INT8_C( -35), INT8_C(  40),
                           INT8_C(-119), INT8_C( -28), INT8_C( -11), INT8_C( -21),
                           INT8_C( -21), INT8_C(  36), INT8_C( -54), INT8_C( -56),
                           INT8_C(  78), INT8_C(   7), INT8_C( -48), INT8_C( -59),
                           INT8_C( 121), INT8_C(  74), INT8_C( -58), INT8_C( 102),
                           INT8_C(  91), INT8_C( 126), INT8_C( -48), INT8_C( 121),
                           INT8_C( -54), INT8_C(  92), INT8_C( -18), INT8_C( 115),
                           INT8_C( -82), INT8_C(-102), INT8_C( -44), INT8_C(  35),
                           INT8_C(  20), INT8_C(-107), INT8_C(  72), INT8_C(  -9),
                           INT8_C( -37), INT8_C( -54), INT8_C( -20), INT8_C( -31),
                           INT8_C(  67), INT8_C(  96), INT8_C( -94), INT8_C(  -5),
                           INT8_C( -22), INT8_C(  67), INT8_C(  22), INT8_C( -62),
                           INT8_C( -72), INT8_C( -76), INT8_C( -32), INT8_C(  86),
                           INT8_C(  -8), INT8_C(  57), INT8_C( -71), INT8_C( -16),
                           INT8_C(-124), INT8_C( -88), INT8_C(  49), INT8_C(  35)),
      UINT64_C(3535798313217705733) }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])); i++) {
    simde__mmask64 r = simde_mm512_cmplt_epi8_mask(test_vec[i].a, test_vec[i].b);
    simde_assert_mmask64(r, ==, test_vec[i].r);
  }

  return 0;
}

static int
test_simde_mm512_cmplt_epu8_mask(SIMDE_MUNIT_TEST_ARGS) {
  const struct {
    simde__m512i a;
    simde__m512i b;
    simde__mmask64 r;
  } test_vec[8] = {
    { simde_x_mm512_set_epu8(UINT8_C(200), UINT8_C( 64), UINT8_C(228), UINT8_C(187),
                             UINT8_C( 53), UINT8_C(115), UINT8_C(212), UINT8_C(224),
                             UINT8_C(234), UINT8_C( 45), UINT8_C(183), UINT8_C(185),
                             UINT8_C(117), UINT8_C(137), UINT8_C(224), UINT8_C( 48),
                             UINT8_C(225), UINT8_C(229), UINT8_C(194), UINT8_C(201),
                             UINT8_C(105), UINT8_C(193), UINT8_C(219), UINT8_C(144),
                             UINT8_C( 87), UINT8_C(205), UINT8_C( 38), UINT8_C(200),
                             UINT8_C( 89), UINT8_C(  3), UINT8_C(155), UINT8_C(245),
                             UINT8_C( 35), UINT8_C(246), UINT8_C( 15), UINT8_C(254),
                             UINT8_C(226), UINT8_C(163), UINT8_C( 22), UINT8_C(135),
                             UINT8_C(105), UINT8_C(246), UINT8_C(210), UINT8_C(152),
                             UINT8_C(131), UINT8_C(226), UINT8_C(111), UINT8_C(207),
                             UINT8_C( 48), UINT8_C(166), UINT8_C( 61), UINT8_C( 72),
                             UINT8_C(115), UINT8_C( 10), UINT8_C(124), UINT8_C( 60),
                             UINT8_C(127), UINT8_C( 50), UINT8_C( 32), UINT8_C( 65),
                             UINT8_C(138), UINT8_C(206), UINT8_C( 67), UINT8_C( 10)),
      simde_x_mm512_set_epu8(UINT8_C(101), UINT8_C(156), UINT8_C(229), UINT8_C( 20),
                             UINT8_C(123), UINT8_C(204), UINT8_C(216), UINT8_C( 73),
                             UINT8_C(103), UINT8_C(232), UINT8_C(253), UINT8_C(122),
                             UINT8_C( 63), UINT8_C(129), UINT8_C(179), UINT8_C(165),
                             UINT8_C(219), UINT8_C( 23), UINT8_C( 44), UINT8_C(209),
                             UINT8_C( 74), UINT8_C(150), UINT8_C(180), UINT8_C(217),
                             UINT8_C( 86), UINT8_C(119), UINT8_C( 26), UINT8_C( 59),
                             UINT8_C(214), UINT8_C( 93), UINT8_C( 27), UINT8_C( 37),
                             UINT8_C( 61), UINT8_C( 47), UINT8_C(126), UINT8_C(138),
                             UINT8_C(246), UINT8_C( 88), UINT8_C(146), UINT8_C(144),
                             UINT8_C(216), UINT8_C( 36), UINT8_C(167), UINT8_C(247),
                             UINT8_C(118), UINT8_C( 82), UINT8_C( 16), UINT8_C(237),
                             UINT8_C(182), UINT8_C(219), UINT8_C( 49), UINT8_C( 46),
                             UINT8_C(225), UINT8_C( 22), UINT8_C(189), UINT8_C( 65),
                             UINT8_C(101), UINT8_C(226), UINT8_C( 23), UINT8_C(220),
                             UINT8_C( 28), UINT8_C( 93), UINT8_C(158), UINT8_C(  8)),
      UINT64_C(7953657163028746066) },
    { simde_x_mm512_set_epu8(UINT8_C( 72), UINT8_C( 33), UINT8_C(154), UINT8_C(122),
                             UINT8_C( 74), UINT8_C(178), UINT8_C( 50), UINT8_C(213),
                             UINT8_C( 98), UINT8_C(217), UINT8_C( 79), UINT8_C(232),
                             UINT8_C(132), UINT8_C(243), UINT8_C(145), UINT8_C(149),
                             UINT8_C( 59), UINT8_C(222), UINT8_C(125), UINT8_C(147),
                             UINT8_C(164), UINT8_C(104), UINT8_C(229), UINT8_C(111),
                             UINT8_C( 98), UINT8_C(138), UINT8_C(193), UINT8_C(124),
                             UINT8_C( 63), UINT8_C(242), UINT8_C(  1), UINT8_C( 40),
                             UINT8_C(135), UINT8_C(187), UINT8_C(113), UINT8_C(230),
                             UINT8_C(208), UINT8_C(113), UINT8_C(106), UINT8_C( 33),
                             UINT8_C(173), UINT8_C( 82), UINT8_C( 93), UINT8_C(149),
                             UINT8_C(  4), UINT8_C(122), UINT8_C( 61), UINT8_C( 54),
                             UINT8_C(106), UINT8_C(212), UINT8_C( 67), UINT8_C(253),
                             UINT8_C(216), UINT8_C(134), UINT8_C(207), UINT8_C( 61),
                             UINT8_C(208), UINT8_C( 81), UINT8_C(150), UINT8_C(127),
                             UINT8_C( 37), UINT8_C(137), UINT8_C(225), UINT8_C( 78)),
      simde_x_mm512_set_epu8(UINT8_C( 96), UINT8_C(106), UINT8_C(154), UINT8_C(  0),
                             UINT8_C(  1), UINT8_C(122), UINT8_C(193), UINT8_C( 25),
                             UINT8_C(239), UINT8_C(152), UINT8_C( 87), UINT8_C( 80),
                             UINT8_C( 31), UINT8_C(133), UINT8_C(251), UINT8_C( 23),
                             UINT8_C(140), UINT8_C(137), UINT8_C(157), UINT8_C(114),
                             UINT8_C( 93), UINT8_C(199), UINT8_C( 63), UINT8_C( 63),
                             UINT8_C(  7), UINT8_C(151), UINT8_C( 52), UINT8_C( 78),
                             UINT8_C(106), UINT8_C( 19), UINT8_C( 61), UINT8_C( 80),
                             UINT8_C(227), UINT8_C( 61), UINT8_C(244), UINT8_C( 16),
                             UINT8_C(153), UINT8_C(241), UINT8_C(118), UINT8_C(250),
                             UINT8_C(216), UINT8_C( 38), UINT8_C(  9), UINT8_C(176),
                             UINT8_C( 88), UINT8_C(222), UINT8_C( 84), UINT8_C(243),
                             UINT8_C(  6), UINT8_C( 75), UINT8_C(  1), UINT8_C(141),
                             UINT8_C(140), UINT8_C( 75), UINT8_C(187), UINT8_C(128),
                             UINT8_C(101), UINT8_C(169), UINT8_C(202), UINT8_C(205),
                             UINT8_C(101), UINT8_C( 13), UINT8_C(249), UINT8_C(158)),
      UINT64_C(14024952834426863995) },
    { simde_x_mm512_set_epu8(UINT8_C(118), UINT8_C(178), UINT8_C(224), UINT8_C( 82),
                             UINT8_C( 86), UINT8_C(103), UINT8_C( 51), UINT8_C( 73),
                             UINT8_C(131), UINT8_C(150), UINT8_C( 58), UINT8_C(120),
                             UINT8_C( 23), UINT8_C(173), UINT8_C( 81), UINT8_C(210),
                             UINT8_C(130), UINT8_C( 18), UINT8_C(188), UINT8_C( 71),
                             UINT8_C( 31), UINT8_C(136), UINT8_C(151), UINT8_C(116),
                             UINT8_C(141), UINT8_C( 84), UINT8_C( 91), UINT8_C( 42),
                             UINT8_C( 78), UINT8_C(105), UINT8_C( 68), UINT8_C(247),
                             UINT8_C(246), UINT8_C( 98), UINT8_C(236), UINT8_C(254),
                             UINT8_C( 34), UINT8_C( 84), UINT8_C(115), UINT8_C(219),
                             UINT8_C( 18), UINT8_C(  7), UINT8_C( 63), UINT8_C(118),
                             UINT8_C( 52), UINT8_C( 47), UINT8_C(109), UINT8_C( 86),
                             UINT8_C( 94), UINT8_C( 32), UINT8_C( 34), UINT8_C(216),
                             UINT8_C(187), UINT8_C(179), UINT8_C( 76), UINT8_C(176),
                             UINT8_C(254), UINT8_C(105), UINT8_C( 86), UINT8_C(220),
                             UINT8_C(  7), UINT8_C( 77), UINT8_C(  8), UINT8_C(213)),
      simde_x_mm512_set_epu8(UINT8_C(139), UINT8_C( 33), UINT8_C( 28), UINT8_C(170),
                             UINT8_C( 51), UINT8_C(116), UINT8_C(243), UINT8_C( 67),
                             UINT8_C(171), UINT8_C( 22), UINT8_C( 12), UINT8_C( 38),
                             UINT8_C(216), UINT8_C(230), UINT8_C(112), UINT8_C( 69),
                             UINT8_C(229), UINT8_C(115), UINT8_C(110), UINT8_C(236),
                             UINT8_C( 84), UINT8_C(115), UINT8_C(237), UINT8_C(235),
                             UINT8_C( 57), UINT8_C(112), UINT8_C( 59), UINT8_C(169),
                             UINT8_C(188), UINT8_C( 43), UINT8_C( 43), UINT8_C(171),
                             UINT8_C(177), UINT8_C( 79), UINT8_C(216), UINT8_C( 10),
                             UINT8_C(218), UINT8_C(219), UINT8_C(205), UINT8_C( 15),
                             UINT8_C(248), UINT8_C( 98), UINT8_C( 68), UINT8_C( 51),
                             UINT8_C(  2), UINT8_C( 76), UINT8_C(147), UINT8_C(206),
                             UINT8_C(115), UINT8_C(128), UINT8_C(102), UINT8_C(116),
                             UINT8_C( 28), UINT8_C(  5), UINT8_C( 73), UINT8_C(210),
                             UINT8_C(179), UINT8_C(184), UINT8_C( 57), UINT8_C( 24),
                             UINT8_C( 10), UINT8_C( 26), UINT8_C(  0), UINT8_C( 23)),
      UINT64_C(10848849723635786056) },
    { simde_x_mm512_set_epu8(UINT8_C( 59), UINT8_C(122), UINT8_C( 87), UINT8_C(211),
                             UINT8_C(197), UINT8_C(251), UINT8_C( 70), UINT8_C(103),
                             UINT8_C( 31), UINT8_C(245), UINT8_C(135), UINT8_C( 65),
                             UINT8_C(214), UINT8_C(158), UINT8_C(167), UINT8_C(  6),
                             UINT8_C(130), UINT8_C( 46), UINT8_C( 33), UINT8_C( 54),
                             UINT8_C( 11), UINT8_C(245), UINT8_C( 84), UINT8_C(244),
                             UINT8_C(176), UINT8_C( 82), UINT8_C(238), UINT8_C(130),
                             UINT8_C(209), UINT8_C(204), UINT8_C(248), UINT8_C(  0),
                             UINT8_C(157), UINT8_C(108), UINT8_C(156), UINT8_C(156),
                             UINT8_C(237), UINT8_C( 39), UINT8_C(113), UINT8_C(164),
                             UINT8_C( 74), UINT8_C( 17), UINT8_C(157), UINT8_C(212),
                             UINT8_C( 94), UINT8_C(225), UINT8_C(154), UINT8_C(241),
                             UINT8_C(234), UINT8_C( 71), UINT8_C( 97), UINT8_C( 49),
                             UINT8_C(235), UINT8_C( 52), UINT8_C(222), UINT8_C( 20),
                             UINT8_C(  5), UINT8_C(231), UINT8_C(123), UINT8_C( 11),
                             UINT8_C( 62), UINT8_C(215), UINT8_C(218), UINT8_C( 46)),
      simde_x_mm512_set_epu8(UINT8_C(124), UINT8_C(178), UINT8_C(245), UINT8_C(131),
                             UINT8_C( 34), UINT8_C(224), UINT8_C( 87), UINT8_C(197),
                             UINT8_C(182), UINT8_C(209), UINT8_C(166), UINT8_C(  5),
                             UINT8_C(234), UINT8_C(185), UINT8_C(158), UINT8_C(144),
                             UINT8_C( 14), UINT8_C(107), UINT8_C(220), UINT8_C( 70),
                             UINT8_C(119), UINT8_C(160), UINT8_C( 31), UINT8_C(191),
                             UINT8_C(230), UINT8_C(198), UINT8_C(152), UINT8_C( 33),
                             UINT8_C( 22), UINT8_C( 95), UINT8_C(212), UINT8_C(255),
                             UINT8_C(113), UINT8_C(254), UINT8_C(  2), UINT8_C(210),
                             UINT8_C(195), UINT8_C(115), UINT8_C(106), UINT8_C(226),
                             UINT8_C( 64), UINT8_C(138), UINT8_C( 67), UINT8_C( 75),
                             UINT8_C( 11), UINT8_C(130), UINT8_C(117), UINT8_C( 51),
                             UINT8_C(106), UINT8_C(104), UINT8_C( 34), UINT8_C(112),
                             UINT8_C( 78), UINT8_C( 85), UINT8_C(189), UINT8_C( 13),
                             UINT8_C(140), UINT8_C( 10), UINT8_C( 60), UINT8_C( 18),
                             UINT8_C(  8), UINT8_C(179), UINT8_C( 57), UINT8_C(196)),
      UINT64_C(16405901789334885521) },
    { simde_x_mm512_set_epu8(UINT8_C(133), UINT8_C( 51), UINT8_C(153), UINT8_C( 32),
                             UINT8_C( 25), UINT8_C(207), UINT8_C(  4), UINT8_C( 40),
                             UINT8_C( 26), UINT8_C( 76), UINT8_C( 93), UINT8_C(  5),
                             UINT8_C(177), UINT8_C(180), UINT8_C(109), UINT8_C(128),
                             UINT8_C(101), UINT8_C( 26), UINT8_C(223), UINT8_C( 68),
                             UINT8_C( 88), UINT8_C(  3), UINT8_C(  1), UINT8_C(148),
                             UINT8_C(  0), UINT8_C(113), UINT8_C( 62), UINT8_C(107),
                             UINT8_C(163), UINT8_C(164), UINT8_C(165), UINT8_C(185),
                             UINT8_C(198), UINT8_C(  6), UINT8_C(199), UINT8_C(198),
                             UINT8_C(207), UINT8_C(139), UINT8_C(  4), UINT8_C( 52),
                             UINT8_C( 26), UINT8_C(160), UINT8_C(162), UINT8_C(224),
                             UINT8_C( 24), UINT8_C(137), UINT8_C(101), UINT8_C( 24),
                             UINT8_C(115), UINT8_C(224), UINT8_C(208), UINT8_C( 54),
                             UINT8_C(102), UINT8_C( 97), UINT8_C(207), UINT8_C( 72),
                             UINT8_C( 87), UINT8_C( 19), UINT8_C(168), UINT8_C(205),
                             UINT8_C( 92), UINT8_C( 79), UINT8_C( 86), UINT8_C(144)),
      simde_x_mm512_set_epu8(UINT8_C( 76), UINT8_C(120), UINT8_C(206), UINT8_C( 35),
                             UINT8_C( 84), UINT8_C(143), UINT8_C(212), UINT8_C( 97),
                             UINT8_C(238), UINT8_C(159), UINT8_C(181), UINT8_C(100),
                             UINT8_C(208), UINT8_C(157), UINT8_C( 32), UINT8_C(247),
                             UINT8_C( 15), UINT8_C(143), UINT8_C(  2), UINT8_C(229),
                             UINT8_C( 17), UINT8_C( 50), UINT8_C(  1), UINT8_C(241),
                             UINT8_C( 90), UINT8_C(132), UINT8_C( 93), UINT8_C( 20),
                             UINT8_C( 46), UINT8_C(183), UINT8_C(154), UINT8_C(255),
                             UINT8_C(118), UINT8_C(135), UINT8_C(  8), UINT8_C(254),
                             UINT8_C(139), UINT8_C(221), UINT8_C(207), UINT8_C(230),
                             UINT8_C(231), UINT8_C( 92), UINT8_C(100), UINT8_C(108),
                             UINT8_C(158), UINT8_C(233), UINT8_C(  8), UINT8_C(234),
                             UINT8_C(189), UINT8_C(236), UINT8_C( 58), UINT8_C(205),
                             UINT8_C(125), UINT8_C(116), UINT8_C(230), UINT8_C(218),
                             UINT8_C(185), UINT8_C(225), UINT8_C( 61), UINT8_C(183),
                             UINT8_C(233), UINT8_C(244), UINT8_C(138), UINT8_C(204)),
      UINT64_C(8933265779370876879) },
    { simde_x_mm512_set_epu8(UINT8_C( 74), UINT8_C(  8), UINT8_C( 71), UINT8_C( 14),
                             UINT8_C(239), UINT8_C(140), UINT8_C( 39), UINT8_C( 68),
                             UINT8_C( 18), UINT8_C(182), UINT8_C(128), UINT8_C(142),
                             UINT8_C( 75), UINT8_C(196), UINT8_C(121), UINT8_C(239),
                             UINT8_C( 67), UINT8_C(139), UINT8_C( 89), UINT8_C( 42),
                             UINT8_C(150), UINT8_C(200), UINT8_C( 22), UINT8_C( 70),
                             UINT8_C( 92), UINT8_C(114), UINT8_C(  0), UINT8_C(232),
                             UINT8_C(121), UINT8_C(124), UINT8_C(100), UINT8_C(100),
                             UINT8_C(142), UINT8_C( 19), UINT8_C(218), UINT8_C(104),
                             UINT8_C(159), UINT8_C(120), UINT8_C(122), UINT8_C( 55),
                             UINT8_C(213), UINT8_C(170), UINT8_C(221), UINT8_C(149),
                             UINT8_C(230), UINT8_C(250), UINT8_C(104), UINT8_C( 36),
                             UINT8_C( 99), UINT8_C( 18), UINT8_C(124), UINT8_C(175),
                             UINT8_C(103), UINT8_C(186), UINT8_C(205), UINT8_C( 43),
                             UINT8_C(141), UINT8_C(148), UINT8_C(140), UINT8_C( 44),
                             UINT8_C(237), UINT8_C(120), UINT8_C(114), UINT8_C(100)),
      simde_x_mm512_set_epu8(UINT8_C(124), UINT8_C(149), UINT8_C( 71), UINT8_C(212),
                             UINT8_C(137), UINT8_C(252), UINT8_C(249), UINT8_C( 42),
                             UINT8_C(167), UINT8_C(191), UINT8_C(236), UINT8_C(252),
                             UINT8_C( 26), UINT8_C( 50), UINT8_C( 98), UINT8_C(162),
                             UINT8_C( 91), UINT8_C(215), UINT8_C( 44), UINT8_C( 48),
                             UINT8_C( 41), UINT8_C(167), UINT8_C( 25), UINT8_C( 39),
                             UINT8_C(183), UINT8_C(181), UINT8_C(250), UINT8_C( 47),
                             UINT8_C(  5), UINT8_C(113), UINT8_C( 48), UINT8_C(195),
                             UINT8_C(111), UINT8_C( 46), UINT8_C( 74), UINT8_C( 84),
                             UINT8_C(145), UINT8_C( 27), UINT8_C(231), UINT8_C(119),
                             UINT8_C( 33), UINT8_C(230), UINT8_C( 22), UINT8_C( 69),
                             UINT8_C( 48), UINT8_C(  7), UINT8_C( 45), UINT8_C(104),
                             UINT8_C( 71), UINT8_C( 82), UINT8_C(107), UINT8_C( 14),
                             UINT8_C( 73), UINT8_C(202), UINT8_C( 78), UINT8_C(132),
                             UINT8_C( 67), UINT8_C( 79), UINT8_C(233), UINT8_C(140),
                             UINT8_C(133), UINT8_C( 99), UINT8_C(202), UINT8_C( 75)),
      UINT64_C(15488110983464961330) },
    { simde_x_mm512_set_epu8(UINT8_C( 78), UINT8_C( 83), UINT8_C(217), UINT8_C( 23),
                             UINT8_C(204), UINT8_C( 27), UINT8_C( 84), UINT8_C( 42),
                             UINT8_C(170), UINT8_C( 43), UINT8_C(212), UINT8_C(144),
                             UINT8_C( 56), UINT8_C(177), UINT8_C(191), UINT8_C(215),
                             UINT8_C( 39), UINT8_C( 30), UINT8_C(  2), UINT8_C(234),
                             UINT8_C( 49), UINT8_C(151), UINT8_C(136), UINT8_C(175),
                             UINT8_C(252), UINT8_C(162), UINT8_C(152), UINT8_C(153),
                             UINT8_C(239), UINT8_C(231), UINT8_C(133), UINT8_C(178),
                             UINT8_C(148), UINT8_C( 35), UINT8_C(158), UINT8_C(129),
                             UINT8_C( 19), UINT8_C(213), UINT8_C( 89), UINT8_C(159),
                             UINT8_C(156), UINT8_C( 31), UINT8_C(228), UINT8_C(142),
                             UINT8_C( 99), UINT8_C( 45), UINT8_C(244), UINT8_C(239),
                             UINT8_C( 20), UINT8_C( 92), UINT8_C(183), UINT8_C( 74),
                             UINT8_C(105), UINT8_C(182), UINT8_C(238), UINT8_C( 27),
                             UINT8_C(161), UINT8_C(150), UINT8_C(240), UINT8_C( 67),
                             UINT8_C( 60), UINT8_C(157), UINT8_C( 26), UINT8_C( 30)),
      simde_x_mm512_set_epu8(UINT8_C(112), UINT8_C(252), UINT8_C(254), UINT8_C(234),
                             UINT8_C(115), UINT8_C(252), UINT8_C(144), UINT8_C(157),
                             UINT8_C(106), UINT8_C(131), UINT8_C(237), UINT8_C( 28),
                             UINT8_C( 29), UINT8_C( 85), UINT8_C(  8), UINT8_C(128),
                             UINT8_C(244), UINT8_C(127), UINT8_C(116), UINT8_C( 60),
                             UINT8_C( 88), UINT8_C(104), UINT8_C(162), UINT8_C(203),
                             UINT8_C(144), UINT8_C( 38), UINT8_C(193), UINT8_C(181),
                             UINT8_C(155), UINT8_C( 59), UINT8_C( 61), UINT8_C(  4),
                             UINT8_C( 63), UINT8_C(240), UINT8_C( 88), UINT8_C( 14),
                             UINT8_C( 73), UINT8_C(125), UINT8_C(224), UINT8_C(117),
                             UINT8_C(118), UINT8_C(109), UINT8_C( 68), UINT8_C( 42),
                             UINT8_C(150), UINT8_C( 79), UINT8_C(167), UINT8_C( 25),
                             UINT8_C( 58), UINT8_C(250), UINT8_C(130), UINT8_C(160),
                             UINT8_C( 75), UINT8_C(145), UINT8_C(152), UINT8_C(149),
                             UINT8_C(134), UINT8_C(252), UINT8_C( 13), UINT8_C(165),
                             UINT8_C(218), UINT8_C( 88), UINT8_C( 59), UINT8_C(228)),
      UINT64_C(17825505917769929051) },
    { simde_x_mm512_set_epu8(UINT8_C( 80), UINT8_C(151), UINT8_C(216), UINT8_C(130),
                             UINT8_C(149), UINT8_C(124), UINT8_C( 37), UINT8_C( 84),
                             UINT8_C(103), UINT8_C( 99), UINT8_C(115), UINT8_C(151),
                             UINT8_C(233), UINT8_C(197), UINT8_C(132), UINT8_C(158),
                             UINT8_C( 23), UINT8_C( 54), UINT8_C(164), UINT8_C(107),
                             UINT8_C(233), UINT8_C(122), UINT8_C( 62), UINT8_C( 22),
                             UINT8_C(179), UINT8_C( 56), UINT8_C(117), UINT8_C(196),
                             UINT8_C(102), UINT8_C( 82), UINT8_C(  6), UINT8_C(242),
                             UINT8_C(100), UINT8_C(238), UINT8_C(103), UINT8_C( 83),
                             UINT8_C(139), UINT8_C(142), UINT8_C(174), UINT8_C(130),
                             UINT8_C(118), UINT8_C( 29), UINT8_C(246), UINT8_C(127),
                             UINT8_C(235), UINT8_C( 33), UINT8_C(253), UINT8_C(147),
                             UINT8_C( 41), UINT8_C( 14), UINT8_C(193), UINT8_C(126),
                             UINT8_C(220), UINT8_C(114), UINT8_C( 22), UINT8_C( 77),
                             UINT8_C( 40), UINT8_C(150), UINT8_C(218), UINT8_C(187),
                             UINT8_C(209), UINT8_C(123), UINT8_C( 46), UINT8_C(156)),
      simde_x_mm512_set_epu8(UINT8_C(176), UINT8_C( 45), UINT8_C(210), UINT8_C(149),
                             UINT8_C(149), UINT8_C(249), UINT8_C( 13), UINT8_C(137),
                             UINT8_C(118), UINT8_C(232), UINT8_C(127), UINT8_C( 30),
                             UINT8_C(175), UINT8_C(210), UINT8_C(248), UINT8_C(191),
                             UINT8_C( 96), UINT8_C( 79), UINT8_C(110), UINT8_C(154),
                             UINT8_C(119), UINT8_C(253), UINT8_C(133), UINT8_C( 16),
                             UINT8_C(243), UINT8_C(  4), UINT8_C(  4), UINT8_C(112),
                             UINT8_C(245), UINT8_C(173), UINT8_C( 10), UINT8_C(196),
                             UINT8_C(208), UINT8_C( 87), UINT8_C( 86), UINT8_C(157),
                             UINT8_C(215), UINT8_C( 65), UINT8_C(145), UINT8_C(212),
                             UINT8_C( 76), UINT8_C(163), UINT8_C( 24), UINT8_C(147),
                             UINT8_C( 61), UINT8_C(161), UINT8_C( 63), UINT8_C( 34),
                             UINT8_C(236), UINT8_C( 70), UINT8_C(243), UINT8_C(236),
                             UINT8_C( 49), UINT8_C( 99), UINT8_C(157), UINT8_C( 87),
                             UINT8_C(  4), UINT8_C( 86), UINT8_C(157), UINT8_C( 37),
                             UINT8_C( 44), UINT8_C( 59), UINT8_C(149), UINT8_C( 14)),
      UINT64_C(10801838139217605378) }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])); i++) {
    simde__mmask64 r = simde_mm512_cmplt_epu8_mask(test_vec[i].a, test_vec[i].b);
    simde_assert_mmask64(r, ==, test_vec[i].r);
  }

  return 0;
}

static int
test_simde_mm512_cvtepi16_epi8(SIMDE_MUNIT_TEST_ARGS) {
  const struct {
    simde__m512i a;
    simde__m256i r;
  } test_vec[8] = {
    { simde_mm512_set_epi16(INT16_C( 14423), INT16_C(  3775), INT16_C( 16156), INT16_C( 17811),
                            INT16_C(-14881), INT16_C(-30283), INT16_C( 27295), INT16_C(-12290),
                            INT16_C( 12394), INT16_C( 32764), INT16_C(  8681), INT16_C( 21255),
                            INT16_C(-21785), INT16_C(-24065), INT16_C(-28005), INT16_C( 15206),
                            INT16_C(  6131), INT16_C(-29323), INT16_C( -9530), INT16_C( -6655),
                            INT16_C( 14785), INT16_C( -9158), INT16_C(  7009), INT16_C(  4834),
                            INT16_C(-15579), INT16_C(  5296), INT16_C( 20054), INT16_C( 12832),
                            INT16_C( 15724), INT16_C(  5918), INT16_C( 25398), INT16_C( 14084)),
      simde_mm256_set_epi8(INT8_C(  87), INT8_C( -65), INT8_C(  28), INT8_C(-109),
                           INT8_C( -33), INT8_C( -75), INT8_C( -97), INT8_C(  -2),
                           INT8_C( 106), INT8_C(  -4), INT8_C( -23), INT8_C(   7),
                           INT8_C( -25), INT8_C(  -1), INT8_C(-101), INT8_C( 102),
                           INT8_C( -13), INT8_C( 117), INT8_C( -58), INT8_C(   1),
                           INT8_C( -63), INT8_C(  58), INT8_C(  97), INT8_C( -30),
                           INT8_C(  37), INT8_C( -80), INT8_C(  86), INT8_C(  32),
                           INT8_C( 108), INT8_C(  30), INT8_C(  54), INT8_C(   4)) },
    { simde_mm512_set_epi16(INT16_C(  8455), INT16_C(  1140), INT16_C(-23383), INT16_C( 22825),
                            INT16_C(-21438), INT16_C(  8713), INT16_C(-25940), INT16_C(-31180),
                            INT16_C(-13214), INT16_C( 10200), INT16_C(-21253), INT16_C(  2612),
                            INT16_C(-27891), INT16_C( 14031), INT16_C( -9014), INT16_C( 10287),
                            INT16_C(-11660), INT16_C( 26858), INT16_C(-19518), INT16_C(  2472),
                            INT16_C( 27637), INT16_C( 14857), INT16_C( 30034), INT16_C(-24153),
                            INT16_C( 31935), INT16_C( -6397), INT16_C( -2502), INT16_C( 31062),
                            INT16_C( 30236), INT16_C(  5156), INT16_C( 18439), INT16_C(-13074)),
      simde_mm256_set_epi8(INT8_C(   7), INT8_C( 116), INT8_C( -87), INT8_C(  41),
                           INT8_C(  66), INT8_C(   9), INT8_C( -84), INT8_C(  52),
                           INT8_C(  98), INT8_C( -40), INT8_C(  -5), INT8_C(  52),
                           INT8_C(  13), INT8_C( -49), INT8_C( -54), INT8_C(  47),
                           INT8_C( 116), INT8_C( -22), INT8_C( -62), INT8_C( -88),
                           INT8_C( -11), INT8_C(   9), INT8_C(  82), INT8_C( -89),
                           INT8_C( -65), INT8_C(   3), INT8_C(  58), INT8_C(  86),
                           INT8_C(  28), INT8_C(  36), INT8_C(   7), INT8_C( -18)) },
    { simde_mm512_set_epi16(INT16_C( 18175), INT16_C( -3760), INT16_C( 10318), INT16_C(-31849),
                            INT16_C(-32429), INT16_C(-26500), INT16_C( 24084), INT16_C(-23946),
                            INT16_C(  2525), INT16_C(  2478), INT16_C(-15141), INT16_C(-27410),
                            INT16_C( 30961), INT16_C(-31554), INT16_C( -9533), INT16_C(-20012),
                            INT16_C(-21820), INT16_C( 11767), INT16_C(-17849), INT16_C( 24518),
                            INT16_C(-22206), INT16_C(-24996), INT16_C(-19566), INT16_C( 17826),
                            INT16_C( 25765), INT16_C( 29123), INT16_C( 28065), INT16_C(  1432),
                            INT16_C(-24949), INT16_C( 30580), INT16_C( 20499), INT16_C(-29164)),
      simde_mm256_set_epi8(INT8_C(  -1), INT8_C(  80), INT8_C(  78), INT8_C(-105),
                           INT8_C(  83), INT8_C( 124), INT8_C(  20), INT8_C( 118),
                           INT8_C( -35), INT8_C( -82), INT8_C( -37), INT8_C( -18),
                           INT8_C( -15), INT8_C( -66), INT8_C( -61), INT8_C( -44),
                           INT8_C( -60), INT8_C(  -9), INT8_C(  71), INT8_C( -58),
                           INT8_C(  66), INT8_C(  92), INT8_C(-110), INT8_C( -94),
                           INT8_C( -91), INT8_C( -61), INT8_C( -95), INT8_C(-104),
                           INT8_C(-117), INT8_C( 116), INT8_C(  19), INT8_C(  20)) },
    { simde_mm512_set_epi16(INT16_C( 10816), INT16_C( 16713), INT16_C( 29707), INT16_C( 15186),
                            INT16_C( 31860), INT16_C(-28520), INT16_C( 18947), INT16_C(-27460),
                            INT16_C( 10883), INT16_C(   310), INT16_C(  8277), INT16_C(-28768),
                            INT16_C( -4553), INT16_C( 23273), INT16_C(-27696), INT16_C(-20678),
                            INT16_C( 13089), INT16_C( -6620), INT16_C( 31575), INT16_C(-20169),
                            INT16_C( 14440), INT16_C( -9264), INT16_C(-26919), INT16_C(-25720),
                            INT16_C(-18371), INT16_C( 25765), INT16_C(-13162), INT16_C(-16808),
                            INT16_C(  5695), INT16_C(-25080), INT16_C( 19142), INT16_C(  3825)),
      simde_mm256_set_epi8(INT8_C(  64), INT8_C(  73), INT8_C(  11), INT8_C(  82),
                           INT8_C( 116), INT8_C(-104), INT8_C(   3), INT8_C( -68),
                           INT8_C(-125), INT8_C(  54), INT8_C(  85), INT8_C( -96),
                           INT8_C(  55), INT8_C( -23), INT8_C( -48), INT8_C(  58),
                           INT8_C(  33), INT8_C(  36), INT8_C(  87), INT8_C(  55),
                           INT8_C( 104), INT8_C( -48), INT8_C( -39), INT8_C(-120),
                           INT8_C(  61), INT8_C( -91), INT8_C(-106), INT8_C(  88),
                           INT8_C(  63), INT8_C(   8), INT8_C( -58), INT8_C( -15)) },
    { simde_mm512_set_epi16(INT16_C(  5079), INT16_C(-24746), INT16_C( 23487), INT16_C(-22087),
                            INT16_C( -8346), INT16_C( 29848), INT16_C( 14241), INT16_C( 18254),
                            INT16_C( -3124), INT16_C(-16186), INT16_C(-13364), INT16_C( 10652),
                            INT16_C( 31028), INT16_C( 21346), INT16_C(  1443), INT16_C(-20222),
                            INT16_C(-17028), INT16_C(-21899), INT16_C( 18933), INT16_C(  6935),
                            INT16_C( 24619), INT16_C(  1737), INT16_C( 12596), INT16_C( 31606),
                            INT16_C(-32691), INT16_C( 11392), INT16_C( 32126), INT16_C(-32712),
                            INT16_C( 20927), INT16_C(-27859), INT16_C( 22640), INT16_C(  8969)),
      simde_mm256_set_epi8(INT8_C( -41), INT8_C(  86), INT8_C( -65), INT8_C( -71),
                           INT8_C( 102), INT8_C(-104), INT8_C( -95), INT8_C(  78),
                           INT8_C( -52), INT8_C( -58), INT8_C( -52), INT8_C(-100),
                           INT8_C(  52), INT8_C(  98), INT8_C( -93), INT8_C(   2),
                           INT8_C( 124), INT8_C( 117), INT8_C( -11), INT8_C(  23),
                           INT8_C(  43), INT8_C( -55), INT8_C(  52), INT8_C( 118),
                           INT8_C(  77), INT8_C(-128), INT8_C( 126), INT8_C(  56),
                           INT8_C( -65), INT8_C(  45), INT8_C( 112), INT8_C(   9)) },
    { simde_mm512_set_epi16(INT16_C(  6901), INT16_C(-23435), INT16_C(-26040), INT16_C(-11295),
                            INT16_C(   623), INT16_C(-23058), INT16_C( 17549), INT16_C(-23291),
                            INT16_C( 17215), INT16_C( -4892), INT16_C(  -849), INT16_C( 21086),
                            INT16_C(-13056), INT16_C( 19549), INT16_C( 16492), INT16_C(-22767),
                            INT16_C(-24079), INT16_C(  6429), INT16_C( 15302), INT16_C( -9175),
                            INT16_C( 17671), INT16_C(-29856), INT16_C(-12718), INT16_C(-22914),
                            INT16_C(-19613), INT16_C( 14088), INT16_C(-10443), INT16_C( 31757),
                            INT16_C( 24994), INT16_C( 24174), INT16_C( -9596), INT16_C(-22481)),
      simde_mm256_set_epi8(INT8_C( -11), INT8_C( 117), INT8_C(  72), INT8_C( -31),
                           INT8_C( 111), INT8_C( -18), INT8_C(-115), INT8_C(   5),
                           INT8_C(  63), INT8_C( -28), INT8_C( -81), INT8_C(  94),
                           INT8_C(   0), INT8_C(  93), INT8_C( 108), INT8_C(  17),
                           INT8_C( -15), INT8_C(  29), INT8_C( -58), INT8_C(  41),
                           INT8_C(   7), INT8_C(  96), INT8_C(  82), INT8_C( 126),
                           INT8_C(  99), INT8_C(   8), INT8_C(  53), INT8_C(  13),
                           INT8_C( -94), INT8_C( 110), INT8_C(-124), INT8_C(  47)) },
    { simde_mm512_set_epi16(INT16_C( 15520), INT16_C( 15679), INT16_C(  8541), INT16_C(-20376),
                            INT16_C(  8861), INT16_C( 12926), INT16_C( 25712), INT16_C( -8433),
                            INT16_C( -7066), INT16_C(-23691), INT16_C(-20251), INT16_C( 18056),
                            INT16_C(  5498), INT16_C(-18751), INT16_C(-26321), INT16_C(  7918),
                            INT16_C(  1647), INT16_C( 21774), INT16_C(  5430), INT16_C(-19512),
                            INT16_C(-14894), INT16_C( 12466), INT16_C( -9612), INT16_C(-23130),
                            INT16_C( 18357), INT16_C( 32349), INT16_C(-25760), INT16_C( -6559),
                            INT16_C(-24198), INT16_C( 13614), INT16_C( 13473), INT16_C(-25578)),
      simde_mm256_set_epi8(INT8_C( -96), INT8_C(  63), INT8_C(  93), INT8_C( 104),
                           INT8_C( -99), INT8_C( 126), INT8_C( 112), INT8_C(  15),
                           INT8_C( 102), INT8_C( 117), INT8_C( -27), INT8_C(-120),
                           INT8_C( 122), INT8_C( -63), INT8_C(  47), INT8_C( -18),
                           INT8_C( 111), INT8_C(  14), INT8_C(  54), INT8_C( -56),
                           INT8_C( -46), INT8_C( -78), INT8_C( 116), INT8_C( -90),
                           INT8_C( -75), INT8_C(  93), INT8_C(  96), INT8_C(  97),
                           INT8_C( 122), INT8_C(  46), INT8_C( -95), INT8_C(  22)) },
    { simde_mm512_set_epi16(INT16_C(-13944), INT16_C( 30422), INT16_C( 10523), INT16_C( 28986),
                            INT16_C(-23789), INT16_C(-20754), INT16_C( 29282), INT16_C(-10845),
                            INT16_C( 10721), INT16_C(  2777), INT16_C(-18838), INT16_C(  8324),
                            INT16_C( 19192), INT16_C(   114), INT16_C( -9073), INT16_C(  2615),
                            INT16_C( 21008), INT16_C( 12652), INT16_C(-14859), INT16_C(  5734),
                            INT16_C( -5598), INT16_C(-10707), INT16_C(  2170), INT16_C( 23903),
                            INT16_C( 29988), INT16_C( 24405), INT16_C(  5383), INT16_C(-29994),
                            INT16_C(  7143), INT16_C( 22270), INT16_C( -1480), INT16_C( 15491)),
      simde_mm256_set_epi8(INT8_C(-120), INT8_C( -42), INT8_C(  27), INT8_C(  58),
                           INT8_C(  19), INT8_C( -18), INT8_C(  98), INT8_C( -93),
                           INT8_C( -31), INT8_C( -39), INT8_C( 106), INT8_C(-124),
                           INT8_C(  -8), INT8_C( 114), INT8_C(-113), INT8_C(  55),
                           INT8_C(  16), INT8_C( 108), INT8_C( -11), INT8_C( 102),
                           INT8_C(  34), INT8_C(  45), INT8_C( 122), INT8_C(  95),
                           INT8_C(  36), INT8_C(  85), INT8_C(   7), INT8_C( -42),
                           INT8_C( -25), INT8_C(  -2), INT8_C(  56), INT8_C(-125)) }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])); i++) {
    simde__m256i r = simde_mm512_cvtepi16_epi8(test_vec[i].a);
    simde_assert_m256i_i8(r, ==, test_vec[i].r);
  }

  return 0;
}

static int
test_simde_mm512_mask_cvtepi16_epi8(SIMDE_MUNIT_TEST_ARGS) {
  const struct {
    simde__m256i src;
    simde__mmask32 k;
    simde__m512i a;
    simde__m256i r;
  } test_vec[8] = {
    { simde_mm256_set_epi8(INT8_C(-112), INT8_C(  50), INT8_C( -90), INT8_C( -47),
                           INT8_C(  24), INT8_C( -14), INT8_C( -76), INT8_C(  -4),
                           INT8_C(-104), INT8_C( 115), INT8_C( -75), INT8_C(  98),
                           INT8_C( -58), INT8_C( -14), INT8_C(  98), INT8_C(  29),
                           INT8_C( -34), INT8_C(  91), INT8_C(  -9), INT8_C( -32),
                           INT8_C( 105), INT8_C( -54), INT8_C(  11), INT8_C(  76),
                           INT8_C(  83), INT8_C(   3), INT8_C(  48), INT8_C(   2),
                           INT8_C(  92), INT8_C( -54), INT8_C(  99), INT8_C(  95)),
      UINT32_C(     36055),
      simde_mm512_set_epi16(INT16_C( 29253), INT16_C(-14914), INT16_C(  8284), INT16_C( 18521),
                            INT16_C( 32034), INT16_C( 27278), INT16_C( -3730), INT16_C( -7695),
                            INT16_C(  8989), INT16_C(-29300), INT16_C(-14890), INT16_C( 11419),
                            INT16_C( -1355), INT16_C( 25284), INT16_C(-28026), INT16_C(  1548),
                            INT16_C( 26140), INT16_C( -8634), INT16_C( 26242), INT16_C(  1035),
                            INT16_C(-29578), INT16_C( -2997), INT16_C( 22546), INT16_C(-28782),
                            INT16_C(-11973), INT16_C( 12912), INT16_C(-22923), INT16_C(-12898),
                            INT16_C(  4984), INT16_C(   989), INT16_C(  2511), INT16_C( 26483)),
      simde_mm256_set_epi8(INT8_C(-112), INT8_C(  50), INT8_C( -90), INT8_C( -47),
                           INT8_C(  24), INT8_C( -14), INT8_C( -76), INT8_C(  -4),
                           INT8_C(-104), INT8_C( 115), INT8_C( -75), INT8_C(  98),
                           INT8_C( -58), INT8_C( -14), INT8_C(  98), INT8_C(  29),
                           INT8_C(  28), INT8_C(  91), INT8_C(  -9), INT8_C( -32),
                           INT8_C( 118), INT8_C(  75), INT8_C(  11), INT8_C(  76),
                           INT8_C(  59), INT8_C( 112), INT8_C(  48), INT8_C( -98),
                           INT8_C(  92), INT8_C( -35), INT8_C( -49), INT8_C( 115)) },
    { simde_mm256_set_epi8(INT8_C( -93), INT8_C( -75), INT8_C( 109), INT8_C(  43),
                           INT8_C( -79), INT8_C( -91), INT8_C( -13), INT8_C( 103),
                           INT8_C(  -6), INT8_C( -39), INT8_C(   3), INT8_C(-115),
                           INT8_C(  30), INT8_C( -62), INT8_C(  30), INT8_C( 115),
                           INT8_C( -28), INT8_C( -92), INT8_C( 110), INT8_C( -10),
                           INT8_C(  20), INT8_C( -82), INT8_C(  59), INT8_C(  62),
                           INT8_C(  57), INT8_C(  97), INT8_C(  29), INT8_C(  -4),
                           INT8_C( -48), INT8_C(   1), INT8_C(  47), INT8_C(  43)),
      UINT32_C(     13848),
      simde_mm512_set_epi16(INT16_C( 19920), INT16_C( 28417), INT16_C(-26944), INT16_C( -1327),
                            INT16_C(-18966), INT16_C(-19374), INT16_C(  9639), INT16_C(-25572),
                            INT16_C(-16315), INT16_C( 16363), INT16_C( -4686), INT16_C(-14474),
                            INT16_C( 26743), INT16_C( 20737), INT16_C(-16355), INT16_C( 24251),
                            INT16_C(-20830), INT16_C( 19809), INT16_C(-32085), INT16_C(-29115),
                            INT16_C(-21999), INT16_C( 14843), INT16_C( 13075), INT16_C(-28846),
                            INT16_C(-12894), INT16_C( 31357), INT16_C( 16553), INT16_C(-16546),
                            INT16_C(-16544), INT16_C( 30528), INT16_C( -9494), INT16_C(  8241)),
      simde_mm256_set_epi8(INT8_C( -93), INT8_C( -75), INT8_C( 109), INT8_C(  43),
                           INT8_C( -79), INT8_C( -91), INT8_C( -13), INT8_C( 103),
                           INT8_C(  -6), INT8_C( -39), INT8_C(   3), INT8_C(-115),
                           INT8_C(  30), INT8_C( -62), INT8_C(  30), INT8_C( 115),
                           INT8_C( -28), INT8_C( -92), INT8_C( -85), INT8_C(  69),
                           INT8_C(  20), INT8_C(  -5), INT8_C(  19), INT8_C(  62),
                           INT8_C(  57), INT8_C(  97), INT8_C(  29), INT8_C(  94),
                           INT8_C(  96), INT8_C(   1), INT8_C(  47), INT8_C(  43)) },
    { simde_mm256_set_epi8(INT8_C(  57), INT8_C( 119), INT8_C(   6), INT8_C( -62),
                           INT8_C( -27), INT8_C( -22), INT8_C( -69), INT8_C( -61),
                           INT8_C(   8), INT8_C(-101), INT8_C( -24), INT8_C(  69),
                           INT8_C(-111), INT8_C(  66), INT8_C( -48), INT8_C(-122),
                           INT8_C( -19), INT8_C( -25), INT8_C( -88), INT8_C(  96),
                           INT8_C( -81), INT8_C(  28), INT8_C( -73), INT8_C(-105),
                           INT8_C( 109), INT8_C( -84), INT8_C(  26), INT8_C( 108),
                           INT8_C(  16), INT8_C(  69), INT8_C( -67), INT8_C(-122)),
      UINT32_C(     52950),
      simde_mm512_set_epi16(INT16_C(-28100), INT16_C(  2824), INT16_C(-32113), INT16_C(-30059),
                            INT16_C(-19864), INT16_C(-29923), INT16_C( 19573), INT16_C(-11183),
                            INT16_C(-18980), INT16_C( 26281), INT16_C( -7946), INT16_C( 14491),
                            INT16_C( 28715), INT16_C( 26138), INT16_C( 16023), INT16_C( 24398),
                            INT16_C( 20578), INT16_C( -1642), INT16_C( 24774), INT16_C( 26937),
                            INT16_C(-19881), INT16_C(-20408), INT16_C( 26365), INT16_C( -2980),
                            INT16_C( -4479), INT16_C(-10298), INT16_C( 13784), INT16_C(-25535),
                            INT16_C(-26583), INT16_C(-31618), INT16_C(  -202), INT16_C( 28295)),
      simde_mm256_set_epi8(INT8_C(  57), INT8_C( 119), INT8_C(   6), INT8_C( -62),
                           INT8_C( -27), INT8_C( -22), INT8_C( -69), INT8_C( -61),
                           INT8_C(   8), INT8_C(-101), INT8_C( -24), INT8_C(  69),
                           INT8_C(-111), INT8_C(  66), INT8_C( -48), INT8_C(-122),
                           INT8_C(  98), INT8_C(-106), INT8_C( -88), INT8_C(  96),
                           INT8_C(  87), INT8_C(  72), INT8_C(  -3), INT8_C(-105),
                           INT8_C(-127), INT8_C( -58), INT8_C(  26), INT8_C(  65),
                           INT8_C(  16), INT8_C( 126), INT8_C(  54), INT8_C(-122)) },
    { simde_mm256_set_epi8(INT8_C(  89), INT8_C(  16), INT8_C(  86), INT8_C( 124),
                           INT8_C(-106), INT8_C(  54), INT8_C(  30), INT8_C( -60),
                           INT8_C(  41), INT8_C(  45), INT8_C(-103), INT8_C( -75),
                           INT8_C( -46), INT8_C(  -2), INT8_C( 119), INT8_C(  28),
                           INT8_C(  69), INT8_C( -84), INT8_C(  78), INT8_C( -36),
                           INT8_C(  42), INT8_C( -59), INT8_C(  42), INT8_C(   5),
                           INT8_C( -74), INT8_C( -70), INT8_C( 107), INT8_C(  22),
                           INT8_C(  91), INT8_C(  10), INT8_C( -44), INT8_C(  28)),
      UINT32_C(      4183),
      simde_mm512_set_epi16(INT16_C(  8531), INT16_C(  2537), INT16_C(  7090), INT16_C( 32184),
                            INT16_C(   918), INT16_C( -4406), INT16_C( -1230), INT16_C(-20248),
                            INT16_C( 28454), INT16_C( -8033), INT16_C( 29491), INT16_C(  9038),
                            INT16_C( 31537), INT16_C(-32476), INT16_C( 15213), INT16_C(  2771),
                            INT16_C(  9158), INT16_C( 15700), INT16_C( 24392), INT16_C(-14500),
                            INT16_C( 20701), INT16_C( -9424), INT16_C( -5862), INT16_C(  8150),
                            INT16_C(-14293), INT16_C( 29409), INT16_C(-21051), INT16_C(-16951),
                            INT16_C(-32102), INT16_C(-16442), INT16_C(  4517), INT16_C(-32738)),
      simde_mm256_set_epi8(INT8_C(  89), INT8_C(  16), INT8_C(  86), INT8_C( 124),
                           INT8_C(-106), INT8_C(  54), INT8_C(  30), INT8_C( -60),
                           INT8_C(  41), INT8_C(  45), INT8_C(-103), INT8_C( -75),
                           INT8_C( -46), INT8_C(  -2), INT8_C( 119), INT8_C(  28),
                           INT8_C(  69), INT8_C( -84), INT8_C(  78), INT8_C(  92),
                           INT8_C(  42), INT8_C( -59), INT8_C(  42), INT8_C(   5),
                           INT8_C( -74), INT8_C( -31), INT8_C( 107), INT8_C( -55),
                           INT8_C(  91), INT8_C( -58), INT8_C( -91), INT8_C(  30)) },
    { simde_mm256_set_epi8(INT8_C(  66), INT8_C( -53), INT8_C( -22), INT8_C(-109),
                           INT8_C(-122), INT8_C( -34), INT8_C(  49), INT8_C( -51),
                           INT8_C(  45), INT8_C(  96), INT8_C(  21), INT8_C(   9),
                           INT8_C(-107), INT8_C(  88), INT8_C(  41), INT8_C(  63),
                           INT8_C( -15), INT8_C(  66), INT8_C( -60), INT8_C(  80),
                           INT8_C( -27), INT8_C(   9), INT8_C(  30), INT8_C( -73),
                           INT8_C( -55), INT8_C( -22), INT8_C(-122), INT8_C(  86),
                           INT8_C( -35), INT8_C( -54), INT8_C(  95), INT8_C( -17)),
      UINT32_C(     34749),
      simde_mm512_set_epi16(INT16_C(  6349), INT16_C( -1940), INT16_C( 12009), INT16_C( 26974),
                            INT16_C( 15374), INT16_C(  6913), INT16_C(-19915), INT16_C(-14530),
                            INT16_C(-31337), INT16_C( 22983), INT16_C(  6281), INT16_C(  -506),
                            INT16_C(-24168), INT16_C(-22228), INT16_C(-32449), INT16_C(-30658),
                            INT16_C(-16400), INT16_C( -7823), INT16_C( -6600), INT16_C( -5428),
                            INT16_C( 10840), INT16_C(-16201), INT16_C(-15359), INT16_C(-30650),
                            INT16_C(  6966), INT16_C(-30042), INT16_C( 32539), INT16_C(-32588),
                            INT16_C(-23367), INT16_C(-13235), INT16_C(-19835), INT16_C( 15017)),
      simde_mm256_set_epi8(INT8_C(  66), INT8_C( -53), INT8_C( -22), INT8_C(-109),
                           INT8_C(-122), INT8_C( -34), INT8_C(  49), INT8_C( -51),
                           INT8_C(  45), INT8_C(  96), INT8_C(  21), INT8_C(   9),
                           INT8_C(-107), INT8_C(  88), INT8_C(  41), INT8_C(  63),
                           INT8_C( -16), INT8_C(  66), INT8_C( -60), INT8_C(  80),
                           INT8_C( -27), INT8_C( -73), INT8_C(   1), INT8_C(  70),
                           INT8_C(  54), INT8_C( -22), INT8_C(  27), INT8_C( -76),
                           INT8_C( -71), INT8_C(  77), INT8_C(  95), INT8_C( -87)) },
    { simde_mm256_set_epi8(INT8_C(-124), INT8_C(  59), INT8_C( -81), INT8_C(  66),
                           INT8_C( -65), INT8_C( -38), INT8_C( -36), INT8_C(   5),
                           INT8_C(  15), INT8_C(  28), INT8_C( -18), INT8_C( -54),
                           INT8_C(  82), INT8_C(  30), INT8_C(-110), INT8_C(-114),
                           INT8_C(   3), INT8_C(  71), INT8_C(  64), INT8_C(  21),
                           INT8_C( 115), INT8_C( 123), INT8_C( -22), INT8_C(-111),
                           INT8_C( -10), INT8_C(  18), INT8_C(   3), INT8_C(  -8),
                           INT8_C( -97), INT8_C(  26), INT8_C(  72), INT8_C( -94)),
      UINT32_C(     31044),
      simde_mm512_set_epi16(INT16_C(-26750), INT16_C(-23902), INT16_C( 29963), INT16_C(  2819),
                            INT16_C(  9258), INT16_C( 16800), INT16_C(-21230), INT16_C( -2332),
                            INT16_C(-12889), INT16_C( 23107), INT16_C( 17922), INT16_C(  3552),
                            INT16_C( 16956), INT16_C(-21244), INT16_C( -9865), INT16_C( 24672),
                            INT16_C(-32513), INT16_C( -3970), INT16_C( 14993), INT16_C(-21626),
                            INT16_C(-29335), INT16_C( -2219), INT16_C(  4209), INT16_C( 11969),
                            INT16_C( -6560), INT16_C(-26729), INT16_C(  7233), INT16_C( 27170),
                            INT16_C(  5881), INT16_C( -9473), INT16_C(-30967), INT16_C(  3275)),
      simde_mm256_set_epi8(INT8_C(-124), INT8_C(  59), INT8_C( -81), INT8_C(  66),
                           INT8_C( -65), INT8_C( -38), INT8_C( -36), INT8_C(   5),
                           INT8_C(  15), INT8_C(  28), INT8_C( -18), INT8_C( -54),
                           INT8_C(  82), INT8_C(  30), INT8_C(-110), INT8_C(-114),
                           INT8_C(   3), INT8_C( 126), INT8_C(-111), INT8_C(-122),
                           INT8_C( 105), INT8_C( 123), INT8_C( -22), INT8_C( -63),
                           INT8_C( -10), INT8_C(-105), INT8_C(   3), INT8_C(  -8),
                           INT8_C( -97), INT8_C(  -1), INT8_C(  72), INT8_C( -94)) },
    { simde_mm256_set_epi8(INT8_C(  76), INT8_C( -68), INT8_C(   3), INT8_C( 100),
                           INT8_C(  64), INT8_C( -71), INT8_C( -39), INT8_C(  30),
                           INT8_C( 110), INT8_C(  44), INT8_C(  96), INT8_C(  10),
                           INT8_C(  66), INT8_C(  40), INT8_C(  31), INT8_C( -85),
                           INT8_C( 120), INT8_C(  70), INT8_C( -37), INT8_C( -25),
                           INT8_C(  51), INT8_C( -19), INT8_C( 124), INT8_C( -52),
                           INT8_C(  69), INT8_C( 107), INT8_C(  96), INT8_C( 106),
                           INT8_C(-126), INT8_C(  61), INT8_C( -71), INT8_C(   9)),
      UINT32_C(     63997),
      simde_mm512_set_epi16(INT16_C( 25271), INT16_C( 20153), INT16_C(-23804), INT16_C(-24091),
                            INT16_C(  6064), INT16_C(  3189), INT16_C( -2682), INT16_C(  5283),
                            INT16_C( 14900), INT16_C(   731), INT16_C(-14623), INT16_C( 14729),
                            INT16_C( -3836), INT16_C( 26379), INT16_C( 13131), INT16_C( 14975),
                            INT16_C( 19045), INT16_C( 14845), INT16_C(-21672), INT16_C(  4155),
                            INT16_C(  9032), INT16_C(-30375), INT16_C( 14167), INT16_C( 25860),
                            INT16_C( -6683), INT16_C(-21473), INT16_C( -6588), INT16_C( 22432),
                            INT16_C( -4408), INT16_C( -2180), INT16_C( 26333), INT16_C( 18369)),
      simde_mm256_set_epi8(INT8_C(  76), INT8_C( -68), INT8_C(   3), INT8_C( 100),
                           INT8_C(  64), INT8_C( -71), INT8_C( -39), INT8_C(  30),
                           INT8_C( 110), INT8_C(  44), INT8_C(  96), INT8_C(  10),
                           INT8_C(  66), INT8_C(  40), INT8_C(  31), INT8_C( -85),
                           INT8_C( 101), INT8_C(  -3), INT8_C(  88), INT8_C(  59),
                           INT8_C(  72), INT8_C( -19), INT8_C( 124), INT8_C(   4),
                           INT8_C( -27), INT8_C(  31), INT8_C(  68), INT8_C( -96),
                           INT8_C( -56), INT8_C( 124), INT8_C( -71), INT8_C( -63)) },
    { simde_mm256_set_epi8(INT8_C(  40), INT8_C( -41), INT8_C(-126), INT8_C(   8),
                           INT8_C(-115), INT8_C( 108), INT8_C(  31), INT8_C(  41),
                           INT8_C( -21), INT8_C( -60), INT8_C(  76), INT8_C(  74),
                           INT8_C(  86), INT8_C(  39), INT8_C(  41), INT8_C( -61),
                           INT8_C( 120), INT8_C(  -6), INT8_C(-117), INT8_C(  43),
                           INT8_C(  64), INT8_C( -40), INT8_C( -63), INT8_C(  39),
                           INT8_C(  82), INT8_C(  -3), INT8_C(  -8), INT8_C(-102),
                           INT8_C(  21), INT8_C(-109), INT8_C(  -6), INT8_C( 102)),
      UINT32_C(     16734),
      simde_mm512_set_epi16(INT16_C(-25905), INT16_C( 19727), INT16_C( 28735), INT16_C(  3852),
                            INT16_C(-23084), INT16_C( -6530), INT16_C( -1505), INT16_C(  9601),
                            INT16_C( -7362), INT16_C(  8505), INT16_C(-26382), INT16_C( 25139),
                            INT16_C(  4198), INT16_C( -1011), INT16_C( -5955), INT16_C( 29084),
                            INT16_C( 25996), INT16_C( 30463), INT16_C( -4775), INT16_C( 11032),
                            INT16_C(-28689), INT16_C(-14740), INT16_C( -1416), INT16_C(  8406),
                            INT16_C(-23209), INT16_C( 25079), INT16_C( 23521), INT16_C( 23507),
                            INT16_C( 15383), INT16_C(-27993), INT16_C(  2371), INT16_C(-19992)),
      simde_mm256_set_epi8(INT8_C(  40), INT8_C( -41), INT8_C(-126), INT8_C(   8),
                           INT8_C(-115), INT8_C( 108), INT8_C(  31), INT8_C(  41),
                           INT8_C( -21), INT8_C( -60), INT8_C(  76), INT8_C(  74),
                           INT8_C(  86), INT8_C(  39), INT8_C(  41), INT8_C( -61),
                           INT8_C( 120), INT8_C(  -1), INT8_C(-117), INT8_C(  43),
                           INT8_C(  64), INT8_C( -40), INT8_C( -63), INT8_C( -42),
                           INT8_C(  82), INT8_C(  -9), INT8_C(  -8), INT8_C( -45),
                           INT8_C(  23), INT8_C( -89), INT8_C(  67), INT8_C( 102)) }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])); i++) {
    simde__m256i r = simde_mm512_mask_cvtepi16_epi8(test_vec[i].src, test_vec[i].k, test_vec[i].a);
    simde_assert_m256i_i8(r, ==, test_vec[i].r);
  }

  return 0;
}

static int
test_simde_mm512_maskz_cvtepi16_epi8(SIMDE_MUNIT_TEST_ARGS) {
  const struct {
    simde__mmask32 k;
    simde__m512i a;
    simde__m256i r;
  } test_vec[8] = {
    { UINT32_C(     25439),
      simde_mm512_set_epi16(INT16_C( 26140), INT16_C( -8634), INT16_C( 26242), INT16_C(  1035),
                            INT16_C(-29578), INT16_C( -2997), INT16_C( 22546), INT16_C(-28782),
                            INT16_C(-11973), INT16_C( 12912), INT16_C(-22923), INT16_C(-12898),
                            INT16_C(  4984), INT16_C(   989), INT16_C(  2511), INT16_C( 26483),
                            INT16_C(-18247), INT16_C( 15612), INT16_C( -5009), INT16_C(-29481),
                            INT16_C(-28622), INT16_C(-22831), INT16_C(  6386), INT16_C(-19204),
                            INT16_C(-26509), INT16_C(-19102), INT16_C(-14606), INT16_C( 25117),
                            INT16_C( -8613), INT16_C( -2080), INT16_C( 27082), INT16_C(  2892)),
      simde_mm256_set_epi8(INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(  -4), INT8_C( 111), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C( -14), INT8_C(  -4),
                           INT8_C(   0), INT8_C(  98), INT8_C(   0), INT8_C(  29),
                           INT8_C(  91), INT8_C( -32), INT8_C( -54), INT8_C(  76)) },
    { UINT32_C(      1548),
      simde_mm512_set_epi16(INT16_C( -5255), INT16_C( 10791), INT16_C(-28009), INT16_C( 13848),
                            INT16_C(-23627), INT16_C( 27947), INT16_C(-20059), INT16_C( -3225),
                            INT16_C( -1319), INT16_C(   909), INT16_C(  7874), INT16_C(  7795),
                            INT16_C( -7004), INT16_C( 28406), INT16_C(  5294), INT16_C( 15166),
                            INT16_C( 14689), INT16_C(  7676), INT16_C(-12287), INT16_C( 12075),
                            INT16_C( 29253), INT16_C(-14914), INT16_C(  8284), INT16_C( 18521),
                            INT16_C( 32034), INT16_C( 27278), INT16_C( -3730), INT16_C( -7695),
                            INT16_C(  8989), INT16_C(-29300), INT16_C(-14890), INT16_C( 11419)),
      simde_mm256_set_epi8(INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C( -66), INT8_C(  92), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(  29), INT8_C(-116), INT8_C(   0), INT8_C(   0)) },
    { UINT32_C(      8241),
      simde_mm512_set_epi16(INT16_C( 28076), INT16_C(  6764), INT16_C(  4165), INT16_C(-17018),
                            INT16_C( 19920), INT16_C( 28417), INT16_C(-26944), INT16_C( -1327),
                            INT16_C(-18966), INT16_C(-19374), INT16_C(  9639), INT16_C(-25572),
                            INT16_C(-16315), INT16_C( 16363), INT16_C( -4686), INT16_C(-14474),
                            INT16_C( 26743), INT16_C( 20737), INT16_C(-16355), INT16_C( 24251),
                            INT16_C(-20830), INT16_C( 19809), INT16_C(-32085), INT16_C(-29115),
                            INT16_C(-21999), INT16_C( 14843), INT16_C( 13075), INT16_C(-28846),
                            INT16_C(-12894), INT16_C( 31357), INT16_C( 16553), INT16_C(-16546)),
      simde_mm256_set_epi8(INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(  29), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(  19), INT8_C(  82),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(  94)) },
    { UINT32_C(     46999),
      simde_mm512_set_epi16(INT16_C( 28715), INT16_C( 26138), INT16_C( 16023), INT16_C( 24398),
                            INT16_C( 20578), INT16_C( -1642), INT16_C( 24774), INT16_C( 26937),
                            INT16_C(-19881), INT16_C(-20408), INT16_C( 26365), INT16_C( -2980),
                            INT16_C( -4479), INT16_C(-10298), INT16_C( 13784), INT16_C(-25535),
                            INT16_C(-26583), INT16_C(-31618), INT16_C(  -202), INT16_C( 28295),
                            INT16_C(-12554), INT16_C( -5929), INT16_C(-27764), INT16_C(-12586),
                            INT16_C( 14711), INT16_C(  1730), INT16_C( -6678), INT16_C(-17469),
                            INT16_C(  2203), INT16_C( -6075), INT16_C(-28350), INT16_C(-12154)),
      simde_mm256_set_epi8(INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(  41), INT8_C(   0), INT8_C(  54), INT8_C(-121),
                           INT8_C(   0), INT8_C( -41), INT8_C(-116), INT8_C( -42),
                           INT8_C( 119), INT8_C(   0), INT8_C(   0), INT8_C( -61),
                           INT8_C(   0), INT8_C(  69), INT8_C(  66), INT8_C(-122)) },
    { UINT32_C(     14491),
      simde_mm512_set_epi16(INT16_C(-32102), INT16_C(-16442), INT16_C(  4517), INT16_C(-32738),
                            INT16_C(  -320), INT16_C(  2839), INT16_C( 18963), INT16_C(  4183),
                            INT16_C( 22800), INT16_C( 22140), INT16_C(-27082), INT16_C(  7876),
                            INT16_C( 10541), INT16_C(-26187), INT16_C(-11522), INT16_C( 30492),
                            INT16_C( 17836), INT16_C( 20188), INT16_C( 10949), INT16_C( 10757),
                            INT16_C(-18758), INT16_C( 27414), INT16_C( 23306), INT16_C(-11236),
                            INT16_C(-28100), INT16_C(  2824), INT16_C(-32113), INT16_C(-30059),
                            INT16_C(-19864), INT16_C(-29923), INT16_C( 19573), INT16_C(-11183)),
      simde_mm256_set_epi8(INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C( -59), INT8_C(   5),
                           INT8_C( -70), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(  60), INT8_C(   0), INT8_C(   0), INT8_C(-107),
                           INT8_C( 104), INT8_C(   0), INT8_C( 117), INT8_C(  81)) },
    { UINT32_C(     48585),
      simde_mm512_set_epi16(INT16_C( -3774), INT16_C(-15280), INT16_C( -6903), INT16_C(  7863),
                            INT16_C(-13846), INT16_C(-31146), INT16_C( -8758), INT16_C( 24559),
                            INT16_C(  8531), INT16_C(  2537), INT16_C(  7090), INT16_C( 32184),
                            INT16_C(   918), INT16_C( -4406), INT16_C( -1230), INT16_C(-20248),
                            INT16_C( 28454), INT16_C( -8033), INT16_C( 29491), INT16_C(  9038),
                            INT16_C( 31537), INT16_C(-32476), INT16_C( 15213), INT16_C(  2771),
                            INT16_C(  9158), INT16_C( 15700), INT16_C( 24392), INT16_C(-14500),
                            INT16_C( 20701), INT16_C( -9424), INT16_C( -5862), INT16_C(  8150)),
      simde_mm256_set_epi8(INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(  38), INT8_C(   0), INT8_C(  51), INT8_C(  78),
                           INT8_C(  49), INT8_C(  36), INT8_C(   0), INT8_C( -45),
                           INT8_C( -58), INT8_C(  84), INT8_C(   0), INT8_C(   0),
                           INT8_C( -35), INT8_C(   0), INT8_C(   0), INT8_C( -42)) },
    { UINT32_C(     10559),
      simde_mm512_set_epi16(INT16_C(-31337), INT16_C( 22983), INT16_C(  6281), INT16_C(  -506),
                            INT16_C(-24168), INT16_C(-22228), INT16_C(-32449), INT16_C(-30658),
                            INT16_C(-16400), INT16_C( -7823), INT16_C( -6600), INT16_C( -5428),
                            INT16_C( 10840), INT16_C(-16201), INT16_C(-15359), INT16_C(-30650),
                            INT16_C(  6966), INT16_C(-30042), INT16_C( 32539), INT16_C(-32588),
                            INT16_C(-23367), INT16_C(-13235), INT16_C(-19835), INT16_C( 15017),
                            INT16_C( -4677), INT16_C(-14834), INT16_C(  9957), INT16_C(-30787),
                            INT16_C( 17099), INT16_C( -5485), INT16_C(-31010), INT16_C( 12749)),
      simde_mm256_set_epi8(INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(  27), INT8_C(   0),
                           INT8_C( -71), INT8_C(   0), INT8_C(   0), INT8_C( -87),
                           INT8_C(   0), INT8_C(   0), INT8_C( -27), INT8_C( -67),
                           INT8_C( -53), INT8_C(-109), INT8_C( -34), INT8_C( -51)) },
    { UINT32_C(     51006),
      simde_mm512_set_epi16(INT16_C( -6560), INT16_C(-26729), INT16_C(  7233), INT16_C( 27170),
                            INT16_C(  5881), INT16_C( -9473), INT16_C(-30967), INT16_C(  3275),
                            INT16_C( -2646), INT16_C( 14621), INT16_C( 19871), INT16_C( 31044),
                            INT16_C(-31685), INT16_C(-20670), INT16_C(-16422), INT16_C( -9211),
                            INT16_C(  3868), INT16_C( -4406), INT16_C( 21022), INT16_C(-28018),
                            INT16_C(   839), INT16_C( 16405), INT16_C( 29563), INT16_C( -5487),
                            INT16_C( -2542), INT16_C(  1016), INT16_C(-24806), INT16_C( 18594),
                            INT16_C(  6349), INT16_C( -1940), INT16_C( 12009), INT16_C( 26974)),
      simde_mm256_set_epi8(INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(  28), INT8_C( -54), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(  21), INT8_C( 123), INT8_C(-111),
                           INT8_C(   0), INT8_C(   0), INT8_C(  26), INT8_C( -94),
                           INT8_C( -51), INT8_C( 108), INT8_C( -23), INT8_C(   0)) }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])); i++) {
    simde__m256i r = simde_mm512_maskz_cvtepi16_epi8(test_vec[i].k, test_vec[i].a);
    simde_assert_m256i_i8(r, ==, test_vec[i].r);
  }

  return 0;
}

static int
test_simde_mm512_cvtepi8_epi16(SIMDE_MUNIT_TEST_ARGS) {
  const struct {
    simde__m256i a;
    simde__m512i r;
  } test_vec[8] = {
    { simde_mm256_set_epi8(INT8_C(   7), INT8_C(  68), INT8_C( -86), INT8_C( -36),
                           INT8_C( -19), INT8_C(  73), INT8_C(  92), INT8_C( -27),
                           INT8_C(  55), INT8_C( -65), INT8_C( -50), INT8_C(  19),
                           INT8_C(-111), INT8_C( -79), INT8_C( -16), INT8_C(  70),
                           INT8_C(  27), INT8_C( -28), INT8_C( 116), INT8_C(  42),
                           INT8_C(  -4), INT8_C(  78), INT8_C(  31), INT8_C(  51),
                           INT8_C(  92), INT8_C(  39), INT8_C(-125), INT8_C(  94),
                           INT8_C( -78), INT8_C(  67), INT8_C( -43), INT8_C( -71)),
      simde_mm512_set_epi16(INT16_C(     7), INT16_C(    68), INT16_C(   -86), INT16_C(   -36),
                            INT16_C(   -19), INT16_C(    73), INT16_C(    92), INT16_C(   -27),
                            INT16_C(    55), INT16_C(   -65), INT16_C(   -50), INT16_C(    19),
                            INT16_C(  -111), INT16_C(   -79), INT16_C(   -16), INT16_C(    70),
                            INT16_C(    27), INT16_C(   -28), INT16_C(   116), INT16_C(    42),
                            INT16_C(    -4), INT16_C(    78), INT16_C(    31), INT16_C(    51),
                            INT16_C(    92), INT16_C(    39), INT16_C(  -125), INT16_C(    94),
                            INT16_C(   -78), INT16_C(    67), INT16_C(   -43), INT16_C(   -71)) },
    { simde_mm256_set_epi8(INT8_C(  29), INT8_C( -37), INT8_C(  27), INT8_C(  10),
                           INT8_C( -22), INT8_C(  -9), INT8_C(-125), INT8_C(  -3),
                           INT8_C( -53), INT8_C(  92), INT8_C( 103), INT8_C(  92),
                           INT8_C( 123), INT8_C(  74), INT8_C(  36), INT8_C(  59),
                           INT8_C(  46), INT8_C( -29), INT8_C(-103), INT8_C(  -4),
                           INT8_C( 109), INT8_C( -54), INT8_C(  41), INT8_C(  79),
                           INT8_C(  15), INT8_C( -92), INT8_C( 102), INT8_C( 116),
                           INT8_C( -42), INT8_C(  52), INT8_C( -61), INT8_C( -99)),
      simde_mm512_set_epi16(INT16_C(    29), INT16_C(   -37), INT16_C(    27), INT16_C(    10),
                            INT16_C(   -22), INT16_C(    -9), INT16_C(  -125), INT16_C(    -3),
                            INT16_C(   -53), INT16_C(    92), INT16_C(   103), INT16_C(    92),
                            INT16_C(   123), INT16_C(    74), INT16_C(    36), INT16_C(    59),
                            INT16_C(    46), INT16_C(   -29), INT16_C(  -103), INT16_C(    -4),
                            INT16_C(   109), INT16_C(   -54), INT16_C(    41), INT16_C(    79),
                            INT16_C(    15), INT16_C(   -92), INT16_C(   102), INT16_C(   116),
                            INT16_C(   -42), INT16_C(    52), INT16_C(   -61), INT16_C(   -99)) },
    { simde_mm256_set_epi8(INT8_C(  -9), INT8_C( -47), INT8_C( 107), INT8_C( -74),
                           INT8_C(-126), INT8_C(  34), INT8_C(  64), INT8_C( 115),
                           INT8_C( -65), INT8_C(-124), INT8_C(  54), INT8_C(  27),
                           INT8_C(  41), INT8_C( 112), INT8_C(  61), INT8_C(   6),
                           INT8_C(   7), INT8_C(  39), INT8_C(-109), INT8_C( -99),
                           INT8_C(  63), INT8_C( -35), INT8_C(-111), INT8_C( -72),
                           INT8_C( 109), INT8_C( -39), INT8_C( -99), INT8_C(  26),
                           INT8_C(  66), INT8_C( -78), INT8_C(  30), INT8_C(  38)),
      simde_mm512_set_epi16(INT16_C(    -9), INT16_C(   -47), INT16_C(   107), INT16_C(   -74),
                            INT16_C(  -126), INT16_C(    34), INT16_C(    64), INT16_C(   115),
                            INT16_C(   -65), INT16_C(  -124), INT16_C(    54), INT16_C(    27),
                            INT16_C(    41), INT16_C(   112), INT16_C(    61), INT16_C(     6),
                            INT16_C(     7), INT16_C(    39), INT16_C(  -109), INT16_C(   -99),
                            INT16_C(    63), INT16_C(   -35), INT16_C(  -111), INT16_C(   -72),
                            INT16_C(   109), INT16_C(   -39), INT16_C(   -99), INT16_C(    26),
                            INT16_C(    66), INT16_C(   -78), INT16_C(    30), INT16_C(    38)) },
    { simde_mm256_set_epi8(INT8_C( -72), INT8_C( -80), INT8_C( 101), INT8_C(  81),
                           INT8_C(  23), INT8_C( -68), INT8_C( -57), INT8_C(-111),
                           INT8_C(  -3), INT8_C(  21), INT8_C( 121), INT8_C( -22),
                           INT8_C(-104), INT8_C( -10), INT8_C( -37), INT8_C(  66),
                           INT8_C( -93), INT8_C( -80), INT8_C(  34), INT8_C( 104),
                           INT8_C( -39), INT8_C( -99), INT8_C(  18), INT8_C( 110),
                           INT8_C(-118), INT8_C(  38), INT8_C( 112), INT8_C( -67),
                           INT8_C(  60), INT8_C(  47), INT8_C(  32), INT8_C(  33)),
      simde_mm512_set_epi16(INT16_C(   -72), INT16_C(   -80), INT16_C(   101), INT16_C(    81),
                            INT16_C(    23), INT16_C(   -68), INT16_C(   -57), INT16_C(  -111),
                            INT16_C(    -3), INT16_C(    21), INT16_C(   121), INT16_C(   -22),
                            INT16_C(  -104), INT16_C(   -10), INT16_C(   -37), INT16_C(    66),
                            INT16_C(   -93), INT16_C(   -80), INT16_C(    34), INT16_C(   104),
                            INT16_C(   -39), INT16_C(   -99), INT16_C(    18), INT16_C(   110),
                            INT16_C(  -118), INT16_C(    38), INT16_C(   112), INT16_C(   -67),
                            INT16_C(    60), INT16_C(    47), INT16_C(    32), INT16_C(    33)) },
    { simde_mm256_set_epi8(INT8_C( 120), INT8_C( -90), INT8_C(-101), INT8_C(-106),
                           INT8_C(  70), INT8_C( -49), INT8_C(  29), INT8_C( -43),
                           INT8_C( -42), INT8_C(  38), INT8_C(  16), INT8_C( -43),
                           INT8_C( -40), INT8_C( -76), INT8_C( -67), INT8_C(  53),
                           INT8_C( -73), INT8_C( -17), INT8_C(  66), INT8_C(  57),
                           INT8_C( -65), INT8_C( -63), INT8_C(  17), INT8_C(  -9),
                           INT8_C(  95), INT8_C( -50), INT8_C(-118), INT8_C( 114),
                           INT8_C(  58), INT8_C( -28), INT8_C( -81), INT8_C( -37)),
      simde_mm512_set_epi16(INT16_C(   120), INT16_C(   -90), INT16_C(  -101), INT16_C(  -106),
                            INT16_C(    70), INT16_C(   -49), INT16_C(    29), INT16_C(   -43),
                            INT16_C(   -42), INT16_C(    38), INT16_C(    16), INT16_C(   -43),
                            INT16_C(   -40), INT16_C(   -76), INT16_C(   -67), INT16_C(    53),
                            INT16_C(   -73), INT16_C(   -17), INT16_C(    66), INT16_C(    57),
                            INT16_C(   -65), INT16_C(   -63), INT16_C(    17), INT16_C(    -9),
                            INT16_C(    95), INT16_C(   -50), INT16_C(  -118), INT16_C(   114),
                            INT16_C(    58), INT16_C(   -28), INT16_C(   -81), INT16_C(   -37)) },
    { simde_mm256_set_epi8(INT8_C( -97), INT8_C(  10), INT8_C( -75), INT8_C(-120),
                           INT8_C( -32), INT8_C(-105), INT8_C( -75), INT8_C(-101),
                           INT8_C(  71), INT8_C(-122), INT8_C(-112), INT8_C(  -2),
                           INT8_C(  60), INT8_C( -71), INT8_C( 101), INT8_C(  -1),
                           INT8_C(  95), INT8_C( -58), INT8_C( -70), INT8_C( 102),
                           INT8_C( 115), INT8_C( -68), INT8_C(-110), INT8_C( -36),
                           INT8_C(   6), INT8_C(  58), INT8_C(  73), INT8_C(  97),
                           INT8_C( -51), INT8_C(  -4), INT8_C(  58), INT8_C(  31)),
      simde_mm512_set_epi16(INT16_C(   -97), INT16_C(    10), INT16_C(   -75), INT16_C(  -120),
                            INT16_C(   -32), INT16_C(  -105), INT16_C(   -75), INT16_C(  -101),
                            INT16_C(    71), INT16_C(  -122), INT16_C(  -112), INT16_C(    -2),
                            INT16_C(    60), INT16_C(   -71), INT16_C(   101), INT16_C(    -1),
                            INT16_C(    95), INT16_C(   -58), INT16_C(   -70), INT16_C(   102),
                            INT16_C(   115), INT16_C(   -68), INT16_C(  -110), INT16_C(   -36),
                            INT16_C(     6), INT16_C(    58), INT16_C(    73), INT16_C(    97),
                            INT16_C(   -51), INT16_C(    -4), INT16_C(    58), INT16_C(    31)) },
    { simde_mm256_set_epi8(INT8_C( -73), INT8_C(-123), INT8_C( -11), INT8_C(  62),
                           INT8_C( -96), INT8_C(-103), INT8_C(  85), INT8_C(  88),
                           INT8_C( -19), INT8_C(  28), INT8_C(-107), INT8_C( -81),
                           INT8_C(-125), INT8_C(  88), INT8_C(  84), INT8_C( 115),
                           INT8_C( 105), INT8_C( -47), INT8_C(  68), INT8_C(-124),
                           INT8_C(  32), INT8_C(-100), INT8_C(  10), INT8_C( -69),
                           INT8_C( 124), INT8_C( -51), INT8_C( -89), INT8_C( -72),
                           INT8_C( -92), INT8_C(  -5), INT8_C( -46), INT8_C( 115)),
      simde_mm512_set_epi16(INT16_C(   -73), INT16_C(  -123), INT16_C(   -11), INT16_C(    62),
                            INT16_C(   -96), INT16_C(  -103), INT16_C(    85), INT16_C(    88),
                            INT16_C(   -19), INT16_C(    28), INT16_C(  -107), INT16_C(   -81),
                            INT16_C(  -125), INT16_C(    88), INT16_C(    84), INT16_C(   115),
                            INT16_C(   105), INT16_C(   -47), INT16_C(    68), INT16_C(  -124),
                            INT16_C(    32), INT16_C(  -100), INT16_C(    10), INT16_C(   -69),
                            INT16_C(   124), INT16_C(   -51), INT16_C(   -89), INT16_C(   -72),
                            INT16_C(   -92), INT16_C(    -5), INT16_C(   -46), INT16_C(   115)) },
    { simde_mm256_set_epi8(INT8_C( 104), INT8_C(  66), INT8_C(  51), INT8_C(  81),
                           INT8_C( -69), INT8_C( 104), INT8_C( 126), INT8_C( -43),
                           INT8_C( -40), INT8_C(  23), INT8_C(-124), INT8_C(  98),
                           INT8_C(-125), INT8_C(  95), INT8_C( -36), INT8_C(  46),
                           INT8_C(-115), INT8_C( -93), INT8_C(   2), INT8_C( -77),
                           INT8_C(  80), INT8_C(-116), INT8_C(  61), INT8_C( -89),
                           INT8_C( -37), INT8_C(   9), INT8_C(  84), INT8_C( -64),
                           INT8_C(  94), INT8_C(  67), INT8_C( -53), INT8_C( 111)),
      simde_mm512_set_epi16(INT16_C(   104), INT16_C(    66), INT16_C(    51), INT16_C(    81),
                            INT16_C(   -69), INT16_C(   104), INT16_C(   126), INT16_C(   -43),
                            INT16_C(   -40), INT16_C(    23), INT16_C(  -124), INT16_C(    98),
                            INT16_C(  -125), INT16_C(    95), INT16_C(   -36), INT16_C(    46),
                            INT16_C(  -115), INT16_C(   -93), INT16_C(     2), INT16_C(   -77),
                            INT16_C(    80), INT16_C(  -116), INT16_C(    61), INT16_C(   -89),
                            INT16_C(   -37), INT16_C(     9), INT16_C(    84), INT16_C(   -64),
                            INT16_C(    94), INT16_C(    67), INT16_C(   -53), INT16_C(   111)) }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])); i++) {
    simde__m512i r = simde_mm512_cvtepi8_epi16(test_vec[i].a);
    simde_assert_m512i_i16(r, ==, test_vec[i].r);
  }

  return 0;
}

static int
test_simde_mm512_cvtsepi16_epi8(SIMDE_MUNIT_TEST_ARGS) {
  const struct {
    simde__m512i a;
    simde__m256i r;
  } test_vec[8] = {
        { simde_mm512_set_epi16(INT16_C(  8002), INT16_C(   -42), INT16_C(   317), INT16_C(     3),
                            INT16_C(     2), INT16_C(    22), INT16_C(     2), INT16_C(   102),
                            INT16_C(     0), INT16_C(   130), INT16_C(   297), INT16_C(  4068),
                            INT16_C(  -202), INT16_C(  4593), INT16_C(  1545), INT16_C(    -2),
                            INT16_C( -4392), INT16_C( -3947), INT16_C(   301), INT16_C(-11526),
                            INT16_C(    -1), INT16_C(     1), INT16_C(  -437), INT16_C(     4),
                            INT16_C(  -139), INT16_C( -4859), INT16_C(    -1), INT16_C(    12),
                            INT16_C(  -591), INT16_C(   -40), INT16_C(  -269), INT16_C(   -24)),
      simde_mm256_set_epi8(INT8_C( 127), INT8_C( -42), INT8_C( 127), INT8_C(   3),
                           INT8_C(   2), INT8_C(  22), INT8_C(   2), INT8_C( 102),
                           INT8_C(   0), INT8_C( 127), INT8_C( 127), INT8_C( 127),
                           INT8_C(-128), INT8_C( 127), INT8_C( 127), INT8_C(  -2),
                           INT8_C(-128), INT8_C(-128), INT8_C( 127), INT8_C(-128),
                           INT8_C(  -1), INT8_C(   1), INT8_C(-128), INT8_C(   4),
                           INT8_C(-128), INT8_C(-128), INT8_C(  -1), INT8_C(  12),
                           INT8_C(-128), INT8_C( -40), INT8_C(-128), INT8_C( -24)) },
    { simde_mm512_set_epi16(INT16_C(     2), INT16_C(    49), INT16_C(     2), INT16_C(   131),
                            INT16_C(     1), INT16_C(-15743), INT16_C(  1984), INT16_C(     9),
                            INT16_C(-20648), INT16_C( -5458), INT16_C(    -1), INT16_C(    -1),
                            INT16_C( -3713), INT16_C(   -60), INT16_C( -1328), INT16_C(     4),
                            INT16_C(   150), INT16_C(    -8), INT16_C(  1864), INT16_C(   -14),
                            INT16_C(    20), INT16_C(   194), INT16_C(     0), INT16_C(  5954),
                            INT16_C(   -13), INT16_C(  -288), INT16_C(  3162), INT16_C(     1),
                            INT16_C(    14), INT16_C(  2628), INT16_C(    -1), INT16_C(    -8)),
      simde_mm256_set_epi8(INT8_C(   2), INT8_C(  49), INT8_C(   2), INT8_C( 127),
                           INT8_C(   1), INT8_C(-128), INT8_C( 127), INT8_C(   9),
                           INT8_C(-128), INT8_C(-128), INT8_C(  -1), INT8_C(  -1),
                           INT8_C(-128), INT8_C( -60), INT8_C(-128), INT8_C(   4),
                           INT8_C( 127), INT8_C(  -8), INT8_C( 127), INT8_C( -14),
                           INT8_C(  20), INT8_C( 127), INT8_C(   0), INT8_C( 127),
                           INT8_C( -13), INT8_C(-128), INT8_C( 127), INT8_C(   1),
                           INT8_C(  14), INT8_C( 127), INT8_C(  -1), INT8_C(  -8)) },
    { simde_mm512_set_epi16(INT16_C(  -562), INT16_C(    -4), INT16_C( 14830), INT16_C( 23439),
                            INT16_C(  -872), INT16_C(     2), INT16_C(  -152), INT16_C(    42),
                            INT16_C( 23882), INT16_C(    -7), INT16_C(-27326), INT16_C(  5025),
                            INT16_C(  7663), INT16_C(-14858), INT16_C(     0), INT16_C(    -1),
                            INT16_C(    27), INT16_C(     3), INT16_C(    -6), INT16_C(    54),
                            INT16_C(   -16), INT16_C(  -120), INT16_C(    -1), INT16_C(     0),
                            INT16_C(    50), INT16_C(    -3), INT16_C(     1), INT16_C(  -128),
                            INT16_C( -6425), INT16_C(     1), INT16_C(    -1), INT16_C(  -167)),
      simde_mm256_set_epi8(INT8_C(-128), INT8_C(  -4), INT8_C( 127), INT8_C( 127),
                           INT8_C(-128), INT8_C(   2), INT8_C(-128), INT8_C(  42),
                           INT8_C( 127), INT8_C(  -7), INT8_C(-128), INT8_C( 127),
                           INT8_C( 127), INT8_C(-128), INT8_C(   0), INT8_C(  -1),
                           INT8_C(  27), INT8_C(   3), INT8_C(  -6), INT8_C(  54),
                           INT8_C( -16), INT8_C(-120), INT8_C(  -1), INT8_C(   0),
                           INT8_C(  50), INT8_C(  -3), INT8_C(   1), INT8_C(-128),
                           INT8_C(-128), INT8_C(   1), INT8_C(  -1), INT8_C(-128)) },
    { simde_mm512_set_epi16(INT16_C(   117), INT16_C(    75), INT16_C(   -56), INT16_C(    -1),
                            INT16_C(    53), INT16_C(  -283), INT16_C(   138), INT16_C(     3),
                            INT16_C(    -1), INT16_C(  6705), INT16_C(   138), INT16_C( -3521),
                            INT16_C(    22), INT16_C(  1779), INT16_C(  2888), INT16_C(    -1),
                            INT16_C(  -189), INT16_C( 17712), INT16_C(   -18), INT16_C(   923),
                            INT16_C(     1), INT16_C(     1), INT16_C(  2605), INT16_C(   353),
                            INT16_C(   201), INT16_C(  -120), INT16_C(-28865), INT16_C(   -13),
                            INT16_C(  -701), INT16_C(   945), INT16_C( -2270), INT16_C(     0)),
      simde_mm256_set_epi8(INT8_C( 117), INT8_C(  75), INT8_C( -56), INT8_C(  -1),
                           INT8_C(  53), INT8_C(-128), INT8_C( 127), INT8_C(   3),
                           INT8_C(  -1), INT8_C( 127), INT8_C( 127), INT8_C(-128),
                           INT8_C(  22), INT8_C( 127), INT8_C( 127), INT8_C(  -1),
                           INT8_C(-128), INT8_C( 127), INT8_C( -18), INT8_C( 127),
                           INT8_C(   1), INT8_C(   1), INT8_C( 127), INT8_C( 127),
                           INT8_C( 127), INT8_C(-120), INT8_C(-128), INT8_C( -13),
                           INT8_C(-128), INT8_C( 127), INT8_C(-128), INT8_C(   0)) },
    { simde_mm512_set_epi16(INT16_C(   127), INT16_C(   406), INT16_C(    74), INT16_C(    -2),
                            INT16_C(   -12), INT16_C(   196), INT16_C(    -4), INT16_C( -4852),
                            INT16_C(    38), INT16_C(   -10), INT16_C(  -408), INT16_C(   453),
                            INT16_C( -6833), INT16_C(    37), INT16_C( -3464), INT16_C(    -2),
                            INT16_C(  -488), INT16_C(     0), INT16_C(   643), INT16_C(     6),
                            INT16_C(    51), INT16_C(     0), INT16_C(    -4), INT16_C(    -1),
                            INT16_C(-14928), INT16_C(   -46), INT16_C(    58), INT16_C(    -3),
                            INT16_C(     0), INT16_C(  -343), INT16_C(-10019), INT16_C(     0)),
      simde_mm256_set_epi8(INT8_C( 127), INT8_C( 127), INT8_C(  74), INT8_C(  -2),
                           INT8_C( -12), INT8_C( 127), INT8_C(  -4), INT8_C(-128),
                           INT8_C(  38), INT8_C( -10), INT8_C(-128), INT8_C( 127),
                           INT8_C(-128), INT8_C(  37), INT8_C(-128), INT8_C(  -2),
                           INT8_C(-128), INT8_C(   0), INT8_C( 127), INT8_C(   6),
                           INT8_C(  51), INT8_C(   0), INT8_C(  -4), INT8_C(  -1),
                           INT8_C(-128), INT8_C( -46), INT8_C(  58), INT8_C(  -3),
                           INT8_C(   0), INT8_C(-128), INT8_C(-128), INT8_C(   0)) },
    { simde_mm512_set_epi16(INT16_C(    -1), INT16_C(  -378), INT16_C(  3797), INT16_C(     1),
                            INT16_C(   -61), INT16_C( -6468), INT16_C(     0), INT16_C(-18745),
                            INT16_C(     3), INT16_C(    -5), INT16_C(    -1), INT16_C(  4066),
                            INT16_C(    -1), INT16_C(   -11), INT16_C(    -2), INT16_C(   881),
                            INT16_C(  -116), INT16_C(    22), INT16_C(     1), INT16_C( -1127),
                            INT16_C(    15), INT16_C(  2276), INT16_C(  -149), INT16_C(  7345),
                            INT16_C(   850), INT16_C(   -84), INT16_C(    -2), INT16_C(     0),
                            INT16_C(    -6), INT16_C( -3696), INT16_C(    -2), INT16_C(  2136)),
      simde_mm256_set_epi8(INT8_C(  -1), INT8_C(-128), INT8_C( 127), INT8_C(   1),
                           INT8_C( -61), INT8_C(-128), INT8_C(   0), INT8_C(-128),
                           INT8_C(   3), INT8_C(  -5), INT8_C(  -1), INT8_C( 127),
                           INT8_C(  -1), INT8_C( -11), INT8_C(  -2), INT8_C( 127),
                           INT8_C(-116), INT8_C(  22), INT8_C(   1), INT8_C(-128),
                           INT8_C(  15), INT8_C( 127), INT8_C(-128), INT8_C( 127),
                           INT8_C( 127), INT8_C( -84), INT8_C(  -2), INT8_C(   0),
                           INT8_C(  -6), INT8_C(-128), INT8_C(  -2), INT8_C( 127)) },
    { simde_mm512_set_epi16(INT16_C(  -368), INT16_C( -1403), INT16_C(   -10), INT16_C(  2787),
                            INT16_C(  6145), INT16_C(  -228), INT16_C(  2519), INT16_C(    -1),
                            INT16_C(  -244), INT16_C(    10), INT16_C(    14), INT16_C(   113),
                            INT16_C(    23), INT16_C(     1), INT16_C( 21613), INT16_C(    -2),
                            INT16_C(    -2), INT16_C(   -29), INT16_C(  9866), INT16_C(   356),
                            INT16_C(  -254), INT16_C(   -21), INT16_C(     9), INT16_C(     9),
                            INT16_C(   249), INT16_C(  3052), INT16_C( -8880), INT16_C(     7),
                            INT16_C(     0), INT16_C( -4602), INT16_C( -8839), INT16_C( 18288)),
      simde_mm256_set_epi8(INT8_C(-128), INT8_C(-128), INT8_C( -10), INT8_C( 127),
                           INT8_C( 127), INT8_C(-128), INT8_C( 127), INT8_C(  -1),
                           INT8_C(-128), INT8_C(  10), INT8_C(  14), INT8_C( 113),
                           INT8_C(  23), INT8_C(   1), INT8_C( 127), INT8_C(  -2),
                           INT8_C(  -2), INT8_C( -29), INT8_C( 127), INT8_C( 127),
                           INT8_C(-128), INT8_C( -21), INT8_C(   9), INT8_C(   9),
                           INT8_C( 127), INT8_C( 127), INT8_C(-128), INT8_C(   7),
                           INT8_C(   0), INT8_C(-128), INT8_C(-128), INT8_C( 127)) },
    { simde_mm512_set_epi16(INT16_C(   502), INT16_C(    22), INT16_C(    -4), INT16_C(     1),
                            INT16_C(     2), INT16_C( -1148), INT16_C(     1), INT16_C(     8),
                            INT16_C(    25), INT16_C(  8616), INT16_C(    -1), INT16_C(     0),
                            INT16_C(  1091), INT16_C(  -370), INT16_C(     0), INT16_C(    -1),
                            INT16_C( -1549), INT16_C(    12), INT16_C(    -2), INT16_C(     4),
                            INT16_C( -3952), INT16_C(  1681), INT16_C(     3), INT16_C(    35),
                            INT16_C(    -6), INT16_C(     0), INT16_C(    -2), INT16_C(    51),
                            INT16_C(     0), INT16_C(  3760), INT16_C(    -1), INT16_C(    -1)),
      simde_mm256_set_epi8(INT8_C( 127), INT8_C(  22), INT8_C(  -4), INT8_C(   1),
                           INT8_C(   2), INT8_C(-128), INT8_C(   1), INT8_C(   8),
                           INT8_C(  25), INT8_C( 127), INT8_C(  -1), INT8_C(   0),
                           INT8_C( 127), INT8_C(-128), INT8_C(   0), INT8_C(  -1),
                           INT8_C(-128), INT8_C(  12), INT8_C(  -2), INT8_C(   4),
                           INT8_C(-128), INT8_C( 127), INT8_C(   3), INT8_C(  35),
                           INT8_C(  -6), INT8_C(   0), INT8_C(  -2), INT8_C(  51),
                           INT8_C(   0), INT8_C( 127), INT8_C(  -1), INT8_C(  -1)) }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])); i++) {
    simde__m256i r = simde_mm512_cvtsepi16_epi8(test_vec[i].a);
    simde_assert_m256i_i8(r, ==, test_vec[i].r);
  }

  return 0;
}

static int
test_simde_mm512_mask_cvtsepi16_epi8(SIMDE_MUNIT_TEST_ARGS) {
  const struct {
    simde__m256i src;
    simde__mmask32 k;
    simde__m512i a;
    simde__m256i r;
  } test_vec[8] = {
    { simde_mm256_set_epi8(INT8_C( -40), INT8_C(  93), INT8_C( -64), INT8_C( 127),
                           INT8_C(-121), INT8_C( -33), INT8_C( -51), INT8_C(  86),
                           INT8_C(-123), INT8_C(-117), INT8_C(-108), INT8_C( -18),
                           INT8_C(  37), INT8_C(  26), INT8_C( -88), INT8_C(  80),
                           INT8_C(  30), INT8_C(  81), INT8_C(-126), INT8_C( 115),
                           INT8_C(-113), INT8_C(  80), INT8_C( -70), INT8_C(  14),
                           INT8_C(  67), INT8_C(-122), INT8_C( -52), INT8_C( -49),
                           INT8_C( -61), INT8_C( -10), INT8_C( -10), INT8_C(   9)),
      UINT32_C(   9464246),
      simde_mm512_set_epi16(INT16_C(  2661), INT16_C(  8241), INT16_C(-31365), INT16_C(-28794),
                            INT16_C( 31420), INT16_C(  5279), INT16_C(-11307), INT16_C(  8621),
                            INT16_C( 25450), INT16_C(-29219), INT16_C(  7142), INT16_C(  6454),
                            INT16_C( 22666), INT16_C( 22972), INT16_C( 22678), INT16_C(-10349),
                            INT16_C( 26453), INT16_C(-25565), INT16_C(-27471), INT16_C(-25692),
                            INT16_C( 24633), INT16_C(-12996), INT16_C( -7464), INT16_C(  6163),
                            INT16_C(-14301), INT16_C(  4709), INT16_C( 31142), INT16_C(-11353),
                            INT16_C(-11078), INT16_C( -7297), INT16_C( -6389), INT16_C(-27388)),
      simde_mm256_set_epi8(INT8_C( -40), INT8_C(  93), INT8_C( -64), INT8_C( 127),
                           INT8_C(-121), INT8_C( -33), INT8_C( -51), INT8_C(  86),
                           INT8_C( 127), INT8_C(-117), INT8_C(-108), INT8_C( 127),
                           INT8_C(  37), INT8_C(  26), INT8_C( -88), INT8_C(  80),
                           INT8_C(  30), INT8_C(-128), INT8_C(-128), INT8_C( 115),
                           INT8_C( 127), INT8_C(  80), INT8_C( -70), INT8_C( 127),
                           INT8_C(-128), INT8_C(-122), INT8_C( 127), INT8_C(-128),
                           INT8_C( -61), INT8_C(-128), INT8_C(-128), INT8_C(   9)) },
    { simde_mm256_set_epi8(INT8_C(-127), INT8_C(  79), INT8_C( -17), INT8_C( -57),
                           INT8_C(  84), INT8_C(  25), INT8_C( -42), INT8_C( -98),
                           INT8_C( -48), INT8_C( -88), INT8_C(  64), INT8_C(-126),
                           INT8_C(  55), INT8_C(  85), INT8_C(  23), INT8_C( 101),
                           INT8_C(  98), INT8_C( -22), INT8_C(  51), INT8_C(  32),
                           INT8_C( -91), INT8_C(  43), INT8_C( 124), INT8_C( -87),
                           INT8_C( -45), INT8_C( 117), INT8_C( -35), INT8_C(  88),
                           INT8_C(  36), INT8_C(  62), INT8_C( -51), INT8_C(  54)),
      UINT32_C(  16139739),
      simde_mm512_set_epi16(INT16_C( 29247), INT16_C( -8471), INT16_C( -1085), INT16_C( 30870),
                            INT16_C( 25891), INT16_C(-21158), INT16_C( 12488), INT16_C( -6908),
                            INT16_C( -1323), INT16_C(-29158), INT16_C( 19744), INT16_C( -9433),
                            INT16_C( 32012), INT16_C(-30047), INT16_C( 12083), INT16_C(  5703),
                            INT16_C(-23507), INT16_C(  9265), INT16_C(  9307), INT16_C( 19873),
                            INT16_C( -2618), INT16_C( -1149), INT16_C( 18681), INT16_C(  7098),
                            INT16_C(-13814), INT16_C( 19632), INT16_C(-21387), INT16_C(-19281),
                            INT16_C(-23963), INT16_C(-20730), INT16_C(-32754), INT16_C(-15371)),
      simde_mm256_set_epi8(INT8_C(-127), INT8_C(  79), INT8_C( -17), INT8_C( -57),
                           INT8_C(  84), INT8_C(  25), INT8_C( -42), INT8_C( -98),
                           INT8_C(-128), INT8_C(-128), INT8_C( 127), INT8_C(-128),
                           INT8_C(  55), INT8_C(-128), INT8_C( 127), INT8_C( 101),
                           INT8_C(  98), INT8_C( 127), INT8_C(  51), INT8_C(  32),
                           INT8_C( -91), INT8_C(-128), INT8_C( 124), INT8_C( 127),
                           INT8_C(-128), INT8_C( 127), INT8_C( -35), INT8_C(-128),
                           INT8_C(-128), INT8_C(  62), INT8_C(-128), INT8_C(-128)) },
    { simde_mm256_set_epi8(INT8_C(-113), INT8_C( -29), INT8_C( -74), INT8_C(-125),
                           INT8_C(  84), INT8_C( 106), INT8_C(-102), INT8_C(-121),
                           INT8_C(-106), INT8_C(   7), INT8_C(  31), INT8_C( -22),
                           INT8_C(   0), INT8_C( -95), INT8_C( -48), INT8_C(-118),
                           INT8_C(  70), INT8_C( -51), INT8_C(  81), INT8_C( -73),
                           INT8_C(   6), INT8_C( -50), INT8_C( -28), INT8_C(-105),
                           INT8_C(  13), INT8_C( -36), INT8_C( 105), INT8_C( -99),
                           INT8_C( -94), INT8_C( -98), INT8_C( -55), INT8_C( 107)),
      UINT32_C(    885729),
      simde_mm512_set_epi16(INT16_C( 27294), INT16_C( 16674), INT16_C( -5346), INT16_C(-13180),
                            INT16_C( -6683), INT16_C( 30235), INT16_C(-31280), INT16_C( -5669),
                            INT16_C( 12288), INT16_C(-24546), INT16_C(  9831), INT16_C(-31819),
                            INT16_C( 14268), INT16_C(-17608), INT16_C(  4735), INT16_C( 29092),
                            INT16_C(  3348), INT16_C( 20490), INT16_C(  9048), INT16_C(-14230),
                            INT16_C(-24731), INT16_C(-20916), INT16_C( 15138), INT16_C( 30554),
                            INT16_C( 12356), INT16_C(-12154), INT16_C( -1803), INT16_C( -2954),
                            INT16_C( -6857), INT16_C( -6626), INT16_C(-23034), INT16_C( 23374)),
      simde_mm256_set_epi8(INT8_C(-113), INT8_C( -29), INT8_C( -74), INT8_C(-125),
                           INT8_C(  84), INT8_C( 106), INT8_C(-102), INT8_C(-121),
                           INT8_C(-106), INT8_C(   7), INT8_C(  31), INT8_C( -22),
                           INT8_C( 127), INT8_C(-128), INT8_C( -48), INT8_C( 127),
                           INT8_C( 127), INT8_C( -51), INT8_C(  81), INT8_C( -73),
                           INT8_C(   6), INT8_C( -50), INT8_C( 127), INT8_C( 127),
                           INT8_C( 127), INT8_C(-128), INT8_C(-128), INT8_C( -99),
                           INT8_C( -94), INT8_C( -98), INT8_C( -55), INT8_C( 127)) },
    { simde_mm256_set_epi8(INT8_C( 106), INT8_C( 125), INT8_C(  -9), INT8_C( -42),
                           INT8_C(  10), INT8_C( -67), INT8_C( -69), INT8_C( -15),
                           INT8_C(-128), INT8_C( -93), INT8_C( -51), INT8_C(  63),
                           INT8_C( -48), INT8_C( -19), INT8_C( -88), INT8_C(   0),
                           INT8_C(  21), INT8_C(-113), INT8_C(  68), INT8_C(  50),
                           INT8_C(  14), INT8_C( -17), INT8_C( -38), INT8_C(  21),
                           INT8_C(  68), INT8_C(  38), INT8_C( -14), INT8_C(-115),
                           INT8_C(  96), INT8_C( -92), INT8_C( -38), INT8_C(  61)),
      UINT32_C(  14868571),
      simde_mm512_set_epi16(INT16_C( -4902), INT16_C(-30912), INT16_C( -9873), INT16_C( -3317),
                            INT16_C( 28529), INT16_C( 10810), INT16_C( 14756), INT16_C(-11980),
                            INT16_C(  8230), INT16_C( 14663), INT16_C(-28044), INT16_C( 14810),
                            INT16_C(  3087), INT16_C( 22573), INT16_C(-19115), INT16_C( 26647),
                            INT16_C(  3404), INT16_C(-13826), INT16_C( 16604), INT16_C( 11097),
                            INT16_C( 31149), INT16_C(-30463), INT16_C(-25032), INT16_C(-30305),
                            INT16_C( 14499), INT16_C(-27532), INT16_C(-28183), INT16_C( 13580),
                            INT16_C( 32147), INT16_C(-28462), INT16_C( 24823), INT16_C( 22687)),
      simde_mm256_set_epi8(INT8_C( 106), INT8_C( 125), INT8_C(  -9), INT8_C( -42),
                           INT8_C(  10), INT8_C( -67), INT8_C( -69), INT8_C( -15),
                           INT8_C( 127), INT8_C( 127), INT8_C(-128), INT8_C(  63),
                           INT8_C( -48), INT8_C( -19), INT8_C(-128), INT8_C(   0),
                           INT8_C( 127), INT8_C(-128), INT8_C( 127), INT8_C(  50),
                           INT8_C(  14), INT8_C( -17), INT8_C( -38), INT8_C(  21),
                           INT8_C(  68), INT8_C(-128), INT8_C( -14), INT8_C( 127),
                           INT8_C( 127), INT8_C( -92), INT8_C( 127), INT8_C( 127)) },
    { simde_mm256_set_epi8(INT8_C(   2), INT8_C(  -9), INT8_C( -57), INT8_C( 115),
                           INT8_C(  59), INT8_C(  73), INT8_C(  48), INT8_C( -68),
                           INT8_C(  25), INT8_C(  22), INT8_C( 111), INT8_C( -11),
                           INT8_C(  15), INT8_C(  80), INT8_C( -28), INT8_C( 103),
                           INT8_C( 112), INT8_C(  70), INT8_C( -85), INT8_C(  93),
                           INT8_C( 119), INT8_C( 109), INT8_C( -22), INT8_C(  25),
                           INT8_C( -22), INT8_C(  45), INT8_C( -15), INT8_C( -72),
                           INT8_C( 118), INT8_C( -32), INT8_C( -96), INT8_C(  60)),
      UINT32_C(   8515470),
      simde_mm512_set_epi16(INT16_C(-15796), INT16_C( 30043), INT16_C( 18714), INT16_C(-25916),
                            INT16_C( 32734), INT16_C( -8707), INT16_C(  8469), INT16_C(  -164),
                            INT16_C( 16857), INT16_C(  3751), INT16_C(-17844), INT16_C( 25466),
                            INT16_C( 11414), INT16_C(-10297), INT16_C( 19393), INT16_C(-20590),
                            INT16_C(-15444), INT16_C(-25233), INT16_C( 18470), INT16_C(-31576),
                            INT16_C(-31191), INT16_C(-25805), INT16_C( 18489), INT16_C(-13757),
                            INT16_C( 25106), INT16_C(  2901), INT16_C( 15043), INT16_C(  7932),
                            INT16_C( 16442), INT16_C(-31838), INT16_C(  6259), INT16_C( -3601)),
      simde_mm256_set_epi8(INT8_C(   2), INT8_C(  -9), INT8_C( -57), INT8_C( 115),
                           INT8_C(  59), INT8_C(  73), INT8_C(  48), INT8_C( -68),
                           INT8_C( 127), INT8_C(  22), INT8_C( 111), INT8_C( -11),
                           INT8_C(  15), INT8_C(  80), INT8_C( -28), INT8_C(-128),
                           INT8_C(-128), INT8_C(-128), INT8_C( 127), INT8_C(  93),
                           INT8_C(-128), INT8_C(-128), INT8_C( 127), INT8_C(-128),
                           INT8_C( 127), INT8_C(  45), INT8_C( -15), INT8_C( -72),
                           INT8_C( 127), INT8_C(-128), INT8_C( 127), INT8_C(  60)) },
    { simde_mm256_set_epi8(INT8_C(  -4), INT8_C(  -3), INT8_C(  85), INT8_C( -85),
                           INT8_C( -30), INT8_C( -90), INT8_C(  17), INT8_C(  33),
                           INT8_C(  39), INT8_C(-100), INT8_C( -52), INT8_C( 125),
                           INT8_C( -92), INT8_C( -97), INT8_C(  56), INT8_C( -59),
                           INT8_C( -44), INT8_C( -99), INT8_C( 111), INT8_C( -71),
                           INT8_C( -30), INT8_C(  31), INT8_C( -11), INT8_C( 118),
                           INT8_C(   7), INT8_C(-107), INT8_C(  79), INT8_C(   3),
                           INT8_C(  24), INT8_C( -11), INT8_C(  32), INT8_C(  -4)),
      UINT32_C(   6113317),
      simde_mm512_set_epi16(INT16_C( 11384), INT16_C(-29809), INT16_C( 14601), INT16_C(-32436),
                            INT16_C(  2836), INT16_C( 23731), INT16_C( 16401), INT16_C(  1507),
                            INT16_C( -6852), INT16_C( 24555), INT16_C(-18463), INT16_C(  1023),
                            INT16_C(-29174), INT16_C( 23081), INT16_C( 30328), INT16_C(-13892),
                            INT16_C( -2629), INT16_C( -6761), INT16_C( -2701), INT16_C(  4637),
                            INT16_C( 12641), INT16_C( 27159), INT16_C( -5860), INT16_C( 17953),
                            INT16_C(  4257), INT16_C( 13148), INT16_C(-26937), INT16_C(  3270),
                            INT16_C(-27177), INT16_C( -7723), INT16_C(-15174), INT16_C(-31459)),
      simde_mm256_set_epi8(INT8_C(  -4), INT8_C(  -3), INT8_C(  85), INT8_C( -85),
                           INT8_C( -30), INT8_C( -90), INT8_C(  17), INT8_C(  33),
                           INT8_C(  39), INT8_C( 127), INT8_C( -52), INT8_C( 127),
                           INT8_C(-128), INT8_C( 127), INT8_C(  56), INT8_C(-128),
                           INT8_C( -44), INT8_C(-128), INT8_C( 111), INT8_C( -71),
                           INT8_C( 127), INT8_C(  31), INT8_C( -11), INT8_C( 118),
                           INT8_C(   7), INT8_C(-107), INT8_C(-128), INT8_C(   3),
                           INT8_C(  24), INT8_C(-128), INT8_C(  32), INT8_C(-128)) },
    { simde_mm256_set_epi8(INT8_C(  81), INT8_C( -88), INT8_C( -80), INT8_C(   3),
                           INT8_C(  13), INT8_C(-121), INT8_C(  22), INT8_C(  32),
                           INT8_C( -40), INT8_C( 127), INT8_C( -26), INT8_C(  -3),
                           INT8_C( 106), INT8_C( -33), INT8_C( -31), INT8_C(-105),
                           INT8_C(  59), INT8_C( -77), INT8_C(  -5), INT8_C(-117),
                           INT8_C(  83), INT8_C(  56), INT8_C( -44), INT8_C( -77),
                           INT8_C( 117), INT8_C(  36), INT8_C( -73), INT8_C( -39),
                           INT8_C(   3), INT8_C( -92), INT8_C(  31), INT8_C( -95)),
      UINT32_C(  10953837),
      simde_mm512_set_epi16(INT16_C(-11142), INT16_C(-22777), INT16_C( -6414), INT16_C(  9569),
                            INT16_C( 17271), INT16_C( -3594), INT16_C( 10850), INT16_C(-11973),
                            INT16_C(  9012), INT16_C( 10724), INT16_C(-16786), INT16_C( -2912),
                            INT16_C( -9979), INT16_C(-18969), INT16_C(  4915), INT16_C( 10628),
                            INT16_C(  8002), INT16_C(  -445), INT16_C(  4038), INT16_C(  -403),
                            INT16_C( -4668), INT16_C(-24641), INT16_C(-17959), INT16_C(  5928),
                            INT16_C(-23858), INT16_C(-14464), INT16_C( 22098), INT16_C(-14446),
                            INT16_C(-19436), INT16_C(-24649), INT16_C(-32418), INT16_C( 13277)),
      simde_mm256_set_epi8(INT8_C(  81), INT8_C( -88), INT8_C( -80), INT8_C(   3),
                           INT8_C(  13), INT8_C(-121), INT8_C(  22), INT8_C(  32),
                           INT8_C( 127), INT8_C( 127), INT8_C(-128), INT8_C(  -3),
                           INT8_C( 106), INT8_C(-128), INT8_C( 127), INT8_C( 127),
                           INT8_C(  59), INT8_C( -77), INT8_C( 127), INT8_C(-117),
                           INT8_C(  83), INT8_C(-128), INT8_C( -44), INT8_C( -77),
                           INT8_C( 117), INT8_C(-128), INT8_C( 127), INT8_C( -39),
                           INT8_C(-128), INT8_C(-128), INT8_C(  31), INT8_C( 127)) },
    { simde_mm256_set_epi8(INT8_C(  83), INT8_C( 121), INT8_C(  87), INT8_C(  97),
                           INT8_C(  69), INT8_C(  33), INT8_C( -12), INT8_C(-117),
                           INT8_C(  99), INT8_C( -61), INT8_C(  40), INT8_C( -77),
                           INT8_C(  19), INT8_C( -55), INT8_C(   3), INT8_C( -96),
                           INT8_C( -32), INT8_C( -61), INT8_C(  -5), INT8_C( -43),
                           INT8_C( -47), INT8_C( 118), INT8_C(  58), INT8_C(  64),
                           INT8_C( 116), INT8_C( -63), INT8_C( 114), INT8_C( -16),
                           INT8_C(  31), INT8_C(  76), INT8_C( -13), INT8_C(-112)),
      UINT32_C(   4699534),
      simde_mm512_set_epi16(INT16_C( 27075), INT16_C( -2643), INT16_C(-27919), INT16_C( 22926),
                            INT16_C( -6606), INT16_C(  2828), INT16_C( -5375), INT16_C(-23218),
                            INT16_C(   -30), INT16_C( -9639), INT16_C( 28038), INT16_C( 11270),
                            INT16_C(-27543), INT16_C( 22578), INT16_C( 30460), INT16_C( 13726),
                            INT16_C( 28595), INT16_C( -2815), INT16_C(-21539), INT16_C(-25818),
                            INT16_C(  5191), INT16_C( 18511), INT16_C( 23592), INT16_C( 27668),
                            INT16_C(-21627), INT16_C(-28967), INT16_C(-19124), INT16_C( 27342),
                            INT16_C( 10864), INT16_C(-23627), INT16_C( 10714), INT16_C(-29389)),
      simde_mm256_set_epi8(INT8_C(  83), INT8_C( 121), INT8_C(  87), INT8_C(  97),
                           INT8_C(  69), INT8_C(  33), INT8_C( -12), INT8_C(-117),
                           INT8_C(  99), INT8_C(-128), INT8_C(  40), INT8_C( -77),
                           INT8_C(  19), INT8_C( 127), INT8_C( 127), INT8_C( 127),
                           INT8_C( 127), INT8_C( -61), INT8_C(-128), INT8_C(-128),
                           INT8_C( -47), INT8_C( 127), INT8_C(  58), INT8_C( 127),
                           INT8_C(-128), INT8_C( -63), INT8_C( 114), INT8_C( -16),
                           INT8_C( 127), INT8_C(-128), INT8_C( 127), INT8_C(-112)) }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])); i++) {
    simde__m256i r = simde_mm512_mask_cvtsepi16_epi8(test_vec[i].src, test_vec[i].k, test_vec[i].a);
    simde_assert_m256i_i8(r, ==, test_vec[i].r);
  }

  return 0;
}

static int
test_simde_mm512_maskz_cvtsepi16_epi8(SIMDE_MUNIT_TEST_ARGS) {
  const struct {
    simde__mmask32 k;
    simde__m512i a;
    simde__m256i r;
  } test_vec[8] = {
    { UINT32_C(  16184841),
      simde_mm512_set_epi16(INT16_C( 26453), INT16_C(-25565), INT16_C(-27471), INT16_C(-25692),
                            INT16_C( 24633), INT16_C(-12996), INT16_C( -7464), INT16_C(  6163),
                            INT16_C(-14301), INT16_C(  4709), INT16_C( 31142), INT16_C(-11353),
                            INT16_C(-11078), INT16_C( -7297), INT16_C( -6389), INT16_C(-27388),
                            INT16_C( 18739), INT16_C(-14274), INT16_C(-17264), INT16_C( 27062),
                            INT16_C(-10147), INT16_C(-16257), INT16_C(-30753), INT16_C(-12970),
                            INT16_C(-31349), INT16_C(-27410), INT16_C(  9498), INT16_C(-22448),
                            INT16_C(  7761), INT16_C(-32141), INT16_C(-28848), INT16_C(-17906)),
      simde_mm256_set_epi8(INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(-128), INT8_C( 127), INT8_C( 127), INT8_C(-128),
                           INT8_C(   0), INT8_C(-128), INT8_C(-128), INT8_C(   0),
                           INT8_C( 127), INT8_C(-128), INT8_C(-128), INT8_C( 127),
                           INT8_C(   0), INT8_C(-128), INT8_C(-128), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C( 127), INT8_C(   0), INT8_C(   0), INT8_C(-128)) },
    { UINT32_C(   9885587),
      simde_mm512_set_epi16(INT16_C(-16097), INT16_C(  -410), INT16_C( -7690), INT16_C( 17883),
                            INT16_C(-32433), INT16_C( -4153), INT16_C( 21529), INT16_C(-10594),
                            INT16_C(-12120), INT16_C( 16514), INT16_C( 14165), INT16_C(  5989),
                            INT16_C( 25322), INT16_C( 13088), INT16_C(-23253), INT16_C( 31913),
                            INT16_C(-11403), INT16_C( -8872), INT16_C(  9278), INT16_C(-13002),
                            INT16_C(  2661), INT16_C(  8241), INT16_C(-31365), INT16_C(-28794),
                            INT16_C( 31420), INT16_C(  5279), INT16_C(-11307), INT16_C(  8621),
                            INT16_C( 25450), INT16_C(-29219), INT16_C(  7142), INT16_C(  6454)),
      simde_mm256_set_epi8(INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(-128), INT8_C(   0), INT8_C(   0), INT8_C( 127),
                           INT8_C(   0), INT8_C( 127), INT8_C(-128), INT8_C(   0),
                           INT8_C(-128), INT8_C(-128), INT8_C(   0), INT8_C(-128),
                           INT8_C(   0), INT8_C( 127), INT8_C(-128), INT8_C(-128),
                           INT8_C( 127), INT8_C(   0), INT8_C(   0), INT8_C( 127),
                           INT8_C(   0), INT8_C(   0), INT8_C( 127), INT8_C( 127)) },
    { UINT32_C(    967669),
      simde_mm512_set_epi16(INT16_C(  3548), INT16_C( 27037), INT16_C(-23906), INT16_C(-13973),
                            INT16_C( 29247), INT16_C( -8471), INT16_C( -1085), INT16_C( 30870),
                            INT16_C( 25891), INT16_C(-21158), INT16_C( 12488), INT16_C( -6908),
                            INT16_C( -1323), INT16_C(-29158), INT16_C( 19744), INT16_C( -9433),
                            INT16_C( 32012), INT16_C(-30047), INT16_C( 12083), INT16_C(  5703),
                            INT16_C(-23507), INT16_C(  9265), INT16_C(  9307), INT16_C( 19873),
                            INT16_C( -2618), INT16_C( -1149), INT16_C( 18681), INT16_C(  7098),
                            INT16_C(-13814), INT16_C( 19632), INT16_C(-21387), INT16_C(-19281)),
      simde_mm256_set_epi8(INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(-128), INT8_C(-128), INT8_C( 127), INT8_C(   0),
                           INT8_C( 127), INT8_C(-128), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C( 127), INT8_C( 127),
                           INT8_C(-128), INT8_C(-128), INT8_C( 127), INT8_C( 127),
                           INT8_C(   0), INT8_C( 127), INT8_C(   0), INT8_C(-128)) },
    { UINT32_C(  13558935),
      simde_mm512_set_epi16(INT16_C( 14268), INT16_C(-17608), INT16_C(  4735), INT16_C( 29092),
                            INT16_C(  3348), INT16_C( 20490), INT16_C(  9048), INT16_C(-14230),
                            INT16_C(-24731), INT16_C(-20916), INT16_C( 15138), INT16_C( 30554),
                            INT16_C( 12356), INT16_C(-12154), INT16_C( -1803), INT16_C( -2954),
                            INT16_C( -6857), INT16_C( -6626), INT16_C(-23034), INT16_C( 23374),
                            INT16_C( 26785), INT16_C(-11163), INT16_C( 28429), INT16_C(-31775),
                            INT16_C(-28701), INT16_C(-18813), INT16_C( 21610), INT16_C(-25977),
                            INT16_C(-27129), INT16_C(  8170), INT16_C(   161), INT16_C(-12150)),
      simde_mm256_set_epi8(INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(-128), INT8_C(-128), INT8_C(   0), INT8_C(   0),
                           INT8_C( 127), INT8_C(-128), INT8_C(-128), INT8_C(   0),
                           INT8_C(-128), INT8_C(-128), INT8_C(-128), INT8_C(   0),
                           INT8_C(   0), INT8_C(-128), INT8_C(   0), INT8_C(   0),
                           INT8_C(-128), INT8_C(   0), INT8_C(   0), INT8_C(-128),
                           INT8_C(   0), INT8_C( 127), INT8_C( 127), INT8_C(-128)) },
    { UINT32_C(   6783925),
      simde_mm512_set_epi16(INT16_C( 32147), INT16_C(-28462), INT16_C( 24823), INT16_C( 22687),
                            INT16_C(-15505), INT16_C(  -251), INT16_C( -9246), INT16_C( -8101),
                            INT16_C( 27261), INT16_C( -2090), INT16_C(  2749), INT16_C(-17423),
                            INT16_C(-32605), INT16_C(-12993), INT16_C(-12051), INT16_C(-22528),
                            INT16_C(  5519), INT16_C( 17458), INT16_C(  3823), INT16_C( -9707),
                            INT16_C( 17446), INT16_C( -3443), INT16_C( 24740), INT16_C( -9667),
                            INT16_C( 27294), INT16_C( 16674), INT16_C( -5346), INT16_C(-13180),
                            INT16_C( -6683), INT16_C( 30235), INT16_C(-31280), INT16_C( -5669)),
      simde_mm256_set_epi8(INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(-128), INT8_C( 127), INT8_C(   0),
                           INT8_C(   0), INT8_C(-128), INT8_C(-128), INT8_C(-128),
                           INT8_C( 127), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C( 127), INT8_C(-128),
                           INT8_C( 127), INT8_C(   0), INT8_C(-128), INT8_C(-128),
                           INT8_C(   0), INT8_C( 127), INT8_C(   0), INT8_C(-128)) },
    { UINT32_C(  15283468),
      simde_mm512_set_epi16(INT16_C( 28742), INT16_C(-21667), INT16_C( 30573), INT16_C( -5607),
                            INT16_C( -5587), INT16_C( -3656), INT16_C( 30432), INT16_C(-24516),
                            INT16_C( -4902), INT16_C(-30912), INT16_C( -9873), INT16_C( -3317),
                            INT16_C( 28529), INT16_C( 10810), INT16_C( 14756), INT16_C(-11980),
                            INT16_C(  8230), INT16_C( 14663), INT16_C(-28044), INT16_C( 14810),
                            INT16_C(  3087), INT16_C( 22573), INT16_C(-19115), INT16_C( 26647),
                            INT16_C(  3404), INT16_C(-13826), INT16_C( 16604), INT16_C( 11097),
                            INT16_C( 31149), INT16_C(-30463), INT16_C(-25032), INT16_C(-30305)),
      simde_mm256_set_epi8(INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(-128), INT8_C(-128), INT8_C(-128), INT8_C(   0),
                           INT8_C( 127), INT8_C(   0), INT8_C(   0), INT8_C(-128),
                           INT8_C(   0), INT8_C(   0), INT8_C(-128), INT8_C( 127),
                           INT8_C(   0), INT8_C( 127), INT8_C(   0), INT8_C( 127),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C( 127), INT8_C(-128), INT8_C(   0), INT8_C(   0)) },
    { UINT32_C(   5301351),
      simde_mm512_set_epi16(INT16_C( 16857), INT16_C(  3751), INT16_C(-17844), INT16_C( 25466),
                            INT16_C( 11414), INT16_C(-10297), INT16_C( 19393), INT16_C(-20590),
                            INT16_C(-15444), INT16_C(-25233), INT16_C( 18470), INT16_C(-31576),
                            INT16_C(-31191), INT16_C(-25805), INT16_C( 18489), INT16_C(-13757),
                            INT16_C( 25106), INT16_C(  2901), INT16_C( 15043), INT16_C(  7932),
                            INT16_C( 16442), INT16_C(-31838), INT16_C(  6259), INT16_C( -3601),
                            INT16_C( 27012), INT16_C( 21875), INT16_C(-15231), INT16_C( -4210),
                            INT16_C(   759), INT16_C(-14477), INT16_C( 15177), INT16_C( 12476)),
      simde_mm256_set_epi8(INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(-128), INT8_C(   0), INT8_C(-128),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C( 127), INT8_C( 127), INT8_C( 127), INT8_C(   0),
                           INT8_C(   0), INT8_C(-128), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C( 127), INT8_C(-128), INT8_C(   0),
                           INT8_C(   0), INT8_C(-128), INT8_C( 127), INT8_C( 127)) },
    { UINT32_C(   1441628),
      simde_mm512_set_epi16(INT16_C(  4257), INT16_C( 13148), INT16_C(-26937), INT16_C(  3270),
                            INT16_C(-27177), INT16_C( -7723), INT16_C(-15174), INT16_C(-31459),
                            INT16_C(-29502), INT16_C(-16960), INT16_C(  -675), INT16_C( 18469),
                            INT16_C(  -771), INT16_C( 21931), INT16_C( -7514), INT16_C(  4385),
                            INT16_C( 10140), INT16_C(-13187), INT16_C(-23393), INT16_C( 14533),
                            INT16_C(-11107), INT16_C( 28601), INT16_C( -7649), INT16_C( -2698),
                            INT16_C(  1941), INT16_C( 20227), INT16_C(  6389), INT16_C(  8444),
                            INT16_C(-15796), INT16_C( 30043), INT16_C( 18714), INT16_C(-25916)),
      simde_mm256_set_epi8(INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C( 127),
                           INT8_C(   0), INT8_C( 127), INT8_C(   0), INT8_C( 127),
                           INT8_C( 127), INT8_C(-128), INT8_C(-128), INT8_C( 127),
                           INT8_C(-128), INT8_C( 127), INT8_C(-128), INT8_C(-128),
                           INT8_C(   0), INT8_C( 127), INT8_C(   0), INT8_C( 127),
                           INT8_C(-128), INT8_C( 127), INT8_C(   0), INT8_C(   0)) }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])); i++) {
    simde__m256i r = simde_mm512_maskz_cvtsepi16_epi8(test_vec[i].k, test_vec[i].a);
    simde_assert_m256i_i8(r, ==, test_vec[i].r);
  }

  return 0;
}

static int
test_simde_mm512_min_epi8 (SIMDE_MUNIT_TEST_ARGS) {
  static const struct {
    const int8_t a[64];
    const int8_t b[64];
    const int8_t r[64];
  } test_vec[] = {
    { {  INT8_C(  99),  INT8_C(  57),  INT8_C(  67), -INT8_C(   9), -INT8_C(   6),  INT8_C(  33), -INT8_C( 124),  INT8_C(  36),
         INT8_C(  33),  INT8_C(  54), -INT8_C(  88), -INT8_C(  42), -INT8_C(   2),  INT8_C( 100), -INT8_C(  20), -INT8_C(  26),
         INT8_C(  12),  INT8_C(  68), -INT8_C(  19),  INT8_C(   5),  INT8_C(  93), -INT8_C(  21),      INT8_MAX,  INT8_C( 103),
         INT8_C( 108),  INT8_C(  29),  INT8_C(  35), -INT8_C(  11),  INT8_C(  48),  INT8_C(  37), -INT8_C(  11), -INT8_C( 108),
         INT8_C(  94),  INT8_C(  56), -INT8_C( 117),  INT8_C(  88),  INT8_C(  89),  INT8_C(  15),  INT8_C( 124),  INT8_C( 122),
         INT8_C(  69),  INT8_C(  37),  INT8_C(  80),  INT8_C(  67), -INT8_C( 119),  INT8_C(  60),  INT8_C(  42), -INT8_C( 107),
             INT8_MIN,  INT8_C(  23), -INT8_C( 102), -INT8_C(  34),  INT8_C(   2),  INT8_C(  26),  INT8_C(  69),  INT8_C( 111),
         INT8_C(  55),  INT8_C( 104),  INT8_C( 100),  INT8_C( 104), -INT8_C( 114),  INT8_C(  89), -INT8_C(   4), -INT8_C(  20) },
      { -INT8_C( 111), -INT8_C( 121),  INT8_C(  69), -INT8_C(  22), -INT8_C( 106), -INT8_C(  63),  INT8_C( 101), -INT8_C(  37),
        -INT8_C(  26), -INT8_C(  75),  INT8_C(  31),  INT8_C( 111), -INT8_C(  14),  INT8_C(  73),  INT8_C(   4),  INT8_C( 114),
         INT8_C(  96), -INT8_C(  97),  INT8_C(  80),  INT8_C(  98), -INT8_C(  71), -INT8_C( 106), -INT8_C(  47), -INT8_C(  16),
        -INT8_C(   2),  INT8_C(  54),  INT8_C(  88), -INT8_C( 116), -INT8_C( 113),  INT8_C(  84),  INT8_C( 121),  INT8_C(  33),
        -INT8_C(  37), -INT8_C(  66),  INT8_C(  11),  INT8_C( 113),      INT8_MAX,  INT8_C( 112),  INT8_C(  77),  INT8_C( 102),
         INT8_C(  38),  INT8_C( 108), -INT8_C(  43),  INT8_C(  24), -INT8_C(  75), -INT8_C(  38), -INT8_C( 118),  INT8_C(  21),
         INT8_C( 121), -INT8_C(  37),  INT8_C( 119),  INT8_C(  50),  INT8_C( 113),  INT8_C(  73),  INT8_C(  34),  INT8_C( 111),
             INT8_MAX,  INT8_C( 123), -INT8_C(   4),  INT8_C(  14), -INT8_C(  49),  INT8_C( 117),  INT8_C(  47), -INT8_C(  85) },
      { -INT8_C( 111), -INT8_C( 121),  INT8_C(  67), -INT8_C(  22), -INT8_C( 106), -INT8_C(  63), -INT8_C( 124), -INT8_C(  37),
        -INT8_C(  26), -INT8_C(  75), -INT8_C(  88), -INT8_C(  42), -INT8_C(  14),  INT8_C(  73), -INT8_C(  20), -INT8_C(  26),
         INT8_C(  12), -INT8_C(  97), -INT8_C(  19),  INT8_C(   5), -INT8_C(  71), -INT8_C( 106), -INT8_C(  47), -INT8_C(  16),
        -INT8_C(   2),  INT8_C(  29),  INT8_C(  35), -INT8_C( 116), -INT8_C( 113),  INT8_C(  37), -INT8_C(  11), -INT8_C( 108),
        -INT8_C(  37), -INT8_C(  66), -INT8_C( 117),  INT8_C(  88),  INT8_C(  89),  INT8_C(  15),  INT8_C(  77),  INT8_C( 102),
         INT8_C(  38),  INT8_C(  37), -INT8_C(  43),  INT8_C(  24), -INT8_C( 119), -INT8_C(  38), -INT8_C( 118), -INT8_C( 107),
             INT8_MIN, -INT8_C(  37), -INT8_C( 102), -INT8_C(  34),  INT8_C(   2),  INT8_C(  26),  INT8_C(  34),  INT8_C( 111),
         INT8_C(  55),  INT8_C( 104), -INT8_C(   4),  INT8_C(  14), -INT8_C( 114),  INT8_C(  89), -INT8_C(   4), -INT8_C(  85) } },
    { {  INT8_C(  51),  INT8_C(  59),  INT8_C(  28), -INT8_C(  78), -INT8_C(  85),  INT8_C( 105),  INT8_C(  24), -INT8_C(  47),
        -INT8_C(  43), -INT8_C(  18), -INT8_C(  23), -INT8_C( 118), -INT8_C(  56),  INT8_C( 116), -INT8_C(  97),  INT8_C(  65),
         INT8_C(  79),  INT8_C(  23),  INT8_C( 115), -INT8_C(  64),  INT8_C(  96), -INT8_C( 107),  INT8_C(  47), -INT8_C(  33),
         INT8_C(  16),  INT8_C(  43), -INT8_C(  19), -INT8_C(  32), -INT8_C(  96),  INT8_C(  29), -INT8_C( 117), -INT8_C(  45),
         INT8_C(  88), -INT8_C(  89), -INT8_C( 122),  INT8_C(   3),  INT8_C(  17), -INT8_C(  98), -INT8_C(  43), -INT8_C(  26),
        -INT8_C( 116), -INT8_C(  66),  INT8_C( 113),  INT8_C(  84),  INT8_C(  50),  INT8_C(  16), -INT8_C( 107), -INT8_C( 127),
         INT8_C(  39),  INT8_C(   8),  INT8_C(  65), -INT8_C( 121), -INT8_C(  98),  INT8_C( 113),  INT8_C( 102), -INT8_C(  82),
        -INT8_C( 100),  INT8_C(  84), -INT8_C( 114),  INT8_C(  61),  INT8_C( 113),  INT8_C(  25),  INT8_C(  16), -INT8_C(  55) },
      { -INT8_C(  63), -INT8_C( 106), -INT8_C(  52), -INT8_C(  46),  INT8_C(  53), -INT8_C(  95), -INT8_C(  72), -INT8_C(  63),
         INT8_C(  96),  INT8_C(  41),  INT8_C(  22), -INT8_C( 110),  INT8_C(  58), -INT8_C(  85),  INT8_C(  20),  INT8_C(  97),
        -INT8_C(  76),  INT8_C(  85), -INT8_C(  23),  INT8_C(  82), -INT8_C(  58),  INT8_C(  79),  INT8_C(   0),  INT8_C(  99),
        -INT8_C(  93), -INT8_C( 113), -INT8_C(  96),  INT8_C(  20), -INT8_C(  88), -INT8_C(  80), -INT8_C(  35),  INT8_C( 105),
         INT8_C(  71), -INT8_C(  86),  INT8_C(  59),  INT8_C( 124),  INT8_C(  75), -INT8_C(  12),  INT8_C(  61), -INT8_C(  85),
         INT8_C(  29),  INT8_C(  83),  INT8_C(  62),  INT8_C(  87), -INT8_C(   1),  INT8_C(  82), -INT8_C(  71), -INT8_C(  77),
        -INT8_C(  89), -INT8_C(  94),  INT8_C(   5),  INT8_C( 110), -INT8_C(  15),  INT8_C(   5), -INT8_C(  47), -INT8_C( 107),
        -INT8_C( 108),  INT8_C( 113), -INT8_C(  87),  INT8_C(  61),  INT8_C(  33), -INT8_C( 121), -INT8_C(  90),  INT8_C( 104) },
      { -INT8_C(  63), -INT8_C( 106), -INT8_C(  52), -INT8_C(  78), -INT8_C(  85), -INT8_C(  95), -INT8_C(  72), -INT8_C(  63),
        -INT8_C(  43), -INT8_C(  18), -INT8_C(  23), -INT8_C( 118), -INT8_C(  56), -INT8_C(  85), -INT8_C(  97),  INT8_C(  65),
        -INT8_C(  76),  INT8_C(  23), -INT8_C(  23), -INT8_C(  64), -INT8_C(  58), -INT8_C( 107),  INT8_C(   0), -INT8_C(  33),
        -INT8_C(  93), -INT8_C( 113), -INT8_C(  96), -INT8_C(  32), -INT8_C(  96), -INT8_C(  80), -INT8_C( 117), -INT8_C(  45),
         INT8_C(  71), -INT8_C(  89), -INT8_C( 122),  INT8_C(   3),  INT8_C(  17), -INT8_C(  98), -INT8_C(  43), -INT8_C(  85),
        -INT8_C( 116), -INT8_C(  66),  INT8_C(  62),  INT8_C(  84), -INT8_C(   1),  INT8_C(  16), -INT8_C( 107), -INT8_C( 127),
        -INT8_C(  89), -INT8_C(  94),  INT8_C(   5), -INT8_C( 121), -INT8_C(  98),  INT8_C(   5), -INT8_C(  47), -INT8_C( 107),
        -INT8_C( 108),  INT8_C(  84), -INT8_C( 114),  INT8_C(  61),  INT8_C(  33), -INT8_C( 121), -INT8_C(  90), -INT8_C(  55) } },
    { {  INT8_C(  49), -INT8_C(  30), -INT8_C(  28),  INT8_C( 124), -INT8_C(  42),  INT8_C(  34),  INT8_C(  40), -INT8_C(  13),
         INT8_C( 117),  INT8_C( 102),  INT8_C(  75),  INT8_C( 116), -INT8_C(  72),  INT8_C(   4),  INT8_C(  39),  INT8_C(  95),
        -INT8_C(  90),  INT8_C(  44), -INT8_C(  51), -INT8_C( 105),  INT8_C(  50), -INT8_C(  98),  INT8_C(  44), -INT8_C(  58),
         INT8_C(  15), -INT8_C(  42),  INT8_C(   3),  INT8_C(  49),  INT8_C(  93), -INT8_C(  86), -INT8_C( 103), -INT8_C( 114),
        -INT8_C( 116),  INT8_C( 126),  INT8_C(  10),  INT8_C(  98), -INT8_C(  96),  INT8_C(  50),  INT8_C(  85),  INT8_C(  21),
        -INT8_C( 104), -INT8_C(  96), -INT8_C( 118),  INT8_C(  80), -INT8_C(  92), -INT8_C(  79), -INT8_C(  80),  INT8_C(  74),
        -INT8_C(  34),  INT8_C( 125), -INT8_C(  30),  INT8_C(  16),  INT8_C(  28),  INT8_C(  14), -INT8_C(  42),  INT8_C(  43),
        -INT8_C(  28), -INT8_C(  38),  INT8_C(  92),  INT8_C(  65), -INT8_C( 124), -INT8_C(  10), -INT8_C(  49),  INT8_C(  16) },
      {  INT8_C( 116), -INT8_C(  38),  INT8_C( 114),  INT8_C(  20),  INT8_C(  12), -INT8_C(  57),  INT8_C(  41), -INT8_C(  91),
         INT8_C( 104), -INT8_C(  77), -INT8_C(  11),  INT8_C(  12),  INT8_C( 101), -INT8_C(  91),  INT8_C(  87),  INT8_C(  67),
         INT8_C(  35),  INT8_C(  57),  INT8_C(  83),  INT8_C(  63),  INT8_C(  71),  INT8_C(  41),  INT8_C( 106),  INT8_C(  44),
         INT8_C(   3), -INT8_C(  57),  INT8_C( 109), -INT8_C( 121), -INT8_C(  67),  INT8_C(  61), -INT8_C( 105),  INT8_C(  49),
         INT8_C(  23),  INT8_C(   9),  INT8_C(  69),  INT8_C(  35), -INT8_C(  47),  INT8_C( 110), -INT8_C(  56),  INT8_C(  57),
         INT8_C(  34), -INT8_C(  66),  INT8_C(  69), -INT8_C( 121),  INT8_C(  99), -INT8_C( 100), -INT8_C(  54), -INT8_C( 122),
        -INT8_C(  43),  INT8_C(  29), -INT8_C(  59),  INT8_C(  29),  INT8_C(  70),  INT8_C(  48),  INT8_C(  73),  INT8_C(  74),
        -INT8_C(   9), -INT8_C(  74), -INT8_C(  47), -INT8_C(  76), -INT8_C(  13),  INT8_C( 105), -INT8_C(  27),  INT8_C(  10) },
      {  INT8_C(  49), -INT8_C(  38), -INT8_C(  28),  INT8_C(  20), -INT8_C(  42), -INT8_C(  57),  INT8_C(  40), -INT8_C(  91),
         INT8_C( 104), -INT8_C(  77), -INT8_C(  11),  INT8_C(  12), -INT8_C(  72), -INT8_C(  91),  INT8_C(  39),  INT8_C(  67),
        -INT8_C(  90),  INT8_C(  44), -INT8_C(  51), -INT8_C( 105),  INT8_C(  50), -INT8_C(  98),  INT8_C(  44), -INT8_C(  58),
         INT8_C(   3), -INT8_C(  57),  INT8_C(   3), -INT8_C( 121), -INT8_C(  67), -INT8_C(  86), -INT8_C( 105), -INT8_C( 114),
        -INT8_C( 116),  INT8_C(   9),  INT8_C(  10),  INT8_C(  35), -INT8_C(  96),  INT8_C(  50), -INT8_C(  56),  INT8_C(  21),
        -INT8_C( 104), -INT8_C(  96), -INT8_C( 118), -INT8_C( 121), -INT8_C(  92), -INT8_C( 100), -INT8_C(  80), -INT8_C( 122),
        -INT8_C(  43),  INT8_C(  29), -INT8_C(  59),  INT8_C(  16),  INT8_C(  28),  INT8_C(  14), -INT8_C(  42),  INT8_C(  43),
        -INT8_C(  28), -INT8_C(  74), -INT8_C(  47), -INT8_C(  76), -INT8_C( 124), -INT8_C(  10), -INT8_C(  49),  INT8_C(  10) } },
    { {  INT8_C( 114),  INT8_C(  42),  INT8_C(  46),  INT8_C(  67), -INT8_C( 104), -INT8_C(  10),  INT8_C( 124), -INT8_C(  70),
        -INT8_C(  76), -INT8_C(  62),  INT8_C(  65),  INT8_C(  24),  INT8_C(  94),  INT8_C(  11), -INT8_C(  98),  INT8_C(  52),
         INT8_C(  40),  INT8_C( 100),  INT8_C(  81),  INT8_C( 111), -INT8_C( 108), -INT8_C( 102), -INT8_C(  71), -INT8_C( 117),
         INT8_C(  80), -INT8_C( 118),  INT8_C(  63),  INT8_C(  68), -INT8_C(  13),  INT8_C(  36),  INT8_C(  78),  INT8_C( 102),
         INT8_C(  78),  INT8_C( 124), -INT8_C(  87), -INT8_C(  26),  INT8_C( 115),  INT8_C(  38), -INT8_C(  95),  INT8_C(  39),
        -INT8_C(  24), -INT8_C(  30),  INT8_C(  63),  INT8_C(  70), -INT8_C(  18), -INT8_C(  34),  INT8_C( 122),  INT8_C(  22),
         INT8_C(  66), -INT8_C(  53), -INT8_C( 123), -INT8_C(  42),  INT8_C( 101),  INT8_C(  62),  INT8_C(  97), -INT8_C(  74),
        -INT8_C(  55), -INT8_C(  96), -INT8_C(   6), -INT8_C(  68), -INT8_C(  60),  INT8_C(  72),  INT8_C(  34),  INT8_C(  18) },
      { -INT8_C(  59), -INT8_C(  52), -INT8_C(   8),  INT8_C(  56), -INT8_C(  14), -INT8_C( 103),  INT8_C(  95), -INT8_C(  38),
         INT8_C( 124), -INT8_C(  97),  INT8_C(  32),  INT8_C( 106),  INT8_C( 125), -INT8_C( 101),      INT8_MIN, -INT8_C(  65),
         INT8_C( 102),  INT8_C(   6), -INT8_C( 107), -INT8_C(  52),  INT8_C(  68), -INT8_C(  10), -INT8_C( 126),  INT8_C(  13),
        -INT8_C( 106),  INT8_C( 124), -INT8_C(  54),  INT8_C(  90), -INT8_C(  60), -INT8_C(  20),  INT8_C( 108), -INT8_C( 119),
        -INT8_C(  72),  INT8_C( 100), -INT8_C(  63), -INT8_C(  86), -INT8_C(   2),  INT8_C(  33), -INT8_C( 124),  INT8_C( 122),
        -INT8_C(  64), -INT8_C(  91), -INT8_C(  28),  INT8_C(  61),  INT8_C(  64),  INT8_C( 100), -INT8_C(   4), -INT8_C(  90),
         INT8_C( 106), -INT8_C( 111),  INT8_C( 114), -INT8_C(  81), -INT8_C( 121), -INT8_C(  12), -INT8_C(  68),  INT8_C(  29),
         INT8_C( 112), -INT8_C( 122),  INT8_C( 119),  INT8_C(  53),  INT8_C( 115), -INT8_C(  29), -INT8_C(  66),  INT8_C(  43) },
      { -INT8_C(  59), -INT8_C(  52), -INT8_C(   8),  INT8_C(  56), -INT8_C( 104), -INT8_C( 103),  INT8_C(  95), -INT8_C(  70),
        -INT8_C(  76), -INT8_C(  97),  INT8_C(  32),  INT8_C(  24),  INT8_C(  94), -INT8_C( 101),      INT8_MIN, -INT8_C(  65),
         INT8_C(  40),  INT8_C(   6), -INT8_C( 107), -INT8_C(  52), -INT8_C( 108), -INT8_C( 102), -INT8_C( 126), -INT8_C( 117),
        -INT8_C( 106), -INT8_C( 118), -INT8_C(  54),  INT8_C(  68), -INT8_C(  60), -INT8_C(  20),  INT8_C(  78), -INT8_C( 119),
        -INT8_C(  72),  INT8_C( 100), -INT8_C(  87), -INT8_C(  86), -INT8_C(   2),  INT8_C(  33), -INT8_C( 124),  INT8_C(  39),
        -INT8_C(  64), -INT8_C(  91), -INT8_C(  28),  INT8_C(  61), -INT8_C(  18), -INT8_C(  34), -INT8_C(   4), -INT8_C(  90),
         INT8_C(  66), -INT8_C( 111), -INT8_C( 123), -INT8_C(  81), -INT8_C( 121), -INT8_C(  12), -INT8_C(  68), -INT8_C(  74),
        -INT8_C(  55), -INT8_C( 122), -INT8_C(   6), -INT8_C(  68), -INT8_C(  60), -INT8_C(  29), -INT8_C(  66),  INT8_C(  18) } },
    { {  INT8_C(  71),      INT8_MIN, -INT8_C(  42),  INT8_C(  69), -INT8_C(  95),  INT8_C(  90), -INT8_C(  65),  INT8_C(  97),
        -INT8_C(   1), -INT8_C(  93), -INT8_C(  98),  INT8_C(  63),  INT8_C(   8), -INT8_C( 102), -INT8_C(  26),  INT8_C( 114),
         INT8_C(  43),  INT8_C(  88),  INT8_C(  33), -INT8_C(  78),  INT8_C(  77), -INT8_C(  34), -INT8_C(  49), -INT8_C(  67),
         INT8_C( 100),  INT8_C(  70), -INT8_C(  14), -INT8_C(  41),  INT8_C(  41), -INT8_C(  79),  INT8_C(   3),  INT8_C( 112),
         INT8_C(  49), -INT8_C(  39), -INT8_C(  74), -INT8_C(  46),  INT8_C(  51),  INT8_C( 117),  INT8_C(  51),  INT8_C(  51),
         INT8_C(  25), -INT8_C(  47),  INT8_C( 114),  INT8_C(  33),  INT8_C( 107),  INT8_C(  88), -INT8_C( 109), -INT8_C( 106),
        -INT8_C(  79), -INT8_C(  75),  INT8_C(  72), -INT8_C(   2), -INT8_C( 109),  INT8_C(  23), -INT8_C(  69), -INT8_C(   9),
         INT8_C(  93), -INT8_C(  82), -INT8_C(  49), -INT8_C( 122),  INT8_C(  95), -INT8_C(  46), -INT8_C(  10), -INT8_C( 112) },
      { -INT8_C(  85), -INT8_C(  84),  INT8_C(  98), -INT8_C(  34),  INT8_C(  34), -INT8_C( 107),  INT8_C(  17),  INT8_C(  59),
         INT8_C( 102), -INT8_C( 124),  INT8_C(  92), -INT8_C(  47), -INT8_C(  36), -INT8_C(  17),  INT8_C( 103), -INT8_C( 115),
        -INT8_C(  92), -INT8_C(  81), -INT8_C( 117),  INT8_C(  55), -INT8_C(  58),  INT8_C(  71),  INT8_C(  47),  INT8_C(  35),
        -INT8_C(  11), -INT8_C(   2), -INT8_C(  87),  INT8_C(  84), -INT8_C(  48), -INT8_C(  97), -INT8_C(  28),  INT8_C( 123),
         INT8_C(  76),  INT8_C(  70),  INT8_C(  89),  INT8_C( 110), -INT8_C(  37),  INT8_C( 107), -INT8_C(  87),  INT8_C(  65),
        -INT8_C(  17),  INT8_C(   5),  INT8_C(  18), -INT8_C(  53), -INT8_C(  12),  INT8_C( 121),  INT8_C(  89), -INT8_C( 103),
         INT8_C(  40), -INT8_C(  28), -INT8_C(  48), -INT8_C(  18),  INT8_C(  43), -INT8_C(   1),  INT8_C(  17),  INT8_C(  32),
        -INT8_C(   3), -INT8_C(  70),  INT8_C( 116), -INT8_C(  51),  INT8_C(  89),  INT8_C(  88),  INT8_C(  72), -INT8_C(  91) },
      { -INT8_C(  85),      INT8_MIN, -INT8_C(  42), -INT8_C(  34), -INT8_C(  95), -INT8_C( 107), -INT8_C(  65),  INT8_C(  59),
        -INT8_C(   1), -INT8_C( 124), -INT8_C(  98), -INT8_C(  47), -INT8_C(  36), -INT8_C( 102), -INT8_C(  26), -INT8_C( 115),
        -INT8_C(  92), -INT8_C(  81), -INT8_C( 117), -INT8_C(  78), -INT8_C(  58), -INT8_C(  34), -INT8_C(  49), -INT8_C(  67),
        -INT8_C(  11), -INT8_C(   2), -INT8_C(  87), -INT8_C(  41), -INT8_C(  48), -INT8_C(  97), -INT8_C(  28),  INT8_C( 112),
         INT8_C(  49), -INT8_C(  39), -INT8_C(  74), -INT8_C(  46), -INT8_C(  37),  INT8_C( 107), -INT8_C(  87),  INT8_C(  51),
        -INT8_C(  17), -INT8_C(  47),  INT8_C(  18), -INT8_C(  53), -INT8_C(  12),  INT8_C(  88), -INT8_C( 109), -INT8_C( 106),
        -INT8_C(  79), -INT8_C(  75), -INT8_C(  48), -INT8_C(  18), -INT8_C( 109), -INT8_C(   1), -INT8_C(  69), -INT8_C(   9),
        -INT8_C(   3), -INT8_C(  82), -INT8_C(  49), -INT8_C( 122),  INT8_C(  89), -INT8_C(  46), -INT8_C(  10), -INT8_C( 112) } },
    { { -INT8_C(  98), -INT8_C(  94),  INT8_C(  19),  INT8_C( 121),  INT8_C(  13), -INT8_C(  68), -INT8_C(  70), -INT8_C(   4),
        -INT8_C(  63), -INT8_C(  52), -INT8_C(  57), -INT8_C(  74),  INT8_C(  69),  INT8_C(  32),  INT8_C(  79),  INT8_C( 109),
         INT8_C(   5),  INT8_C(  31),  INT8_C(  91),  INT8_C(  48),  INT8_C(  31),  INT8_C( 108),  INT8_C(  81),  INT8_C(  28),
         INT8_C(  38), -INT8_C(  59), -INT8_C(  22),      INT8_MIN,  INT8_C(  30),  INT8_C(  50),  INT8_C(  37), -INT8_C(  68),
        -INT8_C(  44),  INT8_C(  57),  INT8_C(  54), -INT8_C(  31), -INT8_C(  11), -INT8_C(  16), -INT8_C(  35), -INT8_C(  73),
        -INT8_C(  67), -INT8_C(  91),  INT8_C( 109),  INT8_C(   2), -INT8_C(  59), -INT8_C(  68),  INT8_C( 112), -INT8_C(  54),
        -INT8_C(  37), -INT8_C(  53), -INT8_C(   5), -INT8_C(   6),  INT8_C(  56),  INT8_C(  76),  INT8_C(  23),  INT8_C(  94),
         INT8_C(  17),  INT8_C(   1), -INT8_C(  34),  INT8_C(  47),  INT8_C(  51),  INT8_C(   4), -INT8_C(  20),  INT8_C(   8) },
      {  INT8_C(  61),  INT8_C(  34), -INT8_C(  23),  INT8_C(  50),  INT8_C(  18), -INT8_C(  57), -INT8_C(  23), -INT8_C(  49),
         INT8_C( 108),  INT8_C(  86), -INT8_C(  46),  INT8_C(  49),  INT8_C(  18),  INT8_C(  66), -INT8_C(   4), -INT8_C(  18),
         INT8_C(  13), -INT8_C(   9), -INT8_C(  24),  INT8_C(  69),  INT8_C(  67), -INT8_C(   1), -INT8_C(  92),  INT8_C(  84),
         INT8_C(   0), -INT8_C( 126), -INT8_C( 124),  INT8_C(  52), -INT8_C( 122),  INT8_C( 112),  INT8_C(  60), -INT8_C(  61),
        -INT8_C( 110),  INT8_C(  37), -INT8_C(  10), -INT8_C(  92), -INT8_C(  20), -INT8_C(  33),  INT8_C( 116),  INT8_C(  88),
         INT8_C(  54),  INT8_C(  70), -INT8_C( 118),  INT8_C(  72), -INT8_C( 120), -INT8_C( 122),  INT8_C(  54), -INT8_C( 107),
         INT8_C( 125),  INT8_C(  31), -INT8_C(  37), -INT8_C(  64),  INT8_C(  30),      INT8_MAX,  INT8_C(  20),  INT8_C(  31),
         INT8_C(   1), -INT8_C( 104),  INT8_C(  83), -INT8_C( 120),  INT8_C(   8), -INT8_C( 113),  INT8_C(  75), -INT8_C( 102) },
      { -INT8_C(  98), -INT8_C(  94), -INT8_C(  23),  INT8_C(  50),  INT8_C(  13), -INT8_C(  68), -INT8_C(  70), -INT8_C(  49),
        -INT8_C(  63), -INT8_C(  52), -INT8_C(  57), -INT8_C(  74),  INT8_C(  18),  INT8_C(  32), -INT8_C(   4), -INT8_C(  18),
         INT8_C(   5), -INT8_C(   9), -INT8_C(  24),  INT8_C(  48),  INT8_C(  31), -INT8_C(   1), -INT8_C(  92),  INT8_C(  28),
         INT8_C(   0), -INT8_C( 126), -INT8_C( 124),      INT8_MIN, -INT8_C( 122),  INT8_C(  50),  INT8_C(  37), -INT8_C(  68),
        -INT8_C( 110),  INT8_C(  37), -INT8_C(  10), -INT8_C(  92), -INT8_C(  20), -INT8_C(  33), -INT8_C(  35), -INT8_C(  73),
        -INT8_C(  67), -INT8_C(  91), -INT8_C( 118),  INT8_C(   2), -INT8_C( 120), -INT8_C( 122),  INT8_C(  54), -INT8_C( 107),
        -INT8_C(  37), -INT8_C(  53), -INT8_C(  37), -INT8_C(  64),  INT8_C(  30),  INT8_C(  76),  INT8_C(  20),  INT8_C(  31),
         INT8_C(   1), -INT8_C( 104), -INT8_C(  34), -INT8_C( 120),  INT8_C(   8), -INT8_C( 113), -INT8_C(  20), -INT8_C( 102) } },
    { { -INT8_C(  76),  INT8_C(  65),  INT8_C(  63), -INT8_C(  95),  INT8_C(  33), -INT8_C(  77), -INT8_C(   7),  INT8_C(  87),
        -INT8_C(   7), -INT8_C( 125), -INT8_C(  97), -INT8_C( 127),  INT8_C(   9), -INT8_C(  42),  INT8_C(  22), -INT8_C( 122),
        -INT8_C(  11), -INT8_C(  15),  INT8_C(  70),  INT8_C(  19),  INT8_C( 112),  INT8_C(  91),  INT8_C(  50),  INT8_C( 114),
        -INT8_C(  13), -INT8_C( 123), -INT8_C(   6), -INT8_C(   4),  INT8_C(  20),  INT8_C(  69), -INT8_C( 106), -INT8_C(  55),
        -INT8_C( 121), -INT8_C(  43),  INT8_C( 106), -INT8_C(  88), -INT8_C( 120),  INT8_C(  99), -INT8_C(   1), -INT8_C( 127),
        -INT8_C(  25), -INT8_C(  98),  INT8_C(   2), -INT8_C(  16),  INT8_C( 116),  INT8_C(  25),  INT8_C( 119),  INT8_C( 105),
         INT8_C(  10), -INT8_C(  67),  INT8_C( 125),  INT8_C( 123),  INT8_C(  24), -INT8_C(  81), -INT8_C(  19),  INT8_C(  12),
         INT8_C(  53), -INT8_C(  25),  INT8_C(   8),  INT8_C(  73),  INT8_C(  44), -INT8_C(  98),  INT8_C(  18), -INT8_C(  77) },
      {  INT8_C( 116),  INT8_C( 124),  INT8_C(  91), -INT8_C(   4), -INT8_C(  32),  INT8_C(  90),  INT8_C( 126), -INT8_C(  57),
        -INT8_C(   7),      INT8_MIN, -INT8_C(  73),  INT8_C( 109), -INT8_C( 103),  INT8_C(  46), -INT8_C(  41), -INT8_C(  92),
        -INT8_C(  20),  INT8_C(  84),  INT8_C(  31),  INT8_C(   4),  INT8_C(   3),  INT8_C(  12),  INT8_C(  16),  INT8_C(  56),
        -INT8_C(  13),  INT8_C(  24), -INT8_C( 126),  INT8_C(  31), -INT8_C(  73), -INT8_C( 108), -INT8_C(  45),  INT8_C(  43),
         INT8_C(  17),  INT8_C(  46),  INT8_C(  39), -INT8_C(  15), -INT8_C( 119), -INT8_C(  91), -INT8_C(  72), -INT8_C( 126),
         INT8_C(  38),  INT8_C( 111), -INT8_C(  17), -INT8_C(  65), -INT8_C(  98), -INT8_C(  58),  INT8_C(  99), -INT8_C( 118),
         INT8_C(  26), -INT8_C( 126), -INT8_C( 114),  INT8_C(  30), -INT8_C( 114), -INT8_C(  97),  INT8_C(  86), -INT8_C( 127),
        -INT8_C(  73), -INT8_C(  40), -INT8_C(  95),  INT8_C( 110),  INT8_C( 109),  INT8_C( 116), -INT8_C( 103),  INT8_C( 126) },
      { -INT8_C(  76),  INT8_C(  65),  INT8_C(  63), -INT8_C(  95), -INT8_C(  32), -INT8_C(  77), -INT8_C(   7), -INT8_C(  57),
        -INT8_C(   7),      INT8_MIN, -INT8_C(  97), -INT8_C( 127), -INT8_C( 103), -INT8_C(  42), -INT8_C(  41), -INT8_C( 122),
        -INT8_C(  20), -INT8_C(  15),  INT8_C(  31),  INT8_C(   4),  INT8_C(   3),  INT8_C(  12),  INT8_C(  16),  INT8_C(  56),
        -INT8_C(  13), -INT8_C( 123), -INT8_C( 126), -INT8_C(   4), -INT8_C(  73), -INT8_C( 108), -INT8_C( 106), -INT8_C(  55),
        -INT8_C( 121), -INT8_C(  43),  INT8_C(  39), -INT8_C(  88), -INT8_C( 120), -INT8_C(  91), -INT8_C(  72), -INT8_C( 127),
        -INT8_C(  25), -INT8_C(  98), -INT8_C(  17), -INT8_C(  65), -INT8_C(  98), -INT8_C(  58),  INT8_C(  99), -INT8_C( 118),
         INT8_C(  10), -INT8_C( 126), -INT8_C( 114),  INT8_C(  30), -INT8_C( 114), -INT8_C(  97), -INT8_C(  19), -INT8_C( 127),
        -INT8_C(  73), -INT8_C(  40), -INT8_C(  95),  INT8_C(  73),  INT8_C(  44), -INT8_C(  98), -INT8_C( 103), -INT8_C(  77) } },
    { { -INT8_C(  94), -INT8_C(  63),  INT8_C( 111),  INT8_C(  43),  INT8_C( 102),  INT8_C(  39), -INT8_C(  83), -INT8_C( 116),
        -INT8_C( 106), -INT8_C(  99),  INT8_C(  76),  INT8_C(  52),  INT8_C(  99), -INT8_C(  81), -INT8_C(  66),  INT8_C( 126),
         INT8_C(  50),  INT8_C(  77), -INT8_C( 100), -INT8_C(  64), -INT8_C(  20), -INT8_C(  14),  INT8_C(  66), -INT8_C(  93),
        -INT8_C(  53), -INT8_C(  29),  INT8_C(  18),  INT8_C(  56),  INT8_C(  87), -INT8_C(  85), -INT8_C(  74), -INT8_C(   7),
         INT8_C( 108),  INT8_C(  37),  INT8_C(  37), -INT8_C(  45),  INT8_C(  76), -INT8_C(  46),  INT8_C(  95), -INT8_C(  30),
         INT8_C( 111), -INT8_C(  85),  INT8_C(  23), -INT8_C(  45),  INT8_C(  91), -INT8_C(  43),  INT8_C(  81), -INT8_C( 115),
         INT8_C(  34), -INT8_C(  19),  INT8_C(  77),  INT8_C(  14), -INT8_C(  33), -INT8_C( 113), -INT8_C(  78), -INT8_C(  86),
         INT8_C( 114), -INT8_C(  60), -INT8_C(  30), -INT8_C(  55),  INT8_C( 111), -INT8_C( 104), -INT8_C(  61), -INT8_C(  36) },
      { -INT8_C(  67), -INT8_C(  24), -INT8_C(  81),  INT8_C(   9), -INT8_C(  70),  INT8_C(  14), -INT8_C(  20),  INT8_C(  42),
        -INT8_C(  70),  INT8_C(   3), -INT8_C(   3),  INT8_C(  21), -INT8_C(  40),  INT8_C(  78), -INT8_C(  94), -INT8_C(   5),
         INT8_C(  59), -INT8_C(  17),  INT8_C(   9),  INT8_C(  26),      INT8_MAX, -INT8_C(  69), -INT8_C(  59), -INT8_C(  15),
             INT8_MAX, -INT8_C(  89), -INT8_C(  69), -INT8_C(  17),  INT8_C(  64),  INT8_C( 126), -INT8_C(  53), -INT8_C(   3),
         INT8_C( 102),  INT8_C( 122),  INT8_C(   7),  INT8_C(  32), -INT8_C( 120), -INT8_C(  13),  INT8_C(  74),  INT8_C(  66),
        -INT8_C(  10),  INT8_C(  71),  INT8_C(  87), -INT8_C(  50), -INT8_C( 107), -INT8_C(   7), -INT8_C(  55), -INT8_C(  48),
        -INT8_C(  23), -INT8_C(  45), -INT8_C(  21),  INT8_C( 104), -INT8_C( 114), -INT8_C(  80),  INT8_C(  89),  INT8_C(  14),
         INT8_C(  87),  INT8_C(  20), -INT8_C(   3), -INT8_C( 105), -INT8_C( 110), -INT8_C(  56), -INT8_C( 107), -INT8_C(   8) },
      { -INT8_C(  94), -INT8_C(  63), -INT8_C(  81),  INT8_C(   9), -INT8_C(  70),  INT8_C(  14), -INT8_C(  83), -INT8_C( 116),
        -INT8_C( 106), -INT8_C(  99), -INT8_C(   3),  INT8_C(  21), -INT8_C(  40), -INT8_C(  81), -INT8_C(  94), -INT8_C(   5),
         INT8_C(  50), -INT8_C(  17), -INT8_C( 100), -INT8_C(  64), -INT8_C(  20), -INT8_C(  69), -INT8_C(  59), -INT8_C(  93),
        -INT8_C(  53), -INT8_C(  89), -INT8_C(  69), -INT8_C(  17),  INT8_C(  64), -INT8_C(  85), -INT8_C(  74), -INT8_C(   7),
         INT8_C( 102),  INT8_C(  37),  INT8_C(   7), -INT8_C(  45), -INT8_C( 120), -INT8_C(  46),  INT8_C(  74), -INT8_C(  30),
        -INT8_C(  10), -INT8_C(  85),  INT8_C(  23), -INT8_C(  50), -INT8_C( 107), -INT8_C(  43), -INT8_C(  55), -INT8_C( 115),
        -INT8_C(  23), -INT8_C(  45), -INT8_C(  21),  INT8_C(  14), -INT8_C( 114), -INT8_C( 113), -INT8_C(  78), -INT8_C(  86),
         INT8_C(  87), -INT8_C(  60), -INT8_C(  30), -INT8_C( 105), -INT8_C( 110), -INT8_C( 104), -INT8_C( 107), -INT8_C(  36) } }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
    simde__m512i a = simde_mm512_loadu_epi8(test_vec[i].a);
    simde__m512i b = simde_mm512_loadu_epi8(test_vec[i].b);
    simde__m512i r = simde_mm512_min_epi8(a, b);
    simde_test_x86_assert_equal_i8x64(r, simde_mm512_loadu_epi8(test_vec[i].r));
  }

  return 0;
}

static int
test_simde_mm512_mask_min_epi8 (SIMDE_MUNIT_TEST_ARGS) {
  static const struct {
    const int8_t src[64];
    const simde__mmask64 k;
    const int8_t a[64];
    const int8_t b[64];
    const int8_t r[64];
  } test_vec[] = {
    { {  INT8_C(  69),  INT8_C(  77),  INT8_C( 104),  INT8_C(  74), -INT8_C(  56),  INT8_C(  84),  INT8_C( 106),  INT8_C( 109),
        -INT8_C(  29), -INT8_C(  33),  INT8_C(  11),  INT8_C(  57),  INT8_C(  28), -INT8_C( 111),  INT8_C( 107), -INT8_C(  70),
         INT8_C(  59), -INT8_C(  51),  INT8_C(   3), -INT8_C(  78),  INT8_C(  49),  INT8_C(   6),  INT8_C(  85), -INT8_C(  50),
         INT8_C(  24),  INT8_C(  48), -INT8_C(  61), -INT8_C(   7), -INT8_C( 125),  INT8_C(   2), -INT8_C(  65), -INT8_C(  55),
         INT8_C(  79),  INT8_C(  39),  INT8_C(  19),  INT8_C(  24),  INT8_C( 123),  INT8_C( 126), -INT8_C( 123),  INT8_C(  94),
         INT8_C(  93), -INT8_C( 112), -INT8_C( 105),  INT8_C( 121),  INT8_C(  34),  INT8_C(   3),  INT8_C(  52),  INT8_C(  93),
        -INT8_C(  48),  INT8_C(  55),  INT8_C(  15),  INT8_C(   2),  INT8_C(  61),  INT8_C( 100), -INT8_C(  48),  INT8_C(  85),
        -INT8_C( 108), -INT8_C( 108),  INT8_C(  79),  INT8_C(  24), -INT8_C( 106),  INT8_C(  14), -INT8_C(  31), -INT8_C(  27) },
      UINT64_C(14920570094114174006),
      {  INT8_C(  19), -INT8_C(  89),  INT8_C(  73),  INT8_C(  53), -INT8_C(  86),  INT8_C( 125), -INT8_C( 110),  INT8_C( 123),
        -INT8_C(  76), -INT8_C(  94),  INT8_C( 125), -INT8_C(  15),  INT8_C(   6),  INT8_C(  77),  INT8_C(  71), -INT8_C( 101),
        -INT8_C(  31), -INT8_C( 106), -INT8_C(  77),  INT8_C( 119), -INT8_C(  92), -INT8_C( 108),  INT8_C(  93), -INT8_C(  38),
        -INT8_C( 120),  INT8_C(  90), -INT8_C( 116), -INT8_C(   5), -INT8_C(  35), -INT8_C( 100), -INT8_C(  54), -INT8_C(  15),
         INT8_C(  67),  INT8_C(  19),  INT8_C(  38), -INT8_C(  18), -INT8_C( 112), -INT8_C(  71),  INT8_C( 105),  INT8_C(  68),
         INT8_C(  91), -INT8_C(  26),  INT8_C(  54),  INT8_C(  97),  INT8_C(  51),  INT8_C( 125), -INT8_C(   4),  INT8_C(  21),
         INT8_C(  19), -INT8_C(  81), -INT8_C( 116), -INT8_C(  73),  INT8_C(  67), -INT8_C(  23), -INT8_C( 110), -INT8_C(  52),
         INT8_C(  68),  INT8_C(  30), -INT8_C(  57),  INT8_C(  33), -INT8_C(  70), -INT8_C( 111),  INT8_C(  18), -INT8_C(   3) },
      { -INT8_C(  91),  INT8_C(  57), -INT8_C(  21),  INT8_C(  53), -INT8_C(  14),  INT8_C(  84),  INT8_C( 122),  INT8_C(  77),
         INT8_C(  58), -INT8_C(  80), -INT8_C(  82),  INT8_C( 110),  INT8_C(  45), -INT8_C(  85), -INT8_C( 125),  INT8_C(  64),
         INT8_C(  90),  INT8_C(  15), -INT8_C(   9), -INT8_C(  98), -INT8_C(   7), -INT8_C( 119),  INT8_C( 106),  INT8_C(  61),
        -INT8_C(  89),  INT8_C(  49),  INT8_C(  94),  INT8_C(  97), -INT8_C(  62),  INT8_C( 113),  INT8_C(  95),  INT8_C( 103),
        -INT8_C(  86),  INT8_C(  74), -INT8_C(  99), -INT8_C( 100), -INT8_C(  97),  INT8_C(  23), -INT8_C(  23), -INT8_C(  39),
        -INT8_C(  57), -INT8_C( 105),  INT8_C(  71), -INT8_C(  12),  INT8_C(  66), -INT8_C(  54),  INT8_C(  52), -INT8_C(  99),
        -INT8_C(  38),  INT8_C(  43),  INT8_C(  59), -INT8_C(  45), -INT8_C(  75), -INT8_C(  91),  INT8_C(  16),  INT8_C(  92),
        -INT8_C(  42),  INT8_C( 110), -INT8_C(  66), -INT8_C( 104), -INT8_C(  33),  INT8_C(  29),  INT8_C(   0), -INT8_C( 119) },
      {  INT8_C(  69), -INT8_C(  89), -INT8_C(  21),  INT8_C(  74), -INT8_C(  86),  INT8_C(  84),  INT8_C( 106),  INT8_C( 109),
        -INT8_C(  29), -INT8_C(  33), -INT8_C(  82),  INT8_C(  57),  INT8_C(   6), -INT8_C(  85), -INT8_C( 125), -INT8_C( 101),
        -INT8_C(  31), -INT8_C(  51), -INT8_C(  77), -INT8_C(  98), -INT8_C(  92), -INT8_C( 119),  INT8_C(  93), -INT8_C(  38),
        -INT8_C( 120),  INT8_C(  48), -INT8_C(  61), -INT8_C(   7), -INT8_C(  62), -INT8_C( 100), -INT8_C(  65), -INT8_C(  15),
         INT8_C(  79),  INT8_C(  19),  INT8_C(  19),  INT8_C(  24), -INT8_C( 112), -INT8_C(  71), -INT8_C(  23),  INT8_C(  94),
        -INT8_C(  57), -INT8_C( 105), -INT8_C( 105),  INT8_C( 121),  INT8_C(  34),  INT8_C(   3),  INT8_C(  52), -INT8_C(  99),
        -INT8_C(  48),  INT8_C(  55),  INT8_C(  15),  INT8_C(   2), -INT8_C(  75),  INT8_C( 100), -INT8_C(  48),  INT8_C(  85),
        -INT8_C(  42),  INT8_C(  30), -INT8_C(  66), -INT8_C( 104), -INT8_C( 106),  INT8_C(  14),  INT8_C(   0), -INT8_C( 119) } },
    { {  INT8_C( 103), -INT8_C(  99),  INT8_C(  37),  INT8_C(   6), -INT8_C(  76),  INT8_C(  14), -INT8_C(  32),  INT8_C( 123),
        -INT8_C(  90),  INT8_C(  39),  INT8_C( 111), -INT8_C(  24), -INT8_C(  14), -INT8_C(  93), -INT8_C( 123), -INT8_C(  52),
        -INT8_C(  50), -INT8_C(  64), -INT8_C(  97), -INT8_C( 125),  INT8_C( 101), -INT8_C(  81), -INT8_C(  32),  INT8_C(  59),
         INT8_C(  29), -INT8_C(  98), -INT8_C(  44), -INT8_C(   3), -INT8_C(  69), -INT8_C(  44), -INT8_C( 122),  INT8_C(  34),
         INT8_C( 113), -INT8_C(  84),  INT8_C(  41),  INT8_C(  37), -INT8_C(  70),  INT8_C(   9), -INT8_C(  96),  INT8_C(  96),
         INT8_C(  48),  INT8_C(  15),  INT8_C(  73),  INT8_C(  34), -INT8_C(  78), -INT8_C(  50), -INT8_C(  18),      INT8_MIN,
        -INT8_C( 113), -INT8_C( 115),  INT8_C(   4), -INT8_C(  12),  INT8_C(  60), -INT8_C(  28),  INT8_C(  48),  INT8_C(  90),
        -INT8_C( 126),  INT8_C(   4),  INT8_C(  87),  INT8_C(  61), -INT8_C(  40), -INT8_C(  35),  INT8_C(  95),  INT8_C(  73) },
      UINT64_C(14025351156619708553),
      {  INT8_C(  29), -INT8_C(  19), -INT8_C(  28), -INT8_C(  49), -INT8_C(  68), -INT8_C(  45),  INT8_C(  79),  INT8_C(  75),
         INT8_C(  96),  INT8_C(  83),  INT8_C(  63), -INT8_C(  99),  INT8_C(  55),  INT8_C( 111), -INT8_C(   9), -INT8_C(  71),
         INT8_C( 115),  INT8_C(  78), -INT8_C(  10),  INT8_C(  75),  INT8_C(  43),  INT8_C(  86), -INT8_C( 108), -INT8_C(  75),
        -INT8_C(  34),  INT8_C(   2), -INT8_C(   7),  INT8_C( 112),  INT8_C(  16), -INT8_C(  99),  INT8_C(  50),  INT8_C(  45),
        -INT8_C( 117),  INT8_C(  22), -INT8_C(   4),  INT8_C(  71), -INT8_C(  23),  INT8_C(  76), -INT8_C( 110),  INT8_C(  74),
        -INT8_C(  97), -INT8_C(  47), -INT8_C(  25), -INT8_C(  41),  INT8_C(  65), -INT8_C(  34), -INT8_C( 112), -INT8_C(  76),
         INT8_C(  44), -INT8_C( 121),  INT8_C(   0),  INT8_C(  87), -INT8_C(  35), -INT8_C( 108),  INT8_C(  12), -INT8_C(  69),
        -INT8_C( 105),  INT8_C(   5),  INT8_C(  43), -INT8_C(  89), -INT8_C(  93),  INT8_C(  93), -INT8_C(  43),  INT8_C(  46) },
      {  INT8_C( 116), -INT8_C(  47),  INT8_C( 117),  INT8_C(  93),  INT8_C(  29),  INT8_C(   7), -INT8_C(  89), -INT8_C(  67),
        -INT8_C(  40), -INT8_C( 114), -INT8_C( 108),  INT8_C(  25),  INT8_C( 108),  INT8_C(  36), -INT8_C(  50), -INT8_C( 104),
        -INT8_C(  85), -INT8_C(  50), -INT8_C(  16), -INT8_C( 120),  INT8_C(  98), -INT8_C(   4),  INT8_C(  68), -INT8_C(   7),
         INT8_C(   2),  INT8_C( 111), -INT8_C(  95), -INT8_C(  91), -INT8_C(  51),  INT8_C( 118), -INT8_C(  45),  INT8_C(  65),
         INT8_C(  71),  INT8_C(  72), -INT8_C(  98),  INT8_C( 101),  INT8_C(  79),  INT8_C(  70),  INT8_C(  34),  INT8_C(  39),
        -INT8_C(  44), -INT8_C(  74),  INT8_C(  65),  INT8_C(  65), -INT8_C(  38),  INT8_C(  15), -INT8_C(  39), -INT8_C( 122),
        -INT8_C(  35), -INT8_C(  55),  INT8_C(  14),  INT8_C(  63), -INT8_C(  58),  INT8_C(  82),  INT8_C(  57), -INT8_C(  56),
        -INT8_C(  62), -INT8_C(  38),  INT8_C( 109), -INT8_C( 113),  INT8_C(  80),  INT8_C(  64), -INT8_C(  48), -INT8_C( 105) },
      {  INT8_C(  29), -INT8_C(  99),  INT8_C(  37), -INT8_C(  49), -INT8_C(  76),  INT8_C(  14), -INT8_C(  32), -INT8_C(  67),
        -INT8_C(  90),  INT8_C(  39),  INT8_C( 111), -INT8_C(  99), -INT8_C(  14), -INT8_C(  93), -INT8_C( 123), -INT8_C( 104),
        -INT8_C(  50), -INT8_C(  50), -INT8_C(  16), -INT8_C( 120),  INT8_C( 101), -INT8_C(   4), -INT8_C( 108),  INT8_C(  59),
         INT8_C(  29), -INT8_C(  98), -INT8_C(  95), -INT8_C(   3), -INT8_C(  69), -INT8_C(  44), -INT8_C(  45),  INT8_C(  34),
        -INT8_C( 117), -INT8_C(  84),  INT8_C(  41),  INT8_C(  37), -INT8_C(  23),  INT8_C(   9), -INT8_C(  96),  INT8_C(  39),
         INT8_C(  48), -INT8_C(  74), -INT8_C(  25), -INT8_C(  41), -INT8_C(  78), -INT8_C(  50), -INT8_C(  18),      INT8_MIN,
        -INT8_C( 113), -INT8_C( 115),  INT8_C(   0), -INT8_C(  12),  INT8_C(  60), -INT8_C( 108),  INT8_C(  48), -INT8_C(  69),
        -INT8_C( 126), -INT8_C(  38),  INT8_C(  87),  INT8_C(  61), -INT8_C(  40), -INT8_C(  35), -INT8_C(  48), -INT8_C( 105) } },
    { { -INT8_C( 120),  INT8_C( 110), -INT8_C(   4), -INT8_C(  41), -INT8_C(  76),  INT8_C(  30), -INT8_C(   2), -INT8_C( 119),
        -INT8_C(  44),  INT8_C(  63), -INT8_C(  54), -INT8_C(  81),  INT8_C(  78), -INT8_C(  93),  INT8_C(  53),  INT8_C(  43),
         INT8_C( 109),  INT8_C(  67),  INT8_C( 107),  INT8_C(  51), -INT8_C( 106), -INT8_C(  92), -INT8_C(   5),  INT8_C(  88),
         INT8_C( 126),  INT8_C( 104), -INT8_C(  25), -INT8_C(  50), -INT8_C(  88), -INT8_C(  73),  INT8_C( 101),  INT8_C(  48),
         INT8_C(  37),  INT8_C(  98),  INT8_C(   7), -INT8_C(  38),      INT8_MIN,  INT8_C(   5),  INT8_C(  99),  INT8_C(  85),
         INT8_C(  69),  INT8_C(  45),  INT8_C(   4), -INT8_C( 109), -INT8_C(  48),  INT8_C(  57), -INT8_C(  65),  INT8_C(  61),
         INT8_C( 124),  INT8_C(  42),  INT8_C( 112),  INT8_C(  18), -INT8_C(  50),  INT8_C( 107),  INT8_C( 106),  INT8_C(  76),
        -INT8_C(  45),  INT8_C(  81),  INT8_C(  26),  INT8_C( 123),  INT8_C(   8),      INT8_MAX, -INT8_C(  85),  INT8_C(  46) },
      UINT64_C(18282199651996709601),
      { -INT8_C( 104), -INT8_C(  69), -INT8_C( 112),  INT8_C( 104), -INT8_C(  12),  INT8_C(  79), -INT8_C(  90),  INT8_C( 112),
         INT8_C( 121),  INT8_C(  22), -INT8_C( 125),  INT8_C(  71), -INT8_C( 126), -INT8_C(  19), -INT8_C( 109),  INT8_C(  85),
         INT8_C(  63), -INT8_C(  83), -INT8_C(  47),  INT8_C(  71),  INT8_C(  45),  INT8_C( 124),  INT8_C( 117),  INT8_C(  14),
         INT8_C(  47),  INT8_C( 125),  INT8_C( 112), -INT8_C(  25), -INT8_C(  24),  INT8_C(  39), -INT8_C(  28),      INT8_MIN,
        -INT8_C(  30),  INT8_C( 116), -INT8_C(  23), -INT8_C(  42), -INT8_C(  60), -INT8_C( 113),  INT8_C(  71),  INT8_C(  61),
        -INT8_C(  91), -INT8_C(  54), -INT8_C( 123),  INT8_C(  39), -INT8_C(  73),  INT8_C(  24),  INT8_C( 125), -INT8_C(  10),
        -INT8_C(  58),  INT8_C(  78),  INT8_C(  62), -INT8_C(  13), -INT8_C(  54), -INT8_C(  77),  INT8_C(   1), -INT8_C(   7),
         INT8_C(  49),  INT8_C( 114), -INT8_C(  32),  INT8_C(  25), -INT8_C( 103), -INT8_C(  60), -INT8_C( 102),  INT8_C( 124) },
      {  INT8_C(  57), -INT8_C( 125),  INT8_C(  82), -INT8_C(   3),  INT8_C(  18), -INT8_C( 103),  INT8_C(  58), -INT8_C(  73),
         INT8_C(  99), -INT8_C(  65), -INT8_C(  33),  INT8_C(  27), -INT8_C(  40),  INT8_C(  92),  INT8_C(  17), -INT8_C(  98),
        -INT8_C(  86),  INT8_C(  79), -INT8_C( 111),  INT8_C( 116),  INT8_C(   3), -INT8_C( 110),  INT8_C( 110),  INT8_C(  52),
         INT8_C(   4),  INT8_C(  78),  INT8_C(  77), -INT8_C(  98),  INT8_C(  19), -INT8_C(  25),  INT8_C(  26),  INT8_C(  76),
         INT8_C( 106),  INT8_C( 108),  INT8_C(  73),  INT8_C( 124),  INT8_C(   6), -INT8_C( 125),  INT8_C(  52),  INT8_C( 105),
         INT8_C(  67),  INT8_C(  19), -INT8_C( 124),  INT8_C(  27),  INT8_C( 111), -INT8_C( 106), -INT8_C(  71),  INT8_C(  25),
        -INT8_C(  27),  INT8_C(  74), -INT8_C( 115), -INT8_C(  24), -INT8_C(  36), -INT8_C(   5),  INT8_C(  28), -INT8_C(  31),
         INT8_C(  74),  INT8_C( 106),      INT8_MAX,  INT8_C(  93),  INT8_C(  81), -INT8_C( 103), -INT8_C(  87), -INT8_C(  68) },
      { -INT8_C( 104),  INT8_C( 110), -INT8_C(   4), -INT8_C(  41), -INT8_C(  76), -INT8_C( 103), -INT8_C(  90), -INT8_C(  73),
        -INT8_C(  44), -INT8_C(  65), -INT8_C(  54), -INT8_C(  81), -INT8_C( 126), -INT8_C(  19),  INT8_C(  53), -INT8_C(  98),
         INT8_C( 109),  INT8_C(  67),  INT8_C( 107),  INT8_C(  71), -INT8_C( 106), -INT8_C(  92), -INT8_C(   5),  INT8_C(  88),
         INT8_C( 126),  INT8_C(  78), -INT8_C(  25), -INT8_C(  50), -INT8_C(  88), -INT8_C(  25), -INT8_C(  28),  INT8_C(  48),
         INT8_C(  37),  INT8_C(  98),  INT8_C(   7), -INT8_C(  42), -INT8_C(  60), -INT8_C( 125),  INT8_C(  99),  INT8_C(  61),
        -INT8_C(  91), -INT8_C(  54),  INT8_C(   4),  INT8_C(  27), -INT8_C(  48), -INT8_C( 106), -INT8_C(  71),  INT8_C(  61),
        -INT8_C(  58),  INT8_C(  74), -INT8_C( 115),  INT8_C(  18), -INT8_C(  54), -INT8_C(  77),  INT8_C( 106), -INT8_C(  31),
         INT8_C(  49),  INT8_C(  81), -INT8_C(  32),  INT8_C(  25), -INT8_C( 103), -INT8_C( 103), -INT8_C( 102), -INT8_C(  68) } },
    { {  INT8_C(   5), -INT8_C(  14),  INT8_C(  56),  INT8_C(  11),  INT8_C( 117),  INT8_C( 108),  INT8_C( 117), -INT8_C(  72),
             INT8_MAX, -INT8_C(   7), -INT8_C(  45), -INT8_C(  18), -INT8_C( 113), -INT8_C( 116),  INT8_C(   7),  INT8_C( 117),
        -INT8_C(  42), -INT8_C( 107),  INT8_C(  93), -INT8_C(  77), -INT8_C( 112),  INT8_C( 122), -INT8_C( 108), -INT8_C(  38),
        -INT8_C(  28),  INT8_C(  19),  INT8_C(  55),  INT8_C(  53), -INT8_C(  84), -INT8_C(  32), -INT8_C(  15), -INT8_C(  79),
        -INT8_C(  46),  INT8_C(  42), -INT8_C(  67),  INT8_C(  72), -INT8_C( 106),  INT8_C(  50),  INT8_C(   0),  INT8_C(  22),
         INT8_C(  43), -INT8_C(  44),  INT8_C(   4), -INT8_C(  69),  INT8_C(  96),  INT8_C(  12),  INT8_C(  48),  INT8_C(  55),
        -INT8_C(  95), -INT8_C( 115), -INT8_C(  22),  INT8_C(  49),  INT8_C(   7),  INT8_C( 126),  INT8_C(  12), -INT8_C(  21),
        -INT8_C( 111),  INT8_C(  67),  INT8_C(  33),  INT8_C(  61),  INT8_C(  36),  INT8_C(  18), -INT8_C(  18), -INT8_C(  10) },
      UINT64_C(  714172237879356220),
      {  INT8_C(  19), -INT8_C(  19), -INT8_C(  60),  INT8_C( 115), -INT8_C(   7), -INT8_C(  12), -INT8_C(  86), -INT8_C( 102),
        -INT8_C( 127), -INT8_C( 108), -INT8_C(  52), -INT8_C( 119),  INT8_C(  18), -INT8_C(  40),  INT8_C( 116), -INT8_C(  93),
         INT8_C(  27), -INT8_C( 107), -INT8_C(  32),  INT8_C(  63), -INT8_C(  88), -INT8_C(  49),  INT8_C(  54), -INT8_C(  28),
         INT8_C( 122),  INT8_C( 116), -INT8_C(  73),  INT8_C(  88), -INT8_C(  77), -INT8_C(  96),  INT8_C(  97), -INT8_C(  58),
        -INT8_C( 114),  INT8_C(  37),  INT8_C(  58), -INT8_C( 121),  INT8_C(  25), -INT8_C(  28),  INT8_C(  34), -INT8_C( 102),
         INT8_C( 121), -INT8_C(  18),  INT8_C(  35), -INT8_C( 117), -INT8_C(  58), -INT8_C( 104),  INT8_C(  47), -INT8_C(  31),
         INT8_C(  45),  INT8_C(  15),  INT8_C(  33), -INT8_C(  43), -INT8_C(  34),  INT8_C(  87), -INT8_C(  70),  INT8_C(  89),
        -INT8_C(  53),  INT8_C( 113), -INT8_C(  79),      INT8_MAX,  INT8_C(  18),  INT8_C(  18),  INT8_C(  69), -INT8_C(  96) },
      {  INT8_C(  55),      INT8_MAX,  INT8_C(  39),  INT8_C(  80),  INT8_C( 100),  INT8_C(  73), -INT8_C(  22), -INT8_C(  35),
         INT8_C(  55),  INT8_C(  14),  INT8_C( 104), -INT8_C(   3), -INT8_C(  90), -INT8_C( 105), -INT8_C(  33), -INT8_C(  45),
        -INT8_C(  89),  INT8_C(   0), -INT8_C(  87), -INT8_C( 123),  INT8_C(  87),  INT8_C(  99), -INT8_C(  34),  INT8_C(  34),
        -INT8_C(  44), -INT8_C( 113), -INT8_C(  95), -INT8_C(  26), -INT8_C(  95), -INT8_C(  25), -INT8_C( 122), -INT8_C(  40),
         INT8_C( 102), -INT8_C(  82),  INT8_C(  40), -INT8_C(  54), -INT8_C(   9),  INT8_C(  19), -INT8_C(  89),  INT8_C(  47),
         INT8_C(  33),  INT8_C(  16),  INT8_C(  44), -INT8_C(  57), -INT8_C(  89),  INT8_C(  11), -INT8_C( 102),  INT8_C(  78),
         INT8_C(  11),  INT8_C(  67), -INT8_C(  44),  INT8_C(  98), -INT8_C(  90), -INT8_C(  78), -INT8_C( 123),  INT8_C( 123),
         INT8_C(  66),  INT8_C(  38),  INT8_C(  97), -INT8_C(  29),  INT8_C(  13), -INT8_C(  24), -INT8_C(  68),  INT8_C( 116) },
      {  INT8_C(   5), -INT8_C(  14), -INT8_C(  60),  INT8_C(  80), -INT8_C(   7), -INT8_C(  12),  INT8_C( 117), -INT8_C(  72),
        -INT8_C( 127), -INT8_C( 108), -INT8_C(  45), -INT8_C( 119), -INT8_C( 113), -INT8_C( 105),  INT8_C(   7), -INT8_C(  93),
        -INT8_C(  42), -INT8_C( 107), -INT8_C(  87), -INT8_C( 123), -INT8_C(  88), -INT8_C(  49), -INT8_C( 108), -INT8_C(  38),
        -INT8_C(  44), -INT8_C( 113),  INT8_C(  55),  INT8_C(  53), -INT8_C(  95), -INT8_C(  32), -INT8_C( 122), -INT8_C(  58),
        -INT8_C( 114),  INT8_C(  42),  INT8_C(  40), -INT8_C( 121), -INT8_C(   9),  INT8_C(  50), -INT8_C(  89), -INT8_C( 102),
         INT8_C(  33), -INT8_C(  18),  INT8_C(  35), -INT8_C( 117), -INT8_C(  89), -INT8_C( 104),  INT8_C(  48),  INT8_C(  55),
         INT8_C(  11), -INT8_C( 115), -INT8_C(  22), -INT8_C(  43),  INT8_C(   7), -INT8_C(  78), -INT8_C( 123),  INT8_C(  89),
        -INT8_C(  53),  INT8_C(  67),  INT8_C(  33), -INT8_C(  29),  INT8_C(  36),  INT8_C(  18), -INT8_C(  18), -INT8_C(  10) } },
    { { -INT8_C( 106), -INT8_C(  28),  INT8_C(  62), -INT8_C( 115), -INT8_C(   9), -INT8_C(  26), -INT8_C(  68),  INT8_C(  24),
        -INT8_C(  10), -INT8_C(  23), -INT8_C(  33), -INT8_C(  99), -INT8_C(  12),  INT8_C( 122), -INT8_C(  20),  INT8_C(   0),
        -INT8_C(  67), -INT8_C(  64),  INT8_C(  98),  INT8_C( 100),  INT8_C( 114), -INT8_C(  25), -INT8_C(  33), -INT8_C(  76),
         INT8_C(  14),  INT8_C(  64), -INT8_C( 104),  INT8_C(  27),  INT8_C(  40),  INT8_C(  84), -INT8_C( 113), -INT8_C(  66),
         INT8_C(  56), -INT8_C(  50),  INT8_C(  76),  INT8_C(  48), -INT8_C(  76),  INT8_C(   8),  INT8_C(  72), -INT8_C(  86),
        -INT8_C(  15),  INT8_C(  40),  INT8_C(  71), -INT8_C(  26), -INT8_C(  94),  INT8_C(  51), -INT8_C(  26),  INT8_C(  95),
        -INT8_C(  13),  INT8_C(  72), -INT8_C(  61),  INT8_C( 102),  INT8_C(  48), -INT8_C(  94),  INT8_C(  26),  INT8_C(  62),
        -INT8_C(  29), -INT8_C(  78),  INT8_C(  89),  INT8_C(  11),  INT8_C(   6), -INT8_C(  23), -INT8_C(  54),  INT8_C(  63) },
      UINT64_C( 1159033820397115063),
      { -INT8_C(  33),  INT8_C(  92), -INT8_C(  10), -INT8_C( 127), -INT8_C( 112), -INT8_C(  36), -INT8_C(  31), -INT8_C( 125),
         INT8_C(  36), -INT8_C(  92), -INT8_C(  23),  INT8_C(  84),  INT8_C(  71),  INT8_C(   4), -INT8_C( 110),  INT8_C(  42),
        -INT8_C(  74), -INT8_C(  20),  INT8_C(  53), -INT8_C(  67), -INT8_C(  43), -INT8_C(   1), -INT8_C(   4), -INT8_C( 116),
         INT8_C(  21),  INT8_C( 107), -INT8_C(   9),  INT8_C(  52),  INT8_C(  34),  INT8_C(  12),  INT8_C(  68),  INT8_C(   2),
         INT8_C( 104),  INT8_C(  58), -INT8_C( 125), -INT8_C(   8),  INT8_C(  22),  INT8_C( 100),  INT8_C( 124),  INT8_C(  58),
         INT8_C(   9),  INT8_C( 101), -INT8_C( 113),  INT8_C(  80),  INT8_C( 105),  INT8_C(  33),  INT8_C( 122),  INT8_C(  32),
         INT8_C(  13), -INT8_C(  81), -INT8_C(  35), -INT8_C(  30), -INT8_C(  81), -INT8_C(  39),  INT8_C( 110), -INT8_C(  60),
         INT8_C(  68),  INT8_C( 101), -INT8_C(   8),  INT8_C( 102),  INT8_C( 113),  INT8_C(  60),  INT8_C( 104), -INT8_C(  38) },
      {  INT8_C( 118), -INT8_C(  20), -INT8_C(  46), -INT8_C( 116),  INT8_C(  80),  INT8_C(  78), -INT8_C(  57),  INT8_C(  89),
        -INT8_C(  76),  INT8_C(  86), -INT8_C(  87),  INT8_C(  29),  INT8_C( 119),  INT8_C(  35),  INT8_C(  61), -INT8_C( 123),
        -INT8_C(  45),  INT8_C(  26),  INT8_C( 103), -INT8_C( 126), -INT8_C(  13), -INT8_C(  42),  INT8_C(  70),  INT8_C(  55),
         INT8_C(  59),  INT8_C(  63), -INT8_C(  98), -INT8_C(  83),  INT8_C( 123),  INT8_C(   6), -INT8_C( 121), -INT8_C(  14),
        -INT8_C(  14),  INT8_C(  89),  INT8_C( 126),  INT8_C(  67), -INT8_C(  88),  INT8_C(  69), -INT8_C( 100),  INT8_C(  92),
        -INT8_C( 101),  INT8_C(  70),  INT8_C( 121),  INT8_C(  19),  INT8_C( 105), -INT8_C(  73), -INT8_C( 104),  INT8_C(  60),
        -INT8_C(  47), -INT8_C(   1), -INT8_C(  66), -INT8_C(  59), -INT8_C(  43),  INT8_C(   5), -INT8_C(   4),  INT8_C(  17),
         INT8_C(  68), -INT8_C( 102), -INT8_C(  66), -INT8_C(  65), -INT8_C(  95),  INT8_C(  69), -INT8_C(  79), -INT8_C( 109) },
      { -INT8_C(  33), -INT8_C(  20), -INT8_C(  46), -INT8_C( 115), -INT8_C( 112), -INT8_C(  36), -INT8_C(  68), -INT8_C( 125),
        -INT8_C(  10), -INT8_C(  92), -INT8_C(  87), -INT8_C(  99),  INT8_C(  71),  INT8_C( 122), -INT8_C(  20),  INT8_C(   0),
        -INT8_C(  74), -INT8_C(  20),  INT8_C(  53), -INT8_C( 126),  INT8_C( 114), -INT8_C(  42), -INT8_C(   4), -INT8_C(  76),
         INT8_C(  21),  INT8_C(  63), -INT8_C( 104), -INT8_C(  83),  INT8_C(  40),  INT8_C(   6), -INT8_C( 121), -INT8_C(  66),
         INT8_C(  56),  INT8_C(  58), -INT8_C( 125), -INT8_C(   8), -INT8_C(  88),  INT8_C(   8),  INT8_C(  72), -INT8_C(  86),
        -INT8_C( 101),  INT8_C(  70), -INT8_C( 113), -INT8_C(  26),  INT8_C( 105), -INT8_C(  73), -INT8_C(  26),  INT8_C(  32),
        -INT8_C(  47),  INT8_C(  72), -INT8_C(  66),  INT8_C( 102), -INT8_C(  81), -INT8_C(  94),  INT8_C(  26),  INT8_C(  62),
        -INT8_C(  29), -INT8_C(  78),  INT8_C(  89),  INT8_C(  11), -INT8_C(  95), -INT8_C(  23), -INT8_C(  54),  INT8_C(  63) } },
    { { -INT8_C(  98),  INT8_C(  48), -INT8_C(  42),  INT8_C(  70),  INT8_C( 117),  INT8_C( 115), -INT8_C(  94),  INT8_C(  17),
        -INT8_C(  71),  INT8_C(  28),  INT8_C(  36),  INT8_C(  34), -INT8_C(  45), -INT8_C(  68),  INT8_C(  95), -INT8_C(  92),
        -INT8_C(  69),  INT8_C(  29),  INT8_C( 105), -INT8_C( 111),  INT8_C(  34),  INT8_C( 102), -INT8_C(  94),  INT8_C( 102),
         INT8_C(   0),  INT8_C(  96),  INT8_C(  38), -INT8_C(  95), -INT8_C(  91), -INT8_C(  41),  INT8_C(  53),  INT8_C(  67),
         INT8_C(   7),  INT8_C(  11), -INT8_C( 118),  INT8_C( 125),  INT8_C( 126),  INT8_C(  44), -INT8_C( 114),  INT8_C(  55),
         INT8_C(  72), -INT8_C(  78),  INT8_C(  90),  INT8_C(  27),  INT8_C( 110), -INT8_C(  71), -INT8_C(  64),  INT8_C(  41),
        -INT8_C(  42),  INT8_C(  41), -INT8_C(  70), -INT8_C(   7), -INT8_C( 113),  INT8_C(  92),  INT8_C(  95), -INT8_C( 112),
        -INT8_C(  68), -INT8_C( 123),  INT8_C(  49),  INT8_C(  97),  INT8_C(  93),  INT8_C( 102), -INT8_C(  91),  INT8_C( 100) },
      UINT64_C(11828826861962604402),
      {  INT8_C(  33), -INT8_C( 126), -INT8_C(  65), -INT8_C( 113),  INT8_C(  59),      INT8_MAX, -INT8_C(  71),  INT8_C(  17),
        -INT8_C(  87),  INT8_C( 115),  INT8_C(  10),  INT8_C(  56), -INT8_C(  48),  INT8_C( 106), -INT8_C(  56), -INT8_C( 116),
        -INT8_C(  17), -INT8_C(   6), -INT8_C(  18),  INT8_C(  76),  INT8_C(  96), -INT8_C( 109), -INT8_C(  79), -INT8_C(  46),
        -INT8_C(  62), -INT8_C( 110), -INT8_C(  61),  INT8_C(  29),  INT8_C(   2), -INT8_C(  21), -INT8_C(  63),  INT8_C(  35),
         INT8_C( 109), -INT8_C( 127), -INT8_C(  77), -INT8_C(  88),  INT8_C(   0),  INT8_C( 108), -INT8_C(  71), -INT8_C(  87),
        -INT8_C(  33), -INT8_C(  60), -INT8_C(  30), -INT8_C(  81),  INT8_C(  46), -INT8_C(  86),  INT8_C(  60),  INT8_C(  29),
        -INT8_C(  92),  INT8_C(  42),  INT8_C( 106),  INT8_C(   5), -INT8_C(  67),  INT8_C(  27), -INT8_C(  41),      INT8_MAX,
        -INT8_C(  83), -INT8_C( 102), -INT8_C( 100), -INT8_C(  81), -INT8_C( 123),  INT8_C(  94), -INT8_C(  45), -INT8_C(  14) },
      { -INT8_C(  33), -INT8_C( 122), -INT8_C( 102), -INT8_C(  33), -INT8_C(  14),  INT8_C(  84), -INT8_C( 119), -INT8_C(  47),
         INT8_C(  24),  INT8_C( 107), -INT8_C( 127),  INT8_C(  70),  INT8_C(  21), -INT8_C(  67),  INT8_C(  99), -INT8_C(  70),
        -INT8_C(  25), -INT8_C(  51), -INT8_C(  65), -INT8_C(  92), -INT8_C(  24), -INT8_C( 106),  INT8_C(  35), -INT8_C( 106),
         INT8_C(  49), -INT8_C(  65),  INT8_C(  69), -INT8_C(  74),  INT8_C(  29),  INT8_C(  24), -INT8_C(  87), -INT8_C(   4),
        -INT8_C(  98),  INT8_C(  67), -INT8_C(  36), -INT8_C( 112), -INT8_C( 105),  INT8_C( 101),  INT8_C(  98), -INT8_C(  81),
        -INT8_C(  48), -INT8_C(  29), -INT8_C(  11), -INT8_C(  27), -INT8_C(  96),  INT8_C(  89), -INT8_C(  97), -INT8_C( 121),
         INT8_C(  38),  INT8_C(  94),  INT8_C(  43),  INT8_C(  15), -INT8_C(  11),  INT8_C(  78), -INT8_C(  91),  INT8_C(  38),
         INT8_C(  13), -INT8_C(  22), -INT8_C(  36),  INT8_C(  43),  INT8_C(   3), -INT8_C( 123),  INT8_C(  39), -INT8_C(  95) },
      { -INT8_C(  98), -INT8_C( 126), -INT8_C(  42),  INT8_C(  70), -INT8_C(  14),  INT8_C(  84), -INT8_C( 119),  INT8_C(  17),
        -INT8_C(  87),  INT8_C( 107), -INT8_C( 127),  INT8_C(  56), -INT8_C(  45), -INT8_C(  67),  INT8_C(  95), -INT8_C(  92),
        -INT8_C(  25),  INT8_C(  29),  INT8_C( 105), -INT8_C( 111),  INT8_C(  34), -INT8_C( 109), -INT8_C(  79), -INT8_C( 106),
         INT8_C(   0),  INT8_C(  96),  INT8_C(  38), -INT8_C(  95),  INT8_C(   2), -INT8_C(  21), -INT8_C(  87), -INT8_C(   4),
        -INT8_C(  98), -INT8_C( 127), -INT8_C( 118), -INT8_C( 112), -INT8_C( 105),  INT8_C(  44), -INT8_C(  71),  INT8_C(  55),
        -INT8_C(  48), -INT8_C(  60), -INT8_C(  30), -INT8_C(  81),  INT8_C( 110), -INT8_C(  86), -INT8_C(  97),  INT8_C(  41),
        -INT8_C(  42),  INT8_C(  41), -INT8_C(  70),  INT8_C(   5), -INT8_C( 113),  INT8_C(  27),  INT8_C(  95), -INT8_C( 112),
        -INT8_C(  68), -INT8_C( 123), -INT8_C( 100),  INT8_C(  97),  INT8_C(  93), -INT8_C( 123), -INT8_C(  91), -INT8_C(  95) } },
    { { -INT8_C(  55),  INT8_C(   3),  INT8_C(  50),  INT8_C(  96),  INT8_C( 104), -INT8_C( 108),  INT8_C(  16),  INT8_C(  56),
         INT8_C( 119),  INT8_C(   5),  INT8_C(  30),  INT8_C(  23),  INT8_C(  94), -INT8_C(  67), -INT8_C(  98), -INT8_C( 123),
         INT8_C(  28), -INT8_C(  55), -INT8_C( 108),  INT8_C(  17),  INT8_C(  23),  INT8_C(  57),  INT8_C(  55),  INT8_C(  36),
         INT8_C(  35),  INT8_C(  19),  INT8_C(  79),  INT8_C(  38), -INT8_C( 103),  INT8_C( 119), -INT8_C(  56),  INT8_C(  98),
         INT8_C( 122), -INT8_C(   6), -INT8_C(  62), -INT8_C(  29), -INT8_C( 114), -INT8_C(  46),  INT8_C(  27),  INT8_C(   5),
        -INT8_C(  40),  INT8_C(  57),  INT8_C(  28),  INT8_C(  54), -INT8_C(   9), -INT8_C(  70), -INT8_C(  69),  INT8_C(  19),
        -INT8_C( 125),  INT8_C(  79),  INT8_C(  36), -INT8_C( 102), -INT8_C( 120),  INT8_C(  91), -INT8_C(  66), -INT8_C(  84),
         INT8_C( 110),  INT8_C(  14), -INT8_C(  46),  INT8_C(   7), -INT8_C( 123), -INT8_C( 102),  INT8_C( 105), -INT8_C(   1) },
      UINT64_C(15431583015668690068),
      {  INT8_C(  55),  INT8_C(  67),  INT8_C(  13),  INT8_C(  46), -INT8_C(   3), -INT8_C(  56),  INT8_C(  65),      INT8_MIN,
         INT8_C(  24),  INT8_C( 101),  INT8_C(  26), -INT8_C(  96), -INT8_C(  64), -INT8_C(  39),  INT8_C(  76),  INT8_C(  47),
        -INT8_C(  25),  INT8_C(  31),  INT8_C(  54),  INT8_C( 108), -INT8_C(  71), -INT8_C(  96),  INT8_C( 107),  INT8_C(  78),
        -INT8_C(  52),  INT8_C(  78),  INT8_C( 112), -INT8_C(  54),  INT8_C(  76), -INT8_C( 104), -INT8_C(  95), -INT8_C( 125),
        -INT8_C(  37), -INT8_C(  82), -INT8_C(  78), -INT8_C(  39),  INT8_C( 118), -INT8_C(  13),  INT8_C(  89), -INT8_C( 114),
         INT8_C(  89),  INT8_C( 116),  INT8_C(  47),  INT8_C(  25),  INT8_C(  77),  INT8_C( 123),  INT8_C(  72),  INT8_C(  52),
        -INT8_C( 102),      INT8_MAX, -INT8_C(  96),  INT8_C(  84),  INT8_C(  31),  INT8_C(  11), -INT8_C(  94), -INT8_C(  21),
         INT8_C(  89),  INT8_C(  18), -INT8_C(  75), -INT8_C(  91), -INT8_C(  86),  INT8_C(  86),  INT8_C(  41), -INT8_C( 122) },
      {  INT8_C(   4), -INT8_C(  37),  INT8_C(  95),  INT8_C( 123), -INT8_C(  50), -INT8_C(  72),  INT8_C(   9),  INT8_C(  39),
         INT8_C(  44),  INT8_C(  56),  INT8_C(  65),  INT8_C( 121), -INT8_C(  76), -INT8_C( 119), -INT8_C(  83),  INT8_C(  78),
         INT8_C(   8),  INT8_C(  77), -INT8_C(  94),  INT8_C(  39),  INT8_C(  89),  INT8_C(  68),  INT8_C(  18), -INT8_C(  78),
         INT8_C(  87), -INT8_C(  56),  INT8_C(  88),  INT8_C(   1),  INT8_C(  30), -INT8_C( 127), -INT8_C( 121),  INT8_C(  35),
         INT8_C(  92), -INT8_C(  26), -INT8_C(  98),  INT8_C(  42), -INT8_C(  97), -INT8_C(  89),  INT8_C(  82), -INT8_C(  53),
        -INT8_C(  32), -INT8_C( 109),  INT8_C(  69), -INT8_C( 108),  INT8_C(  28), -INT8_C(  14), -INT8_C(  30),  INT8_C(  37),
         INT8_C(  64), -INT8_C( 123),  INT8_C(  76), -INT8_C( 103), -INT8_C(  55),  INT8_C(  95),  INT8_C(  75),  INT8_C(  32),
         INT8_C(  39), -INT8_C(  93),  INT8_C(  34),  INT8_C(  69),  INT8_C(  36), -INT8_C(  87),  INT8_C( 104),      INT8_MIN },
      { -INT8_C(  55),  INT8_C(   3),  INT8_C(  13),  INT8_C(  96), -INT8_C(  50), -INT8_C( 108),  INT8_C(  16),      INT8_MIN,
         INT8_C( 119),  INT8_C(   5),  INT8_C(  26), -INT8_C(  96),  INT8_C(  94), -INT8_C( 119), -INT8_C(  98), -INT8_C( 123),
         INT8_C(  28),  INT8_C(  31), -INT8_C( 108),  INT8_C(  17),  INT8_C(  23), -INT8_C(  96),  INT8_C(  18), -INT8_C(  78),
         INT8_C(  35), -INT8_C(  56),  INT8_C(  79),  INT8_C(  38), -INT8_C( 103), -INT8_C( 127), -INT8_C(  56),  INT8_C(  98),
         INT8_C( 122), -INT8_C(  82), -INT8_C(  98), -INT8_C(  39), -INT8_C(  97), -INT8_C(  89),  INT8_C(  82), -INT8_C( 114),
        -INT8_C(  40), -INT8_C( 109),  INT8_C(  47), -INT8_C( 108),  INT8_C(  28), -INT8_C(  14), -INT8_C(  30),  INT8_C(  37),
        -INT8_C( 102), -INT8_C( 123), -INT8_C(  96), -INT8_C( 102), -INT8_C( 120),  INT8_C(  11), -INT8_C(  66), -INT8_C(  84),
         INT8_C( 110), -INT8_C(  93), -INT8_C(  75),  INT8_C(   7), -INT8_C(  86), -INT8_C( 102),  INT8_C(  41),      INT8_MIN } },
    { { -INT8_C( 112),  INT8_C(   6), -INT8_C(  85),  INT8_C(  47), -INT8_C(  82), -INT8_C(   3), -INT8_C(   6), -INT8_C( 114),
        -INT8_C( 112),  INT8_C(  63),  INT8_C(  34), -INT8_C(  84),  INT8_C(  50),  INT8_C(   4), -INT8_C(  47),  INT8_C( 114),
        -INT8_C( 119),  INT8_C(  30),  INT8_C(  11),  INT8_C(  83),  INT8_C( 125),  INT8_C(  86),  INT8_C( 115), -INT8_C(  92),
        -INT8_C(   6), -INT8_C( 107), -INT8_C(  23),  INT8_C(  30),  INT8_C(  63),  INT8_C(  82), -INT8_C(  97), -INT8_C(  49),
         INT8_C(  88),  INT8_C(  74), -INT8_C(   2),  INT8_C(   6),  INT8_C(  71), -INT8_C(   8), -INT8_C( 108), -INT8_C(  41),
         INT8_C(  56), -INT8_C(  74), -INT8_C( 125),  INT8_C( 106), -INT8_C(  69),  INT8_C(  85), -INT8_C(  36),  INT8_C(  68),
         INT8_C( 115), -INT8_C(  25), -INT8_C( 105), -INT8_C(  16),  INT8_C(  61),  INT8_C(  11), -INT8_C( 108),  INT8_C(  55),
        -INT8_C(  96),  INT8_C( 125),  INT8_C(  86), -INT8_C(  33), -INT8_C(  49), -INT8_C(  11), -INT8_C(  82),  INT8_C(  40) },
      UINT64_C(15951120570904390719),
      {  INT8_C( 121), -INT8_C(  32),  INT8_C(  71),  INT8_C(  52),  INT8_C(  53),  INT8_C(  35),  INT8_C( 121), -INT8_C(  88),
         INT8_C(  10),  INT8_C(  16), -INT8_C( 104),  INT8_C(  71),  INT8_C(  27),  INT8_C(  44),      INT8_MAX, -INT8_C(  68),
        -INT8_C(  86), -INT8_C(  43), -INT8_C( 101),  INT8_C( 121), -INT8_C(  54),  INT8_C(  74), -INT8_C(  95),  INT8_C(   9),
        -INT8_C(  10), -INT8_C(  48), -INT8_C( 113), -INT8_C( 101), -INT8_C( 109), -INT8_C(  20),  INT8_C( 120),  INT8_C(  12),
        -INT8_C(  52), -INT8_C(  65),  INT8_C(  65),  INT8_C(   2), -INT8_C(  30), -INT8_C(  70), -INT8_C(  86), -INT8_C(  20),
        -INT8_C(  54),  INT8_C(  67),  INT8_C(  52), -INT8_C(  26),  INT8_C( 111), -INT8_C(  77), -INT8_C(  94),  INT8_C(  25),
        -INT8_C( 120),  INT8_C(  61), -INT8_C( 109),  INT8_C(  82), -INT8_C( 121),  INT8_C(  52),  INT8_C(  91),  INT8_C( 126),
         INT8_C(   4), -INT8_C(  22),  INT8_C(  25), -INT8_C( 105), -INT8_C(  42), -INT8_C( 110), -INT8_C(  92), -INT8_C(  94) },
      {  INT8_C(  81), -INT8_C(  27), -INT8_C(  92),  INT8_C(  52), -INT8_C(  97),  INT8_C(  79),  INT8_C(  32),  INT8_C( 105),
        -INT8_C( 110),  INT8_C(  84),  INT8_C(  79),  INT8_C(   1),  INT8_C(   7), -INT8_C(  15),  INT8_C(  27), -INT8_C( 113),
         INT8_C(  47), -INT8_C(  82), -INT8_C(  31), -INT8_C(  74), -INT8_C(  30),  INT8_C(  60),  INT8_C(  52), -INT8_C(  25),
         INT8_C(  38),  INT8_C(  78),  INT8_C( 126), -INT8_C(   4), -INT8_C(  32),  INT8_C(  34), -INT8_C(  97),  INT8_C(  49),
         INT8_C(   7),  INT8_C(  67),  INT8_C( 101), -INT8_C(  90), -INT8_C( 110), -INT8_C( 122),  INT8_C(  16),  INT8_C(  36),
        -INT8_C(  38),  INT8_C(  95),  INT8_C(  38), -INT8_C(  30),  INT8_C(  81),  INT8_C(  65),  INT8_C( 113),      INT8_MIN,
        -INT8_C(  17),  INT8_C(  83),  INT8_C(  54), -INT8_C(  47), -INT8_C( 113),  INT8_C( 107), -INT8_C(  72), -INT8_C(  74),
        -INT8_C(  71),  INT8_C(  55), -INT8_C(  78), -INT8_C( 103),  INT8_C(  89),  INT8_C(  81), -INT8_C(  54),  INT8_C(  97) },
      {  INT8_C(  81), -INT8_C(  32), -INT8_C(  92),  INT8_C(  52), -INT8_C(  97),  INT8_C(  35), -INT8_C(   6), -INT8_C( 114),
        -INT8_C( 112),  INT8_C(  63), -INT8_C( 104),  INT8_C(   1),  INT8_C(  50), -INT8_C(  15), -INT8_C(  47), -INT8_C( 113),
        -INT8_C( 119), -INT8_C(  82), -INT8_C( 101), -INT8_C(  74),  INT8_C( 125),  INT8_C(  60),  INT8_C( 115), -INT8_C(  92),
        -INT8_C(   6), -INT8_C(  48), -INT8_C( 113),  INT8_C(  30),  INT8_C(  63),  INT8_C(  82), -INT8_C(  97),  INT8_C(  12),
        -INT8_C(  52),  INT8_C(  74),  INT8_C(  65),  INT8_C(   6),  INT8_C(  71), -INT8_C( 122), -INT8_C( 108), -INT8_C(  20),
        -INT8_C(  54),  INT8_C(  67), -INT8_C( 125),  INT8_C( 106), -INT8_C(  69),  INT8_C(  85), -INT8_C(  94),      INT8_MIN,
        -INT8_C( 120), -INT8_C(  25), -INT8_C( 109), -INT8_C(  47), -INT8_C( 121),  INT8_C(  11), -INT8_C(  72),  INT8_C(  55),
        -INT8_C(  71),  INT8_C( 125), -INT8_C(  78), -INT8_C( 105), -INT8_C(  42), -INT8_C(  11), -INT8_C(  92), -INT8_C(  94) } },
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
    simde__m512i src = simde_mm512_loadu_epi8(test_vec[i].src);
    simde__m512i a = simde_mm512_loadu_epi8(test_vec[i].a);
    simde__m512i b = simde_mm512_loadu_epi8(test_vec[i].b);
    simde__m512i r = simde_mm512_mask_min_epi8(src, test_vec[i].k, a, b);
    simde_test_x86_assert_equal_i8x64(r, simde_mm512_loadu_epi8(test_vec[i].r));
  }

  return 0;
}

static int
test_simde_mm512_maskz_min_epi8 (SIMDE_MUNIT_TEST_ARGS) {
  static const struct {
    const simde__mmask64 k;
    const int8_t a[64];
    const int8_t b[64];
    const int8_t r[64];
  } test_vec[] = {
    { UINT64_C(14163406931381216590),
      {  INT8_C( 107),  INT8_C( 119), -INT8_C(  72),  INT8_C(  51), -INT8_C(  83), -INT8_C(  51),  INT8_C( 101),  INT8_C(  96),
        -INT8_C(  35),  INT8_C(  42), -INT8_C( 114), -INT8_C(  41), -INT8_C(  96), -INT8_C(  15), -INT8_C(   3),  INT8_C( 112),
        -INT8_C(   7),  INT8_C(  37),  INT8_C(  15), -INT8_C( 120), -INT8_C(  21),  INT8_C( 107),  INT8_C(  77),  INT8_C(  58),
        -INT8_C(  48), -INT8_C( 107),  INT8_C( 100),  INT8_C(  97),  INT8_C(  29), -INT8_C(  14),  INT8_C(  37), -INT8_C( 120),
         INT8_C( 105), -INT8_C(  35), -INT8_C(  68),  INT8_C(  22), -INT8_C(  86),  INT8_C(  33),  INT8_C( 118), -INT8_C( 121),
         INT8_C(  75),  INT8_C(   4),  INT8_C(  94), -INT8_C(  21), -INT8_C(  10),  INT8_C(  91),  INT8_C(  91), -INT8_C(  17),
             INT8_MIN,  INT8_C( 106),  INT8_C( 119),  INT8_C( 108), -INT8_C(  42), -INT8_C(  60), -INT8_C(  90), -INT8_C(  90),
         INT8_C(  90),  INT8_C(  10),  INT8_C(   7),  INT8_C( 119), -INT8_C(   3),  INT8_C(  44), -INT8_C(   1),  INT8_C( 102) },
      {  INT8_C(   9), -INT8_C(  69),  INT8_C( 125), -INT8_C(  77), -INT8_C(  36), -INT8_C(  13),  INT8_C(  59),  INT8_C(  39),
        -INT8_C(   8), -INT8_C( 103),  INT8_C(  19), -INT8_C(  18), -INT8_C(  11),  INT8_C( 110), -INT8_C(  35),  INT8_C( 117),
        -INT8_C(  39),  INT8_C(  85), -INT8_C(  31), -INT8_C(  81),  INT8_C(  25), -INT8_C( 121),  INT8_C(  85),  INT8_C( 115),
        -INT8_C( 110),  INT8_C(  93), -INT8_C(  22), -INT8_C( 113), -INT8_C( 119), -INT8_C(  22), -INT8_C(  11), -INT8_C( 109),
        -INT8_C(  91),  INT8_C( 114),  INT8_C(  70), -INT8_C( 126),  INT8_C( 102), -INT8_C( 127), -INT8_C(  87),  INT8_C(  94),
         INT8_C(  27), -INT8_C(  68),  INT8_C(  76),  INT8_C(  16),  INT8_C(  43),  INT8_C(  41), -INT8_C( 123),  INT8_C(   4),
         INT8_C( 126),  INT8_C( 103), -INT8_C(  77), -INT8_C( 104), -INT8_C(  18),  INT8_C(   8),  INT8_C(  11),      INT8_MIN,
         INT8_C( 101), -INT8_C(  10),  INT8_C(  15), -INT8_C(  17), -INT8_C(  32),  INT8_C(   5), -INT8_C( 126), -INT8_C( 123) },
      {  INT8_C(   0), -INT8_C(  69), -INT8_C(  72), -INT8_C(  77),  INT8_C(   0),  INT8_C(   0),  INT8_C(  59),  INT8_C(   0),
        -INT8_C(  35),  INT8_C(   0), -INT8_C( 114),  INT8_C(   0),  INT8_C(   0), -INT8_C(  15), -INT8_C(  35),  INT8_C(   0),
         INT8_C(   0),  INT8_C(   0),  INT8_C(   0), -INT8_C( 120),  INT8_C(   0),  INT8_C(   0),  INT8_C(  77),  INT8_C(   0),
         INT8_C(   0), -INT8_C( 107),  INT8_C(   0), -INT8_C( 113),  INT8_C(   0), -INT8_C(  22),  INT8_C(   0),  INT8_C(   0),
         INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0), -INT8_C(  86),  INT8_C(   0),  INT8_C(   0), -INT8_C( 121),
         INT8_C(  27), -INT8_C(  68),  INT8_C(  76),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0), -INT8_C(  17),
         INT8_C(   0),  INT8_C( 103), -INT8_C(  77), -INT8_C( 104),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),      INT8_MIN,
         INT8_C(   0),  INT8_C(   0),  INT8_C(   7),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0), -INT8_C( 126), -INT8_C( 123) } },
    { UINT64_C( 7294618956550621303),
      {  INT8_C( 109), -INT8_C( 121),  INT8_C( 117), -INT8_C( 104), -INT8_C(  79), -INT8_C(   6), -INT8_C( 100),  INT8_C(  47),
         INT8_C(  97),  INT8_C(  79), -INT8_C(  57),  INT8_C(  80),  INT8_C(  88), -INT8_C(  45), -INT8_C(  48), -INT8_C(  67),
        -INT8_C(  55), -INT8_C(  32), -INT8_C(  84), -INT8_C(  87), -INT8_C(  27),  INT8_C(  46),  INT8_C(  46),  INT8_C(  92),
        -INT8_C(   9),  INT8_C(  54),  INT8_C(  58),  INT8_C(  65), -INT8_C(  25),  INT8_C( 117), -INT8_C(  90),  INT8_C(  84),
        -INT8_C(   3),  INT8_C(  27), -INT8_C(  19), -INT8_C(  82),  INT8_C(  21), -INT8_C( 119), -INT8_C(  35),  INT8_C( 119),
        -INT8_C(  39), -INT8_C(  91), -INT8_C(  57),  INT8_C(  49),  INT8_C( 120), -INT8_C( 105), -INT8_C(  18),  INT8_C(  65),
         INT8_C( 119), -INT8_C( 101), -INT8_C(  22),  INT8_C(  92), -INT8_C(  55),  INT8_C(  24), -INT8_C(  71), -INT8_C(  64),
         INT8_C(  78), -INT8_C(  13),  INT8_C(   1),  INT8_C(  53),  INT8_C( 104), -INT8_C(  89), -INT8_C( 118),  INT8_C( 101) },
      { -INT8_C(  62),  INT8_C( 119),  INT8_C(  19), -INT8_C(  40),  INT8_C(   0), -INT8_C(  15),  INT8_C(  79), -INT8_C(  39),
        -INT8_C( 106),  INT8_C(  22),  INT8_C(  10),  INT8_C(  14), -INT8_C(  83), -INT8_C(   7),  INT8_C(  79),  INT8_C(  37),
        -INT8_C( 108),  INT8_C(  57), -INT8_C( 127),  INT8_C(  93),  INT8_C(  81),  INT8_C(  58),  INT8_C(  30), -INT8_C(  96),
         INT8_C(  45),  INT8_C(  31), -INT8_C(  43), -INT8_C( 106), -INT8_C(  57),  INT8_C(  95), -INT8_C(   5), -INT8_C( 119),
        -INT8_C(  42),  INT8_C(  15),  INT8_C(  97), -INT8_C(  41),  INT8_C(   0), -INT8_C(  80), -INT8_C(  80), -INT8_C( 106),
        -INT8_C(  58), -INT8_C(  69), -INT8_C(  92),  INT8_C( 116), -INT8_C(  76), -INT8_C(  13), -INT8_C( 103),  INT8_C(  72),
         INT8_C(  44),  INT8_C(  26), -INT8_C(  91),  INT8_C( 125),  INT8_C(  85), -INT8_C(  61),  INT8_C(  29), -INT8_C( 126),
        -INT8_C(  29), -INT8_C(  13),  INT8_C(  24), -INT8_C(  86),  INT8_C(  82),  INT8_C(  20),  INT8_C(  51),  INT8_C(  41) },
      { -INT8_C(  62), -INT8_C( 121),  INT8_C(  19),  INT8_C(   0), -INT8_C(  79), -INT8_C(  15), -INT8_C( 100),  INT8_C(   0),
         INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(  14),  INT8_C(   0),  INT8_C(   0), -INT8_C(  48), -INT8_C(  67),
        -INT8_C( 108), -INT8_C(  32), -INT8_C( 127),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),
        -INT8_C(   9),  INT8_C(   0), -INT8_C(  43), -INT8_C( 106), -INT8_C(  57),  INT8_C(   0), -INT8_C(  90), -INT8_C( 119),
         INT8_C(   0),  INT8_C(  15),  INT8_C(   0), -INT8_C(  82),  INT8_C(   0),  INT8_C(   0), -INT8_C(  80),  INT8_C(   0),
        -INT8_C(  58),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0), -INT8_C(  76), -INT8_C( 105),  INT8_C(   0),  INT8_C(  65),
         INT8_C(  44), -INT8_C( 101),  INT8_C(   0),  INT8_C(  92), -INT8_C(  55), -INT8_C(  61),  INT8_C(   0),  INT8_C(   0),
        -INT8_C(  29),  INT8_C(   0),  INT8_C(   1),  INT8_C(   0),  INT8_C(   0), -INT8_C(  89), -INT8_C( 118),  INT8_C(   0) } },
    { UINT64_C(  916957810133079331),
      {  INT8_C( 107),  INT8_C(  93),      INT8_MIN,  INT8_C(  31),  INT8_C(  80),  INT8_C(  25),  INT8_C( 103),  INT8_C( 124),
         INT8_C(  51),  INT8_C(  13), -INT8_C(   7), -INT8_C( 120), -INT8_C(  48),  INT8_C(  23),  INT8_C(  11), -INT8_C(  77),
         INT8_C(  10),  INT8_C(  35),  INT8_C(  93),  INT8_C(  92),  INT8_C(  55), -INT8_C( 111), -INT8_C( 123),  INT8_C(  90),
         INT8_C(  38), -INT8_C( 123),  INT8_C( 125),  INT8_C( 107),  INT8_C(  54),  INT8_C(  54),  INT8_C( 119), -INT8_C(  95),
        -INT8_C( 109), -INT8_C(   9), -INT8_C(  63), -INT8_C(  29),  INT8_C(  16),  INT8_C(  40),  INT8_C(  95),  INT8_C(  68),
         INT8_C(  53),  INT8_C(  89), -INT8_C(  52),  INT8_C(   6),  INT8_C( 112), -INT8_C(  41), -INT8_C(  71),  INT8_C( 122),
        -INT8_C(   5),  INT8_C(  23), -INT8_C(  42),  INT8_C(  50), -INT8_C(  88),  INT8_C(  92), -INT8_C( 115), -INT8_C(  50),
        -INT8_C(  31),  INT8_C(  10),  INT8_C(  57),  INT8_C(  23),  INT8_C(  65), -INT8_C(  79), -INT8_C(  71), -INT8_C(  44) },
      { -INT8_C(  88),  INT8_C( 122), -INT8_C(  72), -INT8_C(  71), -INT8_C(  94),  INT8_C(  23), -INT8_C(   3), -INT8_C(  40),
         INT8_C( 112), -INT8_C(  55), -INT8_C(  34), -INT8_C(  32), -INT8_C(  95), -INT8_C( 105),  INT8_C(  90), -INT8_C( 100),
        -INT8_C(  82),  INT8_C(  49), -INT8_C(  50),  INT8_C(  86), -INT8_C( 115),  INT8_C(  91),  INT8_C(  36),  INT8_C( 110),
         INT8_C( 102),  INT8_C(  94), -INT8_C( 122), -INT8_C(  89),  INT8_C(  15),  INT8_C(  63),  INT8_C( 123), -INT8_C(  73),
        -INT8_C(  71),  INT8_C(  51),  INT8_C( 112),  INT8_C(  91),  INT8_C(  75),  INT8_C( 109),  INT8_C(  51), -INT8_C(  69),
         INT8_C(  55),  INT8_C(  17), -INT8_C( 100), -INT8_C(  40), -INT8_C(  87), -INT8_C(  10),  INT8_C( 116),  INT8_C(  87),
         INT8_C(  39),  INT8_C(  66), -INT8_C(  82), -INT8_C(  76), -INT8_C(  98), -INT8_C(  46),  INT8_C(  35),  INT8_C(   4),
         INT8_C(  48), -INT8_C(  87), -INT8_C(  85),  INT8_C(  63), -INT8_C(  24),  INT8_C(  38), -INT8_C(   9), -INT8_C(  95) },
      { -INT8_C(  88),  INT8_C(  93),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(  23),  INT8_C(   0),  INT8_C(   0),
         INT8_C(  51),  INT8_C(   0), -INT8_C(  34),  INT8_C(   0), -INT8_C(  95),  INT8_C(   0),  INT8_C(   0), -INT8_C( 100),
         INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),
         INT8_C(  38), -INT8_C( 123),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(  54),  INT8_C(   0),  INT8_C(   0),
        -INT8_C( 109),  INT8_C(   0), -INT8_C(  63),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(  51),  INT8_C(   0),
         INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0), -INT8_C(  87), -INT8_C(  41),  INT8_C(   0),  INT8_C(  87),
        -INT8_C(   5),  INT8_C(   0),  INT8_C(   0), -INT8_C(  76), -INT8_C(  98), -INT8_C(  46),  INT8_C(   0), -INT8_C(  50),
         INT8_C(   0),  INT8_C(   0), -INT8_C(  85),  INT8_C(  23),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0) } },
    { UINT64_C(  891766420390307674),
      {  INT8_C(  65), -INT8_C(   4), -INT8_C(  28), -INT8_C(  22), -INT8_C(  13),  INT8_C(  88),  INT8_C(  66),  INT8_C(  26),
        -INT8_C( 102), -INT8_C(  16), -INT8_C(  49),  INT8_C(  56), -INT8_C(  62), -INT8_C(  14),  INT8_C(  60), -INT8_C(  13),
        -INT8_C( 101), -INT8_C(  25),  INT8_C(  50), -INT8_C( 125),  INT8_C(  14),  INT8_C(  41),  INT8_C(  36),  INT8_C( 104),
        -INT8_C( 111),  INT8_C(  32),  INT8_C(  13),  INT8_C( 102),  INT8_C(  80),  INT8_C( 109),  INT8_C( 114), -INT8_C( 110),
         INT8_C( 106),  INT8_C(  86),  INT8_C( 124),  INT8_C(  93), -INT8_C(  82), -INT8_C(  66),  INT8_C( 119),  INT8_C(  72),
        -INT8_C(  82),  INT8_C(  70), -INT8_C( 127),  INT8_C( 113),  INT8_C(  56), -INT8_C(  67),  INT8_C( 100), -INT8_C(  45),
        -INT8_C(  91), -INT8_C( 106),  INT8_C(  86), -INT8_C(  77), -INT8_C(  64),  INT8_C( 122),  INT8_C(  27),  INT8_C(  81),
        -INT8_C( 101),  INT8_C(  40), -INT8_C(  73), -INT8_C(  21), -INT8_C( 107),  INT8_C(  41),  INT8_C( 125), -INT8_C(   1) },
      {      INT8_MAX, -INT8_C(   6),  INT8_C(  92),  INT8_C(  45), -INT8_C(  72), -INT8_C(  44),  INT8_C( 117),  INT8_C( 103),
         INT8_C(  26), -INT8_C(  10), -INT8_C(  40),  INT8_C(  83), -INT8_C(  76),  INT8_C(  60),  INT8_C(  38),  INT8_C(  89),
        -INT8_C(  46),  INT8_C( 125),  INT8_C(  12), -INT8_C( 110), -INT8_C(   9),  INT8_C(  39), -INT8_C(  29), -INT8_C( 110),
         INT8_C(  79), -INT8_C( 102),  INT8_C( 126), -INT8_C(  28), -INT8_C(  61), -INT8_C(   5), -INT8_C(  28),  INT8_C(  66),
        -INT8_C(  11),  INT8_C(  64),  INT8_C( 111), -INT8_C(  82),  INT8_C(  20), -INT8_C(  27),  INT8_C(  21),  INT8_C(  47),
        -INT8_C(  37), -INT8_C(  19), -INT8_C( 126), -INT8_C( 113),  INT8_C(  41), -INT8_C(  88), -INT8_C(  24), -INT8_C(   5),
         INT8_C(  37), -INT8_C(  12), -INT8_C( 114),  INT8_C(  29),  INT8_C(  27),  INT8_C( 113), -INT8_C(  81),  INT8_C( 106),
         INT8_C(  12),  INT8_C(  45),  INT8_C(  79), -INT8_C(  49),  INT8_C(  41),  INT8_C(  51),  INT8_C(  18),  INT8_C(  30) },
      {  INT8_C(   0), -INT8_C(   6),  INT8_C(   0), -INT8_C(  22), -INT8_C(  72),  INT8_C(   0),  INT8_C(  66),  INT8_C(   0),
        -INT8_C( 102), -INT8_C(  16), -INT8_C(  49),  INT8_C(   0),  INT8_C(   0), -INT8_C(  14),  INT8_C(  38),  INT8_C(   0),
         INT8_C(   0),  INT8_C(   0),  INT8_C(  12), -INT8_C( 125), -INT8_C(   9),  INT8_C(  39), -INT8_C(  29), -INT8_C( 110),
        -INT8_C( 111),  INT8_C(   0),  INT8_C(  13),  INT8_C(   0),  INT8_C(   0), -INT8_C(   5),  INT8_C(   0), -INT8_C( 110),
        -INT8_C(  11),  INT8_C(   0),  INT8_C( 111),  INT8_C(   0), -INT8_C(  82),  INT8_C(   0),  INT8_C(  21),  INT8_C(  47),
         INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(  41), -INT8_C(  88),  INT8_C(   0),  INT8_C(   0),
         INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C( 113), -INT8_C(  81),  INT8_C(   0),
         INT8_C(   0),  INT8_C(   0), -INT8_C(  73), -INT8_C(  49),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0) } },
    { UINT64_C( 4807558957739311475),
      { -INT8_C(  50),  INT8_C(  57), -INT8_C(  47), -INT8_C(   9), -INT8_C(  31), -INT8_C(  70), -INT8_C(  13),  INT8_C(   7),
        -INT8_C(  82), -INT8_C( 127),  INT8_C(  36), -INT8_C(  54), -INT8_C(  14), -INT8_C(  45),  INT8_C(  52), -INT8_C(   2),
         INT8_C(   1), -INT8_C( 125), -INT8_C(  50),  INT8_C(  42), -INT8_C(  74), -INT8_C(  32),  INT8_C(  72),  INT8_C(  42),
         INT8_C(  97),  INT8_C(  21), -INT8_C(  78), -INT8_C(  56), -INT8_C(  10),  INT8_C( 105),  INT8_C(  10), -INT8_C(  59),
        -INT8_C(  94), -INT8_C(  37), -INT8_C(  68), -INT8_C( 125), -INT8_C( 107), -INT8_C(  81), -INT8_C( 118),  INT8_C(  68),
         INT8_C(  48), -INT8_C(  82),  INT8_C(  14),  INT8_C(  35), -INT8_C( 126),  INT8_C(  66),  INT8_C(  33), -INT8_C( 125),
        -INT8_C(  58), -INT8_C(  17), -INT8_C(  83),  INT8_C( 124), -INT8_C(  49), -INT8_C(  11), -INT8_C(  90),  INT8_C(  49),
         INT8_C(  10),  INT8_C(  88), -INT8_C(   7),  INT8_C(   1), -INT8_C(  63),  INT8_C(   3), -INT8_C(  58),  INT8_C(  99) },
      { -INT8_C(  34), -INT8_C( 126), -INT8_C(  25),  INT8_C( 116),  INT8_C(  50),  INT8_C( 113), -INT8_C(  72),  INT8_C(  98),
         INT8_C(  32), -INT8_C(  58), -INT8_C( 123), -INT8_C(  94),  INT8_C(   8), -INT8_C(  89),  INT8_C(  37), -INT8_C(  50),
        -INT8_C( 106), -INT8_C(  46),  INT8_C(  75),  INT8_C( 102), -INT8_C(  57), -INT8_C(  15), -INT8_C( 105), -INT8_C(  46),
         INT8_C(  74), -INT8_C( 112), -INT8_C(  45),  INT8_C(  11), -INT8_C( 109), -INT8_C( 103),  INT8_C( 111),  INT8_C( 113),
         INT8_C(  27),  INT8_C(  86), -INT8_C(  27),  INT8_C(  77), -INT8_C(  57), -INT8_C(  99), -INT8_C(  80), -INT8_C(  25),
         INT8_C(  99),  INT8_C(  53), -INT8_C( 119),  INT8_C( 108), -INT8_C(  36), -INT8_C(  82),  INT8_C(  58),  INT8_C( 115),
             INT8_MIN, -INT8_C( 123), -INT8_C(  39),  INT8_C(  72),  INT8_C( 119),  INT8_C( 112),  INT8_C(  26), -INT8_C(  63),
         INT8_C(   0), -INT8_C(  19), -INT8_C(  52), -INT8_C( 109), -INT8_C( 122),  INT8_C(  59),  INT8_C(   4), -INT8_C(  95) },
      { -INT8_C(  50), -INT8_C( 126),  INT8_C(   0),  INT8_C(   0), -INT8_C(  31), -INT8_C(  70), -INT8_C(  72),  INT8_C(   0),
        -INT8_C(  82),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0), -INT8_C(  50),
         INT8_C(   0),  INT8_C(   0), -INT8_C(  50),  INT8_C(  42),  INT8_C(   0),  INT8_C(   0), -INT8_C( 105), -INT8_C(  46),
         INT8_C(   0),  INT8_C(   0),  INT8_C(   0), -INT8_C(  56),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0), -INT8_C(  59),
         INT8_C(   0), -INT8_C(  37), -INT8_C(  68),  INT8_C(   0),  INT8_C(   0), -INT8_C(  99), -INT8_C( 118),  INT8_C(   0),
         INT8_C(  48),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0), -INT8_C(  82),  INT8_C(  33), -INT8_C( 125),
             INT8_MIN, -INT8_C( 123), -INT8_C(  83),  INT8_C(   0), -INT8_C(  49), -INT8_C(  11),  INT8_C(   0), -INT8_C(  63),
         INT8_C(   0), -INT8_C(  19),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0), -INT8_C(  58),  INT8_C(   0) } },
    { UINT64_C(16951724401100843665),
      { -INT8_C(  44), -INT8_C(  54),  INT8_C(  87), -INT8_C(  79),  INT8_C( 120), -INT8_C( 111),  INT8_C(  36), -INT8_C(   7),
         INT8_C(  23), -INT8_C(   3),  INT8_C(  65), -INT8_C( 114),  INT8_C( 109),  INT8_C(  91),  INT8_C(  79),  INT8_C( 109),
         INT8_C(  72),  INT8_C(  27),  INT8_C(   0), -INT8_C(  50),  INT8_C(  87),  INT8_C(   4),  INT8_C( 111), -INT8_C(  24),
        -INT8_C(  18),  INT8_C(  94),  INT8_C(  65),  INT8_C( 118), -INT8_C(   3), -INT8_C( 126),  INT8_C(  97), -INT8_C(  46),
         INT8_C(  76), -INT8_C(  72), -INT8_C( 125), -INT8_C(  60),  INT8_C(  73), -INT8_C(  89), -INT8_C(  67),  INT8_C(  96),
        -INT8_C(  92), -INT8_C(   2), -INT8_C(  18),  INT8_C(  17),  INT8_C(  89),  INT8_C(  61),  INT8_C( 126), -INT8_C(  95),
         INT8_C(  89),  INT8_C( 126),  INT8_C( 111), -INT8_C(  80), -INT8_C( 126), -INT8_C(  33), -INT8_C( 104),  INT8_C( 113),
         INT8_C(  61), -INT8_C(  38), -INT8_C(  25),  INT8_C(  59),  INT8_C(  92),  INT8_C(  72),  INT8_C(  13), -INT8_C(  88) },
      {  INT8_C(   0), -INT8_C( 112),  INT8_C( 108),  INT8_C(  73),  INT8_C(  55),  INT8_C(  42), -INT8_C(  86), -INT8_C(  37),
         INT8_C(  40), -INT8_C( 104), -INT8_C(  20), -INT8_C( 126), -INT8_C(  42),  INT8_C( 106),  INT8_C(  35),  INT8_C(  47),
        -INT8_C(  24), -INT8_C( 109), -INT8_C(  33),  INT8_C( 106),  INT8_C( 114),  INT8_C( 119), -INT8_C(  37), -INT8_C(  81),
         INT8_C(  81), -INT8_C(  62), -INT8_C(  22), -INT8_C(  83),  INT8_C(  10), -INT8_C(   9),  INT8_C(  85),  INT8_C(  10),
        -INT8_C( 121), -INT8_C(  62),  INT8_C(  84), -INT8_C(  66), -INT8_C(  20), -INT8_C(   2), -INT8_C( 103),  INT8_C(  20),
        -INT8_C( 106), -INT8_C( 123), -INT8_C( 106),  INT8_C( 108), -INT8_C(  17), -INT8_C(  70), -INT8_C( 101), -INT8_C(  41),
         INT8_C(  77),  INT8_C( 122),  INT8_C(  66), -INT8_C(  65), -INT8_C(  14),  INT8_C(  29),  INT8_C( 110),  INT8_C(  67),
        -INT8_C(  32),  INT8_C(  89), -INT8_C(  15), -INT8_C(  22),  INT8_C(  80),  INT8_C(  70), -INT8_C(  11), -INT8_C(  40) },
      { -INT8_C(  44),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(  55),  INT8_C(   0),  INT8_C(   0), -INT8_C(  37),
         INT8_C(   0), -INT8_C( 104),  INT8_C(   0), -INT8_C( 126),  INT8_C(   0),  INT8_C(  91),  INT8_C(  35),  INT8_C(  47),
        -INT8_C(  24), -INT8_C( 109), -INT8_C(  33), -INT8_C(  50),  INT8_C(   0),  INT8_C(   4), -INT8_C(  37), -INT8_C(  81),
        -INT8_C(  18),  INT8_C(   0),  INT8_C(   0), -INT8_C(  83), -INT8_C(   3),  INT8_C(   0),  INT8_C(  85),  INT8_C(   0),
        -INT8_C( 121), -INT8_C(  72), -INT8_C( 125),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(  20),
        -INT8_C( 106), -INT8_C( 123), -INT8_C( 106),  INT8_C(  17), -INT8_C(  17),  INT8_C(   0),  INT8_C(   0), -INT8_C(  95),
         INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0), -INT8_C( 104),  INT8_C(   0),
        -INT8_C(  32), -INT8_C(  38),  INT8_C(   0), -INT8_C(  22),  INT8_C(   0),  INT8_C(  70), -INT8_C(  11), -INT8_C(  88) } },
    { UINT64_C(15927314642776770824),
      { -INT8_C(  75), -INT8_C(  97),  INT8_C(  74), -INT8_C(  91),  INT8_C(  89), -INT8_C(  27),  INT8_C( 124), -INT8_C(  90),
         INT8_C(  96), -INT8_C(  66),  INT8_C( 101),  INT8_C(  82), -INT8_C(  36), -INT8_C(  44), -INT8_C( 107), -INT8_C(  68),
         INT8_C(  45), -INT8_C( 122), -INT8_C(  90),  INT8_C( 125), -INT8_C(  51), -INT8_C( 101),  INT8_C(  85), -INT8_C(  43),
        -INT8_C(  28), -INT8_C(  20), -INT8_C(  54),  INT8_C(  43),  INT8_C(  28), -INT8_C(  45),  INT8_C(   9), -INT8_C(  47),
         INT8_C( 114),  INT8_C(  83),  INT8_C( 118), -INT8_C(  52),  INT8_C(  56), -INT8_C(  13),  INT8_C( 114), -INT8_C( 104),
        -INT8_C(  79), -INT8_C(  40), -INT8_C(  22), -INT8_C( 115), -INT8_C(  84),      INT8_MIN,  INT8_C(  73), -INT8_C(  39),
         INT8_C(   6), -INT8_C(  16),  INT8_C(  86), -INT8_C(  45), -INT8_C( 117), -INT8_C(  84), -INT8_C(  87),  INT8_C( 112),
        -INT8_C( 104),  INT8_C( 115), -INT8_C( 101), -INT8_C(  76),  INT8_C(  70), -INT8_C(  92), -INT8_C( 123), -INT8_C(  72) },
      { -INT8_C(   9), -INT8_C(   4), -INT8_C( 124),  INT8_C(  48), -INT8_C(  17), -INT8_C(   9), -INT8_C(  56), -INT8_C(  96),
        -INT8_C(  49), -INT8_C(  77),  INT8_C(  46),  INT8_C( 123),  INT8_C(  51),  INT8_C( 119),  INT8_C(  84),  INT8_C(  57),
         INT8_C( 103), -INT8_C(  86),  INT8_C(  13), -INT8_C(  13),  INT8_C(  86), -INT8_C(  74),  INT8_C(  99), -INT8_C(  18),
         INT8_C(  41), -INT8_C(   2), -INT8_C(  94),  INT8_C( 111), -INT8_C(  93),  INT8_C(  40),  INT8_C(  39), -INT8_C( 102),
         INT8_C(  36), -INT8_C(  84), -INT8_C(  54),  INT8_C(  19), -INT8_C(  93), -INT8_C( 109), -INT8_C(  77),  INT8_C( 114),
         INT8_C(  70), -INT8_C(  31), -INT8_C(  19),  INT8_C( 121),  INT8_C(  89),  INT8_C(  65), -INT8_C(  78), -INT8_C(  64),
        -INT8_C(  21), -INT8_C(  65), -INT8_C(  77),  INT8_C(  66),  INT8_C( 117),  INT8_C(  22),  INT8_C(  48), -INT8_C(  98),
         INT8_C(  21), -INT8_C(  45),  INT8_C(  13), -INT8_C(  72), -INT8_C(   5),  INT8_C(  53),  INT8_C(  82),  INT8_C(  31) },
      {  INT8_C(   0),  INT8_C(   0),  INT8_C(   0), -INT8_C(  91),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),
        -INT8_C(  49),  INT8_C(   0),  INT8_C(   0),  INT8_C(  82),  INT8_C(   0),  INT8_C(   0), -INT8_C( 107),  INT8_C(   0),
         INT8_C(   0), -INT8_C( 122), -INT8_C(  90),  INT8_C(   0), -INT8_C(  51),  INT8_C(   0),  INT8_C(   0), -INT8_C(  43),
         INT8_C(   0),  INT8_C(   0), -INT8_C(  94),  INT8_C(   0), -INT8_C(  93), -INT8_C(  45),  INT8_C(   9), -INT8_C( 102),
         INT8_C(  36), -INT8_C(  84), -INT8_C(  54),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0), -INT8_C(  77),  INT8_C(   0),
         INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0), -INT8_C(  84),      INT8_MIN,  INT8_C(   0),  INT8_C(   0),
        -INT8_C(  21),  INT8_C(   0),  INT8_C(   0), -INT8_C(  45),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),
        -INT8_C( 104),  INT8_C(   0), -INT8_C( 101), -INT8_C(  76), -INT8_C(   5),  INT8_C(   0), -INT8_C( 123), -INT8_C(  72) } },
    { UINT64_C(17795663523895975393),
      { -INT8_C(  57), -INT8_C(  29),  INT8_C( 111),  INT8_C(  32),  INT8_C(  36),  INT8_C(  33), -INT8_C(  32),  INT8_C(  15),
        -INT8_C(  31), -INT8_C( 108),  INT8_C(  81),  INT8_C(  86), -INT8_C(  86), -INT8_C( 126), -INT8_C(  11), -INT8_C(  65),
         INT8_C(  85),  INT8_C(   2),  INT8_C( 119),  INT8_C(  80),  INT8_C(  55), -INT8_C(  54),  INT8_C( 111),  INT8_C(  24),
        -INT8_C(  25), -INT8_C(  95), -INT8_C( 100), -INT8_C( 105), -INT8_C( 122), -INT8_C( 110), -INT8_C( 115),  INT8_C(  77),
         INT8_C( 117), -INT8_C(   4),  INT8_C( 109), -INT8_C( 103),  INT8_C(  29),  INT8_C(  78), -INT8_C(  87), -INT8_C(   2),
        -INT8_C(  30), -INT8_C(   6),  INT8_C(  85), -INT8_C( 116),  INT8_C( 124),  INT8_C(  74),  INT8_C(  76), -INT8_C(  47),
         INT8_C(  76), -INT8_C(  61),  INT8_C(  33), -INT8_C( 124), -INT8_C( 115), -INT8_C( 112), -INT8_C( 100),  INT8_C( 116),
         INT8_C(  49),  INT8_C(  57),  INT8_C(  11), -INT8_C(  72), -INT8_C(  53), -INT8_C( 104),  INT8_C(   5),  INT8_C(  65) },
      { -INT8_C( 108),  INT8_C( 115), -INT8_C(  38), -INT8_C(  78), -INT8_C(  63), -INT8_C( 125), -INT8_C(  80), -INT8_C(  93),
         INT8_C( 126),  INT8_C(   5),  INT8_C(  47), -INT8_C(   6),  INT8_C(  79),  INT8_C( 123), -INT8_C(  52), -INT8_C( 100),
         INT8_C(  63), -INT8_C(  19),  INT8_C(  32), -INT8_C(  52),  INT8_C( 126), -INT8_C(  68),  INT8_C(  65), -INT8_C(  81),
        -INT8_C(  11),  INT8_C(  76),  INT8_C( 103), -INT8_C(  63), -INT8_C(  27),  INT8_C( 109),  INT8_C(   2),  INT8_C( 121),
        -INT8_C(  32), -INT8_C(  36),  INT8_C(  43), -INT8_C(  95),  INT8_C(  96), -INT8_C(  36),  INT8_C(  68), -INT8_C(  34),
        -INT8_C(  31),  INT8_C( 115), -INT8_C(  40),  INT8_C(  49), -INT8_C(  17), -INT8_C(  92), -INT8_C(  51),  INT8_C(  46),
        -INT8_C( 110), -INT8_C(  19), -INT8_C(   6),  INT8_C(  16), -INT8_C(  87),  INT8_C(  59), -INT8_C(  65), -INT8_C(  97),
        -INT8_C( 120),  INT8_C(  39),  INT8_C(  96),  INT8_C( 109), -INT8_C( 108),  INT8_C(  98), -INT8_C(  26),  INT8_C( 116) },
      { -INT8_C( 108),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0), -INT8_C( 125), -INT8_C(  80), -INT8_C(  93),
        -INT8_C(  31),  INT8_C(   0),  INT8_C(  47), -INT8_C(   6), -INT8_C(  86),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),
         INT8_C(   0), -INT8_C(  19),  INT8_C(   0),  INT8_C(   0),  INT8_C(  55), -INT8_C(  68),  INT8_C(   0),  INT8_C(   0),
         INT8_C(   0),  INT8_C(   0), -INT8_C( 100),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(  77),
         INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(  29), -INT8_C(  36),  INT8_C(   0), -INT8_C(  34),
        -INT8_C(  31),  INT8_C(   0), -INT8_C(  40),  INT8_C(   0),  INT8_C(   0), -INT8_C(  92), -INT8_C(  51), -INT8_C(  47),
         INT8_C(   0), -INT8_C(  61), -INT8_C(   6),  INT8_C(   0), -INT8_C( 115), -INT8_C( 112), -INT8_C( 100), -INT8_C(  97),
         INT8_C(   0),  INT8_C(  39),  INT8_C(  11),  INT8_C(   0), -INT8_C( 108), -INT8_C( 104), -INT8_C(  26),  INT8_C(  65) } }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
    simde__m512i a = simde_mm512_loadu_epi8(test_vec[i].a);
    simde__m512i b = simde_mm512_loadu_epi8(test_vec[i].b);
    simde__m512i r = simde_mm512_maskz_min_epi8(test_vec[i].k, a, b);
    simde_test_x86_assert_equal_i8x64(r, simde_mm512_loadu_epi8(test_vec[i].r));
  }

  return 0;
}

static int
test_simde_mm512_min_epu8 (SIMDE_MUNIT_TEST_ARGS) {
  static const struct {
    const uint8_t a[64];
    const uint8_t b[64];
    const uint8_t r[64];
  } test_vec[] = {
    { { UINT8_C( 32), UINT8_C(217), UINT8_C( 27), UINT8_C(164), UINT8_C(193), UINT8_C(103), UINT8_C(171), UINT8_C(196),
        UINT8_C(224), UINT8_C(209), UINT8_C(  8), UINT8_C( 68), UINT8_C(152), UINT8_C(243), UINT8_C( 32), UINT8_C( 54),
        UINT8_C(148), UINT8_C(251), UINT8_C(191), UINT8_C(149), UINT8_C(223), UINT8_C( 23), UINT8_C(177), UINT8_C( 37),
        UINT8_C(144), UINT8_C(177), UINT8_C( 93), UINT8_C(117), UINT8_C(236), UINT8_C( 93), UINT8_C(156), UINT8_C( 12),
        UINT8_C( 54), UINT8_C(183), UINT8_C(176), UINT8_C(247), UINT8_C( 31), UINT8_C( 91), UINT8_C(187),    UINT8_MAX,
        UINT8_C( 44), UINT8_C(196), UINT8_C( 67), UINT8_C(197), UINT8_C(183), UINT8_C( 99), UINT8_C(251), UINT8_C( 75),
        UINT8_C( 94), UINT8_C(186), UINT8_C(224), UINT8_C( 61), UINT8_C(210), UINT8_C(145), UINT8_C( 99), UINT8_C( 98),
        UINT8_C( 66), UINT8_C(192), UINT8_C(215), UINT8_C( 47), UINT8_C( 29), UINT8_C(115), UINT8_C( 59), UINT8_C( 83) },
      { UINT8_C( 43), UINT8_C(236), UINT8_C( 75), UINT8_C( 74), UINT8_C( 71), UINT8_C(  6), UINT8_C( 73), UINT8_C(116),
        UINT8_C(202), UINT8_C(140), UINT8_C( 57), UINT8_C(129), UINT8_C(240), UINT8_C( 52), UINT8_C(204), UINT8_C( 78),
        UINT8_C(239), UINT8_C(172), UINT8_C(140), UINT8_C(193), UINT8_C( 62), UINT8_C(239), UINT8_C( 35), UINT8_C(128),
        UINT8_C(175), UINT8_C(250), UINT8_C(175), UINT8_C(204), UINT8_C(110), UINT8_C(235), UINT8_C( 31), UINT8_C(153),
        UINT8_C(215), UINT8_C(106), UINT8_C(227), UINT8_C( 30), UINT8_C(113), UINT8_C( 44), UINT8_C(146), UINT8_C( 59),
        UINT8_C(184), UINT8_C(203), UINT8_C(189), UINT8_C(168), UINT8_C(  0), UINT8_C(137), UINT8_C(247), UINT8_C(239),
        UINT8_C( 54), UINT8_C(131), UINT8_C(176), UINT8_C(116), UINT8_C(114), UINT8_C(211), UINT8_C(244), UINT8_C( 33),
        UINT8_C(205), UINT8_C(164), UINT8_C(237), UINT8_C( 59), UINT8_C(143), UINT8_C( 12), UINT8_C(212), UINT8_C(102) },
      { UINT8_C( 32), UINT8_C(217), UINT8_C( 27), UINT8_C( 74), UINT8_C( 71), UINT8_C(  6), UINT8_C( 73), UINT8_C(116),
        UINT8_C(202), UINT8_C(140), UINT8_C(  8), UINT8_C( 68), UINT8_C(152), UINT8_C( 52), UINT8_C( 32), UINT8_C( 54),
        UINT8_C(148), UINT8_C(172), UINT8_C(140), UINT8_C(149), UINT8_C( 62), UINT8_C( 23), UINT8_C( 35), UINT8_C( 37),
        UINT8_C(144), UINT8_C(177), UINT8_C( 93), UINT8_C(117), UINT8_C(110), UINT8_C( 93), UINT8_C( 31), UINT8_C( 12),
        UINT8_C( 54), UINT8_C(106), UINT8_C(176), UINT8_C( 30), UINT8_C( 31), UINT8_C( 44), UINT8_C(146), UINT8_C( 59),
        UINT8_C( 44), UINT8_C(196), UINT8_C( 67), UINT8_C(168), UINT8_C(  0), UINT8_C( 99), UINT8_C(247), UINT8_C( 75),
        UINT8_C( 54), UINT8_C(131), UINT8_C(176), UINT8_C( 61), UINT8_C(114), UINT8_C(145), UINT8_C( 99), UINT8_C( 33),
        UINT8_C( 66), UINT8_C(164), UINT8_C(215), UINT8_C( 47), UINT8_C( 29), UINT8_C( 12), UINT8_C( 59), UINT8_C( 83) } },
    { { UINT8_C(119), UINT8_C(183), UINT8_C(132), UINT8_C(232), UINT8_C(227), UINT8_C( 23), UINT8_C( 35), UINT8_C(156),
        UINT8_C(226), UINT8_C(224), UINT8_C( 68), UINT8_C(226), UINT8_C(106), UINT8_C( 59), UINT8_C(209), UINT8_C(160),
        UINT8_C(190), UINT8_C(129), UINT8_C( 20), UINT8_C( 48), UINT8_C( 84), UINT8_C(  8), UINT8_C( 81), UINT8_C( 34),
        UINT8_C(172), UINT8_C( 62), UINT8_C( 93), UINT8_C( 59), UINT8_C( 75), UINT8_C( 50), UINT8_C(161), UINT8_C(194),
        UINT8_C(233), UINT8_C( 38), UINT8_C(170), UINT8_C(205), UINT8_C( 61), UINT8_C(205), UINT8_C(105), UINT8_C( 31),
        UINT8_C(174), UINT8_C(173), UINT8_C(  2), UINT8_C( 24), UINT8_C(233), UINT8_C(211), UINT8_C(184), UINT8_C(167),
        UINT8_C( 85), UINT8_C(204), UINT8_C(216), UINT8_C(169), UINT8_C(212), UINT8_C( 41), UINT8_C(203), UINT8_C(129),
        UINT8_C(104), UINT8_C( 41), UINT8_C(188), UINT8_C(179), UINT8_C( 91), UINT8_C( 94), UINT8_C(117), UINT8_C( 68) },
      { UINT8_C(132), UINT8_C( 31), UINT8_C( 17), UINT8_C(193), UINT8_C(236), UINT8_C(122), UINT8_C(224), UINT8_C(154),
        UINT8_C( 40), UINT8_C(226), UINT8_C(178), UINT8_C( 17), UINT8_C(182), UINT8_C(106), UINT8_C(184), UINT8_C( 11),
        UINT8_C( 54), UINT8_C(144), UINT8_C(180), UINT8_C( 11), UINT8_C(186), UINT8_C(128), UINT8_C(140), UINT8_C( 34),
        UINT8_C(169), UINT8_C( 72), UINT8_C(213), UINT8_C(  4), UINT8_C(166), UINT8_C( 74), UINT8_C( 72), UINT8_C( 42),
        UINT8_C(105), UINT8_C( 90), UINT8_C(235), UINT8_C( 85), UINT8_C(212), UINT8_C(204), UINT8_C(240), UINT8_C(252),
        UINT8_C(174), UINT8_C(162), UINT8_C( 13), UINT8_C(100), UINT8_C( 13), UINT8_C(198), UINT8_C(111), UINT8_C( 67),
        UINT8_C( 86), UINT8_C( 36), UINT8_C( 78), UINT8_C( 16), UINT8_C(164), UINT8_C(218), UINT8_C( 50), UINT8_C( 77),
        UINT8_C( 35), UINT8_C(  7), UINT8_C( 81), UINT8_C(201), UINT8_C( 81), UINT8_C(153), UINT8_C(244), UINT8_C(186) },
      { UINT8_C(119), UINT8_C( 31), UINT8_C( 17), UINT8_C(193), UINT8_C(227), UINT8_C( 23), UINT8_C( 35), UINT8_C(154),
        UINT8_C( 40), UINT8_C(224), UINT8_C( 68), UINT8_C( 17), UINT8_C(106), UINT8_C( 59), UINT8_C(184), UINT8_C( 11),
        UINT8_C( 54), UINT8_C(129), UINT8_C( 20), UINT8_C( 11), UINT8_C( 84), UINT8_C(  8), UINT8_C( 81), UINT8_C( 34),
        UINT8_C(169), UINT8_C( 62), UINT8_C( 93), UINT8_C(  4), UINT8_C( 75), UINT8_C( 50), UINT8_C( 72), UINT8_C( 42),
        UINT8_C(105), UINT8_C( 38), UINT8_C(170), UINT8_C( 85), UINT8_C( 61), UINT8_C(204), UINT8_C(105), UINT8_C( 31),
        UINT8_C(174), UINT8_C(162), UINT8_C(  2), UINT8_C( 24), UINT8_C( 13), UINT8_C(198), UINT8_C(111), UINT8_C( 67),
        UINT8_C( 85), UINT8_C( 36), UINT8_C( 78), UINT8_C( 16), UINT8_C(164), UINT8_C( 41), UINT8_C( 50), UINT8_C( 77),
        UINT8_C( 35), UINT8_C(  7), UINT8_C( 81), UINT8_C(179), UINT8_C( 81), UINT8_C( 94), UINT8_C(117), UINT8_C( 68) } },
    { { UINT8_C(243), UINT8_C(223), UINT8_C( 16), UINT8_C(200), UINT8_C(171), UINT8_C(  0), UINT8_C(196), UINT8_C( 90),
        UINT8_C(162), UINT8_C(210), UINT8_C(190), UINT8_C(175), UINT8_C(152), UINT8_C( 46), UINT8_C(243), UINT8_C(238),
        UINT8_C( 82), UINT8_C( 65),    UINT8_MAX, UINT8_C(246), UINT8_C( 28), UINT8_C( 49), UINT8_C( 67), UINT8_C( 63),
        UINT8_C( 57), UINT8_C(148), UINT8_C(  8), UINT8_C(138), UINT8_C( 45), UINT8_C(252), UINT8_C( 69), UINT8_C( 33),
        UINT8_C(220), UINT8_C( 85), UINT8_C(233), UINT8_C(135), UINT8_C( 85), UINT8_C(173), UINT8_C(225), UINT8_C(247),
        UINT8_C(127), UINT8_C(160), UINT8_C(167), UINT8_C( 23), UINT8_C(206), UINT8_C(154), UINT8_C(  6), UINT8_C( 32),
        UINT8_C(219), UINT8_C(  5), UINT8_C( 22), UINT8_C(247), UINT8_C( 54), UINT8_C( 89), UINT8_C( 54), UINT8_C(111),
        UINT8_C(237), UINT8_C( 63), UINT8_C(250), UINT8_C( 26), UINT8_C( 59), UINT8_C( 63), UINT8_C( 59), UINT8_C( 23) },
      { UINT8_C(148), UINT8_C( 36), UINT8_C(159), UINT8_C(233), UINT8_C(210), UINT8_C(128), UINT8_C(224), UINT8_C( 81),
        UINT8_C( 32), UINT8_C(135), UINT8_C(105), UINT8_C(238), UINT8_C( 33), UINT8_C(111), UINT8_C( 14), UINT8_C(253),
        UINT8_C(116), UINT8_C( 36), UINT8_C(244), UINT8_C(170), UINT8_C(125), UINT8_C( 43), UINT8_C( 26), UINT8_C(106),
        UINT8_C(106), UINT8_C( 20), UINT8_C(133), UINT8_C(165), UINT8_C( 83), UINT8_C(192), UINT8_C(189), UINT8_C(231),
        UINT8_C(229), UINT8_C( 92), UINT8_C(208), UINT8_C(183), UINT8_C(220), UINT8_C(176), UINT8_C(  8), UINT8_C(253),
        UINT8_C( 56), UINT8_C(113), UINT8_C(235), UINT8_C( 89), UINT8_C(224), UINT8_C(250), UINT8_C( 86), UINT8_C( 84),
        UINT8_C( 30), UINT8_C( 75),    UINT8_MAX, UINT8_C(156), UINT8_C(118), UINT8_C( 25), UINT8_C(  6), UINT8_C(224),
        UINT8_C( 45), UINT8_C(139), UINT8_C(133), UINT8_C(128), UINT8_C( 76), UINT8_C( 66), UINT8_C(103), UINT8_C( 49) },
      { UINT8_C(148), UINT8_C( 36), UINT8_C( 16), UINT8_C(200), UINT8_C(171), UINT8_C(  0), UINT8_C(196), UINT8_C( 81),
        UINT8_C( 32), UINT8_C(135), UINT8_C(105), UINT8_C(175), UINT8_C( 33), UINT8_C( 46), UINT8_C( 14), UINT8_C(238),
        UINT8_C( 82), UINT8_C( 36), UINT8_C(244), UINT8_C(170), UINT8_C( 28), UINT8_C( 43), UINT8_C( 26), UINT8_C( 63),
        UINT8_C( 57), UINT8_C( 20), UINT8_C(  8), UINT8_C(138), UINT8_C( 45), UINT8_C(192), UINT8_C( 69), UINT8_C( 33),
        UINT8_C(220), UINT8_C( 85), UINT8_C(208), UINT8_C(135), UINT8_C( 85), UINT8_C(173), UINT8_C(  8), UINT8_C(247),
        UINT8_C( 56), UINT8_C(113), UINT8_C(167), UINT8_C( 23), UINT8_C(206), UINT8_C(154), UINT8_C(  6), UINT8_C( 32),
        UINT8_C( 30), UINT8_C(  5), UINT8_C( 22), UINT8_C(156), UINT8_C( 54), UINT8_C( 25), UINT8_C(  6), UINT8_C(111),
        UINT8_C( 45), UINT8_C( 63), UINT8_C(133), UINT8_C( 26), UINT8_C( 59), UINT8_C( 63), UINT8_C( 59), UINT8_C( 23) } },
    { { UINT8_C(158), UINT8_C( 55), UINT8_C(232), UINT8_C(123), UINT8_C(231), UINT8_C(240), UINT8_C(120), UINT8_C( 31),
        UINT8_C( 98), UINT8_C( 99), UINT8_C(121), UINT8_C( 66), UINT8_C( 93), UINT8_C(207), UINT8_C(151), UINT8_C(124),
        UINT8_C( 26), UINT8_C(150), UINT8_C( 24), UINT8_C(144), UINT8_C(175), UINT8_C( 30), UINT8_C(112), UINT8_C(220),
        UINT8_C(170), UINT8_C(246), UINT8_C( 92), UINT8_C(246), UINT8_C( 56), UINT8_C(195), UINT8_C( 39), UINT8_C(215),
        UINT8_C(250), UINT8_C( 15), UINT8_C( 82), UINT8_C(225),    UINT8_MAX, UINT8_C(202), UINT8_C(  1), UINT8_C( 97),
        UINT8_C( 45), UINT8_C(122), UINT8_C(164), UINT8_C(139), UINT8_C( 73), UINT8_C( 59), UINT8_C(  7), UINT8_C(100),
        UINT8_C(209), UINT8_C( 31), UINT8_C(244), UINT8_C(128), UINT8_C( 61), UINT8_C(101), UINT8_C( 92), UINT8_C(231),
        UINT8_C( 91), UINT8_C(184), UINT8_C(221), UINT8_C(147), UINT8_C(123), UINT8_C(  4), UINT8_C(106), UINT8_C(117) },
      { UINT8_C( 19), UINT8_C(188), UINT8_C( 86), UINT8_C( 19), UINT8_C(134), UINT8_C( 87), UINT8_C(116), UINT8_C(180),
        UINT8_C(209), UINT8_C( 24), UINT8_C( 63), UINT8_C( 27), UINT8_C( 83), UINT8_C( 70), UINT8_C(127), UINT8_C( 36),
        UINT8_C(101), UINT8_C(115), UINT8_C(164), UINT8_C(162), UINT8_C(216), UINT8_C(  0), UINT8_C(138), UINT8_C( 51),
        UINT8_C(184), UINT8_C(103), UINT8_C(199), UINT8_C( 51), UINT8_C(108), UINT8_C( 49), UINT8_C(168), UINT8_C(127),
        UINT8_C(238),    UINT8_MAX, UINT8_C(146), UINT8_C(116), UINT8_C( 86), UINT8_C(  7), UINT8_C( 40), UINT8_C( 40),
        UINT8_C( 31), UINT8_C(103), UINT8_C( 67), UINT8_C(115), UINT8_C(173), UINT8_C(194), UINT8_C(151), UINT8_C( 18),
        UINT8_C( 53), UINT8_C( 60), UINT8_C(181), UINT8_C( 14), UINT8_C( 60), UINT8_C( 63), UINT8_C( 65), UINT8_C(245),
        UINT8_C(166), UINT8_C(  8), UINT8_C( 40), UINT8_C( 18), UINT8_C( 58), UINT8_C(209), UINT8_C(146), UINT8_C( 40) },
      { UINT8_C( 19), UINT8_C( 55), UINT8_C( 86), UINT8_C( 19), UINT8_C(134), UINT8_C( 87), UINT8_C(116), UINT8_C( 31),
        UINT8_C( 98), UINT8_C( 24), UINT8_C( 63), UINT8_C( 27), UINT8_C( 83), UINT8_C( 70), UINT8_C(127), UINT8_C( 36),
        UINT8_C( 26), UINT8_C(115), UINT8_C( 24), UINT8_C(144), UINT8_C(175), UINT8_C(  0), UINT8_C(112), UINT8_C( 51),
        UINT8_C(170), UINT8_C(103), UINT8_C( 92), UINT8_C( 51), UINT8_C( 56), UINT8_C( 49), UINT8_C( 39), UINT8_C(127),
        UINT8_C(238), UINT8_C( 15), UINT8_C( 82), UINT8_C(116), UINT8_C( 86), UINT8_C(  7), UINT8_C(  1), UINT8_C( 40),
        UINT8_C( 31), UINT8_C(103), UINT8_C( 67), UINT8_C(115), UINT8_C( 73), UINT8_C( 59), UINT8_C(  7), UINT8_C( 18),
        UINT8_C( 53), UINT8_C( 31), UINT8_C(181), UINT8_C( 14), UINT8_C( 60), UINT8_C( 63), UINT8_C( 65), UINT8_C(231),
        UINT8_C( 91), UINT8_C(  8), UINT8_C( 40), UINT8_C( 18), UINT8_C( 58), UINT8_C(  4), UINT8_C(106), UINT8_C( 40) } },
    { { UINT8_C(208), UINT8_C( 36), UINT8_C(156), UINT8_C( 38), UINT8_C( 43), UINT8_C(197), UINT8_C( 78), UINT8_C( 75),
        UINT8_C( 44), UINT8_C(145), UINT8_C(190), UINT8_C(218), UINT8_C( 83), UINT8_C( 85), UINT8_C(236), UINT8_C(137),
        UINT8_C(145), UINT8_C(161), UINT8_C(151), UINT8_C(206), UINT8_C(224), UINT8_C(216), UINT8_C(195), UINT8_C(135),
        UINT8_C(225), UINT8_C(235), UINT8_C(153), UINT8_C( 27), UINT8_C(188), UINT8_C( 43), UINT8_C( 67), UINT8_C(140),
        UINT8_C( 80), UINT8_C(223), UINT8_C(179), UINT8_C(123), UINT8_C(164), UINT8_C(  1), UINT8_C(198), UINT8_C(209),
        UINT8_C(147), UINT8_C(132), UINT8_C(171), UINT8_C(230), UINT8_C(218), UINT8_C(151), UINT8_C(111), UINT8_C(107),
        UINT8_C( 57), UINT8_C(  6), UINT8_C( 57), UINT8_C( 25), UINT8_C(223), UINT8_C(252), UINT8_C(160), UINT8_C(192),
        UINT8_C(232), UINT8_C( 58), UINT8_C(219), UINT8_C(164), UINT8_C(101), UINT8_C( 30), UINT8_C( 49), UINT8_C(181) },
      { UINT8_C(253), UINT8_C(228), UINT8_C( 49), UINT8_C(162), UINT8_C(229), UINT8_C(247), UINT8_C(115), UINT8_C(120),
        UINT8_C(124), UINT8_C( 30), UINT8_C( 95), UINT8_C( 86), UINT8_C(181), UINT8_C(206), UINT8_C(193), UINT8_C(238),
        UINT8_C(213), UINT8_C(251), UINT8_C(  8), UINT8_C(180), UINT8_C(247), UINT8_C(168), UINT8_C(116), UINT8_C(223),
        UINT8_C(226), UINT8_C( 79), UINT8_C(132), UINT8_C( 72), UINT8_C(109), UINT8_C(181), UINT8_C(253), UINT8_C(106),
        UINT8_C(153), UINT8_C( 46), UINT8_C( 12), UINT8_C(126), UINT8_C( 38), UINT8_C(127), UINT8_C(247), UINT8_C(162),
        UINT8_C(157), UINT8_C( 86), UINT8_C(248), UINT8_C( 83), UINT8_C( 36), UINT8_C(185), UINT8_C( 65), UINT8_C(249),
        UINT8_C(180), UINT8_C( 73), UINT8_C(173), UINT8_C(172), UINT8_C(242), UINT8_C( 33), UINT8_C(139), UINT8_C(212),
        UINT8_C(112), UINT8_C( 15), UINT8_C( 28), UINT8_C(221), UINT8_C(196), UINT8_C( 26), UINT8_C( 72), UINT8_C( 93) },
      { UINT8_C(208), UINT8_C( 36), UINT8_C( 49), UINT8_C( 38), UINT8_C( 43), UINT8_C(197), UINT8_C( 78), UINT8_C( 75),
        UINT8_C( 44), UINT8_C( 30), UINT8_C( 95), UINT8_C( 86), UINT8_C( 83), UINT8_C( 85), UINT8_C(193), UINT8_C(137),
        UINT8_C(145), UINT8_C(161), UINT8_C(  8), UINT8_C(180), UINT8_C(224), UINT8_C(168), UINT8_C(116), UINT8_C(135),
        UINT8_C(225), UINT8_C( 79), UINT8_C(132), UINT8_C( 27), UINT8_C(109), UINT8_C( 43), UINT8_C( 67), UINT8_C(106),
        UINT8_C( 80), UINT8_C( 46), UINT8_C( 12), UINT8_C(123), UINT8_C( 38), UINT8_C(  1), UINT8_C(198), UINT8_C(162),
        UINT8_C(147), UINT8_C( 86), UINT8_C(171), UINT8_C( 83), UINT8_C( 36), UINT8_C(151), UINT8_C( 65), UINT8_C(107),
        UINT8_C( 57), UINT8_C(  6), UINT8_C( 57), UINT8_C( 25), UINT8_C(223), UINT8_C( 33), UINT8_C(139), UINT8_C(192),
        UINT8_C(112), UINT8_C( 15), UINT8_C( 28), UINT8_C(164), UINT8_C(101), UINT8_C( 26), UINT8_C( 49), UINT8_C( 93) } },
    { { UINT8_C( 72), UINT8_C( 84), UINT8_C(220), UINT8_C(110), UINT8_C(212), UINT8_C(211), UINT8_C( 16), UINT8_C(113),
        UINT8_C( 41), UINT8_C(  8), UINT8_C(196), UINT8_C( 77), UINT8_C(194), UINT8_C(  6), UINT8_C( 71), UINT8_C(118),
        UINT8_C( 79), UINT8_C(244), UINT8_C( 34), UINT8_C( 65), UINT8_C( 22), UINT8_C(174), UINT8_C( 22), UINT8_C(134),
        UINT8_C(189), UINT8_C( 50), UINT8_C(100), UINT8_C(130), UINT8_C( 76), UINT8_C(172), UINT8_C(223), UINT8_C(149),
        UINT8_C(  0), UINT8_C(187), UINT8_C(  3), UINT8_C(212), UINT8_C(142), UINT8_C( 20), UINT8_C( 70), UINT8_C(183),
        UINT8_C( 28), UINT8_C( 10), UINT8_C(  5), UINT8_C(222), UINT8_C( 16), UINT8_C( 76), UINT8_C( 85), UINT8_C( 96),
        UINT8_C( 64), UINT8_C(119), UINT8_C(161), UINT8_C( 86), UINT8_C( 37), UINT8_C(183), UINT8_C(221), UINT8_C(227),
        UINT8_C(234), UINT8_C( 65), UINT8_C(101), UINT8_C( 54), UINT8_C(237), UINT8_C( 68), UINT8_C(203), UINT8_C(237) },
      { UINT8_C(  0), UINT8_C(207), UINT8_C(194), UINT8_C(142), UINT8_C(227), UINT8_C(  8), UINT8_C( 70),    UINT8_MAX,
        UINT8_C( 18), UINT8_C( 75), UINT8_C(222), UINT8_C( 35), UINT8_C(151), UINT8_C( 51), UINT8_C(131), UINT8_C(215),
        UINT8_C(170), UINT8_C( 36), UINT8_C( 46), UINT8_C(208), UINT8_C(220), UINT8_C( 11), UINT8_C(179), UINT8_C(198),
        UINT8_C( 76), UINT8_C( 24), UINT8_C(252), UINT8_C( 57), UINT8_C( 92), UINT8_C(200), UINT8_C( 38), UINT8_C( 92),
        UINT8_C(151), UINT8_C(232), UINT8_C(235), UINT8_C(122), UINT8_C(240), UINT8_C( 49), UINT8_C(121), UINT8_C(  3),
        UINT8_C(124), UINT8_C( 87), UINT8_C( 38), UINT8_C( 19), UINT8_C(138), UINT8_C(169), UINT8_C(234), UINT8_C( 53),
        UINT8_C(205), UINT8_C( 24), UINT8_C(  5), UINT8_C(169), UINT8_C( 35), UINT8_C(184), UINT8_C(111), UINT8_C(111),
        UINT8_C(208), UINT8_C(108), UINT8_C(168), UINT8_C( 44), UINT8_C( 52), UINT8_C(207), UINT8_C(137), UINT8_C(203) },
      { UINT8_C(  0), UINT8_C( 84), UINT8_C(194), UINT8_C(110), UINT8_C(212), UINT8_C(  8), UINT8_C( 16), UINT8_C(113),
        UINT8_C( 18), UINT8_C(  8), UINT8_C(196), UINT8_C( 35), UINT8_C(151), UINT8_C(  6), UINT8_C( 71), UINT8_C(118),
        UINT8_C( 79), UINT8_C( 36), UINT8_C( 34), UINT8_C( 65), UINT8_C( 22), UINT8_C( 11), UINT8_C( 22), UINT8_C(134),
        UINT8_C( 76), UINT8_C( 24), UINT8_C(100), UINT8_C( 57), UINT8_C( 76), UINT8_C(172), UINT8_C( 38), UINT8_C( 92),
        UINT8_C(  0), UINT8_C(187), UINT8_C(  3), UINT8_C(122), UINT8_C(142), UINT8_C( 20), UINT8_C( 70), UINT8_C(  3),
        UINT8_C( 28), UINT8_C( 10), UINT8_C(  5), UINT8_C( 19), UINT8_C( 16), UINT8_C( 76), UINT8_C( 85), UINT8_C( 53),
        UINT8_C( 64), UINT8_C( 24), UINT8_C(  5), UINT8_C( 86), UINT8_C( 35), UINT8_C(183), UINT8_C(111), UINT8_C(111),
        UINT8_C(208), UINT8_C( 65), UINT8_C(101), UINT8_C( 44), UINT8_C( 52), UINT8_C( 68), UINT8_C(137), UINT8_C(203) } },
    { { UINT8_C(183), UINT8_C(116), UINT8_C( 69), UINT8_C(168), UINT8_C(165), UINT8_C(190), UINT8_C(171), UINT8_C( 33),
        UINT8_C( 22), UINT8_C(209), UINT8_C( 52), UINT8_C(160), UINT8_C(122), UINT8_C( 30), UINT8_C(213), UINT8_C( 71),
        UINT8_C( 55), UINT8_C(218), UINT8_C(241), UINT8_C( 90), UINT8_C(146), UINT8_C( 96), UINT8_C(202), UINT8_C( 98),
        UINT8_C(204), UINT8_C(114), UINT8_C(143), UINT8_C(  0), UINT8_C( 65), UINT8_C( 24), UINT8_C(203), UINT8_C(249),
        UINT8_C(140), UINT8_C( 16), UINT8_C(161), UINT8_C( 49), UINT8_C(207), UINT8_C( 76), UINT8_C( 82), UINT8_C(229),
        UINT8_C( 29), UINT8_C(134), UINT8_C(133), UINT8_C(151), UINT8_C(164), UINT8_C( 91), UINT8_C(222), UINT8_C(219),
        UINT8_C( 53), UINT8_C(207), UINT8_C( 54), UINT8_C(200), UINT8_C( 48), UINT8_C(  0), UINT8_C( 42), UINT8_C(252),
        UINT8_C(114), UINT8_C(185), UINT8_C(253), UINT8_C(180), UINT8_C(209), UINT8_C(200), UINT8_C(173), UINT8_C( 93) },
      { UINT8_C(217), UINT8_C( 78), UINT8_C(142), UINT8_C(168), UINT8_C(154), UINT8_C(224), UINT8_C(141), UINT8_C(183),
        UINT8_C(102), UINT8_C( 18), UINT8_C( 78), UINT8_C( 11), UINT8_C(109), UINT8_C( 44), UINT8_C(230), UINT8_C(163),
        UINT8_C(252), UINT8_C( 28), UINT8_C(107), UINT8_C( 44), UINT8_C( 28), UINT8_C(149), UINT8_C( 40), UINT8_C(143),
        UINT8_C( 79), UINT8_C( 37), UINT8_C( 67), UINT8_C( 32), UINT8_C(238), UINT8_C(240), UINT8_C(126), UINT8_C(199),
        UINT8_C( 62), UINT8_C( 12), UINT8_C(111), UINT8_C(216), UINT8_C(237), UINT8_C(252), UINT8_C(143), UINT8_C( 83),
        UINT8_C( 14), UINT8_C(221), UINT8_C( 94), UINT8_C(124), UINT8_C(  9), UINT8_C( 69), UINT8_C( 31), UINT8_C(  5),
        UINT8_C( 97), UINT8_C(138), UINT8_C( 49), UINT8_C(126), UINT8_C( 31), UINT8_C( 90), UINT8_C( 13), UINT8_C(110),
        UINT8_C(127), UINT8_C( 80), UINT8_C(143), UINT8_C(109), UINT8_C( 64), UINT8_C( 13), UINT8_C( 52), UINT8_C(126) },
      { UINT8_C(183), UINT8_C( 78), UINT8_C( 69), UINT8_C(168), UINT8_C(154), UINT8_C(190), UINT8_C(141), UINT8_C( 33),
        UINT8_C( 22), UINT8_C( 18), UINT8_C( 52), UINT8_C( 11), UINT8_C(109), UINT8_C( 30), UINT8_C(213), UINT8_C( 71),
        UINT8_C( 55), UINT8_C( 28), UINT8_C(107), UINT8_C( 44), UINT8_C( 28), UINT8_C( 96), UINT8_C( 40), UINT8_C( 98),
        UINT8_C( 79), UINT8_C( 37), UINT8_C( 67), UINT8_C(  0), UINT8_C( 65), UINT8_C( 24), UINT8_C(126), UINT8_C(199),
        UINT8_C( 62), UINT8_C( 12), UINT8_C(111), UINT8_C( 49), UINT8_C(207), UINT8_C( 76), UINT8_C( 82), UINT8_C( 83),
        UINT8_C( 14), UINT8_C(134), UINT8_C( 94), UINT8_C(124), UINT8_C(  9), UINT8_C( 69), UINT8_C( 31), UINT8_C(  5),
        UINT8_C( 53), UINT8_C(138), UINT8_C( 49), UINT8_C(126), UINT8_C( 31), UINT8_C(  0), UINT8_C( 13), UINT8_C(110),
        UINT8_C(114), UINT8_C( 80), UINT8_C(143), UINT8_C(109), UINT8_C( 64), UINT8_C( 13), UINT8_C( 52), UINT8_C( 93) } },
    { { UINT8_C( 25), UINT8_C(163), UINT8_C( 86), UINT8_C(  6), UINT8_C(159), UINT8_C(229), UINT8_C( 90), UINT8_C(174),
        UINT8_C(194), UINT8_C(184), UINT8_C( 42), UINT8_C(203), UINT8_C(253), UINT8_C( 73), UINT8_C(209), UINT8_C( 95),
        UINT8_C(211), UINT8_C(  2), UINT8_C(221), UINT8_C(242), UINT8_C( 92), UINT8_C(234), UINT8_C( 97), UINT8_C(220),
        UINT8_C( 58), UINT8_C(240), UINT8_C( 73), UINT8_C(122), UINT8_C(253), UINT8_C(126), UINT8_C(248), UINT8_C( 22),
        UINT8_C( 33), UINT8_C( 78), UINT8_C( 29), UINT8_C(193), UINT8_C( 51), UINT8_C(119), UINT8_C(111), UINT8_C(245),
        UINT8_C( 47), UINT8_C(153), UINT8_C(192), UINT8_C( 45), UINT8_C(226), UINT8_C(145), UINT8_C(140), UINT8_C(181),
        UINT8_C(148), UINT8_C(105), UINT8_C(167), UINT8_C(240), UINT8_C( 83), UINT8_C(  8), UINT8_C(204), UINT8_C(141),
        UINT8_C(248), UINT8_C( 22), UINT8_C(  7), UINT8_C(245), UINT8_C(148),    UINT8_MAX, UINT8_C( 12), UINT8_C(181) },
      { UINT8_C( 77), UINT8_C( 41), UINT8_C(118), UINT8_C(128), UINT8_C(160), UINT8_C(229), UINT8_C(117), UINT8_C(207),
        UINT8_C(126), UINT8_C( 53), UINT8_C(252), UINT8_C( 96), UINT8_C(199), UINT8_C(136), UINT8_C( 21), UINT8_C( 91),
        UINT8_C(241), UINT8_C(189), UINT8_C( 75), UINT8_C( 68), UINT8_C(197), UINT8_C( 24), UINT8_C(209), UINT8_C(190),
        UINT8_C( 46), UINT8_C(216), UINT8_C(179), UINT8_C(194), UINT8_C(215), UINT8_C(191), UINT8_C(119), UINT8_C( 36),
        UINT8_C(232), UINT8_C(238), UINT8_C(164), UINT8_C(136), UINT8_C(211), UINT8_C( 25), UINT8_C( 88), UINT8_C( 82),
        UINT8_C( 79), UINT8_C( 84), UINT8_C(178), UINT8_C( 22), UINT8_C(221), UINT8_C(200), UINT8_C(113), UINT8_C(206),
        UINT8_C(133), UINT8_C(188), UINT8_C( 19), UINT8_C( 74), UINT8_C(212), UINT8_C(228), UINT8_C(  8), UINT8_C(  2),
        UINT8_C(189), UINT8_C(188), UINT8_C(196), UINT8_C(148), UINT8_C(123), UINT8_C( 60), UINT8_C(185), UINT8_C(100) },
      { UINT8_C( 25), UINT8_C( 41), UINT8_C( 86), UINT8_C(  6), UINT8_C(159), UINT8_C(229), UINT8_C( 90), UINT8_C(174),
        UINT8_C(126), UINT8_C( 53), UINT8_C( 42), UINT8_C( 96), UINT8_C(199), UINT8_C( 73), UINT8_C( 21), UINT8_C( 91),
        UINT8_C(211), UINT8_C(  2), UINT8_C( 75), UINT8_C( 68), UINT8_C( 92), UINT8_C( 24), UINT8_C( 97), UINT8_C(190),
        UINT8_C( 46), UINT8_C(216), UINT8_C( 73), UINT8_C(122), UINT8_C(215), UINT8_C(126), UINT8_C(119), UINT8_C( 22),
        UINT8_C( 33), UINT8_C( 78), UINT8_C( 29), UINT8_C(136), UINT8_C( 51), UINT8_C( 25), UINT8_C( 88), UINT8_C( 82),
        UINT8_C( 47), UINT8_C( 84), UINT8_C(178), UINT8_C( 22), UINT8_C(221), UINT8_C(145), UINT8_C(113), UINT8_C(181),
        UINT8_C(133), UINT8_C(105), UINT8_C( 19), UINT8_C( 74), UINT8_C( 83), UINT8_C(  8), UINT8_C(  8), UINT8_C(  2),
        UINT8_C(189), UINT8_C( 22), UINT8_C(  7), UINT8_C(148), UINT8_C(123), UINT8_C( 60), UINT8_C( 12), UINT8_C(100) } }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
    simde__m512i a = simde_mm512_loadu_epi8(test_vec[i].a);
    simde__m512i b = simde_mm512_loadu_epi8(test_vec[i].b);
    simde__m512i r = simde_mm512_min_epu8(a, b);
    simde_test_x86_assert_equal_u8x64(r, simde_mm512_loadu_epi8(test_vec[i].r));
  }

  return 0;
}

static int
test_simde_mm512_mask_min_epu8 (SIMDE_MUNIT_TEST_ARGS) {
  static const struct {
    const int8_t src[64];
    const simde__mmask64 k;
    const uint8_t a[64];
    const uint8_t b[64];
    const uint8_t r[64];
  } test_vec[] = {
    { {  INT8_C(  25), -INT8_C( 115),  INT8_C(  79), -INT8_C( 105), -INT8_C( 118), -INT8_C(  48),  INT8_C(  60),  INT8_C( 124),
         INT8_C(  36),  INT8_C(  36),  INT8_C(  79), -INT8_C(  57),  INT8_C(  83),  INT8_C( 122), -INT8_C(  25),  INT8_C( 107),
        -INT8_C(  54),  INT8_C(  79), -INT8_C( 111),  INT8_C( 105),  INT8_C(  61), -INT8_C(   3), -INT8_C(  33), -INT8_C(  44),
        -INT8_C(  34),  INT8_C(  97),  INT8_C(  26),  INT8_C(   1),  INT8_C(  36), -INT8_C(  49), -INT8_C(  78),  INT8_C(  61),
         INT8_C(  92),  INT8_C(   1), -INT8_C(  44), -INT8_C(  26), -INT8_C(  47),  INT8_C(  16),  INT8_C(  99), -INT8_C(  10),
         INT8_C(  52), -INT8_C(  78), -INT8_C(  67), -INT8_C( 121),  INT8_C(  44), -INT8_C(  92), -INT8_C(  14), -INT8_C(  10),
        -INT8_C(  13), -INT8_C( 124),  INT8_C(  95),  INT8_C(  49), -INT8_C( 127),  INT8_C(  63),  INT8_C(   5),  INT8_C(  96),
        -INT8_C(  96),  INT8_C(  31),  INT8_C(  97), -INT8_C(  60), -INT8_C(  18),  INT8_C(  19),  INT8_C(   2),  INT8_C(  74) },
      UINT64_C( 2007643257620780565),
      { UINT8_C( 70), UINT8_C(153), UINT8_C(163), UINT8_C(114), UINT8_C( 61), UINT8_C(149), UINT8_C(104), UINT8_C( 49),
        UINT8_C( 25), UINT8_C(199), UINT8_C( 98), UINT8_C(155), UINT8_C(  6), UINT8_C(103), UINT8_C(251), UINT8_C(167),
        UINT8_C(135), UINT8_C( 92), UINT8_C(107), UINT8_C(117), UINT8_C(112), UINT8_C(109), UINT8_C(192), UINT8_C(133),
        UINT8_C( 68), UINT8_C(241), UINT8_C(107), UINT8_C( 43), UINT8_C(133), UINT8_C( 72), UINT8_C( 70), UINT8_C(203),
        UINT8_C(225), UINT8_C(233), UINT8_C( 61), UINT8_C( 31), UINT8_C(127), UINT8_C(165), UINT8_C( 80), UINT8_C(152),
        UINT8_C(108), UINT8_C(178), UINT8_C( 51), UINT8_C(115), UINT8_C( 25), UINT8_C( 46), UINT8_C( 26), UINT8_C(160),
        UINT8_C(139), UINT8_C(133), UINT8_C( 22), UINT8_C(251), UINT8_C(243), UINT8_C(214), UINT8_C(128), UINT8_C( 55),
        UINT8_C(199), UINT8_C(235), UINT8_C( 98), UINT8_C( 76), UINT8_C( 51), UINT8_C(168), UINT8_C( 23), UINT8_C( 21) },
      { UINT8_C(146), UINT8_C( 84), UINT8_C( 52), UINT8_C( 17), UINT8_C(249), UINT8_C(132), UINT8_C(169), UINT8_C(101),
        UINT8_C( 54), UINT8_C(221), UINT8_C(216), UINT8_C( 79), UINT8_C( 11), UINT8_C(242), UINT8_C(240), UINT8_C(150),
        UINT8_C(120), UINT8_C(  6), UINT8_C(145), UINT8_C(107), UINT8_C(220), UINT8_C( 17), UINT8_C(162), UINT8_C(163),
        UINT8_C(253), UINT8_C(  4), UINT8_C(239), UINT8_C( 48), UINT8_C(172), UINT8_C(  6), UINT8_C( 69), UINT8_C( 62),
        UINT8_C( 90), UINT8_C(121), UINT8_C( 79), UINT8_C( 83), UINT8_C(253), UINT8_C(249), UINT8_C(184), UINT8_C( 51),
        UINT8_C(214), UINT8_C(145), UINT8_C(131), UINT8_C(225), UINT8_C(131), UINT8_C(115), UINT8_C(120), UINT8_C(251),
        UINT8_C(121), UINT8_C(  9), UINT8_C(102), UINT8_C( 85), UINT8_C( 27), UINT8_C(  8), UINT8_C(248), UINT8_C( 24),
        UINT8_C( 12), UINT8_C(231), UINT8_C( 72), UINT8_C(185), UINT8_C(237), UINT8_C(142), UINT8_C(247), UINT8_C( 71) },
      { UINT8_C( 70), UINT8_C(141), UINT8_C( 52), UINT8_C(151), UINT8_C( 61), UINT8_C(208), UINT8_C( 60), UINT8_C(124),
        UINT8_C( 36), UINT8_C(199), UINT8_C( 98), UINT8_C(199), UINT8_C(  6), UINT8_C(122), UINT8_C(240), UINT8_C(150),
        UINT8_C(120), UINT8_C( 79), UINT8_C(145), UINT8_C(105), UINT8_C(112), UINT8_C( 17), UINT8_C(223), UINT8_C(212),
        UINT8_C(222), UINT8_C(  4), UINT8_C(107), UINT8_C(  1), UINT8_C( 36), UINT8_C(  6), UINT8_C( 69), UINT8_C( 62),
        UINT8_C( 90), UINT8_C(121), UINT8_C( 61), UINT8_C(230), UINT8_C(209), UINT8_C(165), UINT8_C( 80), UINT8_C( 51),
        UINT8_C( 52), UINT8_C(178), UINT8_C( 51), UINT8_C(135), UINT8_C( 25), UINT8_C(164), UINT8_C(242), UINT8_C(160),
        UINT8_C(243), UINT8_C(132), UINT8_C( 22), UINT8_C( 85), UINT8_C( 27), UINT8_C( 63), UINT8_C(128), UINT8_C( 24),
        UINT8_C( 12), UINT8_C(231), UINT8_C( 97), UINT8_C( 76), UINT8_C( 51), UINT8_C( 19), UINT8_C(  2), UINT8_C( 74) } },
    { {  INT8_C(   7),  INT8_C(  71), -INT8_C( 102),  INT8_C(   5),  INT8_C(  64),  INT8_C(  82),  INT8_C(  56),  INT8_C(  22),
        -INT8_C(  29), -INT8_C(  69), -INT8_C(   9),  INT8_C( 103),  INT8_C(  46),  INT8_C( 111),  INT8_C(  98), -INT8_C(  89),
         INT8_C( 121), -INT8_C(  55), -INT8_C(   4), -INT8_C( 108), -INT8_C(  47), -INT8_C(  12), -INT8_C(  84), -INT8_C(  34),
        -INT8_C(  37), -INT8_C(  12), -INT8_C( 105), -INT8_C(  56), -INT8_C( 126), -INT8_C( 114),  INT8_C(  15), -INT8_C( 118),
        -INT8_C(  43), -INT8_C(  87), -INT8_C( 113),  INT8_C(  21), -INT8_C(   4), -INT8_C(  57),  INT8_C(  43), -INT8_C(  33),
        -INT8_C( 125),  INT8_C(  35),  INT8_C(  70), -INT8_C(  79), -INT8_C( 110), -INT8_C(  87),  INT8_C(  89),  INT8_C(  11),
         INT8_C( 114),  INT8_C(  85), -INT8_C(  97),  INT8_C(  67),  INT8_C(  74),  INT8_C(  75),  INT8_C(  33),  INT8_C(  37),
         INT8_C(  64), -INT8_C(  72), -INT8_C(  18), -INT8_C(  62),  INT8_C(  71), -INT8_C(   3),  INT8_C(  76),  INT8_C(  28) },
      UINT64_C( 2774883277812718503),
      { UINT8_C(128), UINT8_C(201), UINT8_C(215), UINT8_C( 19), UINT8_C(114), UINT8_C( 48), UINT8_C( 30), UINT8_C(228),
        UINT8_C(134), UINT8_C(190), UINT8_C( 39), UINT8_C(208), UINT8_C(  9), UINT8_C( 73), UINT8_C(245), UINT8_C( 73),
        UINT8_C(  1), UINT8_C(227), UINT8_C( 12), UINT8_C( 72), UINT8_C(225), UINT8_C( 88), UINT8_C(101), UINT8_C(136),
        UINT8_C( 52), UINT8_C(151), UINT8_C( 43), UINT8_C(215), UINT8_C(244), UINT8_C(173), UINT8_C(253), UINT8_C(117),
        UINT8_C(118), UINT8_C(212), UINT8_C(136), UINT8_C(232), UINT8_C(  5), UINT8_C(166), UINT8_C(204), UINT8_C(139),
        UINT8_C(100), UINT8_C(244), UINT8_C( 91), UINT8_C(110), UINT8_C( 61), UINT8_C( 80), UINT8_C(183), UINT8_C( 62),
        UINT8_C( 52), UINT8_C(195), UINT8_C(135), UINT8_C( 21), UINT8_C( 28), UINT8_C(236), UINT8_C(157), UINT8_C( 80),
        UINT8_C(131), UINT8_C(200), UINT8_C( 39), UINT8_C(119), UINT8_C(117), UINT8_C( 36), UINT8_C(236), UINT8_C(236) },
      { UINT8_C(248), UINT8_C(116), UINT8_C(212), UINT8_C(253), UINT8_C( 27), UINT8_C(161), UINT8_C(136), UINT8_C(127),
        UINT8_C(149), UINT8_C(227), UINT8_C(237), UINT8_C(210), UINT8_C( 52), UINT8_C(165), UINT8_C( 16), UINT8_C(104),
        UINT8_C(104), UINT8_C(151), UINT8_C(125), UINT8_C(132), UINT8_C(131), UINT8_C( 26), UINT8_C(212), UINT8_C(  6),
        UINT8_C(226), UINT8_C(251), UINT8_C(126), UINT8_C( 87), UINT8_C( 31), UINT8_C(106), UINT8_C( 67), UINT8_C( 24),
        UINT8_C(223), UINT8_C( 24), UINT8_C( 21), UINT8_C(250), UINT8_C(185), UINT8_C(158), UINT8_C(121), UINT8_C( 78),
        UINT8_C(129), UINT8_C(103), UINT8_C( 32), UINT8_C(181), UINT8_C( 12), UINT8_C( 48), UINT8_C( 29), UINT8_C(116),
        UINT8_C(200), UINT8_C(154), UINT8_C(249), UINT8_C( 75), UINT8_C(180), UINT8_C(205), UINT8_C( 82), UINT8_C(150),
        UINT8_C(201), UINT8_C(208), UINT8_C(238), UINT8_C(232), UINT8_C( 58), UINT8_C( 49), UINT8_C(  0), UINT8_C( 25) },
      { UINT8_C(128), UINT8_C(116), UINT8_C(212), UINT8_C(  5), UINT8_C( 64), UINT8_C( 48), UINT8_C( 56), UINT8_C(127),
        UINT8_C(134), UINT8_C(190), UINT8_C(247), UINT8_C(208), UINT8_C(  9), UINT8_C(111), UINT8_C( 16), UINT8_C( 73),
        UINT8_C(121), UINT8_C(151), UINT8_C(252), UINT8_C(148), UINT8_C(131), UINT8_C( 26), UINT8_C(172), UINT8_C(222),
        UINT8_C( 52), UINT8_C(151), UINT8_C(151), UINT8_C(200), UINT8_C(130), UINT8_C(106), UINT8_C( 15), UINT8_C( 24),
        UINT8_C(118), UINT8_C( 24), UINT8_C(143), UINT8_C( 21), UINT8_C(252), UINT8_C(158), UINT8_C( 43), UINT8_C( 78),
        UINT8_C(100), UINT8_C( 35), UINT8_C( 32), UINT8_C(110), UINT8_C( 12), UINT8_C(169), UINT8_C( 29), UINT8_C( 11),
        UINT8_C(114), UINT8_C(154), UINT8_C(159), UINT8_C( 67), UINT8_C( 74), UINT8_C( 75), UINT8_C( 33), UINT8_C( 80),
        UINT8_C( 64), UINT8_C(200), UINT8_C( 39), UINT8_C(194), UINT8_C( 71), UINT8_C( 36), UINT8_C( 76), UINT8_C( 28) } },
    { {  INT8_C(  73),  INT8_C(  22),  INT8_C(  19),  INT8_C(   2), -INT8_C(  76), -INT8_C( 115),  INT8_C(  80),  INT8_C(  53),
        -INT8_C(  12),  INT8_C( 112), -INT8_C(  21),  INT8_C(   0), -INT8_C(  95),  INT8_C(   8),  INT8_C( 116),  INT8_C( 105),
        -INT8_C(  93),  INT8_C( 109), -INT8_C(  76),  INT8_C(  87),  INT8_C(  59),  INT8_C(   6), -INT8_C(  18),  INT8_C(   4),
        -INT8_C(  42), -INT8_C(  36), -INT8_C(  20),  INT8_C(  17),  INT8_C(  13), -INT8_C(  19),  INT8_C(  42),  INT8_C(  87),
         INT8_C(   3),  INT8_C(  62),  INT8_C(  89), -INT8_C(  73), -INT8_C(  53), -INT8_C(  86), -INT8_C(  20), -INT8_C(  65),
         INT8_C(  26), -INT8_C(  41), -INT8_C(  65), -INT8_C(  69), -INT8_C(  32),  INT8_C(  51),  INT8_C(  36), -INT8_C( 125),
        -INT8_C(  95), -INT8_C(  39), -INT8_C(  38), -INT8_C(  36), -INT8_C(  33), -INT8_C(  56), -INT8_C(  32), -INT8_C(  74),
        -INT8_C(  92), -INT8_C(  52), -INT8_C(  57), -INT8_C(  78), -INT8_C(  71), -INT8_C(  15),  INT8_C(   9), -INT8_C(  68) },
      UINT64_C( 2862424647028400687),
      { UINT8_C( 55), UINT8_C(120), UINT8_C(226), UINT8_C( 23), UINT8_C(172), UINT8_C(  7), UINT8_C(154), UINT8_C( 77),
        UINT8_C(224), UINT8_C(117), UINT8_C( 41), UINT8_C(191), UINT8_C( 61), UINT8_C(  9), UINT8_C(117), UINT8_C(226),
        UINT8_C(213), UINT8_C( 60), UINT8_C(148), UINT8_C(143), UINT8_C( 46), UINT8_C(157), UINT8_C( 75), UINT8_C( 93),
           UINT8_MAX, UINT8_C(191), UINT8_C( 88), UINT8_C( 12), UINT8_C( 31), UINT8_C( 17), UINT8_C( 51), UINT8_C( 86),
        UINT8_C(138), UINT8_C( 21), UINT8_C(110), UINT8_C( 54), UINT8_C( 28), UINT8_C(  8), UINT8_C(131), UINT8_C(252),
        UINT8_C(125), UINT8_C(172), UINT8_C(188), UINT8_C(187), UINT8_C(181), UINT8_C( 49), UINT8_C(157), UINT8_C(138),
        UINT8_C(110), UINT8_C( 49), UINT8_C( 25), UINT8_C(156), UINT8_C(206), UINT8_C(101), UINT8_C(249), UINT8_C(205),
        UINT8_C( 36), UINT8_C( 81), UINT8_C(217), UINT8_C( 67), UINT8_C( 99), UINT8_C( 12), UINT8_C(153), UINT8_C(237) },
      { UINT8_C( 34), UINT8_C(  7), UINT8_C( 35), UINT8_C( 62), UINT8_C( 16), UINT8_C(166), UINT8_C( 59), UINT8_C(141),
        UINT8_C( 82), UINT8_C(247), UINT8_C( 72), UINT8_C(  7), UINT8_C( 40), UINT8_C(229), UINT8_C(145), UINT8_C(150),
        UINT8_C( 22), UINT8_C(171), UINT8_C( 50), UINT8_C(228), UINT8_C( 16), UINT8_C( 44), UINT8_C(178), UINT8_C( 52),
        UINT8_C(125), UINT8_C(139), UINT8_C(119), UINT8_C(224), UINT8_C(152), UINT8_C( 16), UINT8_C(205), UINT8_C(186),
        UINT8_C( 24), UINT8_C(240), UINT8_C(248), UINT8_C( 40), UINT8_C(150), UINT8_C( 51), UINT8_C(181), UINT8_C(232),
        UINT8_C( 42), UINT8_C(254), UINT8_C(239), UINT8_C( 83), UINT8_C(227), UINT8_C(129), UINT8_C(233), UINT8_C(250),
        UINT8_C( 44), UINT8_C( 28), UINT8_C(222), UINT8_C( 60), UINT8_C( 72), UINT8_C(144), UINT8_C(112), UINT8_C(197),
        UINT8_C( 28), UINT8_C(231), UINT8_C(166), UINT8_C(180), UINT8_C(247), UINT8_C(115), UINT8_C(110), UINT8_C( 15) },
      { UINT8_C( 34), UINT8_C(  7), UINT8_C( 35), UINT8_C( 23), UINT8_C(180), UINT8_C(  7), UINT8_C( 80), UINT8_C( 53),
        UINT8_C(244), UINT8_C(117), UINT8_C(235), UINT8_C(  0), UINT8_C(161), UINT8_C(  9), UINT8_C(117), UINT8_C(105),
        UINT8_C( 22), UINT8_C( 60), UINT8_C(180), UINT8_C( 87), UINT8_C( 16), UINT8_C( 44), UINT8_C( 75), UINT8_C(  4),
        UINT8_C(214), UINT8_C(139), UINT8_C(236), UINT8_C( 12), UINT8_C( 31), UINT8_C( 16), UINT8_C( 51), UINT8_C( 86),
        UINT8_C(  3), UINT8_C( 62), UINT8_C(110), UINT8_C( 40), UINT8_C(203), UINT8_C(170), UINT8_C(236), UINT8_C(191),
        UINT8_C( 26), UINT8_C(215), UINT8_C(191), UINT8_C(187), UINT8_C(224), UINT8_C( 49), UINT8_C(157), UINT8_C(131),
        UINT8_C( 44), UINT8_C(217), UINT8_C(218), UINT8_C( 60), UINT8_C( 72), UINT8_C(101), UINT8_C(224), UINT8_C(197),
        UINT8_C( 28), UINT8_C( 81), UINT8_C(166), UINT8_C(178), UINT8_C(185), UINT8_C( 12), UINT8_C(  9), UINT8_C(188) } },
    { {  INT8_C( 100),  INT8_C( 102),  INT8_C(  55), -INT8_C(   6), -INT8_C( 102), -INT8_C(  19), -INT8_C(  29), -INT8_C(  60),
        -INT8_C(  21), -INT8_C(  46),  INT8_C(  23), -INT8_C(  50),  INT8_C(  83),  INT8_C(   1), -INT8_C(  56),      INT8_MAX,
         INT8_C(  29), -INT8_C(  89), -INT8_C(  69),  INT8_C( 101),  INT8_C(  55),  INT8_C(  43),  INT8_C(  42),  INT8_C(  83),
         INT8_C(  18), -INT8_C(  48),  INT8_C(   7),  INT8_C(  10),  INT8_C(  68),  INT8_C( 117),  INT8_C(  25), -INT8_C(  88),
        -INT8_C(  36),  INT8_C(  81), -INT8_C(  94),  INT8_C( 118),  INT8_C(  62), -INT8_C( 123),  INT8_C(  58),  INT8_C(  41),
         INT8_C(  88),  INT8_C(  82), -INT8_C(   9), -INT8_C(  85),  INT8_C(  83), -INT8_C(  64),  INT8_C(  43),  INT8_C( 112),
         INT8_C( 103), -INT8_C(  26), -INT8_C(  43), -INT8_C(  98),  INT8_C(  18), -INT8_C(   1), -INT8_C(  14),  INT8_C(  36),
        -INT8_C(  48), -INT8_C(   7),  INT8_C(  46),  INT8_C(  20),  INT8_C( 111),  INT8_C(  72), -INT8_C(  68),  INT8_C(  75) },
      UINT64_C( 4323732602566565529),
      { UINT8_C( 77), UINT8_C(247), UINT8_C(231), UINT8_C(160), UINT8_C(183), UINT8_C( 18), UINT8_C( 16), UINT8_C( 30),
        UINT8_C(249), UINT8_C(229), UINT8_C(189), UINT8_C( 11), UINT8_C(229), UINT8_C(175), UINT8_C( 47), UINT8_C(181),
        UINT8_C(168), UINT8_C( 94), UINT8_C(201), UINT8_C( 23), UINT8_C(166), UINT8_C(133), UINT8_C( 98), UINT8_C( 63),
        UINT8_C(227), UINT8_C( 35), UINT8_C( 22), UINT8_C(199), UINT8_C( 31), UINT8_C( 22), UINT8_C(  3), UINT8_C(108),
        UINT8_C( 13), UINT8_C(235), UINT8_C( 13), UINT8_C(197), UINT8_C(253), UINT8_C( 29), UINT8_C(227), UINT8_C(246),
        UINT8_C(  3), UINT8_C(160), UINT8_C(  1), UINT8_C(232), UINT8_C( 79), UINT8_C( 49), UINT8_C(157), UINT8_C(248),
        UINT8_C(143), UINT8_C(102), UINT8_C( 15), UINT8_C( 53), UINT8_C(235), UINT8_C(114), UINT8_C(116), UINT8_C(206),
        UINT8_C(149), UINT8_C(138), UINT8_C(150), UINT8_C(180), UINT8_C(160), UINT8_C(153), UINT8_C( 33), UINT8_C(173) },
      { UINT8_C(132), UINT8_C( 46), UINT8_C(114), UINT8_C(130), UINT8_C( 75), UINT8_C( 86), UINT8_C(120), UINT8_C( 78),
        UINT8_C(246), UINT8_C(122), UINT8_C( 54), UINT8_C( 70), UINT8_C(171), UINT8_C(211), UINT8_C( 62), UINT8_C( 58),
        UINT8_C( 57), UINT8_C( 77), UINT8_C(111), UINT8_C( 36), UINT8_C(191), UINT8_C(227), UINT8_C(243), UINT8_C( 85),
        UINT8_C(109), UINT8_C(137), UINT8_C(  9), UINT8_C( 13), UINT8_C( 34), UINT8_C( 42), UINT8_C(186), UINT8_C(167),
        UINT8_C( 88), UINT8_C( 45), UINT8_C( 41), UINT8_C(164), UINT8_C(131), UINT8_C(161), UINT8_C(242), UINT8_C(121),
        UINT8_C( 27), UINT8_C( 41), UINT8_C(191), UINT8_C(198), UINT8_C(252), UINT8_C(253), UINT8_C(  0), UINT8_C( 54),
        UINT8_C( 75), UINT8_C(111), UINT8_C( 90), UINT8_C( 10), UINT8_C( 82), UINT8_C( 77), UINT8_C( 95), UINT8_C(191),
        UINT8_C(214), UINT8_C(105), UINT8_C(204), UINT8_C(249), UINT8_C(147), UINT8_C(135), UINT8_C(160), UINT8_C(236) },
      { UINT8_C( 77), UINT8_C(102), UINT8_C( 55), UINT8_C(130), UINT8_C( 75), UINT8_C(237), UINT8_C(227), UINT8_C( 30),
        UINT8_C(235), UINT8_C(122), UINT8_C( 54), UINT8_C( 11), UINT8_C(171), UINT8_C(  1), UINT8_C( 47), UINT8_C(127),
        UINT8_C( 57), UINT8_C(167), UINT8_C(187), UINT8_C(101), UINT8_C( 55), UINT8_C( 43), UINT8_C( 98), UINT8_C( 63),
        UINT8_C(109), UINT8_C( 35), UINT8_C(  9), UINT8_C( 10), UINT8_C( 31), UINT8_C(117), UINT8_C(  3), UINT8_C(108),
        UINT8_C(220), UINT8_C( 81), UINT8_C( 13), UINT8_C(118), UINT8_C( 62), UINT8_C( 29), UINT8_C(227), UINT8_C(121),
        UINT8_C(  3), UINT8_C( 41), UINT8_C(247), UINT8_C(198), UINT8_C( 79), UINT8_C( 49), UINT8_C(  0), UINT8_C( 54),
        UINT8_C(103), UINT8_C(230), UINT8_C(213), UINT8_C(158), UINT8_C( 18),    UINT8_MAX, UINT8_C(242), UINT8_C( 36),
        UINT8_C(208), UINT8_C(249), UINT8_C(150), UINT8_C(180), UINT8_C(147), UINT8_C(135), UINT8_C(188), UINT8_C( 75) } },
    { { -INT8_C(  76), -INT8_C(  55), -INT8_C( 112),  INT8_C(  55),  INT8_C( 106), -INT8_C( 126), -INT8_C(  80), -INT8_C( 122),
        -INT8_C(  85),  INT8_C( 112),  INT8_C(  76), -INT8_C(  88),  INT8_C( 109),  INT8_C(  77), -INT8_C(  34), -INT8_C(  72),
        -INT8_C(  68),  INT8_C(  56), -INT8_C(  61),  INT8_C(  15), -INT8_C( 122),  INT8_C(  34), -INT8_C(  50),  INT8_C(  92),
        -INT8_C( 117), -INT8_C( 101),  INT8_C(  85),  INT8_C(  31),  INT8_C(  34), -INT8_C(  11),  INT8_C(  11), -INT8_C(  42),
        -INT8_C(  66), -INT8_C( 101),  INT8_C(  13),  INT8_C(  41),  INT8_C(  29), -INT8_C(  67), -INT8_C(  81), -INT8_C(  55),
         INT8_C(  45), -INT8_C(   5),  INT8_C( 113), -INT8_C( 101),  INT8_C(  72),  INT8_C(  79),  INT8_C(  83),  INT8_C(   5),
        -INT8_C( 121),  INT8_C(  22),  INT8_C(  20),  INT8_C(  13),  INT8_C(  57), -INT8_C(  30),  INT8_C( 106), -INT8_C(  60),
         INT8_C( 125), -INT8_C(  65), -INT8_C(  29), -INT8_C(  97), -INT8_C(  75), -INT8_C(  18),  INT8_C( 117),  INT8_C( 115) },
      UINT64_C( 7885885688587780745),
      { UINT8_C( 71), UINT8_C(225), UINT8_C(  8), UINT8_C(143), UINT8_C( 48), UINT8_C( 92), UINT8_C(148), UINT8_C(183),
        UINT8_C(114), UINT8_C(168), UINT8_C(197), UINT8_C(171), UINT8_C(139), UINT8_C( 47), UINT8_C(112), UINT8_C(  8),
        UINT8_C(238), UINT8_C( 83), UINT8_C(168), UINT8_C(163), UINT8_C( 66), UINT8_C( 29), UINT8_C( 23), UINT8_C(203),
        UINT8_C(160), UINT8_C(179), UINT8_C(114), UINT8_C(224),    UINT8_MAX, UINT8_C(226), UINT8_C( 77), UINT8_C( 70),
        UINT8_C(195), UINT8_C( 86), UINT8_C(213), UINT8_C(243), UINT8_C(178), UINT8_C(106), UINT8_C(171), UINT8_C( 36),
        UINT8_C( 18), UINT8_C(112), UINT8_C(208), UINT8_C(157), UINT8_C(159), UINT8_C( 64), UINT8_C(166), UINT8_C(141),
        UINT8_C(147), UINT8_C( 78), UINT8_C( 49), UINT8_C(213), UINT8_C(107), UINT8_C( 72), UINT8_C(161), UINT8_C( 11),
        UINT8_C(251), UINT8_C( 19), UINT8_C(235), UINT8_C(250), UINT8_C(246), UINT8_C( 57), UINT8_C( 64), UINT8_C(185) },
      { UINT8_C(143), UINT8_C( 22), UINT8_C(173), UINT8_C( 65), UINT8_C(128), UINT8_C( 88), UINT8_C(101), UINT8_C(146),
        UINT8_C(200), UINT8_C( 53), UINT8_C( 48), UINT8_C(103), UINT8_C(117), UINT8_C(214), UINT8_C(244), UINT8_C(  9),
        UINT8_C( 36), UINT8_C( 37), UINT8_C(222), UINT8_C(143), UINT8_C(109), UINT8_C(127), UINT8_C(155), UINT8_C(105),
        UINT8_C(147), UINT8_C(134), UINT8_C( 99), UINT8_C(137), UINT8_C(191), UINT8_C(164), UINT8_C( 66), UINT8_C( 78),
        UINT8_C(186), UINT8_C(239), UINT8_C(143), UINT8_C( 58), UINT8_C( 71), UINT8_C(245), UINT8_C(204), UINT8_C( 15),
        UINT8_C( 42), UINT8_C(252), UINT8_C(118), UINT8_C(160), UINT8_C(210), UINT8_C(107), UINT8_C(169), UINT8_C(246),
        UINT8_C(144), UINT8_C(135), UINT8_C(134), UINT8_C(254), UINT8_C(  7), UINT8_C( 33), UINT8_C(103), UINT8_C(154),
        UINT8_C(167), UINT8_C(202), UINT8_C( 35), UINT8_C(103), UINT8_C(110), UINT8_C(101), UINT8_C(181), UINT8_C( 40) },
      { UINT8_C( 71), UINT8_C(201), UINT8_C(144), UINT8_C( 65), UINT8_C(106), UINT8_C(130), UINT8_C(176), UINT8_C(146),
        UINT8_C(171), UINT8_C( 53), UINT8_C( 76), UINT8_C(168), UINT8_C(109), UINT8_C( 77), UINT8_C(222), UINT8_C(  8),
        UINT8_C(188), UINT8_C( 56), UINT8_C(168), UINT8_C(143), UINT8_C( 66), UINT8_C( 34), UINT8_C(206), UINT8_C(105),
        UINT8_C(147), UINT8_C(134), UINT8_C( 99), UINT8_C( 31), UINT8_C( 34), UINT8_C(164), UINT8_C( 11), UINT8_C( 70),
        UINT8_C(190), UINT8_C(155), UINT8_C( 13), UINT8_C( 41), UINT8_C( 29), UINT8_C(189), UINT8_C(171), UINT8_C(201),
        UINT8_C( 18), UINT8_C(112), UINT8_C(113), UINT8_C(157), UINT8_C( 72), UINT8_C( 79), UINT8_C(166), UINT8_C(  5),
        UINT8_C(135), UINT8_C( 22), UINT8_C( 20), UINT8_C( 13), UINT8_C(  7), UINT8_C( 33), UINT8_C(103), UINT8_C(196),
        UINT8_C(167), UINT8_C(191), UINT8_C( 35), UINT8_C(103), UINT8_C(181), UINT8_C( 57), UINT8_C( 64), UINT8_C(115) } },
    { {  INT8_C(  85),  INT8_C(  69),  INT8_C(  98), -INT8_C( 100),  INT8_C(  58),  INT8_C(  47), -INT8_C(  84),  INT8_C( 100),
         INT8_C(  43),  INT8_C(  34),  INT8_C(   4), -INT8_C(   2), -INT8_C( 115), -INT8_C(  83), -INT8_C(  12),  INT8_C(  30),
         INT8_C(  53),  INT8_C( 122),  INT8_C(  28),  INT8_C(  60), -INT8_C( 101), -INT8_C( 125), -INT8_C(  42),  INT8_C(  67),
         INT8_C(  77), -INT8_C(   7), -INT8_C(  86), -INT8_C(  68),  INT8_C(  94),  INT8_C(  95), -INT8_C(  28), -INT8_C(  77),
        -INT8_C(  92),  INT8_C(  71),  INT8_C(  80), -INT8_C(  34),  INT8_C( 118), -INT8_C(   4),  INT8_C(  67), -INT8_C(  95),
         INT8_C(  30),  INT8_C(  71), -INT8_C(  97), -INT8_C(  84), -INT8_C(  11), -INT8_C( 108), -INT8_C(  54),  INT8_C(  42),
         INT8_C(  14), -INT8_C(  26),  INT8_C( 102), -INT8_C(  86),  INT8_C( 105),  INT8_C(  60), -INT8_C(  19), -INT8_C(  74),
         INT8_C(  53), -INT8_C( 105),  INT8_C( 114), -INT8_C( 109), -INT8_C(  10),  INT8_C(  87),  INT8_C(  71), -INT8_C( 101) },
      UINT64_C(12805348455387600798),
      { UINT8_C(  4), UINT8_C( 85), UINT8_C( 93), UINT8_C(249), UINT8_C(233), UINT8_C( 39), UINT8_C( 35), UINT8_C(247),
        UINT8_C( 13), UINT8_C(137), UINT8_C(161), UINT8_C(118), UINT8_C(197), UINT8_C(142), UINT8_C( 45), UINT8_C(250),
        UINT8_C( 37), UINT8_C(159), UINT8_C(141), UINT8_C( 28), UINT8_C(246), UINT8_C(212), UINT8_C(183), UINT8_C(148),
        UINT8_C(107), UINT8_C( 48), UINT8_C(168), UINT8_C(254), UINT8_C(237), UINT8_C( 94), UINT8_C(176), UINT8_C(241),
        UINT8_C(179), UINT8_C( 13), UINT8_C(234), UINT8_C(156), UINT8_C( 53), UINT8_C( 13), UINT8_C(147), UINT8_C( 66),
        UINT8_C(150), UINT8_C( 53), UINT8_C(185), UINT8_C( 91), UINT8_C(195), UINT8_C(230), UINT8_C( 85), UINT8_C(233),
        UINT8_C(133), UINT8_C(226), UINT8_C(  5), UINT8_C(124), UINT8_C(183), UINT8_C(188), UINT8_C( 16), UINT8_C( 34),
        UINT8_C(236), UINT8_C(185), UINT8_C( 33), UINT8_C(217), UINT8_C( 23), UINT8_C(209), UINT8_C(202), UINT8_C(202) },
      { UINT8_C(222), UINT8_C(180), UINT8_C(102), UINT8_C( 19), UINT8_C(193), UINT8_C(249), UINT8_C( 86), UINT8_C( 87),
        UINT8_C( 46), UINT8_C( 15), UINT8_C(178), UINT8_C(242), UINT8_C(245), UINT8_C(  7), UINT8_C(219), UINT8_C(122),
        UINT8_C(234), UINT8_C(224), UINT8_C(246), UINT8_C(161), UINT8_C(156), UINT8_C(  7), UINT8_C(195), UINT8_C(136),
        UINT8_C(192), UINT8_C(228), UINT8_C( 98), UINT8_C(215), UINT8_C(181), UINT8_C( 44), UINT8_C(161), UINT8_C(148),
        UINT8_C(225), UINT8_C(  7), UINT8_C(167), UINT8_C(162), UINT8_C(  0), UINT8_C(253), UINT8_C(250), UINT8_C( 47),
        UINT8_C( 12), UINT8_C(172), UINT8_C( 33), UINT8_C(  1), UINT8_C(180), UINT8_C(252), UINT8_C(124), UINT8_C(158),
        UINT8_C(220), UINT8_C(114), UINT8_C( 63), UINT8_C(120), UINT8_C(121), UINT8_C(  2), UINT8_C(  0), UINT8_C( 57),
        UINT8_C(231), UINT8_C( 98), UINT8_C( 16), UINT8_C(156), UINT8_C(143), UINT8_C(177), UINT8_C( 48), UINT8_C(112) },
      { UINT8_C( 85), UINT8_C( 85), UINT8_C( 93), UINT8_C( 19), UINT8_C(193), UINT8_C( 47), UINT8_C(172), UINT8_C( 87),
        UINT8_C( 13), UINT8_C( 15), UINT8_C(161), UINT8_C(254), UINT8_C(197), UINT8_C(173), UINT8_C(244), UINT8_C(122),
        UINT8_C( 37), UINT8_C(122), UINT8_C( 28), UINT8_C( 28), UINT8_C(156), UINT8_C(  7), UINT8_C(183), UINT8_C( 67),
        UINT8_C( 77), UINT8_C(249), UINT8_C( 98), UINT8_C(188), UINT8_C(181), UINT8_C( 95), UINT8_C(228), UINT8_C(179),
        UINT8_C(179), UINT8_C(  7), UINT8_C( 80), UINT8_C(222), UINT8_C(  0), UINT8_C(252), UINT8_C( 67), UINT8_C( 47),
        UINT8_C( 30), UINT8_C( 71), UINT8_C( 33), UINT8_C(  1), UINT8_C(180), UINT8_C(230), UINT8_C(202), UINT8_C(158),
        UINT8_C(133), UINT8_C(230), UINT8_C(  5), UINT8_C(170), UINT8_C(121), UINT8_C(  2), UINT8_C(237), UINT8_C( 34),
        UINT8_C(231), UINT8_C(151), UINT8_C(114), UINT8_C(147), UINT8_C( 23), UINT8_C(177), UINT8_C( 71), UINT8_C(112) } },
    { { -INT8_C(  72), -INT8_C(  40),  INT8_C(  18), -INT8_C(  71), -INT8_C(  43),  INT8_C(  12), -INT8_C(  24), -INT8_C(  30),
        -INT8_C(  71),  INT8_C(   9), -INT8_C(  29),  INT8_C( 109),  INT8_C(   5),  INT8_C(  95),  INT8_C(  11), -INT8_C(  31),
        -INT8_C(  46),  INT8_C(  74),  INT8_C(  89),  INT8_C(  75),  INT8_C(  76),  INT8_C(  89), -INT8_C( 123),  INT8_C(  51),
        -INT8_C(  68), -INT8_C( 107), -INT8_C(  48),  INT8_C(  75),  INT8_C(  71),  INT8_C(   0), -INT8_C(  69), -INT8_C(   1),
        -INT8_C(  40), -INT8_C(  51), -INT8_C(  72), -INT8_C(  82), -INT8_C(  38), -INT8_C(  96), -INT8_C( 112), -INT8_C( 109),
        -INT8_C(  87),  INT8_C( 115),  INT8_C(   0), -INT8_C(  82), -INT8_C(  45),  INT8_C(  11), -INT8_C( 113), -INT8_C(  91),
         INT8_C(  85), -INT8_C(  24), -INT8_C(  16), -INT8_C(  95),  INT8_C(  66),  INT8_C( 117), -INT8_C(  43), -INT8_C(   2),
         INT8_C(  11), -INT8_C(  91),  INT8_C(  73),  INT8_C(  82), -INT8_C(  91),  INT8_C(   4),  INT8_C(  81),  INT8_C( 126) },
      UINT64_C( 6070496788944259793),
      { UINT8_C( 47), UINT8_C( 62), UINT8_C(  2), UINT8_C(  2), UINT8_C( 73), UINT8_C(146), UINT8_C(167), UINT8_C(158),
        UINT8_C(122), UINT8_C(152), UINT8_C( 64), UINT8_C(188), UINT8_C( 13), UINT8_C( 21), UINT8_C(186), UINT8_C( 24),
        UINT8_C(186), UINT8_C(  3), UINT8_C(106), UINT8_C( 95), UINT8_C(  7), UINT8_C(188), UINT8_C(221), UINT8_C(217),
        UINT8_C(198), UINT8_C(  9), UINT8_C(132), UINT8_C(112), UINT8_C(197), UINT8_C(195), UINT8_C(196), UINT8_C(245),
        UINT8_C(  1), UINT8_C(199), UINT8_C(247), UINT8_C( 75), UINT8_C( 89), UINT8_C(159), UINT8_C(233), UINT8_C(211),
        UINT8_C( 55), UINT8_C( 41), UINT8_C(144), UINT8_C( 68), UINT8_C( 62), UINT8_C( 74), UINT8_C( 93), UINT8_C(248),
        UINT8_C( 78), UINT8_C(199), UINT8_C( 88), UINT8_C( 85), UINT8_C(131), UINT8_C( 53), UINT8_C( 46), UINT8_C( 73),
        UINT8_C( 63), UINT8_C(179), UINT8_C(186), UINT8_C(  4), UINT8_C(118), UINT8_C(126), UINT8_C(249), UINT8_C(119) },
      { UINT8_C( 69), UINT8_C(241), UINT8_C(194), UINT8_C(158), UINT8_C(144), UINT8_C(172), UINT8_C(114), UINT8_C(199),
        UINT8_C(213), UINT8_C(  2), UINT8_C( 11), UINT8_C( 20), UINT8_C( 76), UINT8_C(104), UINT8_C( 12), UINT8_C(154),
        UINT8_C( 48), UINT8_C(100), UINT8_C(240), UINT8_C(179), UINT8_C(154), UINT8_C( 30), UINT8_C(253), UINT8_C(217),
        UINT8_C(209), UINT8_C(183), UINT8_C(221), UINT8_C( 71), UINT8_C( 53), UINT8_C(215), UINT8_C(191), UINT8_C(123),
        UINT8_C(200), UINT8_C(129), UINT8_C( 25), UINT8_C( 88), UINT8_C( 45), UINT8_C(139), UINT8_C( 31), UINT8_C(  3),
        UINT8_C(141), UINT8_C( 42), UINT8_C( 23), UINT8_C(218), UINT8_C(147), UINT8_C( 35), UINT8_C(116), UINT8_C(195),
        UINT8_C(136), UINT8_C(100), UINT8_C(118), UINT8_C( 34), UINT8_C(131), UINT8_C(115), UINT8_C(251), UINT8_C( 84),
        UINT8_C( 42), UINT8_C(216), UINT8_C(156), UINT8_C( 96), UINT8_C(175), UINT8_C( 91), UINT8_C(219), UINT8_C(119) },
      { UINT8_C( 47), UINT8_C(216), UINT8_C( 18), UINT8_C(185), UINT8_C( 73), UINT8_C( 12), UINT8_C(114), UINT8_C(158),
        UINT8_C(185), UINT8_C(  2), UINT8_C(227), UINT8_C( 20), UINT8_C(  5), UINT8_C( 95), UINT8_C( 11), UINT8_C(225),
        UINT8_C(210), UINT8_C( 74), UINT8_C(106), UINT8_C( 95), UINT8_C( 76), UINT8_C( 30), UINT8_C(133), UINT8_C( 51),
        UINT8_C(198), UINT8_C(  9), UINT8_C(208), UINT8_C( 71), UINT8_C( 71), UINT8_C(195), UINT8_C(187), UINT8_C(123),
        UINT8_C(216), UINT8_C(129), UINT8_C(184), UINT8_C( 75), UINT8_C(218), UINT8_C(139), UINT8_C(144), UINT8_C(  3),
        UINT8_C(169), UINT8_C(115), UINT8_C( 23), UINT8_C( 68), UINT8_C( 62), UINT8_C( 35), UINT8_C(143), UINT8_C(195),
        UINT8_C( 85), UINT8_C(100), UINT8_C( 88), UINT8_C( 34), UINT8_C(131), UINT8_C( 53), UINT8_C(213), UINT8_C(254),
        UINT8_C( 11), UINT8_C(165), UINT8_C(156), UINT8_C( 82), UINT8_C(118), UINT8_C(  4), UINT8_C(219), UINT8_C(126) } },
    { { -INT8_C(  36), -INT8_C(  12), -INT8_C(  49),  INT8_C(  10),      INT8_MIN, -INT8_C(  18),  INT8_C(  13),  INT8_C(  13),
         INT8_C(  25),  INT8_C(  36), -INT8_C(  25), -INT8_C(  84),  INT8_C(  71),  INT8_C(  92),  INT8_C( 111), -INT8_C(  49),
        -INT8_C(  64), -INT8_C(  27), -INT8_C(  15),  INT8_C(  67),  INT8_C(  89), -INT8_C(  20), -INT8_C( 104), -INT8_C( 125),
        -INT8_C(  59),  INT8_C(  52), -INT8_C(  29),  INT8_C( 116), -INT8_C( 113), -INT8_C(  66), -INT8_C(  20),  INT8_C( 107),
        -INT8_C(  77), -INT8_C(  69),  INT8_C( 117),  INT8_C(  51), -INT8_C(  86), -INT8_C( 126),  INT8_C(  64), -INT8_C(  61),
        -INT8_C(  90),  INT8_C(  40),  INT8_C( 111), -INT8_C(  18), -INT8_C( 124), -INT8_C(  34), -INT8_C(  67),  INT8_C(  68),
        -INT8_C(  61), -INT8_C(  81), -INT8_C( 120),  INT8_C(  28), -INT8_C( 101),  INT8_C(  32), -INT8_C(  96),  INT8_C(  96),
         INT8_C(  84), -INT8_C( 125), -INT8_C(  43), -INT8_C(  29),  INT8_C(  66), -INT8_C(  63),  INT8_C(  78), -INT8_C(  11) },
      UINT64_C(17143348107059709052),
      { UINT8_C(144), UINT8_C( 88), UINT8_C(219), UINT8_C( 20), UINT8_C( 54), UINT8_C(152), UINT8_C( 89), UINT8_C(250),
        UINT8_C( 71), UINT8_C(225), UINT8_C( 22), UINT8_C(227), UINT8_C(  1), UINT8_C(182), UINT8_C( 67), UINT8_C( 85),
        UINT8_C( 58), UINT8_C( 24), UINT8_C( 56), UINT8_C(124), UINT8_C(217), UINT8_C(134), UINT8_C(113), UINT8_C( 86),
        UINT8_C( 74), UINT8_C(153), UINT8_C(124), UINT8_C(145), UINT8_C(  1), UINT8_C(102), UINT8_C(126), UINT8_C(146),
        UINT8_C(190), UINT8_C( 89), UINT8_C(166), UINT8_C(245), UINT8_C(241),    UINT8_MAX, UINT8_C(239), UINT8_C( 57),
        UINT8_C(224), UINT8_C(  5), UINT8_C( 28), UINT8_C(225), UINT8_C(188), UINT8_C( 95), UINT8_C( 54), UINT8_C(246),
        UINT8_C(120), UINT8_C(110), UINT8_C(114), UINT8_C( 81), UINT8_C(245), UINT8_C(227), UINT8_C(167), UINT8_C( 63),
        UINT8_C(124), UINT8_C( 36), UINT8_C(208), UINT8_C(125), UINT8_C(138), UINT8_C( 78), UINT8_C( 15), UINT8_C( 72) },
      { UINT8_C(167), UINT8_C(182), UINT8_C( 61), UINT8_C(153), UINT8_C(181), UINT8_C( 44), UINT8_C(210), UINT8_C(150),
        UINT8_C( 50), UINT8_C(238), UINT8_C(119), UINT8_C(238), UINT8_C( 77), UINT8_C(174), UINT8_C(228), UINT8_C(197),
        UINT8_C( 28), UINT8_C( 86), UINT8_C( 23), UINT8_C( 17), UINT8_C( 57), UINT8_C(190), UINT8_C( 81), UINT8_C(181),
        UINT8_C(226), UINT8_C( 33), UINT8_C( 50), UINT8_C(108), UINT8_C(112), UINT8_C( 66), UINT8_C(181), UINT8_C( 23),
        UINT8_C(248), UINT8_C(242), UINT8_C(176), UINT8_C(173), UINT8_C( 31), UINT8_C(130), UINT8_C( 67), UINT8_C( 81),
        UINT8_C(112), UINT8_C(187), UINT8_C( 63), UINT8_C(190), UINT8_C(105), UINT8_C( 35), UINT8_C(131), UINT8_C(133),
        UINT8_C(121), UINT8_C(154), UINT8_C(151), UINT8_C(178), UINT8_C( 89), UINT8_C(232), UINT8_C(103), UINT8_C( 59),
        UINT8_C(  9), UINT8_C(153), UINT8_C(168), UINT8_C(121), UINT8_C(219), UINT8_C( 93), UINT8_C(145), UINT8_C(211) },
      { UINT8_C(220), UINT8_C(244), UINT8_C( 61), UINT8_C( 20), UINT8_C( 54), UINT8_C( 44), UINT8_C( 89), UINT8_C( 13),
        UINT8_C( 25), UINT8_C( 36), UINT8_C( 22), UINT8_C(172), UINT8_C( 71), UINT8_C( 92), UINT8_C( 67), UINT8_C( 85),
        UINT8_C(192), UINT8_C(229), UINT8_C(241), UINT8_C( 17), UINT8_C( 89), UINT8_C(134), UINT8_C(152), UINT8_C(131),
        UINT8_C(197), UINT8_C( 33), UINT8_C( 50), UINT8_C(116), UINT8_C(143), UINT8_C( 66), UINT8_C(236), UINT8_C(107),
        UINT8_C(179), UINT8_C( 89), UINT8_C(166), UINT8_C( 51), UINT8_C(170), UINT8_C(130), UINT8_C( 67), UINT8_C(195),
        UINT8_C(166), UINT8_C( 40), UINT8_C(111), UINT8_C(190), UINT8_C(132), UINT8_C( 35), UINT8_C( 54), UINT8_C( 68),
        UINT8_C(120), UINT8_C(175), UINT8_C(136), UINT8_C( 81), UINT8_C(155), UINT8_C(227), UINT8_C(103), UINT8_C( 59),
        UINT8_C(  9), UINT8_C(131), UINT8_C(168), UINT8_C(121), UINT8_C( 66), UINT8_C( 78), UINT8_C( 15), UINT8_C( 72) } }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
    simde__m512i src = simde_mm512_loadu_epi8(test_vec[i].src);
    simde__m512i a = simde_mm512_loadu_epi8(test_vec[i].a);
    simde__m512i b = simde_mm512_loadu_epi8(test_vec[i].b);
    simde__m512i r = simde_mm512_mask_min_epu8(src, test_vec[i].k, a, b);
    simde_test_x86_assert_equal_u8x64(r, simde_mm512_loadu_epi8(test_vec[i].r));
  }

  return 0;
}

static int
test_simde_mm512_maskz_min_epu8 (SIMDE_MUNIT_TEST_ARGS) {
  static const struct {
    const simde__mmask64 k;
    const uint8_t a[64];
    const uint8_t b[64];
    const uint8_t r[64];
  } test_vec[] = {
    { UINT64_C(17082286413152396594),
      { UINT8_C(176), UINT8_C(246), UINT8_C( 65), UINT8_C(226), UINT8_C( 97), UINT8_C(118), UINT8_C( 24), UINT8_C( 47),
        UINT8_C( 52), UINT8_C(202), UINT8_C( 14), UINT8_C( 44), UINT8_C(237), UINT8_C(159), UINT8_C( 11), UINT8_C(251),
        UINT8_C(132), UINT8_C(170), UINT8_C( 10), UINT8_C(208), UINT8_C( 36), UINT8_C( 92), UINT8_C( 27), UINT8_C( 86),
        UINT8_C(129), UINT8_C(137), UINT8_C(253), UINT8_C(125), UINT8_C(  1), UINT8_C( 13), UINT8_C(107), UINT8_C(178),
        UINT8_C(  3), UINT8_C(172), UINT8_C(148), UINT8_C(101), UINT8_C( 34), UINT8_C(172), UINT8_C(148), UINT8_C( 86),
        UINT8_C(119), UINT8_C(162), UINT8_C(131), UINT8_C(100), UINT8_C( 66), UINT8_C(142), UINT8_C( 95), UINT8_C(198),
        UINT8_C( 56), UINT8_C(106), UINT8_C(151), UINT8_C( 92), UINT8_C(198), UINT8_C(178), UINT8_C(178), UINT8_C( 72),
        UINT8_C( 59), UINT8_C(175), UINT8_C(197), UINT8_C( 61), UINT8_C(189), UINT8_C( 48), UINT8_C(239), UINT8_C(192) },
      { UINT8_C(220), UINT8_C(131), UINT8_C( 37), UINT8_C(254), UINT8_C( 48), UINT8_C(185), UINT8_C( 85), UINT8_C(167),
        UINT8_C( 92), UINT8_C(216), UINT8_C( 11), UINT8_C(158), UINT8_C(102), UINT8_C(107), UINT8_C(100), UINT8_C(158),
        UINT8_C(213), UINT8_C(251), UINT8_C(251), UINT8_C(155), UINT8_C(173), UINT8_C(173), UINT8_C(227), UINT8_C(233),
        UINT8_C( 93), UINT8_C(169), UINT8_C( 38), UINT8_C( 26), UINT8_C(217), UINT8_C( 21), UINT8_C(218), UINT8_C(182),
        UINT8_C(152), UINT8_C(  0), UINT8_C(180), UINT8_C(200), UINT8_C(185), UINT8_C(  9), UINT8_C(111), UINT8_C( 21),
        UINT8_C(225), UINT8_C(123), UINT8_C(179), UINT8_C( 71), UINT8_C(230), UINT8_C( 24), UINT8_C(230), UINT8_C(187),
        UINT8_C( 19), UINT8_C(225), UINT8_C( 86), UINT8_C(193), UINT8_C(142), UINT8_C( 58), UINT8_C(170), UINT8_C(235),
        UINT8_C(227), UINT8_C(208), UINT8_C(  5), UINT8_C(188), UINT8_C(229), UINT8_C(224), UINT8_C(114), UINT8_C(125) },
      { UINT8_C(  0), UINT8_C(131), UINT8_C(  0), UINT8_C(  0), UINT8_C( 48), UINT8_C(118), UINT8_C(  0), UINT8_C(  0),
        UINT8_C( 52), UINT8_C(  0), UINT8_C( 11), UINT8_C(  0), UINT8_C(  0), UINT8_C(107), UINT8_C(  0), UINT8_C(  0),
        UINT8_C(  0), UINT8_C(170), UINT8_C( 10), UINT8_C(155), UINT8_C(  0), UINT8_C( 92), UINT8_C( 27), UINT8_C(  0),
        UINT8_C( 93), UINT8_C(137), UINT8_C( 38), UINT8_C(  0), UINT8_C(  0), UINT8_C( 13), UINT8_C(  0), UINT8_C(178),
        UINT8_C(  0), UINT8_C(  0), UINT8_C(148), UINT8_C(101), UINT8_C( 34), UINT8_C(  9), UINT8_C(111), UINT8_C( 21),
        UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C( 71), UINT8_C( 66), UINT8_C( 24), UINT8_C( 95), UINT8_C(  0),
        UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(142), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
        UINT8_C( 59), UINT8_C(  0), UINT8_C(  5), UINT8_C( 61), UINT8_C(  0), UINT8_C( 48), UINT8_C(114), UINT8_C(125) } },
    { UINT64_C( 1346494033941637088),
      { UINT8_C( 48), UINT8_C( 98), UINT8_C( 89), UINT8_C( 22), UINT8_C(122), UINT8_C( 63), UINT8_C(209), UINT8_C(142),
        UINT8_C( 32), UINT8_C( 40), UINT8_C( 79), UINT8_C(175), UINT8_C( 98), UINT8_C(249), UINT8_C(154), UINT8_C( 69),
        UINT8_C(201), UINT8_C(160), UINT8_C(  1), UINT8_C(174), UINT8_C(128), UINT8_C(116), UINT8_C( 43), UINT8_C( 96),
        UINT8_C(155), UINT8_C(113), UINT8_C(249), UINT8_C(203), UINT8_C( 39), UINT8_C(168), UINT8_C(221), UINT8_C( 87),
        UINT8_C( 11), UINT8_C( 55), UINT8_C(110), UINT8_C(133), UINT8_C(118), UINT8_C( 63), UINT8_C( 19), UINT8_C(151),
        UINT8_C(103), UINT8_C( 98), UINT8_C( 70), UINT8_C(201), UINT8_C( 91), UINT8_C(224), UINT8_C( 14), UINT8_C( 36),
        UINT8_C(128), UINT8_C( 16), UINT8_C(210), UINT8_C(  0), UINT8_C(132), UINT8_C(254), UINT8_C( 96), UINT8_C( 31),
        UINT8_C(111), UINT8_C( 90), UINT8_C(234), UINT8_C(150), UINT8_C(  2), UINT8_C(200), UINT8_C(238), UINT8_C( 13) },
      {    UINT8_MAX, UINT8_C( 92), UINT8_C(147), UINT8_C(117), UINT8_C(155), UINT8_C(166), UINT8_C( 12), UINT8_C(  3),
        UINT8_C(  9), UINT8_C( 82), UINT8_C(204), UINT8_C(100), UINT8_C( 51), UINT8_C(219), UINT8_C(137), UINT8_C(179),
        UINT8_C(235), UINT8_C( 91), UINT8_C(180), UINT8_C(111), UINT8_C( 89), UINT8_C( 20), UINT8_C(142), UINT8_C(201),
        UINT8_C(110), UINT8_C(120), UINT8_C( 95), UINT8_C(113), UINT8_C( 64), UINT8_C( 77), UINT8_C(126), UINT8_C( 63),
        UINT8_C(169), UINT8_C( 17), UINT8_C(181), UINT8_C( 69), UINT8_C(184), UINT8_C(193), UINT8_C( 72), UINT8_C(193),
        UINT8_C( 20), UINT8_C( 20), UINT8_C( 37), UINT8_C( 71), UINT8_C(239), UINT8_C(174), UINT8_C(250), UINT8_C(218),
        UINT8_C( 10), UINT8_C(174), UINT8_C( 73), UINT8_C( 99), UINT8_C(195), UINT8_C(215), UINT8_C( 44), UINT8_C( 49),
        UINT8_C( 80), UINT8_C(140), UINT8_C(162), UINT8_C(144), UINT8_C(217), UINT8_C( 33), UINT8_C(208), UINT8_C(131) },
      { UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C( 63), UINT8_C( 12), UINT8_C(  3),
        UINT8_C(  9), UINT8_C( 40), UINT8_C( 79), UINT8_C(  0), UINT8_C(  0), UINT8_C(219), UINT8_C(  0), UINT8_C(  0),
        UINT8_C(  0), UINT8_C( 91), UINT8_C(  1), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C( 43), UINT8_C(  0),
        UINT8_C(110), UINT8_C(  0), UINT8_C(  0), UINT8_C(113), UINT8_C( 39), UINT8_C(  0), UINT8_C(  0), UINT8_C( 63),
        UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(118), UINT8_C( 63), UINT8_C(  0), UINT8_C(  0),
        UINT8_C( 20), UINT8_C(  0), UINT8_C( 37), UINT8_C(  0), UINT8_C( 91), UINT8_C(174), UINT8_C(  0), UINT8_C( 36),
        UINT8_C( 10), UINT8_C( 16), UINT8_C( 73), UINT8_C(  0), UINT8_C(  0), UINT8_C(215), UINT8_C(  0), UINT8_C( 31),
        UINT8_C(  0), UINT8_C( 90), UINT8_C(  0), UINT8_C(  0), UINT8_C(  2), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0) } },
    { UINT64_C( 6533333581203801394),
      { UINT8_C( 36), UINT8_C(209), UINT8_C(161), UINT8_C( 20), UINT8_C(127), UINT8_C(156), UINT8_C(238), UINT8_C(137),
        UINT8_C( 74), UINT8_C( 56), UINT8_C(237), UINT8_C( 13), UINT8_C( 15), UINT8_C( 25), UINT8_C( 63), UINT8_C( 95),
        UINT8_C(165), UINT8_C(225), UINT8_C(240), UINT8_C(127), UINT8_C(  2), UINT8_C(192), UINT8_C(  2), UINT8_C( 53),
        UINT8_C( 69), UINT8_C(202), UINT8_C( 31), UINT8_C(139), UINT8_C(218), UINT8_C(203), UINT8_C(230), UINT8_C(254),
        UINT8_C(156), UINT8_C(135), UINT8_C( 18), UINT8_C( 27), UINT8_C( 35), UINT8_C(  1), UINT8_C(165), UINT8_C(110),
        UINT8_C( 57), UINT8_C(146), UINT8_C(123), UINT8_C( 72), UINT8_C(171), UINT8_C(186), UINT8_C(168), UINT8_C( 81),
        UINT8_C(156), UINT8_C(152), UINT8_C(208), UINT8_C(158), UINT8_C( 88), UINT8_C(210), UINT8_C(211), UINT8_C(157),
        UINT8_C(156), UINT8_C(243), UINT8_C( 40), UINT8_C(118), UINT8_C(190), UINT8_C( 14), UINT8_C(116), UINT8_C( 90) },
      { UINT8_C(150), UINT8_C(135), UINT8_C(117), UINT8_C(185), UINT8_C(136), UINT8_C( 26), UINT8_C( 39), UINT8_C(193),
        UINT8_C(172), UINT8_C(163), UINT8_C(  9), UINT8_C( 88), UINT8_C( 93), UINT8_C(177), UINT8_C(169), UINT8_C(249),
        UINT8_C( 73), UINT8_C(121), UINT8_C(152), UINT8_C(161), UINT8_C( 75), UINT8_C(107), UINT8_C( 62), UINT8_C(231),
        UINT8_C( 94), UINT8_C(103), UINT8_C( 93), UINT8_C( 28), UINT8_C(117), UINT8_C(209), UINT8_C(118), UINT8_C( 11),
        UINT8_C( 88), UINT8_C(236), UINT8_C(197), UINT8_C(224), UINT8_C(  6), UINT8_C(236), UINT8_C(161), UINT8_C(179),
        UINT8_C(143), UINT8_C(171), UINT8_C( 11), UINT8_C(237), UINT8_C( 92), UINT8_C(180), UINT8_C(230), UINT8_C(166),
        UINT8_C( 45), UINT8_C(126), UINT8_C( 71), UINT8_C(120), UINT8_C(234), UINT8_C(134), UINT8_C( 95), UINT8_C( 72),
        UINT8_C(237), UINT8_C(188), UINT8_C(101), UINT8_C( 98), UINT8_C(141), UINT8_C(219), UINT8_C(110), UINT8_C(230) },
      { UINT8_C(  0), UINT8_C(135), UINT8_C(  0), UINT8_C(  0), UINT8_C(127), UINT8_C( 26), UINT8_C(  0), UINT8_C(  0),
        UINT8_C( 74), UINT8_C(  0), UINT8_C(  9), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C( 95),
        UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(127), UINT8_C(  0), UINT8_C(  0), UINT8_C(  2), UINT8_C( 53),
        UINT8_C(  0), UINT8_C(103), UINT8_C(  0), UINT8_C( 28), UINT8_C(  0), UINT8_C(203), UINT8_C(118), UINT8_C( 11),
        UINT8_C(  0), UINT8_C(135), UINT8_C( 18), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(161), UINT8_C(  0),
        UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C( 92), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
        UINT8_C( 45), UINT8_C(126), UINT8_C(  0), UINT8_C(120), UINT8_C(  0), UINT8_C(134), UINT8_C(  0), UINT8_C( 72),
        UINT8_C(  0), UINT8_C(188), UINT8_C(  0), UINT8_C( 98), UINT8_C(141), UINT8_C(  0), UINT8_C(110), UINT8_C(  0) } },
    { UINT64_C(12646503714455434183),
      { UINT8_C( 19), UINT8_C(140), UINT8_C(156), UINT8_C(111), UINT8_C( 64), UINT8_C(130), UINT8_C( 21), UINT8_C(109),
        UINT8_C(  1), UINT8_C( 93), UINT8_C(229), UINT8_C(235), UINT8_C(227), UINT8_C( 68), UINT8_C( 51), UINT8_C(208),
        UINT8_C(  0), UINT8_C(152), UINT8_C( 50), UINT8_C(141), UINT8_C(116), UINT8_C(160), UINT8_C(115), UINT8_C( 59),
        UINT8_C(211), UINT8_C( 58), UINT8_C(  9), UINT8_C(243), UINT8_C(162), UINT8_C(138), UINT8_C(162), UINT8_C(181),
        UINT8_C( 22), UINT8_C( 62), UINT8_C( 36), UINT8_C( 86), UINT8_C(192), UINT8_C( 58), UINT8_C(195), UINT8_C(193),
        UINT8_C(151), UINT8_C(168), UINT8_C(172), UINT8_C(122), UINT8_C(236), UINT8_C(224), UINT8_C( 74), UINT8_C(236),
        UINT8_C(120), UINT8_C(124), UINT8_C(122), UINT8_C(236), UINT8_C( 29), UINT8_C(237), UINT8_C( 40), UINT8_C(240),
        UINT8_C( 39), UINT8_C( 49), UINT8_C(227), UINT8_C(201), UINT8_C(188), UINT8_C(133), UINT8_C(126), UINT8_C(210) },
      { UINT8_C(195), UINT8_C(163), UINT8_C( 41), UINT8_C(132), UINT8_C(221), UINT8_C(236), UINT8_C( 69), UINT8_C(116),
        UINT8_C(149), UINT8_C(242), UINT8_C(238), UINT8_C(129), UINT8_C(210), UINT8_C( 56), UINT8_C(110), UINT8_C( 74),
        UINT8_C(180), UINT8_C(232), UINT8_C( 55), UINT8_C(209), UINT8_C(213), UINT8_C( 95), UINT8_C(194), UINT8_C(253),
        UINT8_C(144), UINT8_C(165), UINT8_C(198), UINT8_C( 76), UINT8_C( 43), UINT8_C( 69), UINT8_C( 31), UINT8_C(238),
        UINT8_C(232), UINT8_C( 72), UINT8_C(114), UINT8_C(197), UINT8_C( 52), UINT8_C(184), UINT8_C( 57), UINT8_C(201),
        UINT8_C(170), UINT8_C( 39), UINT8_C( 75), UINT8_C(124), UINT8_C( 95), UINT8_C(185), UINT8_C(198), UINT8_C( 19),
        UINT8_C(161), UINT8_C(253), UINT8_C(229), UINT8_C(118), UINT8_C( 92), UINT8_C(167), UINT8_C(115), UINT8_C(237),
        UINT8_C( 76), UINT8_C( 58), UINT8_C( 57), UINT8_C(119), UINT8_C(127), UINT8_C( 88), UINT8_C(102), UINT8_C(103) },
      { UINT8_C( 19), UINT8_C(140), UINT8_C( 41), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C( 21), UINT8_C(109),
        UINT8_C(  1), UINT8_C( 93), UINT8_C(  0), UINT8_C(  0), UINT8_C(210), UINT8_C( 56), UINT8_C(  0), UINT8_C(  0),
        UINT8_C(  0), UINT8_C(152), UINT8_C( 50), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(115), UINT8_C( 59),
        UINT8_C(  0), UINT8_C( 58), UINT8_C(  9), UINT8_C( 76), UINT8_C(  0), UINT8_C(  0), UINT8_C( 31), UINT8_C(181),
        UINT8_C( 22), UINT8_C( 62), UINT8_C( 36), UINT8_C( 86), UINT8_C( 52), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
        UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(122), UINT8_C(  0), UINT8_C(185), UINT8_C( 74), UINT8_C(  0),
        UINT8_C(120), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(237),
        UINT8_C( 39), UINT8_C( 49), UINT8_C( 57), UINT8_C(119), UINT8_C(  0), UINT8_C( 88), UINT8_C(  0), UINT8_C(103) } },
    { UINT64_C( 4223925173246285984),
      { UINT8_C(140), UINT8_C(233), UINT8_C(182), UINT8_C(235), UINT8_C(162), UINT8_C(125), UINT8_C(254), UINT8_C( 67),
        UINT8_C(122), UINT8_C(227), UINT8_C(186), UINT8_C(215), UINT8_C(138), UINT8_C( 45), UINT8_C(196), UINT8_C(215),
        UINT8_C(103), UINT8_C(253), UINT8_C( 78), UINT8_C(230), UINT8_C( 86), UINT8_C(180), UINT8_C( 77), UINT8_C(246),
        UINT8_C(141), UINT8_C(121), UINT8_C(203), UINT8_C( 29), UINT8_C(222), UINT8_C(106), UINT8_C( 88), UINT8_C(106),
        UINT8_C( 83), UINT8_C( 14), UINT8_C( 85), UINT8_C(246), UINT8_C(139), UINT8_C( 84), UINT8_C( 57), UINT8_C(  6),
        UINT8_C( 55), UINT8_C(243), UINT8_C(221), UINT8_C(194), UINT8_C( 33), UINT8_C(161), UINT8_C(153), UINT8_C(136),
        UINT8_C(158), UINT8_C(231), UINT8_C(111), UINT8_C(244), UINT8_C(156), UINT8_C(188), UINT8_C(235), UINT8_C( 41),
        UINT8_C( 54), UINT8_C(182), UINT8_C( 70), UINT8_C( 20), UINT8_C( 32), UINT8_C(158), UINT8_C(127), UINT8_C(116) },
      { UINT8_C(173), UINT8_C(212), UINT8_C(106), UINT8_C( 56), UINT8_C( 40), UINT8_C(163), UINT8_C( 62), UINT8_C( 96),
        UINT8_C(151), UINT8_C( 27), UINT8_C( 34), UINT8_C(184), UINT8_C(188), UINT8_C(187), UINT8_C( 64), UINT8_C( 91),
        UINT8_C(162), UINT8_C(175), UINT8_C( 79), UINT8_C( 62), UINT8_C(108), UINT8_C( 58), UINT8_C(103), UINT8_C(162),
        UINT8_C(241), UINT8_C(174), UINT8_C(182), UINT8_C( 17), UINT8_C( 76), UINT8_C( 53), UINT8_C(133), UINT8_C(249),
        UINT8_C( 10), UINT8_C(239), UINT8_C( 50), UINT8_C( 50), UINT8_C(147), UINT8_C(112), UINT8_C(146), UINT8_C( 42),
        UINT8_C(140), UINT8_C(180), UINT8_C(226), UINT8_C( 72), UINT8_C(111), UINT8_C( 34), UINT8_C(163), UINT8_C( 18),
        UINT8_C(210), UINT8_C(243), UINT8_C( 80), UINT8_C( 62), UINT8_C( 45), UINT8_C(184), UINT8_C(224), UINT8_C( 30),
        UINT8_C(102), UINT8_C(150), UINT8_C( 48), UINT8_C(178), UINT8_C(204), UINT8_C(181), UINT8_C(172), UINT8_C(214) },
      { UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(125), UINT8_C(  0), UINT8_C( 67),
        UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(184), UINT8_C(138), UINT8_C(  0), UINT8_C( 64), UINT8_C( 91),
        UINT8_C(  0), UINT8_C(  0), UINT8_C( 78), UINT8_C( 62), UINT8_C(  0), UINT8_C( 58), UINT8_C(  0), UINT8_C(  0),
        UINT8_C(141), UINT8_C(  0), UINT8_C(182), UINT8_C(  0), UINT8_C( 76), UINT8_C(  0), UINT8_C( 88), UINT8_C(106),
        UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(139), UINT8_C(  0), UINT8_C(  0), UINT8_C(  6),
        UINT8_C( 55), UINT8_C(  0), UINT8_C(221), UINT8_C(  0), UINT8_C(  0), UINT8_C( 34), UINT8_C(153), UINT8_C(  0),
        UINT8_C(  0), UINT8_C(231), UINT8_C( 80), UINT8_C( 62), UINT8_C( 45), UINT8_C(  0), UINT8_C(  0), UINT8_C( 30),
        UINT8_C(  0), UINT8_C(150), UINT8_C(  0), UINT8_C( 20), UINT8_C( 32), UINT8_C(158), UINT8_C(  0), UINT8_C(  0) } },
    { UINT64_C(15736310808235794085),
      { UINT8_C( 79), UINT8_C( 68), UINT8_C( 35), UINT8_C(191), UINT8_C(102), UINT8_C(198), UINT8_C(209), UINT8_C( 56),
        UINT8_C(185), UINT8_C( 33), UINT8_C(118), UINT8_C(231), UINT8_C(217), UINT8_C( 86), UINT8_C(  5), UINT8_C( 63),
        UINT8_C(237), UINT8_C( 53), UINT8_C(242), UINT8_C(185), UINT8_C(235), UINT8_C(158), UINT8_C(143), UINT8_C(144),
        UINT8_C(124), UINT8_C(151), UINT8_C(200), UINT8_C(202), UINT8_C( 50), UINT8_C( 42), UINT8_C(165), UINT8_C(130),
        UINT8_C(110), UINT8_C(200), UINT8_C( 65), UINT8_C(212), UINT8_C(142), UINT8_C( 18), UINT8_C( 13), UINT8_C( 72),
        UINT8_C( 51), UINT8_C(131), UINT8_C( 47), UINT8_C( 13), UINT8_C(218), UINT8_C( 52), UINT8_C( 76), UINT8_C(199),
        UINT8_C(106), UINT8_C( 62), UINT8_C(128), UINT8_C( 85), UINT8_C(220), UINT8_C( 15), UINT8_C(229), UINT8_C( 88),
        UINT8_C(166), UINT8_C(173), UINT8_C( 35), UINT8_C(217), UINT8_C(215), UINT8_C(200), UINT8_C( 91), UINT8_C( 69) },
      { UINT8_C(144), UINT8_C(156), UINT8_C( 25), UINT8_C( 30), UINT8_C(174), UINT8_C( 38), UINT8_C(102), UINT8_C(225),
        UINT8_C(170), UINT8_C(149), UINT8_C(238), UINT8_C(132), UINT8_C(202), UINT8_C( 59), UINT8_C( 75), UINT8_C( 52),
        UINT8_C(121), UINT8_C(203), UINT8_C(137), UINT8_C( 86), UINT8_C(218), UINT8_C(110), UINT8_C(174), UINT8_C(128),
        UINT8_C( 27), UINT8_C(209), UINT8_C( 89), UINT8_C(242), UINT8_C(153), UINT8_C(180), UINT8_C( 55), UINT8_C( 41),
        UINT8_C( 80), UINT8_C( 80), UINT8_C( 72), UINT8_C(254), UINT8_C(119), UINT8_C(174), UINT8_C(224), UINT8_C( 33),
        UINT8_C( 68), UINT8_C(206), UINT8_C(165), UINT8_C( 14), UINT8_C(  9), UINT8_C(240), UINT8_C( 66), UINT8_C(131),
        UINT8_C(187), UINT8_C(203), UINT8_C(217), UINT8_C(149), UINT8_C( 57), UINT8_C(135), UINT8_C( 21), UINT8_C( 84),
        UINT8_C( 89), UINT8_C(111), UINT8_C( 70), UINT8_C(242), UINT8_C( 35), UINT8_C(125), UINT8_C( 28), UINT8_C(116) },
      { UINT8_C( 79), UINT8_C(  0), UINT8_C( 25), UINT8_C(  0), UINT8_C(  0), UINT8_C( 38), UINT8_C(  0), UINT8_C( 56),
        UINT8_C(  0), UINT8_C( 33), UINT8_C(118), UINT8_C(132), UINT8_C(202), UINT8_C(  0), UINT8_C(  5), UINT8_C( 52),
        UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C( 86), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
        UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(202), UINT8_C( 50), UINT8_C( 42), UINT8_C(  0), UINT8_C(  0),
        UINT8_C(  0), UINT8_C( 80), UINT8_C( 65), UINT8_C(212), UINT8_C(  0), UINT8_C(  0), UINT8_C( 13), UINT8_C(  0),
        UINT8_C( 51), UINT8_C(131), UINT8_C(  0), UINT8_C( 13), UINT8_C(  9), UINT8_C(  0), UINT8_C(  0), UINT8_C(131),
        UINT8_C(  0), UINT8_C( 62), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C( 15), UINT8_C( 21), UINT8_C(  0),
        UINT8_C(  0), UINT8_C(111), UINT8_C(  0), UINT8_C(217), UINT8_C( 35), UINT8_C(  0), UINT8_C( 28), UINT8_C( 69) } },
    { UINT64_C( 6225472298320815309),
      { UINT8_C( 33), UINT8_C( 10), UINT8_C(100), UINT8_C( 42), UINT8_C(250), UINT8_C(166), UINT8_C(173), UINT8_C(181),
        UINT8_C(113), UINT8_C(134), UINT8_C( 74), UINT8_C(170), UINT8_C( 14), UINT8_C( 96), UINT8_C(254), UINT8_C(103),
        UINT8_C(207), UINT8_C( 68), UINT8_C( 89), UINT8_C(242), UINT8_C(193), UINT8_C(117), UINT8_C(102), UINT8_C(143),
        UINT8_C(217), UINT8_C(217), UINT8_C(211), UINT8_C(236), UINT8_C( 43), UINT8_C( 57), UINT8_C( 66), UINT8_C( 76),
        UINT8_C( 67), UINT8_C(167), UINT8_C(119), UINT8_C( 62), UINT8_C( 77), UINT8_C( 36), UINT8_C(243), UINT8_C(191),
        UINT8_C(171), UINT8_C( 62), UINT8_C(105), UINT8_C(185), UINT8_C(158), UINT8_C(104), UINT8_C( 32), UINT8_C(109),
        UINT8_C(172), UINT8_C(121), UINT8_C( 95), UINT8_C(110), UINT8_C(239), UINT8_C(198), UINT8_C(253), UINT8_C(200),
        UINT8_C(159), UINT8_C(208), UINT8_C(180), UINT8_C(202), UINT8_C(  9), UINT8_C(247), UINT8_C( 23), UINT8_C( 77) },
      { UINT8_C(158), UINT8_C(142), UINT8_C(139), UINT8_C(235), UINT8_C(178), UINT8_C(126), UINT8_C(170), UINT8_C( 93),
        UINT8_C(188), UINT8_C( 20), UINT8_C( 22), UINT8_C( 90), UINT8_C(124), UINT8_C( 54), UINT8_C(199), UINT8_C( 40),
        UINT8_C(176), UINT8_C( 39), UINT8_C(150), UINT8_C(159), UINT8_C(237), UINT8_C(147), UINT8_C(103), UINT8_C(140),
        UINT8_C(100), UINT8_C( 28), UINT8_C( 86), UINT8_C(109), UINT8_C( 19), UINT8_C(109), UINT8_C(186), UINT8_C(177),
        UINT8_C(251), UINT8_C( 69), UINT8_C(156), UINT8_C(174), UINT8_C(196), UINT8_C( 71), UINT8_C( 11), UINT8_C(128),
        UINT8_C( 91), UINT8_C( 34), UINT8_C(219), UINT8_C(215), UINT8_C( 88), UINT8_C(162),    UINT8_MAX, UINT8_C(  8),
        UINT8_C(201), UINT8_C(150), UINT8_C(167), UINT8_C(182), UINT8_C( 41), UINT8_C( 15), UINT8_C( 66), UINT8_C(141),
        UINT8_C( 43), UINT8_C(153), UINT8_C(251), UINT8_C( 62), UINT8_C(  6), UINT8_C(181), UINT8_C(239), UINT8_C(  2) },
      { UINT8_C( 33), UINT8_C(  0), UINT8_C(100), UINT8_C( 42), UINT8_C(  0), UINT8_C(  0), UINT8_C(170), UINT8_C( 93),
        UINT8_C(  0), UINT8_C(  0), UINT8_C( 22), UINT8_C(  0), UINT8_C(  0), UINT8_C( 54), UINT8_C(199), UINT8_C(  0),
        UINT8_C(  0), UINT8_C( 39), UINT8_C(  0), UINT8_C(  0), UINT8_C(193), UINT8_C(117), UINT8_C(102), UINT8_C(  0),
        UINT8_C(  0), UINT8_C(  0), UINT8_C( 86), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C( 66), UINT8_C(  0),
        UINT8_C(  0), UINT8_C( 69), UINT8_C(  0), UINT8_C(  0), UINT8_C( 77), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
        UINT8_C(  0), UINT8_C( 34), UINT8_C(  0), UINT8_C(  0), UINT8_C( 88), UINT8_C(  0), UINT8_C( 32), UINT8_C(  0),
        UINT8_C(172), UINT8_C(  0), UINT8_C( 95), UINT8_C(  0), UINT8_C(  0), UINT8_C( 15), UINT8_C( 66), UINT8_C(  0),
        UINT8_C(  0), UINT8_C(153), UINT8_C(180), UINT8_C(  0), UINT8_C(  6), UINT8_C(  0), UINT8_C( 23), UINT8_C(  0) } },
    { UINT64_C( 3260531169073073147),
      { UINT8_C(221), UINT8_C( 26), UINT8_C(  4), UINT8_C( 54), UINT8_C(189), UINT8_C(  4), UINT8_C( 62), UINT8_C(134),
        UINT8_C(154), UINT8_C(230), UINT8_C( 61), UINT8_C(195), UINT8_C(245), UINT8_C(127), UINT8_C( 81), UINT8_C( 32),
        UINT8_C( 24), UINT8_C( 76), UINT8_C( 94), UINT8_C( 31), UINT8_C(  1), UINT8_C( 77), UINT8_C( 33), UINT8_C(252),
        UINT8_C(216), UINT8_C(209), UINT8_C(187), UINT8_C(171), UINT8_C(140), UINT8_C(251), UINT8_C(216), UINT8_C(106),
        UINT8_C( 21), UINT8_C(221), UINT8_C(160), UINT8_C(210), UINT8_C(225), UINT8_C(222), UINT8_C( 89), UINT8_C(123),
        UINT8_C(196), UINT8_C(150), UINT8_C( 62), UINT8_C(185), UINT8_C( 21), UINT8_C(143), UINT8_C(217), UINT8_C( 46),
        UINT8_C(219), UINT8_C( 55), UINT8_C( 77), UINT8_C(221), UINT8_C(132), UINT8_C(110), UINT8_C(217), UINT8_C( 93),
        UINT8_C( 63), UINT8_C(149), UINT8_C(  8), UINT8_C(203), UINT8_C(144), UINT8_C(224), UINT8_C( 53), UINT8_C(165) },
      { UINT8_C(189), UINT8_C(213), UINT8_C(120), UINT8_C(158), UINT8_C(180), UINT8_C(209), UINT8_C( 25), UINT8_C(120),
        UINT8_C(103), UINT8_C( 88), UINT8_C( 50), UINT8_C(124), UINT8_C(231), UINT8_C( 11), UINT8_C(170), UINT8_C(195),
        UINT8_C( 67), UINT8_C(247), UINT8_C(160), UINT8_C(199), UINT8_C(101), UINT8_C(121), UINT8_C( 36), UINT8_C(164),
        UINT8_C( 14), UINT8_C( 44), UINT8_C(112), UINT8_C(158), UINT8_C( 13), UINT8_C(165), UINT8_C( 68), UINT8_C(202),
        UINT8_C(123), UINT8_C(188), UINT8_C(105), UINT8_C( 47), UINT8_C(141), UINT8_C(130), UINT8_C(167), UINT8_C(244),
        UINT8_C(218), UINT8_C(217), UINT8_C(112), UINT8_C(194), UINT8_C(229), UINT8_C( 27), UINT8_C(133), UINT8_C( 40),
        UINT8_C( 18), UINT8_C( 37), UINT8_C(239), UINT8_C(120), UINT8_C(158), UINT8_C( 20), UINT8_C( 28), UINT8_C(173),
        UINT8_C( 64), UINT8_C(140), UINT8_C( 75), UINT8_C( 77), UINT8_C( 50), UINT8_C(143), UINT8_C( 24), UINT8_C(173) },
      { UINT8_C(189), UINT8_C( 26), UINT8_C(  0), UINT8_C( 54), UINT8_C(180), UINT8_C(  4), UINT8_C( 25), UINT8_C(120),
        UINT8_C(103), UINT8_C( 88), UINT8_C(  0), UINT8_C(124), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C( 32),
        UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  1), UINT8_C( 77), UINT8_C(  0), UINT8_C(164),
        UINT8_C( 14), UINT8_C( 44), UINT8_C(112), UINT8_C(158), UINT8_C( 13), UINT8_C(165), UINT8_C(  0), UINT8_C(106),
        UINT8_C(  0), UINT8_C(188), UINT8_C(  0), UINT8_C(  0), UINT8_C(141), UINT8_C(  0), UINT8_C( 89), UINT8_C(123),
        UINT8_C(196), UINT8_C(150), UINT8_C(  0), UINT8_C(185), UINT8_C( 21), UINT8_C( 27), UINT8_C(  0), UINT8_C( 40),
        UINT8_C( 18), UINT8_C( 37), UINT8_C( 77), UINT8_C(120), UINT8_C(132), UINT8_C( 20), UINT8_C(  0), UINT8_C(  0),
        UINT8_C( 63), UINT8_C(  0), UINT8_C(  8), UINT8_C( 77), UINT8_C(  0), UINT8_C(143), UINT8_C(  0), UINT8_C(  0) } }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
    simde__m512i a = simde_mm512_loadu_epi8(test_vec[i].a);
    simde__m512i b = simde_mm512_loadu_epi8(test_vec[i].b);
    simde__m512i r = simde_mm512_maskz_min_epu8(test_vec[i].k, a, b);
    simde_test_x86_assert_equal_u8x64(r, simde_mm512_loadu_epi8(test_vec[i].r));
  }

  return 0;
}

static int
test_simde_mm512_max_epi8 (SIMDE_MUNIT_TEST_ARGS) {
  static const struct {
    const int8_t a[64];
    const int8_t b[64];
    const int8_t r[64];
  } test_vec[] = {
    { {  INT8_C(  99),  INT8_C(  57),  INT8_C(  67), -INT8_C(   9), -INT8_C(   6),  INT8_C(  33), -INT8_C( 124),  INT8_C(  36),
         INT8_C(  33),  INT8_C(  54), -INT8_C(  88), -INT8_C(  42), -INT8_C(   2),  INT8_C( 100), -INT8_C(  20), -INT8_C(  26),
         INT8_C(  12),  INT8_C(  68), -INT8_C(  19),  INT8_C(   5),  INT8_C(  93), -INT8_C(  21),      INT8_MAX,  INT8_C( 103),
         INT8_C( 108),  INT8_C(  29),  INT8_C(  35), -INT8_C(  11),  INT8_C(  48),  INT8_C(  37), -INT8_C(  11), -INT8_C( 108),
         INT8_C(  94),  INT8_C(  56), -INT8_C( 117),  INT8_C(  88),  INT8_C(  89),  INT8_C(  15),  INT8_C( 124),  INT8_C( 122),
         INT8_C(  69),  INT8_C(  37),  INT8_C(  80),  INT8_C(  67), -INT8_C( 119),  INT8_C(  60),  INT8_C(  42), -INT8_C( 107),
             INT8_MIN,  INT8_C(  23), -INT8_C( 102), -INT8_C(  34),  INT8_C(   2),  INT8_C(  26),  INT8_C(  69),  INT8_C( 111),
         INT8_C(  55),  INT8_C( 104),  INT8_C( 100),  INT8_C( 104), -INT8_C( 114),  INT8_C(  89), -INT8_C(   4), -INT8_C(  20) },
      { -INT8_C( 111), -INT8_C( 121),  INT8_C(  69), -INT8_C(  22), -INT8_C( 106), -INT8_C(  63),  INT8_C( 101), -INT8_C(  37),
        -INT8_C(  26), -INT8_C(  75),  INT8_C(  31),  INT8_C( 111), -INT8_C(  14),  INT8_C(  73),  INT8_C(   4),  INT8_C( 114),
         INT8_C(  96), -INT8_C(  97),  INT8_C(  80),  INT8_C(  98), -INT8_C(  71), -INT8_C( 106), -INT8_C(  47), -INT8_C(  16),
        -INT8_C(   2),  INT8_C(  54),  INT8_C(  88), -INT8_C( 116), -INT8_C( 113),  INT8_C(  84),  INT8_C( 121),  INT8_C(  33),
        -INT8_C(  37), -INT8_C(  66),  INT8_C(  11),  INT8_C( 113),      INT8_MAX,  INT8_C( 112),  INT8_C(  77),  INT8_C( 102),
         INT8_C(  38),  INT8_C( 108), -INT8_C(  43),  INT8_C(  24), -INT8_C(  75), -INT8_C(  38), -INT8_C( 118),  INT8_C(  21),
         INT8_C( 121), -INT8_C(  37),  INT8_C( 119),  INT8_C(  50),  INT8_C( 113),  INT8_C(  73),  INT8_C(  34),  INT8_C( 111),
             INT8_MAX,  INT8_C( 123), -INT8_C(   4),  INT8_C(  14), -INT8_C(  49),  INT8_C( 117),  INT8_C(  47), -INT8_C(  85) },
      {  INT8_C(  99),  INT8_C(  57),  INT8_C(  69), -INT8_C(   9), -INT8_C(   6),  INT8_C(  33),  INT8_C( 101),  INT8_C(  36),
         INT8_C(  33),  INT8_C(  54),  INT8_C(  31),  INT8_C( 111), -INT8_C(   2),  INT8_C( 100),  INT8_C(   4),  INT8_C( 114),
         INT8_C(  96),  INT8_C(  68),  INT8_C(  80),  INT8_C(  98),  INT8_C(  93), -INT8_C(  21),      INT8_MAX,  INT8_C( 103),
         INT8_C( 108),  INT8_C(  54),  INT8_C(  88), -INT8_C(  11),  INT8_C(  48),  INT8_C(  84),  INT8_C( 121),  INT8_C(  33),
         INT8_C(  94),  INT8_C(  56),  INT8_C(  11),  INT8_C( 113),      INT8_MAX,  INT8_C( 112),  INT8_C( 124),  INT8_C( 122),
         INT8_C(  69),  INT8_C( 108),  INT8_C(  80),  INT8_C(  67), -INT8_C(  75),  INT8_C(  60),  INT8_C(  42),  INT8_C(  21),
         INT8_C( 121),  INT8_C(  23),  INT8_C( 119),  INT8_C(  50),  INT8_C( 113),  INT8_C(  73),  INT8_C(  69),  INT8_C( 111),
             INT8_MAX,  INT8_C( 123),  INT8_C( 100),  INT8_C( 104), -INT8_C(  49),  INT8_C( 117),  INT8_C(  47), -INT8_C(  20) } },
    { {  INT8_C(  51),  INT8_C(  59),  INT8_C(  28), -INT8_C(  78), -INT8_C(  85),  INT8_C( 105),  INT8_C(  24), -INT8_C(  47),
        -INT8_C(  43), -INT8_C(  18), -INT8_C(  23), -INT8_C( 118), -INT8_C(  56),  INT8_C( 116), -INT8_C(  97),  INT8_C(  65),
         INT8_C(  79),  INT8_C(  23),  INT8_C( 115), -INT8_C(  64),  INT8_C(  96), -INT8_C( 107),  INT8_C(  47), -INT8_C(  33),
         INT8_C(  16),  INT8_C(  43), -INT8_C(  19), -INT8_C(  32), -INT8_C(  96),  INT8_C(  29), -INT8_C( 117), -INT8_C(  45),
         INT8_C(  88), -INT8_C(  89), -INT8_C( 122),  INT8_C(   3),  INT8_C(  17), -INT8_C(  98), -INT8_C(  43), -INT8_C(  26),
        -INT8_C( 116), -INT8_C(  66),  INT8_C( 113),  INT8_C(  84),  INT8_C(  50),  INT8_C(  16), -INT8_C( 107), -INT8_C( 127),
         INT8_C(  39),  INT8_C(   8),  INT8_C(  65), -INT8_C( 121), -INT8_C(  98),  INT8_C( 113),  INT8_C( 102), -INT8_C(  82),
        -INT8_C( 100),  INT8_C(  84), -INT8_C( 114),  INT8_C(  61),  INT8_C( 113),  INT8_C(  25),  INT8_C(  16), -INT8_C(  55) },
      { -INT8_C(  63), -INT8_C( 106), -INT8_C(  52), -INT8_C(  46),  INT8_C(  53), -INT8_C(  95), -INT8_C(  72), -INT8_C(  63),
         INT8_C(  96),  INT8_C(  41),  INT8_C(  22), -INT8_C( 110),  INT8_C(  58), -INT8_C(  85),  INT8_C(  20),  INT8_C(  97),
        -INT8_C(  76),  INT8_C(  85), -INT8_C(  23),  INT8_C(  82), -INT8_C(  58),  INT8_C(  79),  INT8_C(   0),  INT8_C(  99),
        -INT8_C(  93), -INT8_C( 113), -INT8_C(  96),  INT8_C(  20), -INT8_C(  88), -INT8_C(  80), -INT8_C(  35),  INT8_C( 105),
         INT8_C(  71), -INT8_C(  86),  INT8_C(  59),  INT8_C( 124),  INT8_C(  75), -INT8_C(  12),  INT8_C(  61), -INT8_C(  85),
         INT8_C(  29),  INT8_C(  83),  INT8_C(  62),  INT8_C(  87), -INT8_C(   1),  INT8_C(  82), -INT8_C(  71), -INT8_C(  77),
        -INT8_C(  89), -INT8_C(  94),  INT8_C(   5),  INT8_C( 110), -INT8_C(  15),  INT8_C(   5), -INT8_C(  47), -INT8_C( 107),
        -INT8_C( 108),  INT8_C( 113), -INT8_C(  87),  INT8_C(  61),  INT8_C(  33), -INT8_C( 121), -INT8_C(  90),  INT8_C( 104) },
      {  INT8_C(  51),  INT8_C(  59),  INT8_C(  28), -INT8_C(  46),  INT8_C(  53),  INT8_C( 105),  INT8_C(  24), -INT8_C(  47),
         INT8_C(  96),  INT8_C(  41),  INT8_C(  22), -INT8_C( 110),  INT8_C(  58),  INT8_C( 116),  INT8_C(  20),  INT8_C(  97),
         INT8_C(  79),  INT8_C(  85),  INT8_C( 115),  INT8_C(  82),  INT8_C(  96),  INT8_C(  79),  INT8_C(  47),  INT8_C(  99),
         INT8_C(  16),  INT8_C(  43), -INT8_C(  19),  INT8_C(  20), -INT8_C(  88),  INT8_C(  29), -INT8_C(  35),  INT8_C( 105),
         INT8_C(  88), -INT8_C(  86),  INT8_C(  59),  INT8_C( 124),  INT8_C(  75), -INT8_C(  12),  INT8_C(  61), -INT8_C(  26),
         INT8_C(  29),  INT8_C(  83),  INT8_C( 113),  INT8_C(  87),  INT8_C(  50),  INT8_C(  82), -INT8_C(  71), -INT8_C(  77),
         INT8_C(  39),  INT8_C(   8),  INT8_C(  65),  INT8_C( 110), -INT8_C(  15),  INT8_C( 113),  INT8_C( 102), -INT8_C(  82),
        -INT8_C( 100),  INT8_C( 113), -INT8_C(  87),  INT8_C(  61),  INT8_C( 113),  INT8_C(  25),  INT8_C(  16),  INT8_C( 104) } },
    { {  INT8_C(  49), -INT8_C(  30), -INT8_C(  28),  INT8_C( 124), -INT8_C(  42),  INT8_C(  34),  INT8_C(  40), -INT8_C(  13),
         INT8_C( 117),  INT8_C( 102),  INT8_C(  75),  INT8_C( 116), -INT8_C(  72),  INT8_C(   4),  INT8_C(  39),  INT8_C(  95),
        -INT8_C(  90),  INT8_C(  44), -INT8_C(  51), -INT8_C( 105),  INT8_C(  50), -INT8_C(  98),  INT8_C(  44), -INT8_C(  58),
         INT8_C(  15), -INT8_C(  42),  INT8_C(   3),  INT8_C(  49),  INT8_C(  93), -INT8_C(  86), -INT8_C( 103), -INT8_C( 114),
        -INT8_C( 116),  INT8_C( 126),  INT8_C(  10),  INT8_C(  98), -INT8_C(  96),  INT8_C(  50),  INT8_C(  85),  INT8_C(  21),
        -INT8_C( 104), -INT8_C(  96), -INT8_C( 118),  INT8_C(  80), -INT8_C(  92), -INT8_C(  79), -INT8_C(  80),  INT8_C(  74),
        -INT8_C(  34),  INT8_C( 125), -INT8_C(  30),  INT8_C(  16),  INT8_C(  28),  INT8_C(  14), -INT8_C(  42),  INT8_C(  43),
        -INT8_C(  28), -INT8_C(  38),  INT8_C(  92),  INT8_C(  65), -INT8_C( 124), -INT8_C(  10), -INT8_C(  49),  INT8_C(  16) },
      {  INT8_C( 116), -INT8_C(  38),  INT8_C( 114),  INT8_C(  20),  INT8_C(  12), -INT8_C(  57),  INT8_C(  41), -INT8_C(  91),
         INT8_C( 104), -INT8_C(  77), -INT8_C(  11),  INT8_C(  12),  INT8_C( 101), -INT8_C(  91),  INT8_C(  87),  INT8_C(  67),
         INT8_C(  35),  INT8_C(  57),  INT8_C(  83),  INT8_C(  63),  INT8_C(  71),  INT8_C(  41),  INT8_C( 106),  INT8_C(  44),
         INT8_C(   3), -INT8_C(  57),  INT8_C( 109), -INT8_C( 121), -INT8_C(  67),  INT8_C(  61), -INT8_C( 105),  INT8_C(  49),
         INT8_C(  23),  INT8_C(   9),  INT8_C(  69),  INT8_C(  35), -INT8_C(  47),  INT8_C( 110), -INT8_C(  56),  INT8_C(  57),
         INT8_C(  34), -INT8_C(  66),  INT8_C(  69), -INT8_C( 121),  INT8_C(  99), -INT8_C( 100), -INT8_C(  54), -INT8_C( 122),
        -INT8_C(  43),  INT8_C(  29), -INT8_C(  59),  INT8_C(  29),  INT8_C(  70),  INT8_C(  48),  INT8_C(  73),  INT8_C(  74),
        -INT8_C(   9), -INT8_C(  74), -INT8_C(  47), -INT8_C(  76), -INT8_C(  13),  INT8_C( 105), -INT8_C(  27),  INT8_C(  10) },
      {  INT8_C( 116), -INT8_C(  30),  INT8_C( 114),  INT8_C( 124),  INT8_C(  12),  INT8_C(  34),  INT8_C(  41), -INT8_C(  13),
         INT8_C( 117),  INT8_C( 102),  INT8_C(  75),  INT8_C( 116),  INT8_C( 101),  INT8_C(   4),  INT8_C(  87),  INT8_C(  95),
         INT8_C(  35),  INT8_C(  57),  INT8_C(  83),  INT8_C(  63),  INT8_C(  71),  INT8_C(  41),  INT8_C( 106),  INT8_C(  44),
         INT8_C(  15), -INT8_C(  42),  INT8_C( 109),  INT8_C(  49),  INT8_C(  93),  INT8_C(  61), -INT8_C( 103),  INT8_C(  49),
         INT8_C(  23),  INT8_C( 126),  INT8_C(  69),  INT8_C(  98), -INT8_C(  47),  INT8_C( 110),  INT8_C(  85),  INT8_C(  57),
         INT8_C(  34), -INT8_C(  66),  INT8_C(  69),  INT8_C(  80),  INT8_C(  99), -INT8_C(  79), -INT8_C(  54),  INT8_C(  74),
        -INT8_C(  34),  INT8_C( 125), -INT8_C(  30),  INT8_C(  29),  INT8_C(  70),  INT8_C(  48),  INT8_C(  73),  INT8_C(  74),
        -INT8_C(   9), -INT8_C(  38),  INT8_C(  92),  INT8_C(  65), -INT8_C(  13),  INT8_C( 105), -INT8_C(  27),  INT8_C(  16) } },
    { {  INT8_C( 114),  INT8_C(  42),  INT8_C(  46),  INT8_C(  67), -INT8_C( 104), -INT8_C(  10),  INT8_C( 124), -INT8_C(  70),
        -INT8_C(  76), -INT8_C(  62),  INT8_C(  65),  INT8_C(  24),  INT8_C(  94),  INT8_C(  11), -INT8_C(  98),  INT8_C(  52),
         INT8_C(  40),  INT8_C( 100),  INT8_C(  81),  INT8_C( 111), -INT8_C( 108), -INT8_C( 102), -INT8_C(  71), -INT8_C( 117),
         INT8_C(  80), -INT8_C( 118),  INT8_C(  63),  INT8_C(  68), -INT8_C(  13),  INT8_C(  36),  INT8_C(  78),  INT8_C( 102),
         INT8_C(  78),  INT8_C( 124), -INT8_C(  87), -INT8_C(  26),  INT8_C( 115),  INT8_C(  38), -INT8_C(  95),  INT8_C(  39),
        -INT8_C(  24), -INT8_C(  30),  INT8_C(  63),  INT8_C(  70), -INT8_C(  18), -INT8_C(  34),  INT8_C( 122),  INT8_C(  22),
         INT8_C(  66), -INT8_C(  53), -INT8_C( 123), -INT8_C(  42),  INT8_C( 101),  INT8_C(  62),  INT8_C(  97), -INT8_C(  74),
        -INT8_C(  55), -INT8_C(  96), -INT8_C(   6), -INT8_C(  68), -INT8_C(  60),  INT8_C(  72),  INT8_C(  34),  INT8_C(  18) },
      { -INT8_C(  59), -INT8_C(  52), -INT8_C(   8),  INT8_C(  56), -INT8_C(  14), -INT8_C( 103),  INT8_C(  95), -INT8_C(  38),
         INT8_C( 124), -INT8_C(  97),  INT8_C(  32),  INT8_C( 106),  INT8_C( 125), -INT8_C( 101),      INT8_MIN, -INT8_C(  65),
         INT8_C( 102),  INT8_C(   6), -INT8_C( 107), -INT8_C(  52),  INT8_C(  68), -INT8_C(  10), -INT8_C( 126),  INT8_C(  13),
        -INT8_C( 106),  INT8_C( 124), -INT8_C(  54),  INT8_C(  90), -INT8_C(  60), -INT8_C(  20),  INT8_C( 108), -INT8_C( 119),
        -INT8_C(  72),  INT8_C( 100), -INT8_C(  63), -INT8_C(  86), -INT8_C(   2),  INT8_C(  33), -INT8_C( 124),  INT8_C( 122),
        -INT8_C(  64), -INT8_C(  91), -INT8_C(  28),  INT8_C(  61),  INT8_C(  64),  INT8_C( 100), -INT8_C(   4), -INT8_C(  90),
         INT8_C( 106), -INT8_C( 111),  INT8_C( 114), -INT8_C(  81), -INT8_C( 121), -INT8_C(  12), -INT8_C(  68),  INT8_C(  29),
         INT8_C( 112), -INT8_C( 122),  INT8_C( 119),  INT8_C(  53),  INT8_C( 115), -INT8_C(  29), -INT8_C(  66),  INT8_C(  43) },
      {  INT8_C( 114),  INT8_C(  42),  INT8_C(  46),  INT8_C(  67), -INT8_C(  14), -INT8_C(  10),  INT8_C( 124), -INT8_C(  38),
         INT8_C( 124), -INT8_C(  62),  INT8_C(  65),  INT8_C( 106),  INT8_C( 125),  INT8_C(  11), -INT8_C(  98),  INT8_C(  52),
         INT8_C( 102),  INT8_C( 100),  INT8_C(  81),  INT8_C( 111),  INT8_C(  68), -INT8_C(  10), -INT8_C(  71),  INT8_C(  13),
         INT8_C(  80),  INT8_C( 124),  INT8_C(  63),  INT8_C(  90), -INT8_C(  13),  INT8_C(  36),  INT8_C( 108),  INT8_C( 102),
         INT8_C(  78),  INT8_C( 124), -INT8_C(  63), -INT8_C(  26),  INT8_C( 115),  INT8_C(  38), -INT8_C(  95),  INT8_C( 122),
        -INT8_C(  24), -INT8_C(  30),  INT8_C(  63),  INT8_C(  70),  INT8_C(  64),  INT8_C( 100),  INT8_C( 122),  INT8_C(  22),
         INT8_C( 106), -INT8_C(  53),  INT8_C( 114), -INT8_C(  42),  INT8_C( 101),  INT8_C(  62),  INT8_C(  97),  INT8_C(  29),
         INT8_C( 112), -INT8_C(  96),  INT8_C( 119),  INT8_C(  53),  INT8_C( 115),  INT8_C(  72),  INT8_C(  34),  INT8_C(  43) } },
    { {  INT8_C(  71),      INT8_MIN, -INT8_C(  42),  INT8_C(  69), -INT8_C(  95),  INT8_C(  90), -INT8_C(  65),  INT8_C(  97),
        -INT8_C(   1), -INT8_C(  93), -INT8_C(  98),  INT8_C(  63),  INT8_C(   8), -INT8_C( 102), -INT8_C(  26),  INT8_C( 114),
         INT8_C(  43),  INT8_C(  88),  INT8_C(  33), -INT8_C(  78),  INT8_C(  77), -INT8_C(  34), -INT8_C(  49), -INT8_C(  67),
         INT8_C( 100),  INT8_C(  70), -INT8_C(  14), -INT8_C(  41),  INT8_C(  41), -INT8_C(  79),  INT8_C(   3),  INT8_C( 112),
         INT8_C(  49), -INT8_C(  39), -INT8_C(  74), -INT8_C(  46),  INT8_C(  51),  INT8_C( 117),  INT8_C(  51),  INT8_C(  51),
         INT8_C(  25), -INT8_C(  47),  INT8_C( 114),  INT8_C(  33),  INT8_C( 107),  INT8_C(  88), -INT8_C( 109), -INT8_C( 106),
        -INT8_C(  79), -INT8_C(  75),  INT8_C(  72), -INT8_C(   2), -INT8_C( 109),  INT8_C(  23), -INT8_C(  69), -INT8_C(   9),
         INT8_C(  93), -INT8_C(  82), -INT8_C(  49), -INT8_C( 122),  INT8_C(  95), -INT8_C(  46), -INT8_C(  10), -INT8_C( 112) },
      { -INT8_C(  85), -INT8_C(  84),  INT8_C(  98), -INT8_C(  34),  INT8_C(  34), -INT8_C( 107),  INT8_C(  17),  INT8_C(  59),
         INT8_C( 102), -INT8_C( 124),  INT8_C(  92), -INT8_C(  47), -INT8_C(  36), -INT8_C(  17),  INT8_C( 103), -INT8_C( 115),
        -INT8_C(  92), -INT8_C(  81), -INT8_C( 117),  INT8_C(  55), -INT8_C(  58),  INT8_C(  71),  INT8_C(  47),  INT8_C(  35),
        -INT8_C(  11), -INT8_C(   2), -INT8_C(  87),  INT8_C(  84), -INT8_C(  48), -INT8_C(  97), -INT8_C(  28),  INT8_C( 123),
         INT8_C(  76),  INT8_C(  70),  INT8_C(  89),  INT8_C( 110), -INT8_C(  37),  INT8_C( 107), -INT8_C(  87),  INT8_C(  65),
        -INT8_C(  17),  INT8_C(   5),  INT8_C(  18), -INT8_C(  53), -INT8_C(  12),  INT8_C( 121),  INT8_C(  89), -INT8_C( 103),
         INT8_C(  40), -INT8_C(  28), -INT8_C(  48), -INT8_C(  18),  INT8_C(  43), -INT8_C(   1),  INT8_C(  17),  INT8_C(  32),
        -INT8_C(   3), -INT8_C(  70),  INT8_C( 116), -INT8_C(  51),  INT8_C(  89),  INT8_C(  88),  INT8_C(  72), -INT8_C(  91) },
      {  INT8_C(  71), -INT8_C(  84),  INT8_C(  98),  INT8_C(  69),  INT8_C(  34),  INT8_C(  90),  INT8_C(  17),  INT8_C(  97),
         INT8_C( 102), -INT8_C(  93),  INT8_C(  92),  INT8_C(  63),  INT8_C(   8), -INT8_C(  17),  INT8_C( 103),  INT8_C( 114),
         INT8_C(  43),  INT8_C(  88),  INT8_C(  33),  INT8_C(  55),  INT8_C(  77),  INT8_C(  71),  INT8_C(  47),  INT8_C(  35),
         INT8_C( 100),  INT8_C(  70), -INT8_C(  14),  INT8_C(  84),  INT8_C(  41), -INT8_C(  79),  INT8_C(   3),  INT8_C( 123),
         INT8_C(  76),  INT8_C(  70),  INT8_C(  89),  INT8_C( 110),  INT8_C(  51),  INT8_C( 117),  INT8_C(  51),  INT8_C(  65),
         INT8_C(  25),  INT8_C(   5),  INT8_C( 114),  INT8_C(  33),  INT8_C( 107),  INT8_C( 121),  INT8_C(  89), -INT8_C( 103),
         INT8_C(  40), -INT8_C(  28),  INT8_C(  72), -INT8_C(   2),  INT8_C(  43),  INT8_C(  23),  INT8_C(  17),  INT8_C(  32),
         INT8_C(  93), -INT8_C(  70),  INT8_C( 116), -INT8_C(  51),  INT8_C(  95),  INT8_C(  88),  INT8_C(  72), -INT8_C(  91) } },
    { { -INT8_C(  98), -INT8_C(  94),  INT8_C(  19),  INT8_C( 121),  INT8_C(  13), -INT8_C(  68), -INT8_C(  70), -INT8_C(   4),
        -INT8_C(  63), -INT8_C(  52), -INT8_C(  57), -INT8_C(  74),  INT8_C(  69),  INT8_C(  32),  INT8_C(  79),  INT8_C( 109),
         INT8_C(   5),  INT8_C(  31),  INT8_C(  91),  INT8_C(  48),  INT8_C(  31),  INT8_C( 108),  INT8_C(  81),  INT8_C(  28),
         INT8_C(  38), -INT8_C(  59), -INT8_C(  22),      INT8_MIN,  INT8_C(  30),  INT8_C(  50),  INT8_C(  37), -INT8_C(  68),
        -INT8_C(  44),  INT8_C(  57),  INT8_C(  54), -INT8_C(  31), -INT8_C(  11), -INT8_C(  16), -INT8_C(  35), -INT8_C(  73),
        -INT8_C(  67), -INT8_C(  91),  INT8_C( 109),  INT8_C(   2), -INT8_C(  59), -INT8_C(  68),  INT8_C( 112), -INT8_C(  54),
        -INT8_C(  37), -INT8_C(  53), -INT8_C(   5), -INT8_C(   6),  INT8_C(  56),  INT8_C(  76),  INT8_C(  23),  INT8_C(  94),
         INT8_C(  17),  INT8_C(   1), -INT8_C(  34),  INT8_C(  47),  INT8_C(  51),  INT8_C(   4), -INT8_C(  20),  INT8_C(   8) },
      {  INT8_C(  61),  INT8_C(  34), -INT8_C(  23),  INT8_C(  50),  INT8_C(  18), -INT8_C(  57), -INT8_C(  23), -INT8_C(  49),
         INT8_C( 108),  INT8_C(  86), -INT8_C(  46),  INT8_C(  49),  INT8_C(  18),  INT8_C(  66), -INT8_C(   4), -INT8_C(  18),
         INT8_C(  13), -INT8_C(   9), -INT8_C(  24),  INT8_C(  69),  INT8_C(  67), -INT8_C(   1), -INT8_C(  92),  INT8_C(  84),
         INT8_C(   0), -INT8_C( 126), -INT8_C( 124),  INT8_C(  52), -INT8_C( 122),  INT8_C( 112),  INT8_C(  60), -INT8_C(  61),
        -INT8_C( 110),  INT8_C(  37), -INT8_C(  10), -INT8_C(  92), -INT8_C(  20), -INT8_C(  33),  INT8_C( 116),  INT8_C(  88),
         INT8_C(  54),  INT8_C(  70), -INT8_C( 118),  INT8_C(  72), -INT8_C( 120), -INT8_C( 122),  INT8_C(  54), -INT8_C( 107),
         INT8_C( 125),  INT8_C(  31), -INT8_C(  37), -INT8_C(  64),  INT8_C(  30),      INT8_MAX,  INT8_C(  20),  INT8_C(  31),
         INT8_C(   1), -INT8_C( 104),  INT8_C(  83), -INT8_C( 120),  INT8_C(   8), -INT8_C( 113),  INT8_C(  75), -INT8_C( 102) },
      {  INT8_C(  61),  INT8_C(  34),  INT8_C(  19),  INT8_C( 121),  INT8_C(  18), -INT8_C(  57), -INT8_C(  23), -INT8_C(   4),
         INT8_C( 108),  INT8_C(  86), -INT8_C(  46),  INT8_C(  49),  INT8_C(  69),  INT8_C(  66),  INT8_C(  79),  INT8_C( 109),
         INT8_C(  13),  INT8_C(  31),  INT8_C(  91),  INT8_C(  69),  INT8_C(  67),  INT8_C( 108),  INT8_C(  81),  INT8_C(  84),
         INT8_C(  38), -INT8_C(  59), -INT8_C(  22),  INT8_C(  52),  INT8_C(  30),  INT8_C( 112),  INT8_C(  60), -INT8_C(  61),
        -INT8_C(  44),  INT8_C(  57),  INT8_C(  54), -INT8_C(  31), -INT8_C(  11), -INT8_C(  16),  INT8_C( 116),  INT8_C(  88),
         INT8_C(  54),  INT8_C(  70),  INT8_C( 109),  INT8_C(  72), -INT8_C(  59), -INT8_C(  68),  INT8_C( 112), -INT8_C(  54),
         INT8_C( 125),  INT8_C(  31), -INT8_C(   5), -INT8_C(   6),  INT8_C(  56),      INT8_MAX,  INT8_C(  23),  INT8_C(  94),
         INT8_C(  17),  INT8_C(   1),  INT8_C(  83),  INT8_C(  47),  INT8_C(  51),  INT8_C(   4),  INT8_C(  75),  INT8_C(   8) } },
    { { -INT8_C(  76),  INT8_C(  65),  INT8_C(  63), -INT8_C(  95),  INT8_C(  33), -INT8_C(  77), -INT8_C(   7),  INT8_C(  87),
        -INT8_C(   7), -INT8_C( 125), -INT8_C(  97), -INT8_C( 127),  INT8_C(   9), -INT8_C(  42),  INT8_C(  22), -INT8_C( 122),
        -INT8_C(  11), -INT8_C(  15),  INT8_C(  70),  INT8_C(  19),  INT8_C( 112),  INT8_C(  91),  INT8_C(  50),  INT8_C( 114),
        -INT8_C(  13), -INT8_C( 123), -INT8_C(   6), -INT8_C(   4),  INT8_C(  20),  INT8_C(  69), -INT8_C( 106), -INT8_C(  55),
        -INT8_C( 121), -INT8_C(  43),  INT8_C( 106), -INT8_C(  88), -INT8_C( 120),  INT8_C(  99), -INT8_C(   1), -INT8_C( 127),
        -INT8_C(  25), -INT8_C(  98),  INT8_C(   2), -INT8_C(  16),  INT8_C( 116),  INT8_C(  25),  INT8_C( 119),  INT8_C( 105),
         INT8_C(  10), -INT8_C(  67),  INT8_C( 125),  INT8_C( 123),  INT8_C(  24), -INT8_C(  81), -INT8_C(  19),  INT8_C(  12),
         INT8_C(  53), -INT8_C(  25),  INT8_C(   8),  INT8_C(  73),  INT8_C(  44), -INT8_C(  98),  INT8_C(  18), -INT8_C(  77) },
      {  INT8_C( 116),  INT8_C( 124),  INT8_C(  91), -INT8_C(   4), -INT8_C(  32),  INT8_C(  90),  INT8_C( 126), -INT8_C(  57),
        -INT8_C(   7),      INT8_MIN, -INT8_C(  73),  INT8_C( 109), -INT8_C( 103),  INT8_C(  46), -INT8_C(  41), -INT8_C(  92),
        -INT8_C(  20),  INT8_C(  84),  INT8_C(  31),  INT8_C(   4),  INT8_C(   3),  INT8_C(  12),  INT8_C(  16),  INT8_C(  56),
        -INT8_C(  13),  INT8_C(  24), -INT8_C( 126),  INT8_C(  31), -INT8_C(  73), -INT8_C( 108), -INT8_C(  45),  INT8_C(  43),
         INT8_C(  17),  INT8_C(  46),  INT8_C(  39), -INT8_C(  15), -INT8_C( 119), -INT8_C(  91), -INT8_C(  72), -INT8_C( 126),
         INT8_C(  38),  INT8_C( 111), -INT8_C(  17), -INT8_C(  65), -INT8_C(  98), -INT8_C(  58),  INT8_C(  99), -INT8_C( 118),
         INT8_C(  26), -INT8_C( 126), -INT8_C( 114),  INT8_C(  30), -INT8_C( 114), -INT8_C(  97),  INT8_C(  86), -INT8_C( 127),
        -INT8_C(  73), -INT8_C(  40), -INT8_C(  95),  INT8_C( 110),  INT8_C( 109),  INT8_C( 116), -INT8_C( 103),  INT8_C( 126) },
      {  INT8_C( 116),  INT8_C( 124),  INT8_C(  91), -INT8_C(   4),  INT8_C(  33),  INT8_C(  90),  INT8_C( 126),  INT8_C(  87),
        -INT8_C(   7), -INT8_C( 125), -INT8_C(  73),  INT8_C( 109),  INT8_C(   9),  INT8_C(  46),  INT8_C(  22), -INT8_C(  92),
        -INT8_C(  11),  INT8_C(  84),  INT8_C(  70),  INT8_C(  19),  INT8_C( 112),  INT8_C(  91),  INT8_C(  50),  INT8_C( 114),
        -INT8_C(  13),  INT8_C(  24), -INT8_C(   6),  INT8_C(  31),  INT8_C(  20),  INT8_C(  69), -INT8_C(  45),  INT8_C(  43),
         INT8_C(  17),  INT8_C(  46),  INT8_C( 106), -INT8_C(  15), -INT8_C( 119),  INT8_C(  99), -INT8_C(   1), -INT8_C( 126),
         INT8_C(  38),  INT8_C( 111),  INT8_C(   2), -INT8_C(  16),  INT8_C( 116),  INT8_C(  25),  INT8_C( 119),  INT8_C( 105),
         INT8_C(  26), -INT8_C(  67),  INT8_C( 125),  INT8_C( 123),  INT8_C(  24), -INT8_C(  81),  INT8_C(  86),  INT8_C(  12),
         INT8_C(  53), -INT8_C(  25),  INT8_C(   8),  INT8_C( 110),  INT8_C( 109),  INT8_C( 116),  INT8_C(  18),  INT8_C( 126) } },
    { { -INT8_C(  94), -INT8_C(  63),  INT8_C( 111),  INT8_C(  43),  INT8_C( 102),  INT8_C(  39), -INT8_C(  83), -INT8_C( 116),
        -INT8_C( 106), -INT8_C(  99),  INT8_C(  76),  INT8_C(  52),  INT8_C(  99), -INT8_C(  81), -INT8_C(  66),  INT8_C( 126),
         INT8_C(  50),  INT8_C(  77), -INT8_C( 100), -INT8_C(  64), -INT8_C(  20), -INT8_C(  14),  INT8_C(  66), -INT8_C(  93),
        -INT8_C(  53), -INT8_C(  29),  INT8_C(  18),  INT8_C(  56),  INT8_C(  87), -INT8_C(  85), -INT8_C(  74), -INT8_C(   7),
         INT8_C( 108),  INT8_C(  37),  INT8_C(  37), -INT8_C(  45),  INT8_C(  76), -INT8_C(  46),  INT8_C(  95), -INT8_C(  30),
         INT8_C( 111), -INT8_C(  85),  INT8_C(  23), -INT8_C(  45),  INT8_C(  91), -INT8_C(  43),  INT8_C(  81), -INT8_C( 115),
         INT8_C(  34), -INT8_C(  19),  INT8_C(  77),  INT8_C(  14), -INT8_C(  33), -INT8_C( 113), -INT8_C(  78), -INT8_C(  86),
         INT8_C( 114), -INT8_C(  60), -INT8_C(  30), -INT8_C(  55),  INT8_C( 111), -INT8_C( 104), -INT8_C(  61), -INT8_C(  36) },
      { -INT8_C(  67), -INT8_C(  24), -INT8_C(  81),  INT8_C(   9), -INT8_C(  70),  INT8_C(  14), -INT8_C(  20),  INT8_C(  42),
        -INT8_C(  70),  INT8_C(   3), -INT8_C(   3),  INT8_C(  21), -INT8_C(  40),  INT8_C(  78), -INT8_C(  94), -INT8_C(   5),
         INT8_C(  59), -INT8_C(  17),  INT8_C(   9),  INT8_C(  26),      INT8_MAX, -INT8_C(  69), -INT8_C(  59), -INT8_C(  15),
             INT8_MAX, -INT8_C(  89), -INT8_C(  69), -INT8_C(  17),  INT8_C(  64),  INT8_C( 126), -INT8_C(  53), -INT8_C(   3),
         INT8_C( 102),  INT8_C( 122),  INT8_C(   7),  INT8_C(  32), -INT8_C( 120), -INT8_C(  13),  INT8_C(  74),  INT8_C(  66),
        -INT8_C(  10),  INT8_C(  71),  INT8_C(  87), -INT8_C(  50), -INT8_C( 107), -INT8_C(   7), -INT8_C(  55), -INT8_C(  48),
        -INT8_C(  23), -INT8_C(  45), -INT8_C(  21),  INT8_C( 104), -INT8_C( 114), -INT8_C(  80),  INT8_C(  89),  INT8_C(  14),
         INT8_C(  87),  INT8_C(  20), -INT8_C(   3), -INT8_C( 105), -INT8_C( 110), -INT8_C(  56), -INT8_C( 107), -INT8_C(   8) },
      { -INT8_C(  67), -INT8_C(  24),  INT8_C( 111),  INT8_C(  43),  INT8_C( 102),  INT8_C(  39), -INT8_C(  20),  INT8_C(  42),
        -INT8_C(  70),  INT8_C(   3),  INT8_C(  76),  INT8_C(  52),  INT8_C(  99),  INT8_C(  78), -INT8_C(  66),  INT8_C( 126),
         INT8_C(  59),  INT8_C(  77),  INT8_C(   9),  INT8_C(  26),      INT8_MAX, -INT8_C(  14),  INT8_C(  66), -INT8_C(  15),
             INT8_MAX, -INT8_C(  29),  INT8_C(  18),  INT8_C(  56),  INT8_C(  87),  INT8_C( 126), -INT8_C(  53), -INT8_C(   3),
         INT8_C( 108),  INT8_C( 122),  INT8_C(  37),  INT8_C(  32),  INT8_C(  76), -INT8_C(  13),  INT8_C(  95),  INT8_C(  66),
         INT8_C( 111),  INT8_C(  71),  INT8_C(  87), -INT8_C(  45),  INT8_C(  91), -INT8_C(   7),  INT8_C(  81), -INT8_C(  48),
         INT8_C(  34), -INT8_C(  19),  INT8_C(  77),  INT8_C( 104), -INT8_C(  33), -INT8_C(  80),  INT8_C(  89),  INT8_C(  14),
         INT8_C( 114),  INT8_C(  20), -INT8_C(   3), -INT8_C(  55),  INT8_C( 111), -INT8_C(  56), -INT8_C(  61), -INT8_C(   8) } }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
    simde__m512i a = simde_mm512_loadu_epi8(test_vec[i].a);
    simde__m512i b = simde_mm512_loadu_epi8(test_vec[i].b);
    simde__m512i r = simde_mm512_max_epi8(a, b);
    simde_test_x86_assert_equal_i8x64(r, simde_mm512_loadu_epi8(test_vec[i].r));
  }

  return 0;
}

static int
test_simde_mm512_mask_max_epi8 (SIMDE_MUNIT_TEST_ARGS) {
  static const struct {
    const int8_t src[64];
    const simde__mmask64 k;
    const int8_t a[64];
    const int8_t b[64];
    const int8_t r[64];
  } test_vec[] = {
    { {  INT8_C(  47), -INT8_C( 108), -INT8_C( 103),  INT8_C(  35),  INT8_C(  58), -INT8_C(  33), -INT8_C(  38),  INT8_C(  76),
         INT8_C(  90),  INT8_C(  55), -INT8_C(  80),  INT8_C(  59),  INT8_C( 118),  INT8_C( 110),  INT8_C( 101),  INT8_C(  47),
        -INT8_C( 123), -INT8_C(  34), -INT8_C( 109),  INT8_C(  94), -INT8_C( 124),  INT8_C( 125),  INT8_C( 100), -INT8_C(  88),
         INT8_C( 110), -INT8_C(   4), -INT8_C(  17), -INT8_C(  46),  INT8_C(  96), -INT8_C(  12), -INT8_C(  10), -INT8_C( 113),
        -INT8_C( 120), -INT8_C( 113), -INT8_C(  78), -INT8_C(  62),  INT8_C( 110), -INT8_C( 115),  INT8_C(  15), -INT8_C(  55),
        -INT8_C(  60), -INT8_C(  65),  INT8_C(   4),  INT8_C(  58),  INT8_C(  46),  INT8_C( 105),  INT8_C( 106), -INT8_C(  77),
         INT8_C(  72), -INT8_C(   3),  INT8_C(  17), -INT8_C(  52),  INT8_C( 122),  INT8_C( 118),  INT8_C( 116), -INT8_C(  24),
         INT8_C( 114),  INT8_C( 100), -INT8_C(  70), -INT8_C(  46),  INT8_C(  88), -INT8_C(  79),  INT8_C(  97), -INT8_C(  31) },
      UINT64_C( 7311790402542179392),
      {  INT8_C( 114),  INT8_C( 124), -INT8_C(  97), -INT8_C(  96), -INT8_C(  27),  INT8_C(   9),  INT8_C(  83),  INT8_C(  45),
         INT8_C(   6),  INT8_C( 101), -INT8_C(   7),      INT8_MIN, -INT8_C(  37),  INT8_C( 110),  INT8_C( 104),  INT8_C(  77),
        -INT8_C(  46),  INT8_C(  35),  INT8_C(  31),  INT8_C(  42), -INT8_C(  44),      INT8_MIN,  INT8_C(  11),  INT8_C(  20),
        -INT8_C( 108), -INT8_C(  81), -INT8_C(  61),  INT8_C(  53),  INT8_C(  97),  INT8_C(  59), -INT8_C( 102), -INT8_C(  45),
        -INT8_C(  73),  INT8_C(  58),  INT8_C( 115), -INT8_C(  99),  INT8_C(  67), -INT8_C(  57), -INT8_C(  54),  INT8_C(  74),
         INT8_C(  44), -INT8_C(  60), -INT8_C(  54),  INT8_C(   7),  INT8_C(  50),  INT8_C(  51),  INT8_C(  84),  INT8_C(   4),
         INT8_C(  86),  INT8_C( 115),  INT8_C(  46),  INT8_C(  42), -INT8_C(  13),  INT8_C(  58),  INT8_C(  62), -INT8_C( 120),
        -INT8_C(  23),  INT8_C(   2), -INT8_C(  67),  INT8_C(  74),  INT8_C(  61),  INT8_C(  88),  INT8_C(  30), -INT8_C(  11) },
      { -INT8_C( 110), -INT8_C( 111), -INT8_C( 110), -INT8_C(  43),  INT8_C(  88),  INT8_C(  92),  INT8_C(  31), -INT8_C( 124),
         INT8_C(  32), -INT8_C(  22), -INT8_C( 117),  INT8_C(  82),  INT8_C(  29), -INT8_C(  33),  INT8_C(  86),  INT8_C( 115),
         INT8_C(  82), -INT8_C( 123), -INT8_C(  99),  INT8_C(  70), -INT8_C(  65), -INT8_C(  37), -INT8_C(  50), -INT8_C(  88),
        -INT8_C(  35), -INT8_C( 117), -INT8_C(  14),  INT8_C(  27), -INT8_C(  29),  INT8_C(  16),  INT8_C(  16),  INT8_C( 117),
        -INT8_C(  94), -INT8_C(  94),  INT8_C(  75), -INT8_C(   6), -INT8_C(   2),  INT8_C( 106),      INT8_MAX,  INT8_C(  31),
         INT8_C(  84),  INT8_C(  10),  INT8_C( 113),  INT8_C( 113), -INT8_C(  22), -INT8_C(  56), -INT8_C(  28),  INT8_C(  60),
         INT8_C(  77), -INT8_C( 127), -INT8_C( 126),  INT8_C(  12),  INT8_C(  93),  INT8_C(  80), -INT8_C(  76),  INT8_C(  58),
        -INT8_C(  36), -INT8_C(  90),  INT8_C(  85), -INT8_C(  65), -INT8_C(  73),  INT8_C( 101),  INT8_C(  53),  INT8_C(  89) },
      {  INT8_C(  47), -INT8_C( 108), -INT8_C( 103),  INT8_C(  35),  INT8_C(  58), -INT8_C(  33),  INT8_C(  83),  INT8_C(  76),
         INT8_C(  90),  INT8_C(  55), -INT8_C(   7),  INT8_C(  59),  INT8_C(  29),  INT8_C( 110),  INT8_C( 101),  INT8_C(  47),
         INT8_C(  82),  INT8_C(  35), -INT8_C( 109),  INT8_C(  94), -INT8_C( 124), -INT8_C(  37),  INT8_C( 100),  INT8_C(  20),
        -INT8_C(  35), -INT8_C(  81), -INT8_C(  14),  INT8_C(  53),  INT8_C(  96),  INT8_C(  59), -INT8_C(  10),  INT8_C( 117),
        -INT8_C(  73), -INT8_C( 113), -INT8_C(  78), -INT8_C(  62),  INT8_C( 110),  INT8_C( 106),  INT8_C(  15),  INT8_C(  74),
        -INT8_C(  60),  INT8_C(  10),  INT8_C(   4),  INT8_C(  58),  INT8_C(  50),  INT8_C(  51),  INT8_C( 106),  INT8_C(  60),
         INT8_C(  72), -INT8_C(   3),  INT8_C(  17),  INT8_C(  42),  INT8_C(  93),  INT8_C(  80),  INT8_C(  62), -INT8_C(  24),
        -INT8_C(  23),  INT8_C( 100),  INT8_C(  85), -INT8_C(  46),  INT8_C(  88),  INT8_C( 101),  INT8_C(  53), -INT8_C(  31) } },
    { {  INT8_C(   7),      INT8_MIN,  INT8_C(  83),  INT8_C(   6), -INT8_C(  22), -INT8_C(  46),  INT8_C(  37),  INT8_C(  63),
        -INT8_C(  35), -INT8_C( 106), -INT8_C(  80), -INT8_C(  57),  INT8_C(  94), -INT8_C( 107),  INT8_C(   3), -INT8_C(  85),
         INT8_C(  22), -INT8_C( 122), -INT8_C(  73),  INT8_C( 115), -INT8_C(  42),  INT8_C( 107), -INT8_C(  82), -INT8_C(  78),
         INT8_C(  18),  INT8_C(   3),  INT8_C( 114), -INT8_C(  55),  INT8_C( 105), -INT8_C(  89),  INT8_C(  34),  INT8_C( 112),
         INT8_C(  39),  INT8_C( 117),  INT8_C( 118),  INT8_C(  17),  INT8_C(  72), -INT8_C( 101),  INT8_C(  80),  INT8_C(  37),
         INT8_C(  50),  INT8_C(   1), -INT8_C(  20), -INT8_C( 112), -INT8_C( 106), -INT8_C(  17),  INT8_C(  60), -INT8_C(  84),
         INT8_C( 117), -INT8_C(  13),  INT8_C(  32),  INT8_C(  76),  INT8_C(  95), -INT8_C(  50), -INT8_C(   2),  INT8_C( 113),
        -INT8_C(  47),  INT8_C( 112),  INT8_C(  58),  INT8_C(  58),  INT8_C(  23),  INT8_C(  92), -INT8_C(  85),  INT8_C(  62) },
      UINT64_C(17239393157654782417),
      { -INT8_C(  95),  INT8_C(  42),      INT8_MAX,  INT8_C(  55),  INT8_C(  26), -INT8_C(  69), -INT8_C(  28), -INT8_C( 113),
        -INT8_C(  81),  INT8_C(   4), -INT8_C(  37),  INT8_C(  14), -INT8_C(  46), -INT8_C(  38),      INT8_MAX, -INT8_C(  93),
         INT8_C(  74), -INT8_C(  71), -INT8_C(  34),  INT8_C(  98),  INT8_C(  21), -INT8_C( 119), -INT8_C(  96), -INT8_C(  26),
        -INT8_C(  86), -INT8_C(  16),  INT8_C(   0),  INT8_C( 103), -INT8_C( 111),  INT8_C(  62),  INT8_C(  86),  INT8_C(  50),
         INT8_C( 105), -INT8_C(  42),  INT8_C( 106), -INT8_C( 125), -INT8_C( 111),  INT8_C(  78),  INT8_C(  18),  INT8_C(  64),
         INT8_C(  82), -INT8_C(  18),  INT8_C(  78),  INT8_C(  36), -INT8_C(  56), -INT8_C(  51), -INT8_C(  57),  INT8_C(  18),
        -INT8_C( 122), -INT8_C(  91),  INT8_C( 116), -INT8_C( 101),  INT8_C(  46),  INT8_C(  21), -INT8_C( 126), -INT8_C(  39),
         INT8_C(   5), -INT8_C( 126),  INT8_C(  64), -INT8_C( 106), -INT8_C(  64), -INT8_C( 105), -INT8_C(  55),  INT8_C(  41) },
      {  INT8_C( 109),  INT8_C(  51), -INT8_C(  84), -INT8_C(   2), -INT8_C( 127), -INT8_C(  65),  INT8_C(  63), -INT8_C(  45),
        -INT8_C(  83), -INT8_C( 115), -INT8_C(   9),  INT8_C( 117),  INT8_C(  91), -INT8_C(  66), -INT8_C( 121), -INT8_C(  31),
         INT8_C( 100), -INT8_C(   4),  INT8_C( 125), -INT8_C( 110),  INT8_C(  17), -INT8_C(   1),  INT8_C( 107),  INT8_C(  22),
        -INT8_C( 127), -INT8_C(  84), -INT8_C(  83),  INT8_C(  65),  INT8_C(  67),  INT8_C( 118),  INT8_C( 107), -INT8_C(  80),
        -INT8_C(  87),  INT8_C(  23), -INT8_C(  82),  INT8_C(  42), -INT8_C(  42), -INT8_C(  19), -INT8_C(   3), -INT8_C( 125),
         INT8_C( 123), -INT8_C(  12), -INT8_C(   8), -INT8_C(  42), -INT8_C(  78),      INT8_MIN, -INT8_C(  73),  INT8_C(  22),
         INT8_C( 124),  INT8_C(  52), -INT8_C(  87), -INT8_C( 115),  INT8_C(  51),  INT8_C(  20), -INT8_C(  93), -INT8_C(  76),
        -INT8_C(  64),  INT8_C(  80), -INT8_C(  10),  INT8_C(   3), -INT8_C(  58),  INT8_C(  97), -INT8_C(  77),  INT8_C( 111) },
      {  INT8_C( 109),      INT8_MIN,  INT8_C(  83),  INT8_C(   6),  INT8_C(  26), -INT8_C(  46),  INT8_C(  63), -INT8_C(  45),
        -INT8_C(  81), -INT8_C( 106), -INT8_C(  80), -INT8_C(  57),  INT8_C(  94), -INT8_C(  38),  INT8_C(   3), -INT8_C(  85),
         INT8_C(  22), -INT8_C( 122), -INT8_C(  73),  INT8_C( 115),  INT8_C(  21),  INT8_C( 107),  INT8_C( 107), -INT8_C(  78),
        -INT8_C(  86),  INT8_C(   3),  INT8_C( 114),  INT8_C( 103),  INT8_C(  67), -INT8_C(  89),  INT8_C(  34),  INT8_C( 112),
         INT8_C( 105),  INT8_C( 117),  INT8_C( 106),  INT8_C(  42), -INT8_C(  42),  INT8_C(  78),  INT8_C(  80),  INT8_C(  64),
         INT8_C(  50),  INT8_C(   1), -INT8_C(  20), -INT8_C( 112), -INT8_C( 106), -INT8_C(  51),  INT8_C(  60),  INT8_C(  22),
         INT8_C( 117),  INT8_C(  52),  INT8_C( 116), -INT8_C( 101),  INT8_C(  51),  INT8_C(  21), -INT8_C(   2),  INT8_C( 113),
         INT8_C(   5),  INT8_C(  80),  INT8_C(  64),  INT8_C(   3),  INT8_C(  23),  INT8_C(  97), -INT8_C(  55),  INT8_C( 111) } },
    { {  INT8_C( 120),  INT8_C(  98), -INT8_C( 103),  INT8_C(  79),  INT8_C(  79), -INT8_C( 106), -INT8_C(  46), -INT8_C(  54),
        -INT8_C( 118), -INT8_C(  53), -INT8_C(  96),  INT8_C(  61),  INT8_C(  75),  INT8_C(  88),  INT8_C(  83), -INT8_C(  57),
        -INT8_C( 116), -INT8_C(   4),  INT8_C(  84), -INT8_C(  64),  INT8_C(  17), -INT8_C(   9),  INT8_C( 116), -INT8_C(  47),
         INT8_C(  72),  INT8_C( 106), -INT8_C(  43),  INT8_C(  14), -INT8_C(  53), -INT8_C( 120),  INT8_C( 126),  INT8_C(  68),
        -INT8_C(  22),  INT8_C(  23), -INT8_C( 109),  INT8_C(  58), -INT8_C(  82),  INT8_C( 101),  INT8_C(   4),  INT8_C(  56),
         INT8_C(  48), -INT8_C(  91),  INT8_C( 117),  INT8_C( 123), -INT8_C(   3), -INT8_C(  55),  INT8_C(  66), -INT8_C( 119),
        -INT8_C(  59), -INT8_C( 106),  INT8_C(  73), -INT8_C(  42), -INT8_C( 114), -INT8_C(  66), -INT8_C(  88), -INT8_C(  42),
         INT8_C(  40),  INT8_C( 125), -INT8_C(  28), -INT8_C(  12),  INT8_C(   5),  INT8_C(  98),  INT8_C(  56), -INT8_C(  16) },
      UINT64_C( 7016659003810433914),
      { -INT8_C(  45), -INT8_C(  42), -INT8_C(  36), -INT8_C(  48), -INT8_C(  97),  INT8_C(  31),  INT8_C(  90),  INT8_C( 100),
        -INT8_C(  75), -INT8_C(  93),  INT8_C(  59),  INT8_C(  67),  INT8_C(  97), -INT8_C(  29),  INT8_C(  25), -INT8_C( 118),
         INT8_C(  96), -INT8_C(   2),  INT8_C( 126),  INT8_C( 101),  INT8_C(  96), -INT8_C(  74),  INT8_C(  85), -INT8_C(  38),
        -INT8_C( 127),      INT8_MAX,  INT8_C(   2), -INT8_C(  79), -INT8_C(  82),  INT8_C(  99),  INT8_C(  18), -INT8_C( 127),
         INT8_C(  57), -INT8_C(  17),  INT8_C(  82), -INT8_C(  40),  INT8_C(  14), -INT8_C(  84),  INT8_C(  60), -INT8_C(  61),
         INT8_C(  79),  INT8_C( 119),  INT8_C(   7), -INT8_C(  79),  INT8_C(  90),  INT8_C(  32),  INT8_C(  59), -INT8_C(  70),
         INT8_C(  30), -INT8_C(  71),  INT8_C(  32),      INT8_MAX,  INT8_C( 111),  INT8_C( 117),  INT8_C(  89), -INT8_C(  16),
        -INT8_C(  11),  INT8_C(  92), -INT8_C(  95), -INT8_C(  93), -INT8_C(  65), -INT8_C(  76),  INT8_C(  36), -INT8_C(   8) },
      { -INT8_C(  93),  INT8_C( 118), -INT8_C(  48), -INT8_C(  79),  INT8_C(  34),  INT8_C(  12),  INT8_C( 116),  INT8_C( 114),
        -INT8_C( 124),  INT8_C( 123),  INT8_C(  35), -INT8_C(  34), -INT8_C( 100),  INT8_C(  94), -INT8_C( 103), -INT8_C(  70),
         INT8_C(  23), -INT8_C(  71),  INT8_C(  57), -INT8_C( 122),  INT8_C(  46), -INT8_C( 109),  INT8_C( 118),  INT8_C(  35),
        -INT8_C(  17),  INT8_C(  23), -INT8_C(  58), -INT8_C(  82), -INT8_C(  53), -INT8_C(  21), -INT8_C(  90),  INT8_C( 110),
         INT8_C(  97),  INT8_C( 118),  INT8_C(  31), -INT8_C( 124), -INT8_C( 126), -INT8_C( 108), -INT8_C(  10),  INT8_C(   6),
         INT8_C(  15),  INT8_C(  25), -INT8_C(  27), -INT8_C(  85),  INT8_C( 119),  INT8_C( 126),  INT8_C( 102), -INT8_C( 114),
         INT8_C(  55), -INT8_C(  97),  INT8_C(  20),  INT8_C( 101),  INT8_C(  50), -INT8_C( 118), -INT8_C( 119),  INT8_C(  33),
        -INT8_C(  95),  INT8_C(  79), -INT8_C(  49),  INT8_C( 109),  INT8_C(  58),  INT8_C( 117), -INT8_C(  37), -INT8_C( 100) },
      {  INT8_C( 120),  INT8_C( 118), -INT8_C( 103), -INT8_C(  48),  INT8_C(  34),  INT8_C(  31),  INT8_C( 116), -INT8_C(  54),
        -INT8_C(  75),  INT8_C( 123), -INT8_C(  96),  INT8_C(  67),  INT8_C(  75),  INT8_C(  88),  INT8_C(  25), -INT8_C(  70),
        -INT8_C( 116), -INT8_C(   2),  INT8_C(  84),  INT8_C( 101),  INT8_C(  17), -INT8_C(  74),  INT8_C( 116), -INT8_C(  47),
         INT8_C(  72),  INT8_C( 106), -INT8_C(  43), -INT8_C(  79), -INT8_C(  53),  INT8_C(  99),  INT8_C( 126),  INT8_C(  68),
        -INT8_C(  22),  INT8_C(  23), -INT8_C( 109),  INT8_C(  58),  INT8_C(  14), -INT8_C(  84),  INT8_C(   4),  INT8_C(  56),
         INT8_C(  48),  INT8_C( 119),  INT8_C(   7), -INT8_C(  79), -INT8_C(   3),  INT8_C( 126),  INT8_C(  66), -INT8_C( 119),
        -INT8_C(  59), -INT8_C( 106),  INT8_C(  73), -INT8_C(  42), -INT8_C( 114),  INT8_C( 117),  INT8_C(  89), -INT8_C(  42),
        -INT8_C(  11),  INT8_C( 125), -INT8_C(  28), -INT8_C(  12),  INT8_C(   5),  INT8_C( 117),  INT8_C(  36), -INT8_C(  16) } },
    { { -INT8_C(  21), -INT8_C(   5),  INT8_C(  32),  INT8_C( 110), -INT8_C( 113),  INT8_C(  22),  INT8_C( 116), -INT8_C(  98),
         INT8_C(  47),  INT8_C(  89),  INT8_C(  74), -INT8_C(  90), -INT8_C(  41), -INT8_C(  80),  INT8_C(  52),  INT8_C(  14),
         INT8_C(  79),  INT8_C(  72),  INT8_C( 116), -INT8_C( 126), -INT8_C(  46), -INT8_C(   3), -INT8_C(  93),  INT8_C( 115),
         INT8_C(  76),  INT8_C( 115), -INT8_C(  32), -INT8_C( 121), -INT8_C(  24), -INT8_C(  68),  INT8_C(  35), -INT8_C(  44),
        -INT8_C(  73),  INT8_C(  67),  INT8_C(  66),  INT8_C(  70),  INT8_C(  89), -INT8_C(  74), -INT8_C(  28), -INT8_C( 120),
         INT8_C(  16),  INT8_C(  46),  INT8_C(  46), -INT8_C(  25), -INT8_C(  34),  INT8_C(  98), -INT8_C(  10),  INT8_C(  46),
        -INT8_C(  86),  INT8_C( 106), -INT8_C(  80),  INT8_C( 124),  INT8_C( 103),  INT8_C(  83), -INT8_C(  17), -INT8_C(  77),
        -INT8_C(  58), -INT8_C(  48),  INT8_C(  58), -INT8_C(  81), -INT8_C( 116),  INT8_C(  93), -INT8_C( 125),  INT8_C(  67) },
      UINT64_C(10052436222502618528),
      { -INT8_C( 100), -INT8_C(  81),  INT8_C( 115),  INT8_C( 122),  INT8_C(  17),  INT8_C( 105), -INT8_C(  88), -INT8_C(  69),
        -INT8_C(  45),  INT8_C(  88),  INT8_C(  55),  INT8_C(  58), -INT8_C(  84),  INT8_C(  39), -INT8_C(  19),  INT8_C( 114),
        -INT8_C(   9),  INT8_C(  40),  INT8_C(  33), -INT8_C( 125), -INT8_C( 123), -INT8_C(  92), -INT8_C(  58),  INT8_C(  38),
         INT8_C( 105),  INT8_C(  79),  INT8_C(  31), -INT8_C(  27), -INT8_C(  68), -INT8_C(  95),  INT8_C( 112),  INT8_C(  88),
         INT8_C(  80), -INT8_C(  29), -INT8_C(  45),  INT8_C(  98),  INT8_C(  76),  INT8_C( 123),  INT8_C(  29),  INT8_C(  31),
        -INT8_C(  44),  INT8_C(  85),  INT8_C(  89),      INT8_MIN,  INT8_C( 124),  INT8_C(  71), -INT8_C(  14),  INT8_C( 115),
         INT8_C( 111),  INT8_C(  20), -INT8_C(  10), -INT8_C(  12), -INT8_C(  72), -INT8_C(  68),  INT8_C(  26),  INT8_C(  34),
         INT8_C(  11),  INT8_C(  58),  INT8_C(   7), -INT8_C(  57), -INT8_C(  37),  INT8_C( 119),  INT8_C(  32),  INT8_C(  43) },
      {  INT8_C(  91), -INT8_C(  13), -INT8_C( 115), -INT8_C(  89),  INT8_C( 110), -INT8_C(  85), -INT8_C(  57),  INT8_C(  66),
         INT8_C(   0),  INT8_C(  32), -INT8_C(  62),  INT8_C( 124),  INT8_C( 103), -INT8_C(  75), -INT8_C(  17), -INT8_C(  42),
        -INT8_C(  55), -INT8_C(  27), -INT8_C(  53), -INT8_C( 127), -INT8_C(  95), -INT8_C(  27), -INT8_C(  93), -INT8_C(  84),
         INT8_C(  31), -INT8_C(  86),  INT8_C( 115), -INT8_C(   6),  INT8_C(  34), -INT8_C( 109),  INT8_C(  38),  INT8_C( 125),
        -INT8_C( 122), -INT8_C(  77),  INT8_C(  36), -INT8_C(  11),  INT8_C(  94), -INT8_C(  21),  INT8_C(  55),  INT8_C(  94),
         INT8_C(  12), -INT8_C(   6), -INT8_C(  38),  INT8_C( 115), -INT8_C(  81), -INT8_C(  55),  INT8_C(  74),  INT8_C( 120),
        -INT8_C(  82),  INT8_C(  21), -INT8_C(   7),  INT8_C(  79), -INT8_C(   6), -INT8_C(  99), -INT8_C(   5),  INT8_C(  26),
         INT8_C(  71),  INT8_C( 111),  INT8_C(  20),  INT8_C( 105),  INT8_C(   2),  INT8_C(  58), -INT8_C(  26), -INT8_C( 119) },
      { -INT8_C(  21), -INT8_C(   5),  INT8_C(  32),  INT8_C( 110), -INT8_C( 113),  INT8_C( 105),  INT8_C( 116),  INT8_C(  66),
         INT8_C(   0),  INT8_C(  89),  INT8_C(  55), -INT8_C(  90), -INT8_C(  41), -INT8_C(  80), -INT8_C(  17),  INT8_C( 114),
        -INT8_C(   9),  INT8_C(  72),  INT8_C( 116), -INT8_C( 125), -INT8_C(  46), -INT8_C(   3), -INT8_C(  93),  INT8_C(  38),
         INT8_C( 105),  INT8_C( 115), -INT8_C(  32), -INT8_C(   6),  INT8_C(  34), -INT8_C(  95),  INT8_C( 112),  INT8_C( 125),
         INT8_C(  80), -INT8_C(  29),  INT8_C(  66),  INT8_C(  98),  INT8_C(  94),  INT8_C( 123),  INT8_C(  55), -INT8_C( 120),
         INT8_C(  12),  INT8_C(  46),  INT8_C(  89),  INT8_C( 115), -INT8_C(  34),  INT8_C(  71),  INT8_C(  74),  INT8_C(  46),
         INT8_C( 111),  INT8_C( 106), -INT8_C(  80),  INT8_C( 124),  INT8_C( 103),  INT8_C(  83), -INT8_C(  17),  INT8_C(  34),
         INT8_C(  71),  INT8_C( 111),  INT8_C(  58),  INT8_C( 105), -INT8_C( 116),  INT8_C(  93), -INT8_C( 125),  INT8_C(  43) } },
    { { -INT8_C(  18),  INT8_C(  11),  INT8_C( 126),  INT8_C(  76), -INT8_C(  10), -INT8_C(  75), -INT8_C(  85),  INT8_C(   2),
        -INT8_C(  81), -INT8_C( 123),  INT8_C( 118),  INT8_C(  94),  INT8_C(  79), -INT8_C(  64), -INT8_C(  42), -INT8_C(   3),
        -INT8_C(  43), -INT8_C(  48),  INT8_C(  77), -INT8_C(  49),  INT8_C( 109),  INT8_C(  72), -INT8_C(  23), -INT8_C(  76),
        -INT8_C(  73), -INT8_C(   2),  INT8_C(  30), -INT8_C(  70),  INT8_C(  56),  INT8_C(   4),  INT8_C(  67),  INT8_C(  38),
         INT8_C(  15), -INT8_C(  63),  INT8_C( 115),  INT8_C(   6),  INT8_C( 118),  INT8_C(  30),  INT8_C(   8),  INT8_C(  38),
        -INT8_C(  93),  INT8_C( 126), -INT8_C( 124), -INT8_C(  14),  INT8_C(  62),  INT8_C(  91), -INT8_C(  16),  INT8_C(  19),
         INT8_C(  43),  INT8_C(  61), -INT8_C(  29), -INT8_C( 104), -INT8_C( 123), -INT8_C(  52),  INT8_C(  76),  INT8_C(  61),
        -INT8_C(  54),  INT8_C( 106), -INT8_C(   9),  INT8_C(   3),  INT8_C( 111),  INT8_C(  58),  INT8_C(  41),  INT8_C( 126) },
      UINT64_C( 6816072392956484859),
      {  INT8_C(  11),  INT8_C(  28),  INT8_C(  80),  INT8_C(  74),  INT8_C( 119),  INT8_C(  64),  INT8_C(  93), -INT8_C(  94),
         INT8_C( 125),  INT8_C(  64),  INT8_C(  58),  INT8_C(   3),  INT8_C(  13), -INT8_C( 122),  INT8_C(  64), -INT8_C(  41),
        -INT8_C(  15),  INT8_C(  55), -INT8_C(  38),  INT8_C(  96),  INT8_C( 113),  INT8_C(   4), -INT8_C(  34),  INT8_C( 108),
        -INT8_C(  96),  INT8_C(  99), -INT8_C(  35),  INT8_C(  91), -INT8_C(  16),  INT8_C( 117), -INT8_C(  71), -INT8_C(   5),
        -INT8_C( 111),  INT8_C(   9),  INT8_C(  69),  INT8_C(   8),  INT8_C(  74), -INT8_C(  93), -INT8_C(  86), -INT8_C(  57),
        -INT8_C(  29), -INT8_C(  28), -INT8_C(  54), -INT8_C(  16),  INT8_C( 106),  INT8_C(  10), -INT8_C(  56),  INT8_C(  91),
         INT8_C(  65), -INT8_C(  94), -INT8_C(  69), -INT8_C(  78), -INT8_C(  90), -INT8_C( 102),  INT8_C(  30),  INT8_C(  71),
        -INT8_C(   3), -INT8_C(   4), -INT8_C(  94), -INT8_C(  19),  INT8_C( 113),  INT8_C(  91), -INT8_C(  24),  INT8_C(   2) },
      {  INT8_C( 100),  INT8_C(  46),  INT8_C(  10), -INT8_C(  82), -INT8_C(  47), -INT8_C(  76),  INT8_C( 118), -INT8_C(  76),
        -INT8_C( 104),  INT8_C(  64), -INT8_C(  91),  INT8_C(   2),  INT8_C(  75),  INT8_C( 109),  INT8_C(  94), -INT8_C( 116),
         INT8_C(  15),  INT8_C(  25),  INT8_C(  63), -INT8_C(  74), -INT8_C(  77),  INT8_C(  93), -INT8_C(   3), -INT8_C(  80),
         INT8_C(  89), -INT8_C(  97), -INT8_C(  99), -INT8_C(  54), -INT8_C(   6), -INT8_C( 122), -INT8_C(  52),  INT8_C(  94),
        -INT8_C(  76), -INT8_C(  42),  INT8_C(  13), -INT8_C( 123), -INT8_C( 118), -INT8_C( 125),  INT8_C(  57),  INT8_C(  34),
        -INT8_C(  61), -INT8_C(  34),  INT8_C(  37),  INT8_C(  14),  INT8_C(  75), -INT8_C( 125), -INT8_C( 101),  INT8_C(  91),
        -INT8_C( 100), -INT8_C(  38),  INT8_C(  17),  INT8_C(  80),  INT8_C(  55),  INT8_C(  14),  INT8_C(   0), -INT8_C( 111),
        -INT8_C(  83), -INT8_C(  98),  INT8_C(  91), -INT8_C(  89),  INT8_C(  36),  INT8_C(  40),  INT8_C(   5), -INT8_C(  40) },
      {  INT8_C( 100),  INT8_C(  46),  INT8_C( 126),  INT8_C(  74),  INT8_C( 119),  INT8_C(  64),  INT8_C( 118), -INT8_C(  76),
        -INT8_C(  81), -INT8_C( 123),  INT8_C(  58),  INT8_C(   3),  INT8_C(  75), -INT8_C(  64), -INT8_C(  42), -INT8_C(  41),
        -INT8_C(  43), -INT8_C(  48),  INT8_C(  63), -INT8_C(  49),  INT8_C( 109),  INT8_C(  72), -INT8_C(  23),  INT8_C( 108),
         INT8_C(  89), -INT8_C(   2),  INT8_C(  30), -INT8_C(  70), -INT8_C(   6),  INT8_C( 117), -INT8_C(  52),  INT8_C(  38),
         INT8_C(  15),  INT8_C(   9),  INT8_C( 115),  INT8_C(   8),  INT8_C(  74), -INT8_C(  93),  INT8_C(   8),  INT8_C(  34),
        -INT8_C(  29),  INT8_C( 126),  INT8_C(  37),  INT8_C(  14),  INT8_C(  62),  INT8_C(  91), -INT8_C(  16),  INT8_C(  91),
         INT8_C(  65), -INT8_C(  38),  INT8_C(  17), -INT8_C( 104),  INT8_C(  55), -INT8_C(  52),  INT8_C(  76),  INT8_C(  71),
        -INT8_C(  54), -INT8_C(   4),  INT8_C(  91), -INT8_C(  19),  INT8_C( 113),  INT8_C(  58),  INT8_C(   5),  INT8_C( 126) } },
    { { -INT8_C(   2),  INT8_C(  18),  INT8_C(  93), -INT8_C( 119), -INT8_C( 107), -INT8_C( 106), -INT8_C(  85),  INT8_C(  89),
         INT8_C( 117), -INT8_C(  48),  INT8_C( 103), -INT8_C(  64),  INT8_C(  83),  INT8_C(   2),  INT8_C(  27), -INT8_C(  16),
        -INT8_C(  36),  INT8_C(  44),  INT8_C(  64),  INT8_C(  20),  INT8_C(  58),  INT8_C(  64), -INT8_C(  91), -INT8_C(  25),
        -INT8_C(  34),  INT8_C(   0), -INT8_C( 114),  INT8_C(   2),  INT8_C(  40), -INT8_C( 108), -INT8_C(  38),  INT8_C(  39),
        -INT8_C(  90),  INT8_C(  55), -INT8_C(  80),  INT8_C(  60), -INT8_C(  50),  INT8_C(  91), -INT8_C( 107),  INT8_C(  67),
         INT8_C(  44), -INT8_C(   4),  INT8_C(   3),      INT8_MAX, -INT8_C(   1),  INT8_C(  31),  INT8_C( 111), -INT8_C(  37),
         INT8_C(  75), -INT8_C(  81), -INT8_C(  17), -INT8_C( 122), -INT8_C(  16), -INT8_C( 108),  INT8_C( 109), -INT8_C(  50),
        -INT8_C( 107), -INT8_C(   4), -INT8_C(  47), -INT8_C(  67), -INT8_C( 112), -INT8_C(  85), -INT8_C(  28),  INT8_C(  54) },
      UINT64_C( 2086301257730004195),
      {  INT8_C(   4), -INT8_C(   9), -INT8_C( 101),  INT8_C(   3),  INT8_C(  22),  INT8_C(  11), -INT8_C(  34),  INT8_C(  98),
        -INT8_C(  70), -INT8_C(  50), -INT8_C(  24), -INT8_C(  86),  INT8_C(  98),  INT8_C(  85),  INT8_C( 121), -INT8_C(   9),
         INT8_C(  81),  INT8_C(  74), -INT8_C(  75), -INT8_C(  31), -INT8_C(  11), -INT8_C( 103),  INT8_C(  24), -INT8_C(  40),
         INT8_C(  46), -INT8_C( 118), -INT8_C( 119),  INT8_C(  30), -INT8_C( 110),  INT8_C( 125),  INT8_C(  58), -INT8_C( 106),
         INT8_C( 117), -INT8_C(  43), -INT8_C( 103), -INT8_C( 117), -INT8_C(  32),  INT8_C( 119), -INT8_C(  19), -INT8_C( 101),
         INT8_C(  69), -INT8_C(  43),  INT8_C(  69), -INT8_C(  88),  INT8_C(  43), -INT8_C(  66), -INT8_C(  97),  INT8_C( 124),
         INT8_C(   8),  INT8_C(  84),  INT8_C(  94), -INT8_C(   2), -INT8_C(  18),  INT8_C( 118), -INT8_C(  42),  INT8_C(  28),
         INT8_C(   0),  INT8_C(  96),  INT8_C(  58), -INT8_C( 110), -INT8_C(  35),  INT8_C( 116),  INT8_C(  40),  INT8_C(  82) },
      {  INT8_C(  73), -INT8_C(  63), -INT8_C(  34),  INT8_C(  42),  INT8_C(  57), -INT8_C(  53), -INT8_C(  59),  INT8_C( 126),
        -INT8_C(  95),  INT8_C(  10),  INT8_C(  38), -INT8_C(  52), -INT8_C(  55), -INT8_C(  58),  INT8_C(  72), -INT8_C(  47),
         INT8_C(  26), -INT8_C(  90), -INT8_C(  49),  INT8_C(   8),  INT8_C(  28), -INT8_C(  90),  INT8_C(  36),  INT8_C(  29),
         INT8_C(   6),  INT8_C(  94), -INT8_C(  81), -INT8_C(  29), -INT8_C(  46), -INT8_C(  40),  INT8_C(  54),  INT8_C(  28),
        -INT8_C( 103),  INT8_C(  20),  INT8_C(  70), -INT8_C(  46), -INT8_C(  33),  INT8_C(  11),  INT8_C(  81),      INT8_MIN,
         INT8_C(  21),  INT8_C( 119),  INT8_C(  76), -INT8_C(  34),  INT8_C(  61), -INT8_C( 107), -INT8_C(  80),  INT8_C(  88),
         INT8_C(  59),      INT8_MAX,  INT8_C(  96),  INT8_C(  88),  INT8_C(  37), -INT8_C( 123),  INT8_C( 117),  INT8_C(  43),
        -INT8_C(  29),  INT8_C(  36),  INT8_C(  15), -INT8_C(  74), -INT8_C(   4),  INT8_C(  69), -INT8_C(  46), -INT8_C( 106) },
      {  INT8_C(  73), -INT8_C(   9),  INT8_C(  93), -INT8_C( 119), -INT8_C( 107),  INT8_C(  11), -INT8_C(  34),  INT8_C( 126),
         INT8_C( 117), -INT8_C(  48),  INT8_C(  38), -INT8_C(  64),  INT8_C(  98),  INT8_C(   2),  INT8_C(  27), -INT8_C(   9),
        -INT8_C(  36),  INT8_C(  74),  INT8_C(  64),  INT8_C(  20),  INT8_C(  28), -INT8_C(  90),  INT8_C(  36), -INT8_C(  25),
         INT8_C(  46),  INT8_C(   0), -INT8_C( 114),  INT8_C(   2), -INT8_C(  46),  INT8_C( 125), -INT8_C(  38),  INT8_C(  28),
        -INT8_C(  90),  INT8_C(  55), -INT8_C(  80),  INT8_C(  60), -INT8_C(  32),  INT8_C( 119),  INT8_C(  81), -INT8_C( 101),
         INT8_C(  69),  INT8_C( 119),  INT8_C(  76),      INT8_MAX, -INT8_C(   1),  INT8_C(  31),  INT8_C( 111), -INT8_C(  37),
         INT8_C(  75), -INT8_C(  81),  INT8_C(  96), -INT8_C( 122),  INT8_C(  37),  INT8_C( 118),  INT8_C( 117),  INT8_C(  43),
        -INT8_C( 107), -INT8_C(   4),  INT8_C(  58), -INT8_C(  74), -INT8_C(   4), -INT8_C(  85), -INT8_C(  28),  INT8_C(  54) } },
    { {  INT8_C(  89),  INT8_C(  24),  INT8_C( 104),  INT8_C(  56),  INT8_C(  35), -INT8_C(  71), -INT8_C(  71),  INT8_C(  56),
         INT8_C(  49),  INT8_C(   5),  INT8_C(  23),  INT8_C( 110), -INT8_C( 102), -INT8_C(  57), -INT8_C(  58), -INT8_C(  42),
         INT8_C(  70),  INT8_C(  39),  INT8_C(  46),  INT8_C( 108), -INT8_C(  84), -INT8_C(  93), -INT8_C( 105), -INT8_C( 113),
        -INT8_C(  57), -INT8_C(  90),  INT8_C(  69), -INT8_C(  60), -INT8_C(  21),  INT8_C(  23),  INT8_C(  90),  INT8_C(  68),
         INT8_C(  47), -INT8_C(  62),  INT8_C( 125),  INT8_C(  82),  INT8_C( 124),  INT8_C(  54), -INT8_C( 117), -INT8_C(  83),
         INT8_C(  59), -INT8_C(  94),  INT8_C(  27), -INT8_C(  42),  INT8_C( 105), -INT8_C(  30), -INT8_C(  84), -INT8_C(  81),
         INT8_C(   9), -INT8_C(  38),  INT8_C(  27), -INT8_C(  75),  INT8_C( 125), -INT8_C(  77),  INT8_C(  68),  INT8_C(  68),
         INT8_C(  89), -INT8_C( 118),  INT8_C(   8),  INT8_C(  69), -INT8_C(  95),  INT8_C(  98), -INT8_C( 119), -INT8_C(  47) },
      UINT64_C( 8669057908159481381),
      {  INT8_C(  80),  INT8_C( 105),  INT8_C(  78), -INT8_C(  71),  INT8_C(  75), -INT8_C(   6),  INT8_C( 105),  INT8_C(  84),
        -INT8_C(  44), -INT8_C( 124),  INT8_C(   9),  INT8_C(  81),  INT8_C(  55),  INT8_C(  78), -INT8_C( 107), -INT8_C( 111),
        -INT8_C(  40), -INT8_C(  98), -INT8_C(  42),  INT8_C( 121),  INT8_C(   0),  INT8_C(  95),  INT8_C(  74),  INT8_C(  37),
         INT8_C( 102),  INT8_C( 110), -INT8_C(  58), -INT8_C(  94),  INT8_C(  28),  INT8_C(  20),  INT8_C(  26),  INT8_C( 109),
         INT8_C( 126),  INT8_C( 104),  INT8_C(  38), -INT8_C(  55),  INT8_C(  98), -INT8_C( 113),  INT8_C(  30),  INT8_C(  54),
         INT8_C(  20),  INT8_C(  39), -INT8_C( 121),  INT8_C(  75),  INT8_C( 117),  INT8_C(  29), -INT8_C(  36),  INT8_C(  77),
        -INT8_C(  69), -INT8_C(  78), -INT8_C(  57), -INT8_C(  69),  INT8_C(  18),  INT8_C(  17), -INT8_C(  31),  INT8_C( 120),
             INT8_MAX, -INT8_C(  89),  INT8_C(  26), -INT8_C( 100), -INT8_C(  68),  INT8_C(  53),  INT8_C(   9),  INT8_C(  58) },
      { -INT8_C(  99),  INT8_C(  47),  INT8_C(   3),  INT8_C(   0), -INT8_C(  65),  INT8_C(  33),  INT8_C(  54), -INT8_C(  45),
         INT8_C(  73), -INT8_C(  66),  INT8_C(  30), -INT8_C(  66), -INT8_C(  37), -INT8_C(   5),  INT8_C(  12), -INT8_C( 106),
        -INT8_C(  83), -INT8_C(  45),  INT8_C(  81), -INT8_C(  65), -INT8_C(  28),  INT8_C(  50),  INT8_C(  55),  INT8_C( 100),
        -INT8_C(  38),  INT8_C(  82),  INT8_C(   0), -INT8_C( 106), -INT8_C( 121),  INT8_C(   9), -INT8_C(  48),  INT8_C(  36),
         INT8_C(  56), -INT8_C(  45),  INT8_C(  36), -INT8_C(   9), -INT8_C(  11),  INT8_C(  91), -INT8_C(  54),  INT8_C(  62),
         INT8_C(  25), -INT8_C(  23), -INT8_C(   4), -INT8_C(  12), -INT8_C(  28),  INT8_C(   8), -INT8_C( 118), -INT8_C( 111),
        -INT8_C(  37), -INT8_C(  37),  INT8_C(  81), -INT8_C(  64),  INT8_C(  14), -INT8_C( 120),  INT8_C(  36), -INT8_C(  24),
        -INT8_C(  38),  INT8_C(  36),  INT8_C( 126),  INT8_C(  97),  INT8_C(  45),  INT8_C(  78), -INT8_C( 122),  INT8_C( 101) },
      {  INT8_C(  80),  INT8_C(  24),  INT8_C(  78),  INT8_C(  56),  INT8_C(  35),  INT8_C(  33), -INT8_C(  71),  INT8_C(  56),
         INT8_C(  49), -INT8_C(  66),  INT8_C(  30),  INT8_C( 110), -INT8_C( 102), -INT8_C(  57), -INT8_C(  58), -INT8_C(  42),
        -INT8_C(  40), -INT8_C(  45),  INT8_C(  46),  INT8_C( 108), -INT8_C(  84),  INT8_C(  95), -INT8_C( 105), -INT8_C( 113),
         INT8_C( 102), -INT8_C(  90),  INT8_C(  69), -INT8_C(  60), -INT8_C(  21),  INT8_C(  20),  INT8_C(  90),  INT8_C( 109),
         INT8_C(  47), -INT8_C(  62),  INT8_C(  38), -INT8_C(   9),  INT8_C(  98),  INT8_C(  91), -INT8_C( 117), -INT8_C(  83),
         INT8_C(  59),  INT8_C(  39), -INT8_C(   4),  INT8_C(  75),  INT8_C( 105),  INT8_C(  29), -INT8_C(  84),  INT8_C(  77),
         INT8_C(   9), -INT8_C(  37),  INT8_C(  81), -INT8_C(  64),  INT8_C( 125), -INT8_C(  77),  INT8_C(  36),  INT8_C(  68),
         INT8_C(  89), -INT8_C( 118),  INT8_C(   8),  INT8_C(  97),  INT8_C(  45),  INT8_C(  78),  INT8_C(   9), -INT8_C(  47) } },
    { {  INT8_C(  33), -INT8_C(  86),  INT8_C(  93),  INT8_C(  22),  INT8_C(   5),  INT8_C(  39),  INT8_C(  84),  INT8_C(  30),
         INT8_C(  16),  INT8_C(  81),  INT8_C(  18), -INT8_C(  12),  INT8_C(  89), -INT8_C( 100), -INT8_C( 122),  INT8_C(  53),
         INT8_C( 120), -INT8_C(  41), -INT8_C(  11), -INT8_C( 122),  INT8_C(  95),  INT8_C(  25),  INT8_C( 110),  INT8_C(  58),
         INT8_C(  61), -INT8_C(  20), -INT8_C( 101),  INT8_C( 106),  INT8_C(  58),  INT8_C(  33), -INT8_C(  49),  INT8_C(  91),
        -INT8_C(  52),  INT8_C(  44),  INT8_C( 114), -INT8_C(  47),  INT8_C(  84), -INT8_C(  58), -INT8_C(  16),  INT8_C( 100),
         INT8_C(  23),  INT8_C(   2),  INT8_C(  89),  INT8_C( 113), -INT8_C(  97), -INT8_C(  33), -INT8_C(  90),  INT8_C(  23),
        -INT8_C(  74), -INT8_C( 101), -INT8_C(  99),  INT8_C(  21), -INT8_C(  76),  INT8_C(  11),  INT8_C(  79), -INT8_C(  15),
        -INT8_C(   9), -INT8_C(  21),  INT8_C(  91),  INT8_C(  49),  INT8_C(  12),  INT8_C(  42), -INT8_C( 116), -INT8_C(  40) },
      UINT64_C(15857062986774150743),
      { -INT8_C( 100),  INT8_C( 104),  INT8_C(  77),  INT8_C(  59),  INT8_C(  71), -INT8_C(  13),  INT8_C(  82), -INT8_C(   3),
        -INT8_C( 114), -INT8_C(  17),  INT8_C(  19),  INT8_C(  66), -INT8_C(   6),  INT8_C(  98),  INT8_C(  51), -INT8_C(  15),
         INT8_C(  77), -INT8_C( 114),  INT8_C(  34),  INT8_C(  90), -INT8_C(  71), -INT8_C(  81),  INT8_C(  50),  INT8_C(  16),
        -INT8_C(  83), -INT8_C(  36), -INT8_C(  69),  INT8_C( 114),  INT8_C( 118), -INT8_C(  54),  INT8_C(  79),  INT8_C(  19),
         INT8_C(  51), -INT8_C( 100),  INT8_C(  78),  INT8_C( 122), -INT8_C( 112), -INT8_C(  95),  INT8_C( 120),  INT8_C(  30),
        -INT8_C( 112), -INT8_C( 117),  INT8_C(  97), -INT8_C( 117), -INT8_C(  19), -INT8_C( 108),  INT8_C( 124),  INT8_C(  59),
         INT8_C(  35), -INT8_C(  97), -INT8_C( 107), -INT8_C(  36),  INT8_C(  78), -INT8_C(  57), -INT8_C(  20), -INT8_C(   5),
        -INT8_C(  92), -INT8_C(  89),  INT8_C( 110),  INT8_C(  26),  INT8_C( 113), -INT8_C(  67),  INT8_C(  45), -INT8_C(  92) },
      {  INT8_C(  89),  INT8_C( 124),  INT8_C(  31), -INT8_C(  23),  INT8_C(  29), -INT8_C( 105),  INT8_C(   8), -INT8_C(  83),
         INT8_C(  34),  INT8_C( 105),  INT8_C(  56),  INT8_C(  15), -INT8_C(   3), -INT8_C(  75),  INT8_C(  74),  INT8_C(  32),
         INT8_C(  84), -INT8_C(  33), -INT8_C(   4), -INT8_C(  94), -INT8_C(  89), -INT8_C(  24), -INT8_C(  99),  INT8_C(  75),
        -INT8_C( 113),  INT8_C(  11),  INT8_C( 101),  INT8_C(   1), -INT8_C(  56), -INT8_C( 109), -INT8_C(  91),  INT8_C(  34),
         INT8_C(  15), -INT8_C(  60),  INT8_C(  11),  INT8_C(  44),  INT8_C(  91),  INT8_C(  19), -INT8_C(  39),  INT8_C( 125),
         INT8_C( 124),  INT8_C(  18), -INT8_C( 115),  INT8_C( 122), -INT8_C(  57), -INT8_C(  41), -INT8_C( 102),  INT8_C(  27),
        -INT8_C(  73), -INT8_C( 105), -INT8_C(  67),  INT8_C(  94),      INT8_MAX,  INT8_C(  90), -INT8_C(  87),  INT8_C(  15),
         INT8_C( 102),  INT8_C(  14),  INT8_C(  16),  INT8_C(  46), -INT8_C(  95), -INT8_C(  75),  INT8_C(  80), -INT8_C(  80) },
      {  INT8_C(  89),  INT8_C( 124),  INT8_C(  77),  INT8_C(  22),  INT8_C(  71),  INT8_C(  39),  INT8_C(  82),  INT8_C(  30),
         INT8_C(  16),  INT8_C( 105),  INT8_C(  56),  INT8_C(  66), -INT8_C(   3),  INT8_C(  98),  INT8_C(  74),  INT8_C(  32),
         INT8_C( 120), -INT8_C(  33), -INT8_C(  11),  INT8_C(  90),  INT8_C(  95), -INT8_C(  24),  INT8_C( 110),  INT8_C(  75),
        -INT8_C(  83),  INT8_C(  11), -INT8_C( 101),  INT8_C( 114),  INT8_C(  58), -INT8_C(  54), -INT8_C(  49),  INT8_C(  34),
         INT8_C(  51),  INT8_C(  44),  INT8_C(  78), -INT8_C(  47),  INT8_C(  84), -INT8_C(  58),  INT8_C( 120),  INT8_C( 125),
         INT8_C(  23),  INT8_C(  18),  INT8_C(  89),  INT8_C( 122), -INT8_C(  19), -INT8_C(  33), -INT8_C(  90),  INT8_C(  59),
         INT8_C(  35), -INT8_C(  97), -INT8_C(  67),  INT8_C(  94), -INT8_C(  76),  INT8_C(  11),  INT8_C(  79), -INT8_C(  15),
        -INT8_C(   9), -INT8_C(  21),  INT8_C( 110),  INT8_C(  46),  INT8_C( 113),  INT8_C(  42),  INT8_C(  80), -INT8_C(  80) } }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
    simde__m512i src = simde_mm512_loadu_epi8(test_vec[i].src);
    simde__m512i a = simde_mm512_loadu_epi8(test_vec[i].a);
    simde__m512i b = simde_mm512_loadu_epi8(test_vec[i].b);
    simde__m512i r = simde_mm512_mask_max_epi8(src, test_vec[i].k, a, b);
    simde_test_x86_assert_equal_i8x64(r, simde_mm512_loadu_epi8(test_vec[i].r));
  }

  return 0;
}

static int
test_simde_mm512_maskz_max_epi8 (SIMDE_MUNIT_TEST_ARGS) {
  static const struct {
    const simde__mmask64 k;
    const int8_t a[64];
    const int8_t b[64];
    const int8_t r[64];
  } test_vec[] = {
    { UINT64_C(15100473841603180603),
      { -INT8_C(  76), -INT8_C(  30),  INT8_C(   8),  INT8_C(  48),  INT8_C(  20), -INT8_C( 118), -INT8_C(  64), -INT8_C( 125),
        -INT8_C(  42), -INT8_C(   8), -INT8_C(  20),  INT8_C(  95),  INT8_C(  50), -INT8_C(  41), -INT8_C(  18), -INT8_C(  33),
        -INT8_C(  10), -INT8_C( 104),  INT8_C(  32), -INT8_C( 105),  INT8_C( 107),  INT8_C( 117), -INT8_C(   9), -INT8_C(  90),
         INT8_C( 109), -INT8_C(  52), -INT8_C(  86),  INT8_C(  97),  INT8_C( 116),  INT8_C(  58),  INT8_C(  50),  INT8_C(  40),
         INT8_C(  28),  INT8_C(  58),  INT8_C(  89),  INT8_C(  48), -INT8_C(  59),  INT8_C(  25), -INT8_C(  77), -INT8_C( 101),
         INT8_C(  17), -INT8_C(  96), -INT8_C(   5),  INT8_C(  68),  INT8_C( 119), -INT8_C(  23),  INT8_C(  35),  INT8_C( 110),
        -INT8_C( 127),  INT8_C(  67),  INT8_C(   5), -INT8_C(  19), -INT8_C(  72), -INT8_C(   4), -INT8_C( 109),  INT8_C(  37),
        -INT8_C(  56),  INT8_C(  62), -INT8_C( 122),  INT8_C(  61),  INT8_C( 120), -INT8_C(  72),  INT8_C( 101), -INT8_C( 108) },
      { -INT8_C(  14), -INT8_C(  66), -INT8_C(  60), -INT8_C(  73), -INT8_C(  41),  INT8_C( 120),  INT8_C(  83), -INT8_C(  23),
         INT8_C(  24),  INT8_C(  78),  INT8_C(  45), -INT8_C( 113),  INT8_C(  55),  INT8_C(  80), -INT8_C(   3), -INT8_C(  71),
        -INT8_C( 109),  INT8_C(   2), -INT8_C(  90),  INT8_C(  75), -INT8_C(   2),  INT8_C(  57),  INT8_C( 112), -INT8_C(  57),
         INT8_C( 119), -INT8_C(  10),  INT8_C(   4), -INT8_C(  17), -INT8_C(  82),  INT8_C( 105), -INT8_C( 125), -INT8_C(  96),
         INT8_C(  40),  INT8_C(  72),  INT8_C(  88), -INT8_C(   1), -INT8_C(  64), -INT8_C(  85), -INT8_C(  24), -INT8_C(  40),
        -INT8_C(   7),  INT8_C(  21),  INT8_C( 103),  INT8_C(  48),  INT8_C( 101),  INT8_C( 101), -INT8_C(  23), -INT8_C(   8),
         INT8_C( 103), -INT8_C( 113),  INT8_C(  67),  INT8_C( 102), -INT8_C(  55), -INT8_C(  77),  INT8_C(  45),  INT8_C(  64),
        -INT8_C(  87),  INT8_C(  49),  INT8_C(  48),  INT8_C(  87), -INT8_C( 102), -INT8_C(  77), -INT8_C(   8), -INT8_C(  62) },
      { -INT8_C(  14), -INT8_C(  30),  INT8_C(   0),  INT8_C(  48),  INT8_C(  20),  INT8_C( 120),  INT8_C(   0),  INT8_C(   0),
         INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(  95),  INT8_C(  55),  INT8_C(  80), -INT8_C(   3), -INT8_C(  33),
        -INT8_C(  10),  INT8_C(   0),  INT8_C(  32),  INT8_C(   0),  INT8_C( 107),  INT8_C(   0),  INT8_C( 112), -INT8_C(  57),
         INT8_C(   0),  INT8_C(   0),  INT8_C(   4),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),
         INT8_C(   0),  INT8_C(   0),  INT8_C(  89),  INT8_C(   0), -INT8_C(  59),  INT8_C(  25), -INT8_C(  24), -INT8_C(  40),
         INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(  68),  INT8_C(   0),  INT8_C( 101),  INT8_C(   0),  INT8_C( 110),
         INT8_C( 103),  INT8_C(  67),  INT8_C(  67),  INT8_C( 102),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(  64),
        -INT8_C(  56),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C( 120),  INT8_C(   0),  INT8_C( 101), -INT8_C(  62) } },
    { UINT64_C(17623617764994470139),
      { -INT8_C(  64), -INT8_C(   5),  INT8_C(  36),  INT8_C(  37),  INT8_C(  96),  INT8_C(  14),  INT8_C(  30), -INT8_C(  57),
        -INT8_C(  99),  INT8_C(  97),  INT8_C(  45),  INT8_C( 102),  INT8_C(  21),  INT8_C(  90), -INT8_C(  89), -INT8_C(  66),
        -INT8_C( 117), -INT8_C(  41),  INT8_C(  22),  INT8_C(  38), -INT8_C( 118),  INT8_C(  14), -INT8_C(  24), -INT8_C( 122),
         INT8_C(  94), -INT8_C(  86),  INT8_C(  65),  INT8_C(  89),  INT8_C(  85), -INT8_C(  43),  INT8_C(  77),  INT8_C(  21),
        -INT8_C(  48),  INT8_C( 113),  INT8_C(  58),  INT8_C(  48),      INT8_MAX,  INT8_C(  88), -INT8_C(   9),  INT8_C(  29),
        -INT8_C(  70),  INT8_C(  37), -INT8_C( 125), -INT8_C(  49),      INT8_MAX,  INT8_C(  42), -INT8_C( 115),  INT8_C(  11),
         INT8_C(   1), -INT8_C(  93),  INT8_C(  49), -INT8_C( 116), -INT8_C(  79),  INT8_C(  25),  INT8_C(  18),  INT8_C(  15),
        -INT8_C(  60),  INT8_C(  83),  INT8_C( 104),  INT8_C(  25),  INT8_C(  40), -INT8_C(  75),  INT8_C(  46), -INT8_C(   8) },
      {  INT8_C(  39),  INT8_C( 104),  INT8_C(  40), -INT8_C(  90), -INT8_C(  63),  INT8_C(  32), -INT8_C(  61),  INT8_C( 123),
         INT8_C(  69),  INT8_C(  71),  INT8_C(  74), -INT8_C(  60),  INT8_C( 113), -INT8_C(  41), -INT8_C(  49),  INT8_C( 115),
         INT8_C( 123),  INT8_C(   0), -INT8_C(   1),  INT8_C(  44),  INT8_C(  26),  INT8_C(  17),  INT8_C(  60), -INT8_C(  34),
         INT8_C( 100), -INT8_C(  92), -INT8_C(   9), -INT8_C( 115),  INT8_C(  90),  INT8_C(  37), -INT8_C( 123), -INT8_C( 127),
        -INT8_C( 115), -INT8_C(  82),  INT8_C(  39),  INT8_C(  78), -INT8_C(  50), -INT8_C(  21), -INT8_C(  55),  INT8_C(  19),
         INT8_C(  50),  INT8_C(  19), -INT8_C(  41), -INT8_C(  93), -INT8_C(  21), -INT8_C(  89),  INT8_C(  22),  INT8_C( 102),
        -INT8_C(  89),  INT8_C(  21), -INT8_C( 110), -INT8_C(  63),  INT8_C(  38), -INT8_C(  50), -INT8_C(  97), -INT8_C( 117),
         INT8_C( 115), -INT8_C( 106),  INT8_C(  24), -INT8_C(  51), -INT8_C(  69), -INT8_C(  99),  INT8_C(  78),  INT8_C(  73) },
      {  INT8_C(  39),  INT8_C( 104),  INT8_C(   0),  INT8_C(  37),  INT8_C(  96),  INT8_C(  32),  INT8_C(  30),  INT8_C( 123),
         INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C( 113),  INT8_C(   0), -INT8_C(  49),  INT8_C(   0),
         INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(  60), -INT8_C(  34),
         INT8_C( 100), -INT8_C(  86),  INT8_C(   0),  INT8_C(  89),  INT8_C(  90),  INT8_C(  37),  INT8_C(   0),  INT8_C(  21),
        -INT8_C(  48),  INT8_C( 113),  INT8_C(   0),  INT8_C(  78),      INT8_MAX,  INT8_C(  88), -INT8_C(   9),  INT8_C(  29),
         INT8_C(   0),  INT8_C(  37),  INT8_C(   0), -INT8_C(  49),  INT8_C(   0),  INT8_C(  42),  INT8_C(   0),  INT8_C( 102),
         INT8_C(   1),  INT8_C(  21),  INT8_C(   0),  INT8_C(   0),  INT8_C(  38),  INT8_C(   0),  INT8_C(   0),  INT8_C(  15),
         INT8_C(   0),  INT8_C(   0),  INT8_C( 104),  INT8_C(   0),  INT8_C(  40), -INT8_C(  75),  INT8_C(  78),  INT8_C(  73) } },
    { UINT64_C(10532900693886858571),
      {  INT8_C( 116),  INT8_C(   4),  INT8_C(  54),  INT8_C(  95), -INT8_C(  85),  INT8_C(  76), -INT8_C(  59),  INT8_C(  82),
         INT8_C(  98),  INT8_C(  88),  INT8_C(  20), -INT8_C( 120),  INT8_C(  38), -INT8_C(  77),  INT8_C(  19), -INT8_C( 103),
         INT8_C(  74),  INT8_C(  43),  INT8_C( 102),  INT8_C(   5), -INT8_C(  55), -INT8_C(  76),  INT8_C(  78),  INT8_C(  20),
         INT8_C(  42), -INT8_C(  26),  INT8_C(  46), -INT8_C( 118),  INT8_C(  71),  INT8_C(  90),  INT8_C(  29), -INT8_C(  69),
         INT8_C(  94),  INT8_C(  83),  INT8_C(  27),  INT8_C(   9), -INT8_C(  97), -INT8_C(  32),  INT8_C(  92),  INT8_C(   1),
         INT8_C(  56),  INT8_C( 112), -INT8_C( 118),  INT8_C(  95),  INT8_C(  35), -INT8_C(  99), -INT8_C(   8),  INT8_C( 109),
        -INT8_C(  55),  INT8_C(  95),  INT8_C( 115), -INT8_C( 110),  INT8_C(  19), -INT8_C(  63), -INT8_C(  90),  INT8_C(  61),
        -INT8_C(  89), -INT8_C(  44), -INT8_C(  56), -INT8_C(  18),  INT8_C(  47), -INT8_C(  27), -INT8_C(  86), -INT8_C( 115) },
      {  INT8_C(  56), -INT8_C(  59), -INT8_C( 105), -INT8_C(  41), -INT8_C(  91), -INT8_C(  13), -INT8_C(  39), -INT8_C(  34),
         INT8_C(  99),  INT8_C(  99),  INT8_C(  61), -INT8_C( 122),  INT8_C(   0),  INT8_C(  53), -INT8_C(  12), -INT8_C(  55),
        -INT8_C( 108),  INT8_C( 103),  INT8_C(  91), -INT8_C(  88),  INT8_C(  40),  INT8_C(   2), -INT8_C(  27), -INT8_C(  48),
        -INT8_C(  42), -INT8_C(  83), -INT8_C(  66),  INT8_C(   5), -INT8_C( 110),  INT8_C( 104), -INT8_C( 109), -INT8_C(  54),
         INT8_C(  45),  INT8_C(  42), -INT8_C(  94), -INT8_C(  45),  INT8_C(  29),  INT8_C( 123), -INT8_C(  79),      INT8_MIN,
        -INT8_C(  34), -INT8_C(  18),  INT8_C(   6), -INT8_C(  34),  INT8_C(  35), -INT8_C(   6), -INT8_C(  88), -INT8_C(  72),
         INT8_C(  97),  INT8_C(   3),  INT8_C(  96), -INT8_C( 118),  INT8_C(   5),  INT8_C(  69),  INT8_C(  90), -INT8_C(  36),
        -INT8_C(  13),  INT8_C(  24), -INT8_C(  31), -INT8_C( 123), -INT8_C( 127),  INT8_C( 116),  INT8_C(  80), -INT8_C(  82) },
      {  INT8_C( 116),  INT8_C(   4),  INT8_C(   0),  INT8_C(  95),  INT8_C(   0),  INT8_C(   0), -INT8_C(  39),  INT8_C(   0),
         INT8_C(  99),  INT8_C(   0),  INT8_C(  61),  INT8_C(   0),  INT8_C(  38),  INT8_C(  53),  INT8_C(  19),  INT8_C(   0),
         INT8_C(  74),  INT8_C( 103),  INT8_C( 102),  INT8_C(   0),  INT8_C(  40),  INT8_C(   0),  INT8_C(   0),  INT8_C(  20),
         INT8_C(  42),  INT8_C(   0),  INT8_C(   0),  INT8_C(   5),  INT8_C(  71),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),
         INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C( 123),  INT8_C(  92),  INT8_C(   0),
         INT8_C(  56),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0), -INT8_C(   6), -INT8_C(   8),  INT8_C(   0),
         INT8_C(   0),  INT8_C(   0),  INT8_C( 115), -INT8_C( 110),  INT8_C(   0),  INT8_C(  69),  INT8_C(   0),  INT8_C(   0),
         INT8_C(   0),  INT8_C(  24),  INT8_C(   0),  INT8_C(   0),  INT8_C(  47),  INT8_C(   0),  INT8_C(   0), -INT8_C(  82) } },
    { UINT64_C( 5420982023349203614),
      {  INT8_C(  32),  INT8_C(  66),  INT8_C(  41),  INT8_C(  68),  INT8_C(  60), -INT8_C(  47), -INT8_C(   4), -INT8_C(  98),
        -INT8_C(  43),  INT8_C(  92),  INT8_C(  40), -INT8_C(  38), -INT8_C(  95), -INT8_C( 126), -INT8_C(  74), -INT8_C( 108),
        -INT8_C( 102), -INT8_C( 104),  INT8_C(  26),  INT8_C(  27),  INT8_C(  12),  INT8_C( 106), -INT8_C(  54), -INT8_C(  85),
         INT8_C(  92),  INT8_C(  75),  INT8_C( 102), -INT8_C(  55),  INT8_C( 126), -INT8_C(  94),  INT8_C(  20), -INT8_C(  98),
        -INT8_C(  28),  INT8_C(  61), -INT8_C(  30),  INT8_C(  32),  INT8_C(  15), -INT8_C(  34), -INT8_C(  66), -INT8_C(  28),
         INT8_C(  58), -INT8_C(  26), -INT8_C(  66), -INT8_C(  36),  INT8_C( 104),  INT8_C( 117),  INT8_C( 112),  INT8_C(   3),
         INT8_C(  13), -INT8_C( 118),  INT8_C(  30),  INT8_C(  25), -INT8_C(  12), -INT8_C(  24), -INT8_C(  60),  INT8_C(  80),
         INT8_C(  52),  INT8_C(  43),  INT8_C(  25), -INT8_C(  78), -INT8_C(  51),  INT8_C(  45),  INT8_C(  80), -INT8_C(  79) },
      {  INT8_C( 107),  INT8_C(  51), -INT8_C(  47),  INT8_C( 122),  INT8_C(  17), -INT8_C( 112),  INT8_C(  94),  INT8_C(  76),
         INT8_C( 118),  INT8_C(  28),  INT8_C(  40), -INT8_C(  33), -INT8_C( 111), -INT8_C( 104), -INT8_C(  30), -INT8_C(  98),
         INT8_C(  35),  INT8_C(   0), -INT8_C(  72),  INT8_C(  23), -INT8_C(  23),  INT8_C( 124),  INT8_C( 104),  INT8_C(  29),
        -INT8_C(  89), -INT8_C( 127), -INT8_C(  49),  INT8_C( 116), -INT8_C(  81),  INT8_C(  31),  INT8_C(  37),  INT8_C(  26),
         INT8_C(  82), -INT8_C(   9), -INT8_C( 108),  INT8_C( 100), -INT8_C( 121), -INT8_C(  14), -INT8_C(  80), -INT8_C(   3),
         INT8_C(  14), -INT8_C(  40), -INT8_C(  36), -INT8_C(  96),  INT8_C( 112), -INT8_C(  66),  INT8_C(  62), -INT8_C( 109),
        -INT8_C(  65), -INT8_C(  10), -INT8_C(  85), -INT8_C(  88),  INT8_C( 115),  INT8_C(  19), -INT8_C(  59),  INT8_C(  26),
        -INT8_C( 108), -INT8_C( 108), -INT8_C( 113),  INT8_C(  67), -INT8_C(  77), -INT8_C(  76),  INT8_C(  93),  INT8_C(   6) },
      {  INT8_C(   0),  INT8_C(  66),  INT8_C(  41),  INT8_C( 122),  INT8_C(  60),  INT8_C(   0),  INT8_C(   0),  INT8_C(  76),
         INT8_C(   0),  INT8_C(  92),  INT8_C(   0),  INT8_C(   0), -INT8_C(  95), -INT8_C( 104), -INT8_C(  30), -INT8_C(  98),
         INT8_C(  35),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(  29),
         INT8_C(  92),  INT8_C(  75),  INT8_C(   0),  INT8_C( 116),  INT8_C( 126),  INT8_C(  31),  INT8_C(   0),  INT8_C(  26),
         INT8_C(  82),  INT8_C(   0), -INT8_C(  30),  INT8_C( 100),  INT8_C(   0), -INT8_C(  14), -INT8_C(  66),  INT8_C(   0),
         INT8_C(   0), -INT8_C(  26),  INT8_C(   0),  INT8_C(   0),  INT8_C( 112),  INT8_C( 117),  INT8_C(   0),  INT8_C(   0),
         INT8_C(  13), -INT8_C(  10),  INT8_C(   0),  INT8_C(  25),  INT8_C( 115),  INT8_C(  19),  INT8_C(   0),  INT8_C(   0),
         INT8_C(  52),  INT8_C(  43),  INT8_C(   0),  INT8_C(  67),  INT8_C(   0),  INT8_C(   0),  INT8_C(  93),  INT8_C(   0) } },
    { UINT64_C(17451478119166439851),
      { -INT8_C(  14),  INT8_C(  12), -INT8_C( 110),  INT8_C(  98), -INT8_C(  53), -INT8_C(  48), -INT8_C(  10), -INT8_C( 118),
        -INT8_C(  57), -INT8_C(  95),  INT8_C(  50),  INT8_C(  58), -INT8_C(  76), -INT8_C(   9),  INT8_C(  84),  INT8_C(  72),
        -INT8_C( 117), -INT8_C(  29), -INT8_C( 116),  INT8_C(  62), -INT8_C( 104), -INT8_C(  23),  INT8_C(  68),  INT8_C(  67),
        -INT8_C(  37), -INT8_C(  82),  INT8_C( 118), -INT8_C(  66), -INT8_C(  56), -INT8_C(  90), -INT8_C(  80), -INT8_C(  70),
        -INT8_C(  78),  INT8_C(  66),  INT8_C(  29),  INT8_C( 125),  INT8_C(  19),  INT8_C(  19),  INT8_C(   7), -INT8_C(  38),
        -INT8_C(  76),  INT8_C(  57),  INT8_C(  20),  INT8_C( 104),  INT8_C(  48),  INT8_C( 104), -INT8_C(  80), -INT8_C(  69),
         INT8_C(  76),  INT8_C(  60), -INT8_C(   6), -INT8_C(  28),  INT8_C(  38),  INT8_C(  62),  INT8_C(  39),  INT8_C(   1),
        -INT8_C(  19), -INT8_C(  99), -INT8_C(  65), -INT8_C(  75),  INT8_C(  67),  INT8_C( 112),  INT8_C( 112), -INT8_C(  10) },
      { -INT8_C(  78), -INT8_C( 115),  INT8_C( 115), -INT8_C(  59), -INT8_C(  96),  INT8_C( 123), -INT8_C(  97),  INT8_C(  84),
        -INT8_C(  76), -INT8_C(  77), -INT8_C(  68), -INT8_C(  27),  INT8_C(  28),  INT8_C( 108), -INT8_C(  96),  INT8_C( 104),
        -INT8_C(  87), -INT8_C( 102),  INT8_C(  76), -INT8_C(  49), -INT8_C(  39),  INT8_C( 115), -INT8_C(  48), -INT8_C(  58),
         INT8_C(  17), -INT8_C( 113),  INT8_C( 123),  INT8_C(  84), -INT8_C(   1), -INT8_C(  21),  INT8_C(  74), -INT8_C(  78),
         INT8_C( 120), -INT8_C(  66),  INT8_C( 119),  INT8_C(  24),  INT8_C(  57),  INT8_C(  23),  INT8_C( 108), -INT8_C(  19),
        -INT8_C(  54),  INT8_C(  40), -INT8_C(  46), -INT8_C(  26), -INT8_C( 107),  INT8_C( 115),  INT8_C(  78),  INT8_C(  62),
         INT8_C(  13), -INT8_C( 102),  INT8_C(  13), -INT8_C(  26),  INT8_C(  14), -INT8_C(  35), -INT8_C(  84),  INT8_C(  31),
         INT8_C( 108),  INT8_C(  40),  INT8_C( 115),  INT8_C( 108),  INT8_C(  19), -INT8_C(  66),  INT8_C(  30), -INT8_C( 116) },
      { -INT8_C(  14),  INT8_C(  12),  INT8_C(   0),  INT8_C(  98),  INT8_C(   0),  INT8_C( 123),  INT8_C(   0),  INT8_C(  84),
        -INT8_C(  57),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(  28),  INT8_C( 108),  INT8_C(  84),  INT8_C( 104),
         INT8_C(   0), -INT8_C(  29),  INT8_C(   0),  INT8_C(  62),  INT8_C(   0),  INT8_C( 115),  INT8_C(  68),  INT8_C(   0),
         INT8_C(   0), -INT8_C(  82),  INT8_C(   0),  INT8_C(   0), -INT8_C(   1), -INT8_C(  21),  INT8_C(   0),  INT8_C(   0),
         INT8_C( 120),  INT8_C(  66),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(  23),  INT8_C( 108), -INT8_C(  19),
         INT8_C(   0),  INT8_C(  57),  INT8_C(   0),  INT8_C( 104),  INT8_C(  48),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),
         INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(  38),  INT8_C(  62),  INT8_C(   0),  INT8_C(   0),
         INT8_C(   0),  INT8_C(  40),  INT8_C(   0),  INT8_C(   0),  INT8_C(  67),  INT8_C( 112),  INT8_C( 112), -INT8_C(  10) } },
    { UINT64_C( 8620472070220060028),
      {  INT8_C(  57),  INT8_C( 117),  INT8_C(  93), -INT8_C(  50), -INT8_C(  24), -INT8_C(  84),  INT8_C(  12), -INT8_C(  11),
         INT8_C(  70),  INT8_C(  25), -INT8_C(  36),  INT8_C(  84), -INT8_C(  10), -INT8_C( 120),  INT8_C( 115),  INT8_C(  99),
        -INT8_C(  80), -INT8_C(  25), -INT8_C(  49), -INT8_C(  60), -INT8_C(  91), -INT8_C(  19),  INT8_C(  80),  INT8_C(  33),
        -INT8_C( 126), -INT8_C(  12), -INT8_C(  42),  INT8_C(  47),  INT8_C(   5),  INT8_C( 120), -INT8_C(  90),  INT8_C(  63),
        -INT8_C(  19),  INT8_C(   3),  INT8_C(  13), -INT8_C(  43), -INT8_C(  81),  INT8_C(  26), -INT8_C(  53), -INT8_C(  10),
         INT8_C(  51), -INT8_C(  89),  INT8_C(  74),  INT8_C(  42),  INT8_C(  47), -INT8_C(  66), -INT8_C( 115), -INT8_C(  32),
        -INT8_C(  91),  INT8_C(  92), -INT8_C(  92),  INT8_C(  74),  INT8_C(  73), -INT8_C(  12),  INT8_C( 107), -INT8_C(  53),
        -INT8_C(  24),  INT8_C(  65), -INT8_C(   6), -INT8_C(  18), -INT8_C(  71), -INT8_C(  96),  INT8_C(  45), -INT8_C(  89) },
      { -INT8_C(  92),  INT8_C(  58),  INT8_C( 124),  INT8_C(  83),  INT8_C(  84),  INT8_C(  71),  INT8_C(  73), -INT8_C( 120),
        -INT8_C(  18), -INT8_C( 108), -INT8_C(  78),  INT8_C(  30),  INT8_C(  82),  INT8_C(  63), -INT8_C(   2), -INT8_C(   9),
        -INT8_C( 101), -INT8_C(  94),  INT8_C(  65), -INT8_C(  28), -INT8_C( 106), -INT8_C(  84), -INT8_C(  81),  INT8_C( 126),
        -INT8_C(  19), -INT8_C(  86),  INT8_C( 108), -INT8_C(  90),  INT8_C(  74), -INT8_C( 103),  INT8_C(  77), -INT8_C(  18),
        -INT8_C(  44), -INT8_C(  54),  INT8_C(  66),  INT8_C(  40),  INT8_C(  17), -INT8_C( 117), -INT8_C(  80),  INT8_C(   0),
         INT8_C(  31),  INT8_C(  98),  INT8_C(  30),  INT8_C( 113), -INT8_C(  95),  INT8_C(  28),  INT8_C( 104),  INT8_C(  60),
        -INT8_C(  66), -INT8_C(  87),  INT8_C(  32),  INT8_C(  84),  INT8_C(  85), -INT8_C(  48), -INT8_C(  46),  INT8_C(  66),
         INT8_C( 122),  INT8_C(  63), -INT8_C(  23), -INT8_C(  60), -INT8_C(  40),  INT8_C(  54), -INT8_C(  77), -INT8_C(  84) },
      {  INT8_C(   0),  INT8_C(   0),  INT8_C( 124),  INT8_C(  83),  INT8_C(  84),  INT8_C(  71),  INT8_C(  73),  INT8_C(   0),
         INT8_C(  70),  INT8_C(   0), -INT8_C(  36),  INT8_C(   0),  INT8_C(  82),  INT8_C(   0),  INT8_C(   0),  INT8_C(  99),
         INT8_C(   0),  INT8_C(   0),  INT8_C(  65),  INT8_C(   0),  INT8_C(   0), -INT8_C(  19),  INT8_C(   0),  INT8_C( 126),
        -INT8_C(  19),  INT8_C(   0),  INT8_C( 108),  INT8_C(   0),  INT8_C(  74),  INT8_C( 120),  INT8_C(   0),  INT8_C(  63),
         INT8_C(   0),  INT8_C(   0),  INT8_C(  66),  INT8_C(  40),  INT8_C(   0),  INT8_C(  26),  INT8_C(   0),  INT8_C(   0),
         INT8_C(  51),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(  47),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),
         INT8_C(   0),  INT8_C(  92),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0), -INT8_C(  12),  INT8_C(   0),  INT8_C(  66),
         INT8_C( 122),  INT8_C(  65), -INT8_C(   6),  INT8_C(   0), -INT8_C(  40),  INT8_C(  54),  INT8_C(  45),  INT8_C(   0) } },
    { UINT64_C(11534428380767581440),
      { -INT8_C(  24),  INT8_C(  48),  INT8_C(  17), -INT8_C( 119),  INT8_C(  76),  INT8_C( 122), -INT8_C(  58),  INT8_C(  10),
         INT8_C(  35), -INT8_C(  26),  INT8_C(  94),  INT8_C( 121), -INT8_C(  74),  INT8_C(  48), -INT8_C(  69),  INT8_C(  48),
         INT8_C( 111), -INT8_C(  92), -INT8_C(  11),  INT8_C(  72), -INT8_C(  37), -INT8_C(  88), -INT8_C(  12), -INT8_C(  37),
        -INT8_C(  99), -INT8_C(  55), -INT8_C(  19),  INT8_C(  29),  INT8_C(  79), -INT8_C(   1), -INT8_C(  67),  INT8_C(  55),
         INT8_C(  47), -INT8_C(  49), -INT8_C(  64),  INT8_C( 123),  INT8_C(  73), -INT8_C( 122), -INT8_C( 123),  INT8_C( 108),
         INT8_C( 109), -INT8_C(  29), -INT8_C(  27),  INT8_C(  35),  INT8_C(  20), -INT8_C(  95),  INT8_C(  84), -INT8_C( 125),
         INT8_C(  69),  INT8_C(  73), -INT8_C(  53),  INT8_C(  32), -INT8_C(  15), -INT8_C(  64), -INT8_C(   4), -INT8_C( 114),
        -INT8_C( 119), -INT8_C(  23), -INT8_C(  85), -INT8_C(  40), -INT8_C(  23),  INT8_C( 105),  INT8_C(  15),  INT8_C(  24) },
      {  INT8_C(  56), -INT8_C(  48), -INT8_C( 108), -INT8_C( 127),  INT8_C(  86),  INT8_C(  25), -INT8_C(  19), -INT8_C(  61),
        -INT8_C(   3), -INT8_C(  45), -INT8_C(  25),  INT8_C(  17),  INT8_C( 116),  INT8_C(  59), -INT8_C( 108), -INT8_C(  71),
        -INT8_C( 124),  INT8_C(  96), -INT8_C(  38),  INT8_C( 117),  INT8_C(  32), -INT8_C(  42),  INT8_C(   3), -INT8_C(  87),
        -INT8_C(  65), -INT8_C(  82), -INT8_C( 126), -INT8_C(  88),  INT8_C(  23), -INT8_C( 111), -INT8_C(  63),  INT8_C(  79),
         INT8_C(  97),  INT8_C(  85), -INT8_C(  48), -INT8_C(  72),  INT8_C( 110), -INT8_C(  66),  INT8_C( 123),  INT8_C( 107),
        -INT8_C( 111),  INT8_C(  98),  INT8_C( 124),  INT8_C(   5), -INT8_C(  99),  INT8_C(  17), -INT8_C(  66),  INT8_C(  33),
         INT8_C( 113), -INT8_C( 104), -INT8_C( 106), -INT8_C( 111),  INT8_C( 110), -INT8_C( 103),  INT8_C(  58),  INT8_C(  46),
         INT8_C(  72), -INT8_C(  68), -INT8_C(  42),  INT8_C(  95),  INT8_C(  78), -INT8_C( 105), -INT8_C(  81), -INT8_C(  81) },
      {  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),
         INT8_C(  35),  INT8_C(   0),  INT8_C(  94),  INT8_C(   0),  INT8_C( 116),  INT8_C(  59), -INT8_C(  69),  INT8_C(  48),
         INT8_C( 111),  INT8_C(   0), -INT8_C(  11),  INT8_C(   0),  INT8_C(  32),  INT8_C(   0),  INT8_C(   3), -INT8_C(  37),
         INT8_C(   0), -INT8_C(  55),  INT8_C(   0),  INT8_C(   0),  INT8_C(  79),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),
         INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C( 108),
         INT8_C( 109),  INT8_C(   0),  INT8_C( 124),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(  33),
         INT8_C(   0),  INT8_C(  73),  INT8_C(   0),  INT8_C(   0),  INT8_C( 110),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),
         INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C( 105),  INT8_C(   0),  INT8_C(  24) } },
    { UINT64_C(14899846269867884524),
      {  INT8_C(  69),  INT8_C(  67), -INT8_C(  45), -INT8_C(  29),  INT8_C(  84), -INT8_C( 110),  INT8_C(   4), -INT8_C(  59),
         INT8_C(  42), -INT8_C( 101),  INT8_C(  86), -INT8_C( 103),  INT8_C(  52), -INT8_C( 112), -INT8_C(  57),  INT8_C( 124),
         INT8_C(  77), -INT8_C(  99), -INT8_C(  36), -INT8_C( 101),  INT8_C(  53), -INT8_C( 117),  INT8_C(  74),  INT8_C(  33),
         INT8_C(  10), -INT8_C(  78),  INT8_C( 124),  INT8_C(  72), -INT8_C( 107),  INT8_C(  67),  INT8_C(  22), -INT8_C(  38),
        -INT8_C( 122), -INT8_C(  22), -INT8_C(  67), -INT8_C(  38),  INT8_C( 124), -INT8_C(  62), -INT8_C(  97), -INT8_C(  90),
         INT8_C(  93), -INT8_C(  11),  INT8_C(  63), -INT8_C( 111), -INT8_C( 123),  INT8_C(   6),  INT8_C(  14), -INT8_C(  46),
        -INT8_C(  92), -INT8_C(  22),  INT8_C( 109), -INT8_C(  39),  INT8_C( 117), -INT8_C(  72), -INT8_C(   6),      INT8_MAX,
         INT8_C( 106),  INT8_C( 119), -INT8_C(  57), -INT8_C(   1), -INT8_C(  70), -INT8_C(  34), -INT8_C(  39),  INT8_C(  64) },
      { -INT8_C(  56), -INT8_C( 105),  INT8_C(  26),  INT8_C(  68),  INT8_C(  89), -INT8_C(  71), -INT8_C(  22), -INT8_C(  74),
        -INT8_C(  82),  INT8_C(  42),  INT8_C(  71),  INT8_C(  51),  INT8_C(  48),  INT8_C(  85),  INT8_C(   6), -INT8_C(  44),
         INT8_C(  63),  INT8_C( 115), -INT8_C(  83), -INT8_C(  76),  INT8_C(  43), -INT8_C(  88),  INT8_C(  52), -INT8_C( 107),
         INT8_C(  31), -INT8_C(   5), -INT8_C( 108), -INT8_C(  39), -INT8_C(  39),  INT8_C( 110),  INT8_C(  25), -INT8_C(  95),
         INT8_C(   5),  INT8_C(  51), -INT8_C(  27),  INT8_C(  94), -INT8_C(  20), -INT8_C(  48),  INT8_C(  20), -INT8_C( 102),
        -INT8_C(   6),  INT8_C(  91), -INT8_C(  51),  INT8_C(  42), -INT8_C(  79), -INT8_C(  45), -INT8_C(   1), -INT8_C(  16),
         INT8_C(  71), -INT8_C(  84), -INT8_C(  91),  INT8_C( 114),  INT8_C(  84), -INT8_C(  39),  INT8_C(   8),  INT8_C( 115),
        -INT8_C(  44), -INT8_C( 100),  INT8_C(  76), -INT8_C(  82),  INT8_C(  10),  INT8_C( 101),  INT8_C(  79),  INT8_C(  15) },
      {  INT8_C(   0),  INT8_C(   0),  INT8_C(  26),  INT8_C(  68),  INT8_C(   0), -INT8_C(  71),  INT8_C(   4), -INT8_C(  59),
         INT8_C(  42),  INT8_C(  42),  INT8_C(  86),  INT8_C(  51),  INT8_C(  52),  INT8_C(  85),  INT8_C(   6),  INT8_C(   0),
         INT8_C(  77),  INT8_C( 115), -INT8_C(  36),  INT8_C(   0),  INT8_C(   0), -INT8_C(  88),  INT8_C(  74),  INT8_C(   0),
         INT8_C(  31), -INT8_C(   5),  INT8_C(   0),  INT8_C(  72), -INT8_C(  39),  INT8_C(   0),  INT8_C(  25),  INT8_C(   0),
         INT8_C(   5),  INT8_C(   0), -INT8_C(  27),  INT8_C(  94),  INT8_C( 124), -INT8_C(  48),  INT8_C(   0),  INT8_C(   0),
         INT8_C(  93),  INT8_C(  91),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   6),  INT8_C(  14), -INT8_C(  16),
         INT8_C(   0), -INT8_C(  22),  INT8_C( 109),  INT8_C(   0),  INT8_C(   0),  INT8_C(   0),  INT8_C(   8),      INT8_MAX,
         INT8_C(   0),  INT8_C( 119),  INT8_C(  76), -INT8_C(   1),  INT8_C(   0),  INT8_C(   0),  INT8_C(  79),  INT8_C(  64) } }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
    simde__m512i a = simde_mm512_loadu_epi8(test_vec[i].a);
    simde__m512i b = simde_mm512_loadu_epi8(test_vec[i].b);
    simde__m512i r = simde_mm512_maskz_max_epi8(test_vec[i].k, a, b);
    simde_test_x86_assert_equal_i8x64(r, simde_mm512_loadu_epi8(test_vec[i].r));
  }

  return 0;
}

static int
test_simde_mm512_max_epu8 (SIMDE_MUNIT_TEST_ARGS) {
  static const struct {
    const uint8_t a[64];
    const uint8_t b[64];
    const uint8_t r[64];
  } test_vec[] = {
    { { UINT8_C( 59), UINT8_C(162), UINT8_C(  5), UINT8_C( 15), UINT8_C(230), UINT8_C(146), UINT8_C(192), UINT8_C( 69),
        UINT8_C(125), UINT8_C(138), UINT8_C(150), UINT8_C( 98), UINT8_C(245), UINT8_C(241), UINT8_C(112), UINT8_C(249),
        UINT8_C(152), UINT8_C(155), UINT8_C( 67), UINT8_C(153), UINT8_C(113), UINT8_C(166), UINT8_C(206), UINT8_C(155),
        UINT8_C( 29), UINT8_C(173), UINT8_C( 53), UINT8_C(  7), UINT8_C(175), UINT8_C(212), UINT8_C(130), UINT8_C(234),
        UINT8_C(118), UINT8_C(135), UINT8_C(249), UINT8_C( 92), UINT8_C( 26), UINT8_C(185), UINT8_C(161), UINT8_C(151),
        UINT8_C( 67), UINT8_C( 56), UINT8_C(249), UINT8_C( 57), UINT8_C( 41), UINT8_C(105), UINT8_C( 50), UINT8_C(193),
        UINT8_C(  4), UINT8_C(117), UINT8_C( 90), UINT8_C(118), UINT8_C( 27), UINT8_C( 40), UINT8_C( 17), UINT8_C( 56),
        UINT8_C(214), UINT8_C( 70), UINT8_C( 63), UINT8_C(133), UINT8_C( 26), UINT8_C(193), UINT8_C(111), UINT8_C(144) },
      { UINT8_C( 73), UINT8_C(104), UINT8_C(237), UINT8_C( 99), UINT8_C( 33), UINT8_C(142), UINT8_C(250), UINT8_C(100),
        UINT8_C(198), UINT8_C(244), UINT8_C(157), UINT8_C(240), UINT8_C( 93), UINT8_C(207), UINT8_C(177), UINT8_C( 98),
        UINT8_C( 68), UINT8_C( 12), UINT8_C(216), UINT8_C( 95), UINT8_C( 52), UINT8_C(233), UINT8_C(152), UINT8_C( 10),
        UINT8_C( 47), UINT8_C(215), UINT8_C(143), UINT8_C( 73), UINT8_C(153), UINT8_C(254), UINT8_C(217), UINT8_C(226),
        UINT8_C(102), UINT8_C(198), UINT8_C( 69), UINT8_C(135), UINT8_C( 85), UINT8_C( 63), UINT8_C(236), UINT8_C( 27),
        UINT8_C( 51), UINT8_C(137), UINT8_C( 11), UINT8_C(145), UINT8_C( 89), UINT8_C(189), UINT8_C(243), UINT8_C(157),
        UINT8_C(201), UINT8_C(203), UINT8_C(253), UINT8_C(253), UINT8_C(180), UINT8_C(149), UINT8_C(  8), UINT8_C(227),
        UINT8_C(108), UINT8_C(151), UINT8_C( 44), UINT8_C(  5), UINT8_C(150), UINT8_C(  5), UINT8_C(231), UINT8_C(252) },
      { UINT8_C( 73), UINT8_C(162), UINT8_C(237), UINT8_C( 99), UINT8_C(230), UINT8_C(146), UINT8_C(250), UINT8_C(100),
        UINT8_C(198), UINT8_C(244), UINT8_C(157), UINT8_C(240), UINT8_C(245), UINT8_C(241), UINT8_C(177), UINT8_C(249),
        UINT8_C(152), UINT8_C(155), UINT8_C(216), UINT8_C(153), UINT8_C(113), UINT8_C(233), UINT8_C(206), UINT8_C(155),
        UINT8_C( 47), UINT8_C(215), UINT8_C(143), UINT8_C( 73), UINT8_C(175), UINT8_C(254), UINT8_C(217), UINT8_C(234),
        UINT8_C(118), UINT8_C(198), UINT8_C(249), UINT8_C(135), UINT8_C( 85), UINT8_C(185), UINT8_C(236), UINT8_C(151),
        UINT8_C( 67), UINT8_C(137), UINT8_C(249), UINT8_C(145), UINT8_C( 89), UINT8_C(189), UINT8_C(243), UINT8_C(193),
        UINT8_C(201), UINT8_C(203), UINT8_C(253), UINT8_C(253), UINT8_C(180), UINT8_C(149), UINT8_C( 17), UINT8_C(227),
        UINT8_C(214), UINT8_C(151), UINT8_C( 63), UINT8_C(133), UINT8_C(150), UINT8_C(193), UINT8_C(231), UINT8_C(252) } },
    { { UINT8_C(204), UINT8_C( 44), UINT8_C(132), UINT8_C( 33), UINT8_C(108), UINT8_C(112), UINT8_C( 60), UINT8_C(159),
        UINT8_C(249), UINT8_C( 72), UINT8_C( 48), UINT8_C( 82), UINT8_C(  5), UINT8_C( 35), UINT8_C(240), UINT8_C(206),
        UINT8_C(238), UINT8_C(237), UINT8_C(203), UINT8_C(162), UINT8_C(130), UINT8_C(211), UINT8_C(133), UINT8_C(238),
        UINT8_C(107), UINT8_C(177), UINT8_C(244), UINT8_C(  1), UINT8_C(183), UINT8_C(219), UINT8_C(253), UINT8_C(131),
        UINT8_C(  8), UINT8_C(129), UINT8_C(164), UINT8_C(116), UINT8_C(241), UINT8_C(224), UINT8_C( 19), UINT8_C(235),
        UINT8_C( 40), UINT8_C( 68), UINT8_C( 61), UINT8_C( 45), UINT8_C(103), UINT8_C( 45), UINT8_C(251), UINT8_C( 86),
        UINT8_C( 26), UINT8_C(199), UINT8_C(248), UINT8_C(156), UINT8_C(154), UINT8_C(126), UINT8_C(139), UINT8_C(  5),
        UINT8_C( 47), UINT8_C(127), UINT8_C(  6), UINT8_C(230), UINT8_C( 90), UINT8_C(  4), UINT8_C(105), UINT8_C( 98) },
      { UINT8_C(133), UINT8_C( 13), UINT8_C(214), UINT8_C(119), UINT8_C(238), UINT8_C(234), UINT8_C( 98), UINT8_C( 22),
        UINT8_C( 46), UINT8_C(159), UINT8_C( 68), UINT8_C(149), UINT8_C(205), UINT8_C( 63), UINT8_C(235), UINT8_C(231),
        UINT8_C(  6), UINT8_C(228), UINT8_C(132), UINT8_C(161), UINT8_C( 98), UINT8_C( 15), UINT8_C(166), UINT8_C(145),
        UINT8_C(142), UINT8_C(173), UINT8_C(120), UINT8_C(232), UINT8_C(177), UINT8_C(225), UINT8_C( 75), UINT8_C( 54),
        UINT8_C(239), UINT8_C( 33), UINT8_C(173), UINT8_C(221), UINT8_C( 11), UINT8_C( 15), UINT8_C(243), UINT8_C( 57),
        UINT8_C(175), UINT8_C( 55), UINT8_C(207), UINT8_C(124), UINT8_C(119), UINT8_C(186), UINT8_C( 99), UINT8_C(125),
        UINT8_C(158), UINT8_C(231), UINT8_C( 30), UINT8_C(  0), UINT8_C(246), UINT8_C(197), UINT8_C(146), UINT8_C(132),
        UINT8_C(114), UINT8_C( 10), UINT8_C(109), UINT8_C( 35), UINT8_C(235), UINT8_C(184), UINT8_C( 89), UINT8_C(218) },
      { UINT8_C(204), UINT8_C( 44), UINT8_C(214), UINT8_C(119), UINT8_C(238), UINT8_C(234), UINT8_C( 98), UINT8_C(159),
        UINT8_C(249), UINT8_C(159), UINT8_C( 68), UINT8_C(149), UINT8_C(205), UINT8_C( 63), UINT8_C(240), UINT8_C(231),
        UINT8_C(238), UINT8_C(237), UINT8_C(203), UINT8_C(162), UINT8_C(130), UINT8_C(211), UINT8_C(166), UINT8_C(238),
        UINT8_C(142), UINT8_C(177), UINT8_C(244), UINT8_C(232), UINT8_C(183), UINT8_C(225), UINT8_C(253), UINT8_C(131),
        UINT8_C(239), UINT8_C(129), UINT8_C(173), UINT8_C(221), UINT8_C(241), UINT8_C(224), UINT8_C(243), UINT8_C(235),
        UINT8_C(175), UINT8_C( 68), UINT8_C(207), UINT8_C(124), UINT8_C(119), UINT8_C(186), UINT8_C(251), UINT8_C(125),
        UINT8_C(158), UINT8_C(231), UINT8_C(248), UINT8_C(156), UINT8_C(246), UINT8_C(197), UINT8_C(146), UINT8_C(132),
        UINT8_C(114), UINT8_C(127), UINT8_C(109), UINT8_C(230), UINT8_C(235), UINT8_C(184), UINT8_C(105), UINT8_C(218) } },
    { { UINT8_C(217), UINT8_C(  7), UINT8_C(183), UINT8_C(229), UINT8_C( 22), UINT8_C(171), UINT8_C( 30), UINT8_C(197),
        UINT8_C(226), UINT8_C(237), UINT8_C( 65), UINT8_C( 89), UINT8_C(168), UINT8_C(165), UINT8_C(215), UINT8_C( 70),
        UINT8_C(140), UINT8_C(245), UINT8_C( 71), UINT8_C(131), UINT8_C(186), UINT8_C(217), UINT8_C(  7), UINT8_C( 44),
        UINT8_C(227), UINT8_C(116), UINT8_C( 79), UINT8_C(206), UINT8_C( 44), UINT8_C(169), UINT8_C(169), UINT8_C(  6),
        UINT8_C(176), UINT8_C( 96), UINT8_C(235), UINT8_C(198), UINT8_C( 11), UINT8_C(  9), UINT8_C(140), UINT8_C(238),
        UINT8_C(247), UINT8_C(205), UINT8_C( 71), UINT8_C(159), UINT8_C(114), UINT8_C( 30), UINT8_C(229),    UINT8_MAX,
        UINT8_C( 20), UINT8_C( 44), UINT8_C(130), UINT8_C(206), UINT8_C(  5), UINT8_C(137), UINT8_C(251), UINT8_C(232),
        UINT8_C(254), UINT8_C( 74), UINT8_C(183), UINT8_C( 42), UINT8_C(243), UINT8_C( 96), UINT8_C( 48), UINT8_C(163) },
      { UINT8_C(192), UINT8_C( 27), UINT8_C(106), UINT8_C(204), UINT8_C( 37), UINT8_C(246), UINT8_C(186), UINT8_C( 28),
        UINT8_C(195), UINT8_C(  1), UINT8_C(187), UINT8_C( 54), UINT8_C( 32), UINT8_C(160), UINT8_C( 53), UINT8_C( 52),
        UINT8_C(205), UINT8_C(183), UINT8_C(  2), UINT8_C(210), UINT8_C( 64), UINT8_C(253), UINT8_C(187), UINT8_C( 62),
        UINT8_C( 72), UINT8_C(114), UINT8_C(105), UINT8_C( 59), UINT8_C(210), UINT8_C(153), UINT8_C(223), UINT8_C(146),
        UINT8_C(181), UINT8_C( 73), UINT8_C( 94), UINT8_C(218), UINT8_C( 63), UINT8_C( 24), UINT8_C(246), UINT8_C(  2),
        UINT8_C( 26), UINT8_C(177), UINT8_C( 56), UINT8_C( 58), UINT8_C( 81), UINT8_C(109), UINT8_C(110), UINT8_C( 30),
        UINT8_C( 36), UINT8_C(112), UINT8_C(241), UINT8_C(101), UINT8_C(110), UINT8_C(172), UINT8_C(163), UINT8_C(182),
        UINT8_C( 30), UINT8_C( 12), UINT8_C(241), UINT8_C(240), UINT8_C(166), UINT8_C(208), UINT8_C(130), UINT8_C( 91) },
      { UINT8_C(217), UINT8_C( 27), UINT8_C(183), UINT8_C(229), UINT8_C( 37), UINT8_C(246), UINT8_C(186), UINT8_C(197),
        UINT8_C(226), UINT8_C(237), UINT8_C(187), UINT8_C( 89), UINT8_C(168), UINT8_C(165), UINT8_C(215), UINT8_C( 70),
        UINT8_C(205), UINT8_C(245), UINT8_C( 71), UINT8_C(210), UINT8_C(186), UINT8_C(253), UINT8_C(187), UINT8_C( 62),
        UINT8_C(227), UINT8_C(116), UINT8_C(105), UINT8_C(206), UINT8_C(210), UINT8_C(169), UINT8_C(223), UINT8_C(146),
        UINT8_C(181), UINT8_C( 96), UINT8_C(235), UINT8_C(218), UINT8_C( 63), UINT8_C( 24), UINT8_C(246), UINT8_C(238),
        UINT8_C(247), UINT8_C(205), UINT8_C( 71), UINT8_C(159), UINT8_C(114), UINT8_C(109), UINT8_C(229),    UINT8_MAX,
        UINT8_C( 36), UINT8_C(112), UINT8_C(241), UINT8_C(206), UINT8_C(110), UINT8_C(172), UINT8_C(251), UINT8_C(232),
        UINT8_C(254), UINT8_C( 74), UINT8_C(241), UINT8_C(240), UINT8_C(243), UINT8_C(208), UINT8_C(130), UINT8_C(163) } },
    { { UINT8_C( 25), UINT8_C(225), UINT8_C( 53), UINT8_C( 88), UINT8_C(249), UINT8_C( 43), UINT8_C( 91), UINT8_C( 19),
        UINT8_C(220), UINT8_C(147), UINT8_C( 77), UINT8_C( 45), UINT8_C(  1), UINT8_C(187), UINT8_C( 76), UINT8_C( 37),
        UINT8_C( 44), UINT8_C( 61), UINT8_C(138), UINT8_C(154), UINT8_C(233), UINT8_C( 46), UINT8_C( 80), UINT8_C(  7),
        UINT8_C( 58), UINT8_C( 65), UINT8_C(247), UINT8_C(224), UINT8_C( 18), UINT8_C(121), UINT8_C( 59), UINT8_C( 43),
        UINT8_C( 90), UINT8_C(112), UINT8_C(132), UINT8_C( 84), UINT8_C(155), UINT8_C(223), UINT8_C(103), UINT8_C(119),
        UINT8_C(114), UINT8_C(181), UINT8_C(165), UINT8_C(115), UINT8_C(112), UINT8_C(241), UINT8_C(153), UINT8_C(156),
        UINT8_C( 46), UINT8_C( 35), UINT8_C( 54), UINT8_C( 23), UINT8_C( 81), UINT8_C(134), UINT8_C( 30), UINT8_C(140),
        UINT8_C(200), UINT8_C( 21), UINT8_C(108), UINT8_C(218), UINT8_C(142), UINT8_C(168), UINT8_C(  5), UINT8_C(233) },
      { UINT8_C( 24), UINT8_C(137), UINT8_C( 61), UINT8_C(180), UINT8_C(104), UINT8_C(164), UINT8_C( 43), UINT8_C(219),
        UINT8_C( 89), UINT8_C(208), UINT8_C( 78), UINT8_C(202), UINT8_C(193), UINT8_C(231), UINT8_C(102), UINT8_C(239),
        UINT8_C( 11), UINT8_C(157), UINT8_C(  6), UINT8_C( 92), UINT8_C( 35), UINT8_C( 36), UINT8_C(232), UINT8_C(235),
        UINT8_C( 57), UINT8_C( 85), UINT8_C(197), UINT8_C(200), UINT8_C(253), UINT8_C(203), UINT8_C(177), UINT8_C( 21),
        UINT8_C( 84), UINT8_C(238), UINT8_C(201), UINT8_C(189), UINT8_C(146), UINT8_C(245), UINT8_C(152), UINT8_C(236),
        UINT8_C(197), UINT8_C(230), UINT8_C(182), UINT8_C(135), UINT8_C(206), UINT8_C( 28), UINT8_C(118), UINT8_C(217),
        UINT8_C(185), UINT8_C(125), UINT8_C( 53), UINT8_C(221), UINT8_C(161), UINT8_C( 30), UINT8_C(200), UINT8_C(219),
        UINT8_C(115), UINT8_C(142), UINT8_C(163), UINT8_C(112), UINT8_C( 89), UINT8_C( 84), UINT8_C(133), UINT8_C(173) },
      { UINT8_C( 25), UINT8_C(225), UINT8_C( 61), UINT8_C(180), UINT8_C(249), UINT8_C(164), UINT8_C( 91), UINT8_C(219),
        UINT8_C(220), UINT8_C(208), UINT8_C( 78), UINT8_C(202), UINT8_C(193), UINT8_C(231), UINT8_C(102), UINT8_C(239),
        UINT8_C( 44), UINT8_C(157), UINT8_C(138), UINT8_C(154), UINT8_C(233), UINT8_C( 46), UINT8_C(232), UINT8_C(235),
        UINT8_C( 58), UINT8_C( 85), UINT8_C(247), UINT8_C(224), UINT8_C(253), UINT8_C(203), UINT8_C(177), UINT8_C( 43),
        UINT8_C( 90), UINT8_C(238), UINT8_C(201), UINT8_C(189), UINT8_C(155), UINT8_C(245), UINT8_C(152), UINT8_C(236),
        UINT8_C(197), UINT8_C(230), UINT8_C(182), UINT8_C(135), UINT8_C(206), UINT8_C(241), UINT8_C(153), UINT8_C(217),
        UINT8_C(185), UINT8_C(125), UINT8_C( 54), UINT8_C(221), UINT8_C(161), UINT8_C(134), UINT8_C(200), UINT8_C(219),
        UINT8_C(200), UINT8_C(142), UINT8_C(163), UINT8_C(218), UINT8_C(142), UINT8_C(168), UINT8_C(133), UINT8_C(233) } },
    { { UINT8_C( 66), UINT8_C( 79), UINT8_C(106), UINT8_C(212), UINT8_C( 68), UINT8_C(  2), UINT8_C(192), UINT8_C(  9),
        UINT8_C(233), UINT8_C(118), UINT8_C(144), UINT8_C(183), UINT8_C(147), UINT8_C(  7), UINT8_C(144), UINT8_C( 76),
        UINT8_C(132), UINT8_C(197), UINT8_C( 41), UINT8_C( 37), UINT8_C(227), UINT8_C(242), UINT8_C(  0), UINT8_C( 86),
        UINT8_C(128), UINT8_C(163), UINT8_C(198), UINT8_C(217), UINT8_C(247), UINT8_C( 76), UINT8_C(134), UINT8_C( 57),
        UINT8_C(155), UINT8_C(241), UINT8_C( 14), UINT8_C(223), UINT8_C(243), UINT8_C(206), UINT8_C(232), UINT8_C(220),
        UINT8_C( 69), UINT8_C(121), UINT8_C(147), UINT8_C(216), UINT8_C(128), UINT8_C( 35), UINT8_C( 36), UINT8_C(  4),
        UINT8_C(233), UINT8_C( 78), UINT8_C( 41), UINT8_C(204), UINT8_C( 64), UINT8_C( 42), UINT8_C( 35), UINT8_C(192),
        UINT8_C(205), UINT8_C(233), UINT8_C(153), UINT8_C(197), UINT8_C( 53), UINT8_C( 31), UINT8_C(254), UINT8_C(208) },
      { UINT8_C( 16), UINT8_C( 12), UINT8_C(175), UINT8_C(  4), UINT8_C(219), UINT8_C(152), UINT8_C(224), UINT8_C( 32),
        UINT8_C( 17), UINT8_C(116), UINT8_C(248), UINT8_C(145), UINT8_C(151), UINT8_C( 28), UINT8_C(149), UINT8_C(128),
        UINT8_C(106), UINT8_C(190), UINT8_C( 77), UINT8_C(170), UINT8_C(232), UINT8_C(112), UINT8_C(106), UINT8_C(182),
        UINT8_C( 89), UINT8_C(  3), UINT8_C(123), UINT8_C(143), UINT8_C( 35), UINT8_C(121), UINT8_C( 95), UINT8_C( 51),
        UINT8_C(134), UINT8_C( 15), UINT8_C( 55), UINT8_C( 97), UINT8_C(167), UINT8_C( 24), UINT8_C(129), UINT8_C(184),
        UINT8_C(140), UINT8_C(121), UINT8_C( 73), UINT8_C( 35), UINT8_C(149), UINT8_C(222), UINT8_C(164), UINT8_C(  0),
        UINT8_C(156), UINT8_C(241), UINT8_C(170), UINT8_C(133), UINT8_C( 97), UINT8_C( 21), UINT8_C( 59), UINT8_C(186),
        UINT8_C( 24), UINT8_C(182), UINT8_C( 73), UINT8_C( 59), UINT8_C( 47), UINT8_C(169), UINT8_C(111), UINT8_C(181) },
      { UINT8_C( 66), UINT8_C( 79), UINT8_C(175), UINT8_C(212), UINT8_C(219), UINT8_C(152), UINT8_C(224), UINT8_C( 32),
        UINT8_C(233), UINT8_C(118), UINT8_C(248), UINT8_C(183), UINT8_C(151), UINT8_C( 28), UINT8_C(149), UINT8_C(128),
        UINT8_C(132), UINT8_C(197), UINT8_C( 77), UINT8_C(170), UINT8_C(232), UINT8_C(242), UINT8_C(106), UINT8_C(182),
        UINT8_C(128), UINT8_C(163), UINT8_C(198), UINT8_C(217), UINT8_C(247), UINT8_C(121), UINT8_C(134), UINT8_C( 57),
        UINT8_C(155), UINT8_C(241), UINT8_C( 55), UINT8_C(223), UINT8_C(243), UINT8_C(206), UINT8_C(232), UINT8_C(220),
        UINT8_C(140), UINT8_C(121), UINT8_C(147), UINT8_C(216), UINT8_C(149), UINT8_C(222), UINT8_C(164), UINT8_C(  4),
        UINT8_C(233), UINT8_C(241), UINT8_C(170), UINT8_C(204), UINT8_C( 97), UINT8_C( 42), UINT8_C( 59), UINT8_C(192),
        UINT8_C(205), UINT8_C(233), UINT8_C(153), UINT8_C(197), UINT8_C( 53), UINT8_C(169), UINT8_C(254), UINT8_C(208) } },
    { { UINT8_C(184), UINT8_C(166), UINT8_C( 22), UINT8_C( 95), UINT8_C(190), UINT8_C(151), UINT8_C( 23), UINT8_C( 74),
        UINT8_C( 16), UINT8_C( 96), UINT8_C(110), UINT8_C(166), UINT8_C( 62), UINT8_C( 18), UINT8_C(166), UINT8_C(218),
        UINT8_C(  3), UINT8_C( 80), UINT8_C( 95), UINT8_C(100), UINT8_C(101), UINT8_C(154), UINT8_C( 30), UINT8_C(126),
        UINT8_C( 80), UINT8_C(104), UINT8_C(185), UINT8_C(128), UINT8_C( 17), UINT8_C( 40), UINT8_C( 53), UINT8_C(201),
        UINT8_C(207), UINT8_C( 76), UINT8_C( 40), UINT8_C(141), UINT8_C(227), UINT8_C( 63), UINT8_C(216), UINT8_C(244),
        UINT8_C(159), UINT8_C( 70), UINT8_C(154), UINT8_C(221), UINT8_C( 88), UINT8_C( 64), UINT8_C(183), UINT8_C( 91),
        UINT8_C(144), UINT8_C( 23), UINT8_C(191), UINT8_C(246), UINT8_C(177), UINT8_C(221), UINT8_C(116), UINT8_C(  2),
        UINT8_C( 69), UINT8_C( 45), UINT8_C(130), UINT8_C( 86), UINT8_C( 86), UINT8_C(183), UINT8_C( 31), UINT8_C( 37) },
      { UINT8_C(  3), UINT8_C( 71), UINT8_C(178), UINT8_C(231), UINT8_C(134), UINT8_C(138), UINT8_C(219), UINT8_C( 37),
        UINT8_C(208), UINT8_C(117), UINT8_C(  2), UINT8_C( 40), UINT8_C(181), UINT8_C(186), UINT8_C(131), UINT8_C( 69),
        UINT8_C(209), UINT8_C( 66), UINT8_C( 59), UINT8_C(130), UINT8_C( 32), UINT8_C(175), UINT8_C(132), UINT8_C(101),
        UINT8_C(221), UINT8_C(  6), UINT8_C(188), UINT8_C( 51), UINT8_C(190), UINT8_C(219), UINT8_C( 88), UINT8_C(193),
        UINT8_C( 35), UINT8_C( 10), UINT8_C(168), UINT8_C(169), UINT8_C(149), UINT8_C(131), UINT8_C(207), UINT8_C(101),
        UINT8_C(248), UINT8_C(209), UINT8_C(142), UINT8_C(173), UINT8_C(139), UINT8_C( 17), UINT8_C(243), UINT8_C( 92),
        UINT8_C( 84), UINT8_C( 46), UINT8_C(223), UINT8_C(116), UINT8_C(222), UINT8_C( 99), UINT8_C(217), UINT8_C(187),
        UINT8_C(106), UINT8_C(149), UINT8_C(238), UINT8_C( 40), UINT8_C(113), UINT8_C( 70), UINT8_C(233), UINT8_C(148) },
      { UINT8_C(184), UINT8_C(166), UINT8_C(178), UINT8_C(231), UINT8_C(190), UINT8_C(151), UINT8_C(219), UINT8_C( 74),
        UINT8_C(208), UINT8_C(117), UINT8_C(110), UINT8_C(166), UINT8_C(181), UINT8_C(186), UINT8_C(166), UINT8_C(218),
        UINT8_C(209), UINT8_C( 80), UINT8_C( 95), UINT8_C(130), UINT8_C(101), UINT8_C(175), UINT8_C(132), UINT8_C(126),
        UINT8_C(221), UINT8_C(104), UINT8_C(188), UINT8_C(128), UINT8_C(190), UINT8_C(219), UINT8_C( 88), UINT8_C(201),
        UINT8_C(207), UINT8_C( 76), UINT8_C(168), UINT8_C(169), UINT8_C(227), UINT8_C(131), UINT8_C(216), UINT8_C(244),
        UINT8_C(248), UINT8_C(209), UINT8_C(154), UINT8_C(221), UINT8_C(139), UINT8_C( 64), UINT8_C(243), UINT8_C( 92),
        UINT8_C(144), UINT8_C( 46), UINT8_C(223), UINT8_C(246), UINT8_C(222), UINT8_C(221), UINT8_C(217), UINT8_C(187),
        UINT8_C(106), UINT8_C(149), UINT8_C(238), UINT8_C( 86), UINT8_C(113), UINT8_C(183), UINT8_C(233), UINT8_C(148) } },
    { { UINT8_C( 80), UINT8_C(146), UINT8_C( 61), UINT8_C(229), UINT8_C( 21), UINT8_C( 12), UINT8_C( 75), UINT8_C( 14),
        UINT8_C(222), UINT8_C(217), UINT8_C(187), UINT8_C(105), UINT8_C(234), UINT8_C(174), UINT8_C(198), UINT8_C( 62),
        UINT8_C(221), UINT8_C(165), UINT8_C(178), UINT8_C(187), UINT8_C(  8), UINT8_C(140), UINT8_C(118), UINT8_C(114),
        UINT8_C( 33), UINT8_C(100), UINT8_C(154), UINT8_C(146), UINT8_C(170), UINT8_C(132), UINT8_C( 38), UINT8_C(250),
        UINT8_C( 22), UINT8_C(100), UINT8_C(224), UINT8_C( 43), UINT8_C(112), UINT8_C( 43), UINT8_C( 57), UINT8_C( 78),
        UINT8_C(  4), UINT8_C(245), UINT8_C(184), UINT8_C(238), UINT8_C(163), UINT8_C(126), UINT8_C( 45), UINT8_C(128),
        UINT8_C( 35), UINT8_C(223), UINT8_C( 59), UINT8_C( 43), UINT8_C(107), UINT8_C(177), UINT8_C(158), UINT8_C(141),
        UINT8_C( 21), UINT8_C( 56), UINT8_C( 31), UINT8_C(191), UINT8_C(188), UINT8_C( 70), UINT8_C(186), UINT8_C(210) },
      { UINT8_C(170), UINT8_C(154), UINT8_C(254), UINT8_C( 26), UINT8_C(197), UINT8_C( 55), UINT8_C(105), UINT8_C(201),
        UINT8_C( 44), UINT8_C( 33), UINT8_C(183), UINT8_C(208), UINT8_C(159), UINT8_C(228), UINT8_C( 80), UINT8_C(194),
        UINT8_C(196), UINT8_C(140), UINT8_C(237), UINT8_C( 47), UINT8_C( 61), UINT8_C(139), UINT8_C(188), UINT8_C( 83),
        UINT8_C(196), UINT8_C(220), UINT8_C( 18), UINT8_C(128), UINT8_C( 34), UINT8_C(204), UINT8_C( 83), UINT8_C(204),
        UINT8_C(102), UINT8_C( 81), UINT8_C(230), UINT8_C( 43), UINT8_C(136), UINT8_C( 79), UINT8_C(244), UINT8_C(181),
        UINT8_C(112), UINT8_C(172), UINT8_C(133), UINT8_C( 15), UINT8_C(144), UINT8_C(213), UINT8_C(209), UINT8_C( 84),
        UINT8_C( 97), UINT8_C(191), UINT8_C(132), UINT8_C(159), UINT8_C( 74), UINT8_C( 64), UINT8_C(242), UINT8_C( 14),
        UINT8_C( 28), UINT8_C(  4), UINT8_C(143), UINT8_C( 62), UINT8_C(209), UINT8_C(226), UINT8_C( 10), UINT8_C( 55) },
      { UINT8_C(170), UINT8_C(154), UINT8_C(254), UINT8_C(229), UINT8_C(197), UINT8_C( 55), UINT8_C(105), UINT8_C(201),
        UINT8_C(222), UINT8_C(217), UINT8_C(187), UINT8_C(208), UINT8_C(234), UINT8_C(228), UINT8_C(198), UINT8_C(194),
        UINT8_C(221), UINT8_C(165), UINT8_C(237), UINT8_C(187), UINT8_C( 61), UINT8_C(140), UINT8_C(188), UINT8_C(114),
        UINT8_C(196), UINT8_C(220), UINT8_C(154), UINT8_C(146), UINT8_C(170), UINT8_C(204), UINT8_C( 83), UINT8_C(250),
        UINT8_C(102), UINT8_C(100), UINT8_C(230), UINT8_C( 43), UINT8_C(136), UINT8_C( 79), UINT8_C(244), UINT8_C(181),
        UINT8_C(112), UINT8_C(245), UINT8_C(184), UINT8_C(238), UINT8_C(163), UINT8_C(213), UINT8_C(209), UINT8_C(128),
        UINT8_C( 97), UINT8_C(223), UINT8_C(132), UINT8_C(159), UINT8_C(107), UINT8_C(177), UINT8_C(242), UINT8_C(141),
        UINT8_C( 28), UINT8_C( 56), UINT8_C(143), UINT8_C(191), UINT8_C(209), UINT8_C(226), UINT8_C(186), UINT8_C(210) } },
    { { UINT8_C( 51), UINT8_C(241), UINT8_C( 99), UINT8_C(187), UINT8_C( 64), UINT8_C( 87), UINT8_C(112), UINT8_C(177),
        UINT8_C(  3), UINT8_C(245), UINT8_C(192), UINT8_C(148), UINT8_C(203), UINT8_C(146), UINT8_C(232), UINT8_C( 44),
        UINT8_C( 81), UINT8_C(108), UINT8_C(203), UINT8_C(155), UINT8_C(173), UINT8_C(189), UINT8_C(170), UINT8_C(201),
        UINT8_C(194), UINT8_C( 57), UINT8_C(  8), UINT8_C(147), UINT8_C( 27), UINT8_C( 18), UINT8_C(202), UINT8_C( 78),
        UINT8_C(  3), UINT8_C( 45), UINT8_C(  9), UINT8_C( 68), UINT8_C(133), UINT8_C(122), UINT8_C(245), UINT8_C(136),
        UINT8_C(111), UINT8_C(181), UINT8_C( 28), UINT8_C( 58), UINT8_C( 71), UINT8_C(  5), UINT8_C(103), UINT8_C(152),
        UINT8_C(113), UINT8_C( 50), UINT8_C( 52), UINT8_C( 30), UINT8_C(240), UINT8_C(222), UINT8_C(232), UINT8_C(178),
        UINT8_C( 23), UINT8_C(240), UINT8_C( 69), UINT8_C( 50), UINT8_C(  2), UINT8_C( 15), UINT8_C(128), UINT8_C(  6) },
      { UINT8_C( 61), UINT8_C(137), UINT8_C( 74), UINT8_C(194), UINT8_C(  3), UINT8_C( 63), UINT8_C( 74), UINT8_C(115),
        UINT8_C(244), UINT8_C(103), UINT8_C(173), UINT8_C( 60), UINT8_C(108), UINT8_C( 20), UINT8_C(212), UINT8_C(221),
        UINT8_C( 71), UINT8_C(  8), UINT8_C(252), UINT8_C( 55), UINT8_C(230), UINT8_C(228), UINT8_C(233), UINT8_C(253),
        UINT8_C(212), UINT8_C( 46), UINT8_C( 47), UINT8_C(214), UINT8_C( 61), UINT8_C(175), UINT8_C(220), UINT8_C(122),
        UINT8_C( 57), UINT8_C( 38), UINT8_C( 60), UINT8_C( 60), UINT8_C(101), UINT8_C(135), UINT8_C(175), UINT8_C( 90),
        UINT8_C(238), UINT8_C( 93), UINT8_C(150), UINT8_C( 90), UINT8_C(113), UINT8_C(106), UINT8_C( 55), UINT8_C(184),
        UINT8_C(115), UINT8_C( 51), UINT8_C(239), UINT8_C( 89), UINT8_C( 23), UINT8_C(216), UINT8_C( 87), UINT8_C(235),
        UINT8_C(  6), UINT8_C(134), UINT8_C(194), UINT8_C( 68), UINT8_C( 54), UINT8_C(158), UINT8_C(190), UINT8_C(111) },
      { UINT8_C( 61), UINT8_C(241), UINT8_C( 99), UINT8_C(194), UINT8_C( 64), UINT8_C( 87), UINT8_C(112), UINT8_C(177),
        UINT8_C(244), UINT8_C(245), UINT8_C(192), UINT8_C(148), UINT8_C(203), UINT8_C(146), UINT8_C(232), UINT8_C(221),
        UINT8_C( 81), UINT8_C(108), UINT8_C(252), UINT8_C(155), UINT8_C(230), UINT8_C(228), UINT8_C(233), UINT8_C(253),
        UINT8_C(212), UINT8_C( 57), UINT8_C( 47), UINT8_C(214), UINT8_C( 61), UINT8_C(175), UINT8_C(220), UINT8_C(122),
        UINT8_C( 57), UINT8_C( 45), UINT8_C( 60), UINT8_C( 68), UINT8_C(133), UINT8_C(135), UINT8_C(245), UINT8_C(136),
        UINT8_C(238), UINT8_C(181), UINT8_C(150), UINT8_C( 90), UINT8_C(113), UINT8_C(106), UINT8_C(103), UINT8_C(184),
        UINT8_C(115), UINT8_C( 51), UINT8_C(239), UINT8_C( 89), UINT8_C(240), UINT8_C(222), UINT8_C(232), UINT8_C(235),
        UINT8_C( 23), UINT8_C(240), UINT8_C(194), UINT8_C( 68), UINT8_C( 54), UINT8_C(158), UINT8_C(190), UINT8_C(111) } }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
    simde__m512i a = simde_mm512_loadu_epi8(test_vec[i].a);
    simde__m512i b = simde_mm512_loadu_epi8(test_vec[i].b);
    simde__m512i r = simde_mm512_max_epu8(a, b);
    simde_test_x86_assert_equal_u8x64(r, simde_mm512_loadu_epi8(test_vec[i].r));
  }

  return 0;
}

static int
test_simde_mm512_mask_max_epu8 (SIMDE_MUNIT_TEST_ARGS) {
  static const struct {
    const int8_t src[64];
    const simde__mmask64 k;
    const uint8_t a[64];
    const uint8_t b[64];
    const uint8_t r[64];
  } test_vec[] = {
    { { -INT8_C( 111),  INT8_C(  15),  INT8_C(   4), -INT8_C(  59),  INT8_C(  83),  INT8_C(  68), -INT8_C( 114),  INT8_C(   0),
        -INT8_C(  53),  INT8_C(  19),  INT8_C(  68), -INT8_C(  50),  INT8_C(  36), -INT8_C( 111), -INT8_C( 120),  INT8_C(  56),
         INT8_C(  81), -INT8_C( 111),  INT8_C(  12), -INT8_C( 107), -INT8_C(  59), -INT8_C( 106), -INT8_C(  82), -INT8_C(  55),
        -INT8_C(  82), -INT8_C(  56), -INT8_C(  95),  INT8_C(  57), -INT8_C( 111), -INT8_C(  99),  INT8_C(  95),  INT8_C(  34),
        -INT8_C(  84),  INT8_C(  99), -INT8_C(  24), -INT8_C(   1), -INT8_C(  89),  INT8_C( 118), -INT8_C(   1),  INT8_C( 114),
        -INT8_C( 118),  INT8_C(  67),  INT8_C(  64), -INT8_C(  82), -INT8_C(  44), -INT8_C(  56), -INT8_C(  25),  INT8_C(  38),
         INT8_C(  90), -INT8_C(  13), -INT8_C(  69),  INT8_C(  31), -INT8_C( 118),  INT8_C( 106), -INT8_C(  24),  INT8_C(  56),
         INT8_C(  50), -INT8_C( 119),  INT8_C( 113), -INT8_C(  60),  INT8_C(  38), -INT8_C(  48), -INT8_C(  26), -INT8_C(  46) },
      UINT64_C(14938106012493794868),
      { UINT8_C( 20), UINT8_C(142), UINT8_C(125), UINT8_C(232), UINT8_C( 87), UINT8_C(100), UINT8_C( 14), UINT8_C(177),
        UINT8_C( 88), UINT8_C(202), UINT8_C(208), UINT8_C(226), UINT8_C( 52), UINT8_C(184), UINT8_C( 26), UINT8_C(102),
        UINT8_C( 65), UINT8_C(139), UINT8_C( 42), UINT8_C(104), UINT8_C( 91), UINT8_C( 17), UINT8_C( 58), UINT8_C(143),
        UINT8_C(223), UINT8_C( 12), UINT8_C(107), UINT8_C( 36), UINT8_C(220), UINT8_C(185), UINT8_C(243), UINT8_C(240),
        UINT8_C( 71), UINT8_C(113), UINT8_C(217), UINT8_C(158), UINT8_C(213), UINT8_C(231), UINT8_C( 79), UINT8_C( 45),
        UINT8_C(177), UINT8_C( 31), UINT8_C( 15), UINT8_C(229), UINT8_C(215), UINT8_C( 41), UINT8_C( 76), UINT8_C( 25),
        UINT8_C(180), UINT8_C(118), UINT8_C(129), UINT8_C( 16), UINT8_C(135), UINT8_C(187), UINT8_C(159), UINT8_C(103),
        UINT8_C(199), UINT8_C( 10), UINT8_C(139), UINT8_C(164), UINT8_C(195), UINT8_C(127), UINT8_C(148), UINT8_C( 11) },
      { UINT8_C(240), UINT8_C(109), UINT8_C(169), UINT8_C(197), UINT8_C( 85), UINT8_C(249), UINT8_C(243), UINT8_C(  6),
        UINT8_C( 24), UINT8_C(  2), UINT8_C(236), UINT8_C(240), UINT8_C( 44), UINT8_C( 56), UINT8_C(  9), UINT8_C(224),
        UINT8_C(174), UINT8_C(138), UINT8_C(240), UINT8_C( 54), UINT8_C( 69), UINT8_C(144), UINT8_C(157), UINT8_C( 13),
        UINT8_C(154), UINT8_C( 40), UINT8_C(177), UINT8_C( 94), UINT8_C(167), UINT8_C( 69), UINT8_C(105), UINT8_C(151),
        UINT8_C(179), UINT8_C( 18), UINT8_C( 93), UINT8_C(  8), UINT8_C( 11), UINT8_C( 80), UINT8_C( 14), UINT8_C( 36),
        UINT8_C( 82), UINT8_C(250), UINT8_C( 20), UINT8_C(126), UINT8_C( 50), UINT8_C( 29), UINT8_C( 95), UINT8_C(225),
        UINT8_C(167), UINT8_C( 79), UINT8_C( 23), UINT8_C(236), UINT8_C(223), UINT8_C(180), UINT8_C(249), UINT8_C(122),
        UINT8_C(220), UINT8_C(170), UINT8_C(216), UINT8_C(132), UINT8_C(240), UINT8_C( 65), UINT8_C( 27), UINT8_C(163) },
      { UINT8_C(145), UINT8_C( 15), UINT8_C(169), UINT8_C(197), UINT8_C( 87), UINT8_C(249), UINT8_C(142), UINT8_C(  0),
        UINT8_C(203), UINT8_C(202), UINT8_C(236), UINT8_C(240), UINT8_C( 36), UINT8_C(145), UINT8_C( 26), UINT8_C(224),
        UINT8_C(174), UINT8_C(145), UINT8_C( 12), UINT8_C(149), UINT8_C( 91), UINT8_C(150), UINT8_C(157), UINT8_C(143),
        UINT8_C(223), UINT8_C( 40), UINT8_C(161), UINT8_C( 94), UINT8_C(220), UINT8_C(157), UINT8_C(243), UINT8_C(240),
        UINT8_C(179), UINT8_C( 99), UINT8_C(217),    UINT8_MAX, UINT8_C(167), UINT8_C(118), UINT8_C( 79), UINT8_C(114),
        UINT8_C(138), UINT8_C( 67), UINT8_C( 64), UINT8_C(174), UINT8_C(215), UINT8_C(200), UINT8_C( 95), UINT8_C(225),
        UINT8_C( 90), UINT8_C(118), UINT8_C(129), UINT8_C(236), UINT8_C(138), UINT8_C(106), UINT8_C(249), UINT8_C( 56),
        UINT8_C(220), UINT8_C(170), UINT8_C(216), UINT8_C(164), UINT8_C( 38), UINT8_C(208), UINT8_C(148), UINT8_C(163) } },
    { {  INT8_C(  83),  INT8_C( 120), -INT8_C(  85),  INT8_C(  95), -INT8_C(  56), -INT8_C(  71), -INT8_C( 125),  INT8_C(  27),
        -INT8_C(  76), -INT8_C( 105), -INT8_C( 103), -INT8_C(  26), -INT8_C(  76), -INT8_C(   8), -INT8_C(  57),  INT8_C(  91),
         INT8_C(  72), -INT8_C(  34),  INT8_C(  71),  INT8_C(  39), -INT8_C( 110),  INT8_C(  65), -INT8_C(  95),  INT8_C( 111),
        -INT8_C(  21),  INT8_C( 121), -INT8_C(  13), -INT8_C(  37), -INT8_C(  70),  INT8_C(  14),  INT8_C( 126),  INT8_C(  14),
        -INT8_C( 121),  INT8_C(  41),  INT8_C( 109),  INT8_C(  79), -INT8_C(  29), -INT8_C(  16),  INT8_C( 106), -INT8_C( 105),
        -INT8_C( 121),  INT8_C(   4),  INT8_C( 125),  INT8_C(  59), -INT8_C(   4),  INT8_C(  69), -INT8_C( 106),  INT8_C(  68),
         INT8_C(  35), -INT8_C(  35),  INT8_C( 108), -INT8_C(  74),  INT8_C(  30),  INT8_C(  13),  INT8_C(  37),  INT8_C(  10),
        -INT8_C( 121),  INT8_C(  24), -INT8_C(  27),  INT8_C(  65),  INT8_C(  38),  INT8_C( 100),  INT8_C(  79), -INT8_C(  83) },
      UINT64_C( 3677021611099012237),
      { UINT8_C(107), UINT8_C(133), UINT8_C(110), UINT8_C(104), UINT8_C(202), UINT8_C(  4), UINT8_C(172), UINT8_C(237),
        UINT8_C(226), UINT8_C( 24), UINT8_C(163), UINT8_C(  0), UINT8_C( 38), UINT8_C(200), UINT8_C( 10), UINT8_C(173),
        UINT8_C(224), UINT8_C(240), UINT8_C(238), UINT8_C(  7), UINT8_C( 84), UINT8_C( 62), UINT8_C(180), UINT8_C(225),
        UINT8_C(250), UINT8_C(177), UINT8_C( 82), UINT8_C(167), UINT8_C( 25), UINT8_C( 89), UINT8_C(218), UINT8_C(132),
        UINT8_C(222), UINT8_C( 73), UINT8_C(236), UINT8_C(168), UINT8_C( 77), UINT8_C(153), UINT8_C(150), UINT8_C( 47),
        UINT8_C(177), UINT8_C( 57), UINT8_C( 48), UINT8_C(215), UINT8_C(  2), UINT8_C( 58), UINT8_C(132), UINT8_C(226),
        UINT8_C( 42), UINT8_C(115), UINT8_C(233), UINT8_C(126), UINT8_C(177), UINT8_C(158), UINT8_C( 96), UINT8_C(171),
        UINT8_C( 79), UINT8_C(178), UINT8_C( 82), UINT8_C(104), UINT8_C( 11), UINT8_C( 45), UINT8_C(237), UINT8_C(234) },
      { UINT8_C(118), UINT8_C(217), UINT8_C(146), UINT8_C(195), UINT8_C(114), UINT8_C( 40), UINT8_C(243), UINT8_C( 36),
        UINT8_C( 98), UINT8_C( 35), UINT8_C(251), UINT8_C(100), UINT8_C( 93), UINT8_C(128), UINT8_C( 70), UINT8_C(136),
        UINT8_C(243), UINT8_C( 48), UINT8_C(  6), UINT8_C(164), UINT8_C(206), UINT8_C(102), UINT8_C( 79), UINT8_C( 29),
        UINT8_C( 24), UINT8_C(162), UINT8_C(134), UINT8_C( 36), UINT8_C(207), UINT8_C(115), UINT8_C( 14), UINT8_C( 69),
        UINT8_C( 76), UINT8_C(160), UINT8_C(  8), UINT8_C(191), UINT8_C(201), UINT8_C(251), UINT8_C(227), UINT8_C( 43),
        UINT8_C( 30), UINT8_C(222), UINT8_C(143), UINT8_C(124), UINT8_C( 94), UINT8_C(213), UINT8_C(  4), UINT8_C( 81),
        UINT8_C(  5), UINT8_C( 10), UINT8_C(245), UINT8_C(211), UINT8_C(113), UINT8_C( 69), UINT8_C(241), UINT8_C(137),
        UINT8_C(231), UINT8_C(119), UINT8_C(173), UINT8_C(182), UINT8_C(234), UINT8_C(187), UINT8_C(251), UINT8_C( 54) },
      { UINT8_C(118), UINT8_C(120), UINT8_C(146), UINT8_C(195), UINT8_C(200), UINT8_C(185), UINT8_C(131), UINT8_C(237),
        UINT8_C(180), UINT8_C(151), UINT8_C(251), UINT8_C(100), UINT8_C( 93), UINT8_C(200), UINT8_C(199), UINT8_C(173),
        UINT8_C(243), UINT8_C(222), UINT8_C(238), UINT8_C(164), UINT8_C(206), UINT8_C(102), UINT8_C(180), UINT8_C(225),
        UINT8_C(235), UINT8_C(121), UINT8_C(243), UINT8_C(219), UINT8_C(207), UINT8_C(115), UINT8_C(218), UINT8_C( 14),
        UINT8_C(135), UINT8_C( 41), UINT8_C(236), UINT8_C(191), UINT8_C(227), UINT8_C(251), UINT8_C(106), UINT8_C( 47),
        UINT8_C(177), UINT8_C(222), UINT8_C(143), UINT8_C( 59), UINT8_C(252), UINT8_C(213), UINT8_C(132), UINT8_C( 68),
        UINT8_C( 42), UINT8_C(115), UINT8_C(245), UINT8_C(182), UINT8_C( 30), UINT8_C( 13), UINT8_C( 37), UINT8_C( 10),
        UINT8_C(231), UINT8_C(178), UINT8_C(229), UINT8_C( 65), UINT8_C(234), UINT8_C(187), UINT8_C( 79), UINT8_C(173) } },
    { {  INT8_C(  92),  INT8_C(   3), -INT8_C(  11),  INT8_C(  37), -INT8_C(   1), -INT8_C(  40),  INT8_C(  80),  INT8_C(  29),
        -INT8_C(  73), -INT8_C(  33), -INT8_C( 103),  INT8_C(  21), -INT8_C(  76), -INT8_C(  99),  INT8_C( 103), -INT8_C(  70),
        -INT8_C(  88),  INT8_C(  92), -INT8_C( 115),  INT8_C(  25), -INT8_C(  95),  INT8_C( 126), -INT8_C(  94), -INT8_C( 120),
        -INT8_C(  11),  INT8_C(  80),  INT8_C(  62), -INT8_C(  33),  INT8_C(  11),  INT8_C(  57),  INT8_C(  22),  INT8_C( 103),
         INT8_C(  61),  INT8_C(  11), -INT8_C( 116),  INT8_C(  60), -INT8_C(  28), -INT8_C(  36),  INT8_C(  89), -INT8_C( 101),
        -INT8_C(  69), -INT8_C(  13), -INT8_C(  80),  INT8_C( 112), -INT8_C( 112),  INT8_C(  23),  INT8_C(  42),  INT8_C(  56),
         INT8_C( 116), -INT8_C(  73),  INT8_C(  81),  INT8_C(  21),  INT8_C(  54), -INT8_C(  12), -INT8_C(  98),  INT8_C(  43),
         INT8_C(  68), -INT8_C(  36),  INT8_C(  11),  INT8_C(  79),  INT8_C(  22),  INT8_C(  33), -INT8_C(  73),  INT8_C(  83) },
      UINT64_C(15829000539738161964),
      { UINT8_C(219), UINT8_C( 92), UINT8_C( 75), UINT8_C(108), UINT8_C(115), UINT8_C(117), UINT8_C(164), UINT8_C(231),
        UINT8_C( 45), UINT8_C(246), UINT8_C(253), UINT8_C( 99), UINT8_C(234), UINT8_C(155), UINT8_C(142), UINT8_C( 46),
        UINT8_C(119), UINT8_C(153), UINT8_C(125), UINT8_C(141), UINT8_C(186), UINT8_C( 52), UINT8_C(224), UINT8_C(231),
        UINT8_C(120), UINT8_C(111), UINT8_C(247), UINT8_C(152), UINT8_C( 88), UINT8_C(163), UINT8_C(115), UINT8_C( 51),
           UINT8_MAX, UINT8_C(191), UINT8_C(159), UINT8_C(114), UINT8_C( 52), UINT8_C( 68), UINT8_C( 90), UINT8_C( 97),
        UINT8_C( 58), UINT8_C( 87), UINT8_C(196), UINT8_C( 36), UINT8_C(242), UINT8_C( 83), UINT8_C( 82), UINT8_C(105),
        UINT8_C(236), UINT8_C(207), UINT8_C(247), UINT8_C(167), UINT8_C(  4), UINT8_C(215), UINT8_C(142), UINT8_C(124),
        UINT8_C( 71), UINT8_C(133), UINT8_C( 20), UINT8_C(159), UINT8_C( 40), UINT8_C(135), UINT8_C(210), UINT8_C( 39) },
      { UINT8_C( 70), UINT8_C(114), UINT8_C(154), UINT8_C(123), UINT8_C(182), UINT8_C(244), UINT8_C(220), UINT8_C(240),
        UINT8_C( 75), UINT8_C(161), UINT8_C( 20), UINT8_C( 61), UINT8_C(244), UINT8_C(102), UINT8_C(166), UINT8_C(224),
        UINT8_C( 53), UINT8_C(157), UINT8_C(135), UINT8_C( 57), UINT8_C(117), UINT8_C( 21), UINT8_C(181), UINT8_C(188),
        UINT8_C(155), UINT8_C(201), UINT8_C( 91), UINT8_C(195), UINT8_C( 81), UINT8_C( 45), UINT8_C(235), UINT8_C(151),
        UINT8_C(159), UINT8_C(133), UINT8_C( 18), UINT8_C( 85), UINT8_C(121), UINT8_C(239), UINT8_C( 69), UINT8_C(196),
        UINT8_C(144), UINT8_C( 89), UINT8_C(  1), UINT8_C(132), UINT8_C(191), UINT8_C(167), UINT8_C(100), UINT8_C(245),
        UINT8_C( 69), UINT8_C(236), UINT8_C( 46), UINT8_C(186), UINT8_C(  1), UINT8_C(228), UINT8_C(118), UINT8_C(156),
        UINT8_C(173), UINT8_C(209), UINT8_C( 96), UINT8_C(254), UINT8_C(254), UINT8_C( 75), UINT8_C(150), UINT8_C(158) },
      { UINT8_C( 92), UINT8_C(  3), UINT8_C(154), UINT8_C(123),    UINT8_MAX, UINT8_C(244), UINT8_C( 80), UINT8_C( 29),
        UINT8_C( 75), UINT8_C(246), UINT8_C(153), UINT8_C( 21), UINT8_C(180), UINT8_C(157), UINT8_C(166), UINT8_C(186),
        UINT8_C(119), UINT8_C(157), UINT8_C(135), UINT8_C(141), UINT8_C(161), UINT8_C(126), UINT8_C(162), UINT8_C(231),
        UINT8_C(245), UINT8_C( 80), UINT8_C( 62), UINT8_C(223), UINT8_C( 88), UINT8_C( 57), UINT8_C( 22), UINT8_C(103),
        UINT8_C( 61), UINT8_C( 11), UINT8_C(140), UINT8_C( 60), UINT8_C(228), UINT8_C(239), UINT8_C( 89), UINT8_C(155),
        UINT8_C(187), UINT8_C(243), UINT8_C(176), UINT8_C(132), UINT8_C(144), UINT8_C(167), UINT8_C(100), UINT8_C(245),
        UINT8_C(236), UINT8_C(236), UINT8_C( 81), UINT8_C(186), UINT8_C( 54), UINT8_C(228), UINT8_C(158), UINT8_C(156),
        UINT8_C(173), UINT8_C(209), UINT8_C( 11), UINT8_C(254), UINT8_C(254), UINT8_C( 33), UINT8_C(210), UINT8_C(158) } },
    { { -INT8_C(  48), -INT8_C(  88), -INT8_C(  13),  INT8_C(  73), -INT8_C( 105),  INT8_C(  57),  INT8_C(  13),  INT8_C(  39),
        -INT8_C( 110),  INT8_C(  14), -INT8_C(  85),  INT8_C(  82), -INT8_C(  75),  INT8_C(  16),  INT8_C(  71), -INT8_C(   6),
        -INT8_C(   4),  INT8_C( 117), -INT8_C(  76), -INT8_C(   3),  INT8_C(  89),  INT8_C(  42), -INT8_C( 102),  INT8_C(   7),
        -INT8_C(   5), -INT8_C(   6),  INT8_C(   5), -INT8_C(   6),  INT8_C(  69), -INT8_C( 101), -INT8_C( 104),  INT8_C(  21),
         INT8_C(  68), -INT8_C( 117),  INT8_C(  94), -INT8_C(  37), -INT8_C(  60),  INT8_C( 107),  INT8_C(   3),  INT8_C(  87),
         INT8_C( 121), -INT8_C(  82), -INT8_C(  87),  INT8_C(  46), -INT8_C(  66), -INT8_C(  16),  INT8_C(  41), -INT8_C(  70),
         INT8_C( 101), -INT8_C(  35), -INT8_C(  72), -INT8_C(  65),  INT8_C(   8),  INT8_C(  82), -INT8_C(  58),  INT8_C(   3),
         INT8_C(  76), -INT8_C(  53), -INT8_C(   3), -INT8_C( 111),  INT8_C( 103), -INT8_C( 107), -INT8_C(  90), -INT8_C(  85) },
      UINT64_C(16734401429087061025),
      { UINT8_C( 56), UINT8_C(229), UINT8_C( 22), UINT8_C(246), UINT8_C(213), UINT8_C( 63), UINT8_C(177), UINT8_C( 59),
        UINT8_C( 29), UINT8_C(105), UINT8_C(250), UINT8_C( 37), UINT8_C(187), UINT8_C(192), UINT8_C( 40), UINT8_C(  7),
        UINT8_C(139), UINT8_C( 38), UINT8_C(152), UINT8_C(242), UINT8_C(187), UINT8_C( 62), UINT8_C(157), UINT8_C(220),
        UINT8_C( 66), UINT8_C( 36), UINT8_C(194), UINT8_C(177), UINT8_C(173), UINT8_C(254), UINT8_C(153), UINT8_C(229),
        UINT8_C(228), UINT8_C(175), UINT8_C(220), UINT8_C(185), UINT8_C(239), UINT8_C(141), UINT8_C(244), UINT8_C( 12),
        UINT8_C(246), UINT8_C(238), UINT8_C( 49), UINT8_C(177), UINT8_C(174), UINT8_C( 89), UINT8_C(184), UINT8_C( 58),
        UINT8_C(127), UINT8_C( 80), UINT8_C( 44), UINT8_C( 59), UINT8_C(142), UINT8_C(202), UINT8_C( 23), UINT8_C(208),
        UINT8_C(238), UINT8_C(217), UINT8_C(129), UINT8_C(155), UINT8_C(216), UINT8_C( 26), UINT8_C(129), UINT8_C(188) },
      { UINT8_C(201), UINT8_C( 93), UINT8_C(117), UINT8_C(184), UINT8_C(234), UINT8_C(106), UINT8_C(196), UINT8_C(224),
        UINT8_C( 88), UINT8_C(245), UINT8_C(145), UINT8_C(  7), UINT8_C( 79), UINT8_C( 73), UINT8_C( 65), UINT8_C(206),
        UINT8_C(153), UINT8_C(109), UINT8_C(  9), UINT8_C( 39), UINT8_C( 55), UINT8_C( 33), UINT8_C(247), UINT8_C( 37),
        UINT8_C(250), UINT8_C(120), UINT8_C(193), UINT8_C(210), UINT8_C(146), UINT8_C( 66), UINT8_C(142), UINT8_C( 91),
        UINT8_C(159), UINT8_C(  4), UINT8_C( 20), UINT8_C(137), UINT8_C(110), UINT8_C(216), UINT8_C(105), UINT8_C(198),
        UINT8_C(206), UINT8_C(250), UINT8_C(205), UINT8_C( 29), UINT8_C( 67), UINT8_C( 14), UINT8_C(235), UINT8_C(220),
        UINT8_C(124), UINT8_C(245), UINT8_C(  3), UINT8_C(179), UINT8_C( 22), UINT8_C(250), UINT8_C(217), UINT8_C( 16),
        UINT8_C(114), UINT8_C(154), UINT8_C(227), UINT8_C(  4), UINT8_C(220), UINT8_C(113), UINT8_C( 95), UINT8_C(123) },
      { UINT8_C(201), UINT8_C(168), UINT8_C(243), UINT8_C( 73), UINT8_C(151), UINT8_C(106), UINT8_C( 13), UINT8_C( 39),
        UINT8_C(146), UINT8_C( 14), UINT8_C(250), UINT8_C( 82), UINT8_C(181), UINT8_C( 16), UINT8_C( 71), UINT8_C(250),
        UINT8_C(252), UINT8_C(109), UINT8_C(152), UINT8_C(253), UINT8_C( 89), UINT8_C( 42), UINT8_C(154), UINT8_C(220),
        UINT8_C(250), UINT8_C(250), UINT8_C(194), UINT8_C(250), UINT8_C( 69), UINT8_C(254), UINT8_C(153), UINT8_C(229),
        UINT8_C(228), UINT8_C(175), UINT8_C(220), UINT8_C(185), UINT8_C(196), UINT8_C(216), UINT8_C(244), UINT8_C( 87),
        UINT8_C(246), UINT8_C(174), UINT8_C(169), UINT8_C(177), UINT8_C(190), UINT8_C(240), UINT8_C( 41), UINT8_C(220),
        UINT8_C(101), UINT8_C(221), UINT8_C( 44), UINT8_C(179), UINT8_C(142), UINT8_C(250), UINT8_C(198), UINT8_C(  3),
        UINT8_C( 76), UINT8_C(203), UINT8_C(253), UINT8_C(155), UINT8_C(103), UINT8_C(113), UINT8_C(129), UINT8_C(188) } },
    { {  INT8_C( 117),  INT8_C( 115),  INT8_C(   4), -INT8_C(  29),  INT8_C(  76),  INT8_C( 109), -INT8_C(  86),  INT8_C(  26),
         INT8_C( 103),  INT8_C( 119),  INT8_C(  55), -INT8_C(  86), -INT8_C( 122),  INT8_C(  34), -INT8_C( 122),  INT8_C(   2),
         INT8_C(  23), -INT8_C( 119), -INT8_C(  75),  INT8_C(  45), -INT8_C( 125), -INT8_C( 114),  INT8_C(  62), -INT8_C(  11),
         INT8_C(  40),  INT8_C(  33), -INT8_C(   7),  INT8_C(   4), -INT8_C( 110),  INT8_C(  88),      INT8_MAX,  INT8_C(   8),
        -INT8_C(  52), -INT8_C( 125), -INT8_C(  21),  INT8_C(  24), -INT8_C(  16), -INT8_C( 107),  INT8_C(  50),  INT8_C(  87),
         INT8_C(  13),  INT8_C( 105),  INT8_C(   1), -INT8_C( 109), -INT8_C( 117), -INT8_C( 121), -INT8_C( 107), -INT8_C(  93),
         INT8_C(  16),  INT8_C(  74), -INT8_C(  48), -INT8_C( 109), -INT8_C(  39),  INT8_C(  14), -INT8_C( 120),  INT8_C(   1),
         INT8_C(  47), -INT8_C( 127),  INT8_C(   6), -INT8_C(  62), -INT8_C(  38), -INT8_C( 123), -INT8_C(  54), -INT8_C(  90) },
      UINT64_C( 6364131957554459913),
      { UINT8_C( 89), UINT8_C( 82), UINT8_C(235), UINT8_C(228), UINT8_C(218), UINT8_C(128), UINT8_C(135), UINT8_C(234),
        UINT8_C(202), UINT8_C( 88), UINT8_C(126), UINT8_C(163), UINT8_C(102), UINT8_C(  6), UINT8_C(165), UINT8_C(150),
        UINT8_C(136), UINT8_C(171), UINT8_C( 88), UINT8_C( 98), UINT8_C( 48), UINT8_C( 34), UINT8_C(  8), UINT8_C( 57),
        UINT8_C(215), UINT8_C(198), UINT8_C( 51), UINT8_C( 34), UINT8_C(182), UINT8_C(132), UINT8_C(122), UINT8_C( 15),
        UINT8_C(214), UINT8_C(101), UINT8_C(243), UINT8_C(176), UINT8_C(229), UINT8_C(123), UINT8_C(155), UINT8_C(176),
        UINT8_C(211), UINT8_C( 25), UINT8_C( 83), UINT8_C( 57), UINT8_C( 31), UINT8_C(248), UINT8_C(207), UINT8_C(167),
        UINT8_C(163), UINT8_C( 39), UINT8_C(  9), UINT8_C(212), UINT8_C( 73), UINT8_C( 17), UINT8_C( 13), UINT8_C( 33),
        UINT8_C(215), UINT8_C( 64), UINT8_C( 67), UINT8_C(141), UINT8_C(196), UINT8_C(190), UINT8_C(156), UINT8_C(155) },
      { UINT8_C( 35), UINT8_C(144), UINT8_C( 75), UINT8_C(  9), UINT8_C( 11), UINT8_C(230), UINT8_C(185), UINT8_C(222),
           UINT8_MAX, UINT8_C( 12), UINT8_C( 23), UINT8_C( 31), UINT8_C(  5), UINT8_C(231), UINT8_C(198), UINT8_C(168),
        UINT8_C( 14), UINT8_C(208), UINT8_C(124), UINT8_C( 88), UINT8_C(225), UINT8_C(138), UINT8_C(121), UINT8_C(185),
        UINT8_C(202), UINT8_C(188), UINT8_C( 70), UINT8_C(143), UINT8_C(122), UINT8_C(227), UINT8_C( 42), UINT8_C(158),
        UINT8_C(115), UINT8_C(117), UINT8_C(167), UINT8_C(126), UINT8_C( 92), UINT8_C( 96), UINT8_C( 92), UINT8_C( 91),
        UINT8_C(108), UINT8_C(115), UINT8_C(122), UINT8_C(113), UINT8_C( 90), UINT8_C( 65), UINT8_C( 26), UINT8_C(105),
        UINT8_C( 17), UINT8_C(150), UINT8_C(193), UINT8_C(242), UINT8_C( 32), UINT8_C( 58), UINT8_C(171), UINT8_C(235),
        UINT8_C(246), UINT8_C(242), UINT8_C(122), UINT8_C(113), UINT8_C(213), UINT8_C(164), UINT8_C( 15), UINT8_C( 72) },
      { UINT8_C( 89), UINT8_C(115), UINT8_C(  4), UINT8_C(228), UINT8_C( 76), UINT8_C(109), UINT8_C(170), UINT8_C( 26),
           UINT8_MAX, UINT8_C(119), UINT8_C(126), UINT8_C(170), UINT8_C(102), UINT8_C(231), UINT8_C(134), UINT8_C(168),
        UINT8_C( 23), UINT8_C(208), UINT8_C(124), UINT8_C( 98), UINT8_C(225), UINT8_C(138), UINT8_C( 62), UINT8_C(185),
        UINT8_C(215), UINT8_C( 33), UINT8_C(249), UINT8_C(143), UINT8_C(182), UINT8_C(227), UINT8_C(122), UINT8_C(158),
        UINT8_C(214), UINT8_C(117), UINT8_C(235), UINT8_C(176), UINT8_C(240), UINT8_C(149), UINT8_C(155), UINT8_C( 87),
        UINT8_C( 13), UINT8_C(105), UINT8_C(  1), UINT8_C(147), UINT8_C( 90), UINT8_C(248), UINT8_C(207), UINT8_C(167),
        UINT8_C(163), UINT8_C( 74), UINT8_C(208), UINT8_C(147), UINT8_C( 73), UINT8_C( 14), UINT8_C(171), UINT8_C(  1),
        UINT8_C( 47), UINT8_C(129), UINT8_C(  6), UINT8_C(141), UINT8_C(213), UINT8_C(133), UINT8_C(156), UINT8_C(166) } },
    { {  INT8_C(  25), -INT8_C(  74), -INT8_C(  58),  INT8_C( 117),  INT8_C(  22),  INT8_C(  34), -INT8_C(  47), -INT8_C( 126),
        -INT8_C( 107),  INT8_C(  75), -INT8_C(  12), -INT8_C(  16), -INT8_C( 116),  INT8_C(  14),  INT8_C(  89), -INT8_C(  99),
        -INT8_C(  92),  INT8_C(  26), -INT8_C( 112), -INT8_C(  59),  INT8_C(  84),  INT8_C(  59), -INT8_C(  80),  INT8_C(  74),
         INT8_C(  45),  INT8_C(  42), -INT8_C(  69),  INT8_C(   2), -INT8_C(  50), -INT8_C(  54),  INT8_C(  74), -INT8_C(  25),
             INT8_MIN,  INT8_C(  16),  INT8_C(  93), -INT8_C( 106),  INT8_C(  50),  INT8_C(  46),  INT8_C(  25), -INT8_C(  56),
         INT8_C( 121),  INT8_C(  13), -INT8_C(  72),  INT8_C(   6),  INT8_C(  27),  INT8_C(  17), -INT8_C(  93), -INT8_C(  65),
         INT8_C(  43),  INT8_C(  51), -INT8_C( 124),      INT8_MAX,  INT8_C( 111),  INT8_C(  52), -INT8_C(  55), -INT8_C( 100),
         INT8_C(  94), -INT8_C( 123), -INT8_C(  97),  INT8_C(  44),  INT8_C(  79), -INT8_C(  23),  INT8_C(  20), -INT8_C(  48) },
      UINT64_C( 1798202472849109498),
      { UINT8_C(140), UINT8_C(172), UINT8_C( 30), UINT8_C(167), UINT8_C(189), UINT8_C(194), UINT8_C(103), UINT8_C(232),
        UINT8_C(245), UINT8_C(235), UINT8_C(103), UINT8_C(100), UINT8_C( 32), UINT8_C( 49), UINT8_C(  1), UINT8_C(126),
        UINT8_C(182), UINT8_C(160), UINT8_C(171), UINT8_C(  5), UINT8_C(137), UINT8_C(191), UINT8_C(213), UINT8_C(131),
        UINT8_C( 48), UINT8_C( 60), UINT8_C(176), UINT8_C(207), UINT8_C(187), UINT8_C(164), UINT8_C(231), UINT8_C( 72),
        UINT8_C( 81), UINT8_C(  6), UINT8_C(239), UINT8_C( 14), UINT8_C(200), UINT8_C( 86), UINT8_C(247), UINT8_C(189),
        UINT8_C( 66), UINT8_C( 94), UINT8_C( 34), UINT8_C( 98), UINT8_C(143), UINT8_C( 35), UINT8_C(224), UINT8_C( 69),
        UINT8_C(195), UINT8_C(139), UINT8_C( 75), UINT8_C( 76), UINT8_C( 74), UINT8_C( 32), UINT8_C(208), UINT8_C(122),
        UINT8_C( 92), UINT8_C(128), UINT8_C( 73), UINT8_C( 24), UINT8_C( 36), UINT8_C( 49), UINT8_C( 96), UINT8_C(117) },
      { UINT8_C( 55), UINT8_C( 79), UINT8_C(132),    UINT8_MAX, UINT8_C(166), UINT8_C(123), UINT8_C(188), UINT8_C(232),
        UINT8_C(217), UINT8_C(222), UINT8_C( 74), UINT8_C(105), UINT8_C(  1), UINT8_C( 42), UINT8_C(174), UINT8_C(196),
        UINT8_C(182), UINT8_C(249), UINT8_C( 17), UINT8_C(  0), UINT8_C( 26), UINT8_C(225), UINT8_C(123), UINT8_C(118),
        UINT8_C( 97), UINT8_C(196), UINT8_C(142), UINT8_C(133), UINT8_C(245), UINT8_C(238), UINT8_C(251), UINT8_C( 44),
        UINT8_C( 62), UINT8_C(127), UINT8_C( 43), UINT8_C(228), UINT8_C(250), UINT8_C(232), UINT8_C(204), UINT8_C(211),
        UINT8_C(198), UINT8_C( 22), UINT8_C( 60), UINT8_C(200), UINT8_C( 64), UINT8_C(235), UINT8_C(140), UINT8_C(246),
        UINT8_C(228), UINT8_C(157), UINT8_C(247), UINT8_C(254), UINT8_C(126), UINT8_C(114), UINT8_C(117), UINT8_C(223),
        UINT8_C( 54), UINT8_C(  3), UINT8_C(101), UINT8_C( 44), UINT8_C(242), UINT8_C( 96), UINT8_C( 88), UINT8_C( 48) },
      { UINT8_C( 25), UINT8_C(172), UINT8_C(198),    UINT8_MAX, UINT8_C(189), UINT8_C(194), UINT8_C(188), UINT8_C(232),
        UINT8_C(245), UINT8_C( 75), UINT8_C(244), UINT8_C(240), UINT8_C( 32), UINT8_C( 49), UINT8_C(174), UINT8_C(157),
        UINT8_C(164), UINT8_C(249), UINT8_C(171), UINT8_C(197), UINT8_C( 84), UINT8_C(225), UINT8_C(213), UINT8_C( 74),
        UINT8_C( 45), UINT8_C( 42), UINT8_C(176), UINT8_C(207), UINT8_C(206), UINT8_C(238), UINT8_C( 74), UINT8_C(231),
        UINT8_C( 81), UINT8_C(127), UINT8_C(239), UINT8_C(228), UINT8_C(250), UINT8_C( 46), UINT8_C( 25), UINT8_C(211),
        UINT8_C(198), UINT8_C( 94), UINT8_C( 60), UINT8_C(200), UINT8_C(143), UINT8_C(235), UINT8_C(224), UINT8_C(191),
        UINT8_C( 43), UINT8_C( 51), UINT8_C(247), UINT8_C(127), UINT8_C(126), UINT8_C(114), UINT8_C(208), UINT8_C(223),
        UINT8_C( 94), UINT8_C(133), UINT8_C(159), UINT8_C( 44), UINT8_C(242), UINT8_C(233), UINT8_C( 20), UINT8_C(208) } },
    { { -INT8_C(  33), -INT8_C( 124),  INT8_C(  20), -INT8_C(  39),  INT8_C( 108), -INT8_C(  32), -INT8_C(  84),  INT8_C(  50),
        -INT8_C(  10), -INT8_C(  23), -INT8_C(   6),  INT8_C(  54), -INT8_C(  44), -INT8_C( 121),  INT8_C(  45), -INT8_C(  72),
         INT8_C(  36),  INT8_C(  36), -INT8_C(  73), -INT8_C(  93), -INT8_C( 106),  INT8_C(  44), -INT8_C( 126), -INT8_C(  52),
         INT8_C(  47), -INT8_C(  25), -INT8_C(   8),  INT8_C(  33),  INT8_C(  71),  INT8_C(  81),  INT8_C(  81),  INT8_C(  38),
        -INT8_C(  43),  INT8_C( 101), -INT8_C(   1),  INT8_C(  65),  INT8_C(  69), -INT8_C(  84),  INT8_C( 115),  INT8_C(  59),
        -INT8_C( 107),  INT8_C( 110),  INT8_C( 114),  INT8_C( 105), -INT8_C(  11), -INT8_C(  97),  INT8_C(  33),  INT8_C(  25),
        -INT8_C(  61), -INT8_C(  40), -INT8_C(  68),  INT8_C(  89),  INT8_C(   4),  INT8_C(  63),  INT8_C(  37),  INT8_C(  52),
         INT8_C(  38),  INT8_C(  30),  INT8_C(  85),  INT8_C( 110),  INT8_C( 111), -INT8_C(  89), -INT8_C( 108),  INT8_C(  68) },
      UINT64_C(15388228456940934156),
      { UINT8_C(102),    UINT8_MAX, UINT8_C( 62), UINT8_C( 91), UINT8_C(158), UINT8_C( 95), UINT8_C(117), UINT8_C( 97),
        UINT8_C( 56), UINT8_C( 49), UINT8_C(186), UINT8_C( 60), UINT8_C(112), UINT8_C(224), UINT8_C(112), UINT8_C(151),
        UINT8_C(254), UINT8_C(198), UINT8_C(  5), UINT8_C(109), UINT8_C(109), UINT8_C(153), UINT8_C(177), UINT8_C(121),
        UINT8_C( 45), UINT8_C( 54), UINT8_C(203), UINT8_C(109), UINT8_C( 46), UINT8_C( 89), UINT8_C( 66), UINT8_C(149),
        UINT8_C( 88), UINT8_C(128), UINT8_C(240), UINT8_C(247), UINT8_C(224), UINT8_C(101), UINT8_C( 88), UINT8_C( 24),
        UINT8_C(151), UINT8_C( 19), UINT8_C( 84), UINT8_C(  7), UINT8_C(243), UINT8_C(197), UINT8_C(158), UINT8_C(241),
        UINT8_C(139), UINT8_C(163), UINT8_C( 94), UINT8_C(248), UINT8_C( 61), UINT8_C( 15), UINT8_C(113), UINT8_C(106),
        UINT8_C( 69), UINT8_C( 61), UINT8_C(216), UINT8_C(115), UINT8_C(150), UINT8_C( 26), UINT8_C(  8), UINT8_C(238) },
      { UINT8_C(155), UINT8_C(249), UINT8_C(229), UINT8_C(123), UINT8_C( 94), UINT8_C( 62), UINT8_C(147), UINT8_C(245),
        UINT8_C( 81), UINT8_C(231), UINT8_C(253), UINT8_C( 68), UINT8_C(172), UINT8_C(155), UINT8_C( 53), UINT8_C( 55),
        UINT8_C( 63), UINT8_C(147), UINT8_C( 47), UINT8_C(124), UINT8_C(162), UINT8_C(161), UINT8_C(230), UINT8_C(231),
        UINT8_C(222), UINT8_C(190), UINT8_C( 90), UINT8_C(116), UINT8_C(217), UINT8_C( 99), UINT8_C( 98), UINT8_C(116),
        UINT8_C( 92), UINT8_C( 72), UINT8_C(239), UINT8_C(186), UINT8_C(134), UINT8_C(130), UINT8_C(176), UINT8_C(215),
        UINT8_C(105), UINT8_C(173), UINT8_C( 27), UINT8_C( 22), UINT8_C( 72), UINT8_C( 80), UINT8_C( 77), UINT8_C(135),
        UINT8_C(227), UINT8_C(125), UINT8_C(  3), UINT8_C(133), UINT8_C( 30), UINT8_C(234), UINT8_C(108), UINT8_C(252),
        UINT8_C(168), UINT8_C(198), UINT8_C(112), UINT8_C(129), UINT8_C( 41), UINT8_C(210), UINT8_C(245), UINT8_C(133) },
      { UINT8_C(223), UINT8_C(132), UINT8_C(229), UINT8_C(123), UINT8_C(108), UINT8_C(224), UINT8_C(172), UINT8_C( 50),
        UINT8_C(246), UINT8_C(233), UINT8_C(253), UINT8_C( 54), UINT8_C(172), UINT8_C(135), UINT8_C( 45), UINT8_C(151),
        UINT8_C(254), UINT8_C( 36), UINT8_C( 47), UINT8_C(163), UINT8_C(150), UINT8_C( 44), UINT8_C(130), UINT8_C(231),
        UINT8_C( 47), UINT8_C(190), UINT8_C(248), UINT8_C( 33), UINT8_C(217), UINT8_C( 81), UINT8_C( 98), UINT8_C( 38),
        UINT8_C(213), UINT8_C(101),    UINT8_MAX, UINT8_C( 65), UINT8_C( 69), UINT8_C(172), UINT8_C(176), UINT8_C( 59),
        UINT8_C(149), UINT8_C(110), UINT8_C(114), UINT8_C( 22), UINT8_C(243), UINT8_C(197), UINT8_C(158), UINT8_C(241),
        UINT8_C(227), UINT8_C(216), UINT8_C( 94), UINT8_C(248), UINT8_C(  4), UINT8_C( 63), UINT8_C( 37), UINT8_C(252),
        UINT8_C(168), UINT8_C( 30), UINT8_C(216), UINT8_C(110), UINT8_C(150), UINT8_C(167), UINT8_C(245), UINT8_C(238) } },
    { {  INT8_C(  26), -INT8_C(  28),  INT8_C(  64), -INT8_C(  96),  INT8_C( 102), -INT8_C(  16),  INT8_C( 119), -INT8_C(  48),
        -INT8_C(  99), -INT8_C( 110), -INT8_C(  26), -INT8_C(  27), -INT8_C(  30),  INT8_C(  51),  INT8_C( 109), -INT8_C(  59),
        -INT8_C(  80),  INT8_C( 112),  INT8_C(  74), -INT8_C(  50),  INT8_C(  90), -INT8_C(  74), -INT8_C(  54),  INT8_C(   3),
         INT8_C( 125),  INT8_C(  58), -INT8_C( 124), -INT8_C(  90),  INT8_C(  13),  INT8_C( 122),  INT8_C(  44),  INT8_C(  39),
         INT8_C(  94),  INT8_C( 108), -INT8_C(  56), -INT8_C(  59),  INT8_C(  92),  INT8_C(  63), -INT8_C( 107), -INT8_C(   7),
        -INT8_C(  46),  INT8_C( 123), -INT8_C(  34), -INT8_C(  76), -INT8_C(  82),  INT8_C(  75),  INT8_C( 122),  INT8_C(  95),
        -INT8_C(  68), -INT8_C(  60),  INT8_C(  45),  INT8_C(  22),  INT8_C( 123), -INT8_C(   8),  INT8_C(  25), -INT8_C(   8),
         INT8_C(  50), -INT8_C(  98), -INT8_C(  98),  INT8_C(  63),  INT8_C(  24), -INT8_C(  54),  INT8_C( 103),  INT8_C( 118) },
      UINT64_C( 4651040213508501302),
      { UINT8_C( 75), UINT8_C(106), UINT8_C(245), UINT8_C(250), UINT8_C(181), UINT8_C(111), UINT8_C( 89), UINT8_C(113),
        UINT8_C( 51), UINT8_C(134), UINT8_C(136), UINT8_C(174), UINT8_C(126), UINT8_C(161), UINT8_C(166), UINT8_C(177),
        UINT8_C( 63), UINT8_C( 69), UINT8_C(240), UINT8_C( 87), UINT8_C( 15), UINT8_C( 87), UINT8_C(206), UINT8_C( 70),
        UINT8_C(134), UINT8_C(  9), UINT8_C(216), UINT8_C(245), UINT8_C(218), UINT8_C(100), UINT8_C( 53), UINT8_C( 37),
        UINT8_C(206), UINT8_C( 42), UINT8_C( 31), UINT8_C(131), UINT8_C(153), UINT8_C(120), UINT8_C(245), UINT8_C(205),
           UINT8_MAX, UINT8_C(125), UINT8_C(123), UINT8_C(125), UINT8_C( 30), UINT8_C( 34), UINT8_C( 46), UINT8_C( 94),
        UINT8_C(103), UINT8_C( 31), UINT8_C(181), UINT8_C(118), UINT8_C(118), UINT8_C(131), UINT8_C(188), UINT8_C(253),
        UINT8_C(141), UINT8_C(149), UINT8_C(242), UINT8_C(103), UINT8_C(249), UINT8_C( 39), UINT8_C(140), UINT8_C(199) },
      { UINT8_C( 82), UINT8_C(172), UINT8_C( 74), UINT8_C(235), UINT8_C( 36), UINT8_C( 63), UINT8_C(184), UINT8_C( 35),
        UINT8_C(188), UINT8_C( 52), UINT8_C(161), UINT8_C(219), UINT8_C( 86), UINT8_C(207), UINT8_C( 57), UINT8_C(189),
        UINT8_C(238), UINT8_C(238), UINT8_C( 51), UINT8_C(101), UINT8_C(114), UINT8_C(240), UINT8_C( 98),    UINT8_MAX,
        UINT8_C(133), UINT8_C( 84), UINT8_C(102), UINT8_C(126), UINT8_C(123), UINT8_C(242), UINT8_C( 69), UINT8_C(205),
        UINT8_C(158), UINT8_C(143), UINT8_C(185), UINT8_C(195), UINT8_C(207), UINT8_C(113), UINT8_C(230), UINT8_C(139),
        UINT8_C(165), UINT8_C(135), UINT8_C(102), UINT8_C(251), UINT8_C( 87), UINT8_C(159), UINT8_C(184), UINT8_C( 69),
        UINT8_C(142), UINT8_C(236), UINT8_C(170), UINT8_C(  0), UINT8_C(220), UINT8_C( 12),    UINT8_MAX, UINT8_C( 97),
        UINT8_C( 96), UINT8_C(101), UINT8_C(223), UINT8_C(220), UINT8_C( 87), UINT8_C( 36), UINT8_C(169), UINT8_C(246) },
      { UINT8_C( 26), UINT8_C(172), UINT8_C(245), UINT8_C(160), UINT8_C(181), UINT8_C(111), UINT8_C(119), UINT8_C(208),
        UINT8_C(188), UINT8_C(134), UINT8_C(161), UINT8_C(219), UINT8_C(226), UINT8_C(207), UINT8_C(109), UINT8_C(197),
        UINT8_C(238), UINT8_C(238), UINT8_C( 74), UINT8_C(101), UINT8_C(114), UINT8_C(240), UINT8_C(202), UINT8_C(  3),
        UINT8_C(125), UINT8_C( 84), UINT8_C(132), UINT8_C(166), UINT8_C(218), UINT8_C(122), UINT8_C( 44), UINT8_C(205),
        UINT8_C( 94), UINT8_C(143), UINT8_C(185), UINT8_C(195), UINT8_C( 92), UINT8_C(120), UINT8_C(245), UINT8_C(249),
        UINT8_C(210), UINT8_C(123), UINT8_C(222), UINT8_C(180), UINT8_C( 87), UINT8_C( 75), UINT8_C(184), UINT8_C( 94),
        UINT8_C(142), UINT8_C(236), UINT8_C( 45), UINT8_C(118), UINT8_C(123), UINT8_C(248), UINT8_C( 25), UINT8_C(253),
        UINT8_C( 50), UINT8_C(158), UINT8_C(158), UINT8_C( 63), UINT8_C( 24), UINT8_C(202), UINT8_C(169), UINT8_C(118) } }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
    simde__m512i src = simde_mm512_loadu_epi8(test_vec[i].src);
    simde__m512i a = simde_mm512_loadu_epi8(test_vec[i].a);
    simde__m512i b = simde_mm512_loadu_epi8(test_vec[i].b);
    simde__m512i r = simde_mm512_mask_max_epu8(src, test_vec[i].k, a, b);
    simde_test_x86_assert_equal_u8x64(r, simde_mm512_loadu_epi8(test_vec[i].r));
  }

  return 0;
}

static int
test_simde_mm512_maskz_max_epu8 (SIMDE_MUNIT_TEST_ARGS) {
  static const struct {
    const simde__mmask64 k;
    const uint8_t a[64];
    const uint8_t b[64];
    const uint8_t r[64];
  } test_vec[] = {
    { UINT64_C(  768989401926260750),
      { UINT8_C(200), UINT8_C(153), UINT8_C(184), UINT8_C(140), UINT8_C(198), UINT8_C(202), UINT8_C(130), UINT8_C(163),
        UINT8_C( 22), UINT8_C(136), UINT8_C(176), UINT8_C(145), UINT8_C( 38), UINT8_C( 80), UINT8_C(249), UINT8_C( 26),
        UINT8_C(160), UINT8_C( 32), UINT8_C(211), UINT8_C( 88), UINT8_C(134), UINT8_C(202), UINT8_C(182), UINT8_C(148),
        UINT8_C(163), UINT8_C(144), UINT8_C(253), UINT8_C(108), UINT8_C(143), UINT8_C(168), UINT8_C(118), UINT8_C( 87),
        UINT8_C( 65), UINT8_C( 47), UINT8_C(228), UINT8_C(  8), UINT8_C(249), UINT8_C(102), UINT8_C(171), UINT8_C( 15),
        UINT8_C(238), UINT8_C( 91), UINT8_C(160), UINT8_C( 21), UINT8_C(171), UINT8_C(153), UINT8_C( 47), UINT8_C( 75),
        UINT8_C(185), UINT8_C(  2), UINT8_C(163), UINT8_C( 64), UINT8_C(205), UINT8_C( 89), UINT8_C(212), UINT8_C(112),
        UINT8_C(233), UINT8_C(210), UINT8_C(220), UINT8_C(121), UINT8_C(122), UINT8_C( 83), UINT8_C(208), UINT8_C(188) },
      { UINT8_C(130), UINT8_C(180), UINT8_C(196), UINT8_C(123), UINT8_C( 26), UINT8_C(111), UINT8_C(138), UINT8_C(  9),
        UINT8_C(202), UINT8_C( 43), UINT8_C( 30), UINT8_C(117), UINT8_C(196), UINT8_C( 77), UINT8_C(192), UINT8_C(126),
        UINT8_C( 80), UINT8_C( 99), UINT8_C(190), UINT8_C( 29), UINT8_C(188), UINT8_C(146), UINT8_C(141), UINT8_C(165),
        UINT8_C(100), UINT8_C(105), UINT8_C( 30), UINT8_C(223), UINT8_C(188), UINT8_C(239), UINT8_C(155), UINT8_C( 62),
        UINT8_C(163), UINT8_C( 95), UINT8_C(185), UINT8_C(190), UINT8_C(206), UINT8_C( 68), UINT8_C(199), UINT8_C(152),
        UINT8_C(111), UINT8_C(229), UINT8_C( 13), UINT8_C( 51), UINT8_C( 50), UINT8_C(205), UINT8_C(177), UINT8_C(130),
        UINT8_C( 48), UINT8_C(111), UINT8_C(159), UINT8_C(236), UINT8_C(  2), UINT8_C( 44), UINT8_C(145), UINT8_C(102),
        UINT8_C(150), UINT8_C(176), UINT8_C( 69), UINT8_C( 82), UINT8_C(159), UINT8_C(224), UINT8_C(145), UINT8_C( 66) },
      { UINT8_C(  0), UINT8_C(180), UINT8_C(196), UINT8_C(140), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
        UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(145), UINT8_C(196), UINT8_C(  0), UINT8_C(249), UINT8_C(126),
        UINT8_C(  0), UINT8_C( 99), UINT8_C(  0), UINT8_C( 88), UINT8_C(188), UINT8_C(  0), UINT8_C(182), UINT8_C(165),
        UINT8_C(163), UINT8_C(  0), UINT8_C(  0), UINT8_C(223), UINT8_C(  0), UINT8_C(239), UINT8_C(155), UINT8_C(  0),
        UINT8_C(163), UINT8_C(  0), UINT8_C(  0), UINT8_C(190), UINT8_C(  0), UINT8_C(  0), UINT8_C(199), UINT8_C(152),
        UINT8_C(238), UINT8_C(229), UINT8_C(160), UINT8_C( 51), UINT8_C(171), UINT8_C(205), UINT8_C(177), UINT8_C(130),
        UINT8_C(185), UINT8_C(111), UINT8_C(  0), UINT8_C(236), UINT8_C(  0), UINT8_C( 89), UINT8_C(  0), UINT8_C(112),
        UINT8_C(  0), UINT8_C(210), UINT8_C(  0), UINT8_C(121), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0) } },
    { UINT64_C(18277234075670432319),
      { UINT8_C(172), UINT8_C(178), UINT8_C( 49), UINT8_C(223), UINT8_C(127), UINT8_C(226), UINT8_C( 97), UINT8_C(175),
        UINT8_C( 82), UINT8_C(  1), UINT8_C(155), UINT8_C( 84), UINT8_C( 45), UINT8_C( 45), UINT8_C(186), UINT8_C(195),
        UINT8_C(221), UINT8_C(  0), UINT8_C( 22), UINT8_C(124), UINT8_C(224), UINT8_C(167), UINT8_C(190), UINT8_C( 32),
        UINT8_C(241), UINT8_C(191), UINT8_C( 45), UINT8_C(128), UINT8_C(134), UINT8_C(211), UINT8_C(125), UINT8_C( 51),
        UINT8_C(133), UINT8_C(174), UINT8_C( 18), UINT8_C(  5), UINT8_C(145), UINT8_C(115), UINT8_C(180), UINT8_C(227),
        UINT8_C(116), UINT8_C( 80), UINT8_C( 55), UINT8_C(162), UINT8_C(125), UINT8_C(241), UINT8_C(101), UINT8_C( 90),
        UINT8_C(241), UINT8_C(123), UINT8_C(214), UINT8_C(210), UINT8_C( 34), UINT8_C(148), UINT8_C(242), UINT8_C( 20),
        UINT8_C( 83), UINT8_C( 31), UINT8_C(148), UINT8_C(218), UINT8_C(242), UINT8_C( 17), UINT8_C( 13), UINT8_C(120) },
      { UINT8_C(192), UINT8_C( 31), UINT8_C(125), UINT8_C( 81), UINT8_C(146), UINT8_C( 49), UINT8_C( 52), UINT8_C(  7),
        UINT8_C(129), UINT8_C(107), UINT8_C(169), UINT8_C(254), UINT8_C( 92), UINT8_C( 14), UINT8_C( 88), UINT8_C( 78),
        UINT8_C(138), UINT8_C( 46), UINT8_C( 32), UINT8_C(172), UINT8_C(195), UINT8_C( 18), UINT8_C(192), UINT8_C( 22),
        UINT8_C( 49), UINT8_C( 84), UINT8_C(240), UINT8_C( 36), UINT8_C(102), UINT8_C(253), UINT8_C(156), UINT8_C( 38),
        UINT8_C( 28), UINT8_C( 25), UINT8_C(119), UINT8_C(175), UINT8_C( 74), UINT8_C(171), UINT8_C(182), UINT8_C(204),
        UINT8_C( 22), UINT8_C( 95), UINT8_C(202), UINT8_C(114), UINT8_C(109), UINT8_C( 35), UINT8_C(192), UINT8_C(247),
        UINT8_C( 81), UINT8_C(224), UINT8_C(164), UINT8_C( 20), UINT8_C(242), UINT8_C(100), UINT8_C( 43), UINT8_C( 36),
        UINT8_C(185), UINT8_C( 27), UINT8_C( 72), UINT8_C( 31), UINT8_C( 25), UINT8_C(228), UINT8_C( 69), UINT8_C( 53) },
      { UINT8_C(192), UINT8_C(178), UINT8_C(125), UINT8_C(223), UINT8_C(146), UINT8_C(226), UINT8_C(  0), UINT8_C(  0),
        UINT8_C(  0), UINT8_C(107), UINT8_C(  0), UINT8_C(254), UINT8_C(  0), UINT8_C(  0), UINT8_C(186), UINT8_C(  0),
        UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
        UINT8_C(241), UINT8_C(  0), UINT8_C(240), UINT8_C(128), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
        UINT8_C(  0), UINT8_C(174), UINT8_C(119), UINT8_C(175), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(227),
        UINT8_C(116), UINT8_C( 95), UINT8_C(202), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(192), UINT8_C(247),
        UINT8_C(241), UINT8_C(  0), UINT8_C(214), UINT8_C(  0), UINT8_C(  0), UINT8_C(148), UINT8_C(  0), UINT8_C( 36),
        UINT8_C(185), UINT8_C(  0), UINT8_C(148), UINT8_C(218), UINT8_C(242), UINT8_C(228), UINT8_C( 69), UINT8_C(120) } },
    { UINT64_C( 9012717047676976381),
      { UINT8_C(249), UINT8_C(222), UINT8_C(239), UINT8_C(103), UINT8_C(  1), UINT8_C(176), UINT8_C( 94), UINT8_C( 82),
        UINT8_C(144), UINT8_C(  2), UINT8_C(103), UINT8_C(131), UINT8_C(103), UINT8_C(146), UINT8_C(167), UINT8_C( 32),
        UINT8_C(173), UINT8_C(239), UINT8_C( 63), UINT8_C(198), UINT8_C(211), UINT8_C(132), UINT8_C(252), UINT8_C(208),
        UINT8_C( 64), UINT8_C(224), UINT8_C( 23), UINT8_C(167), UINT8_C(123), UINT8_C( 43), UINT8_C( 36), UINT8_C(116),
        UINT8_C(  9), UINT8_C( 19), UINT8_C(219), UINT8_C( 10), UINT8_C(195), UINT8_C( 58), UINT8_C( 92), UINT8_C( 84),
        UINT8_C( 60), UINT8_C(195), UINT8_C(215), UINT8_C(163), UINT8_C( 85), UINT8_C(126), UINT8_C(195), UINT8_C(  3),
        UINT8_C(109), UINT8_C(  2), UINT8_C(201), UINT8_C( 64), UINT8_C(134), UINT8_C(197), UINT8_C( 16), UINT8_C(198),
        UINT8_C(166), UINT8_C( 39), UINT8_C(109), UINT8_C( 33), UINT8_C( 82), UINT8_C(145), UINT8_C(149), UINT8_C( 91) },
      { UINT8_C(165), UINT8_C(113), UINT8_C(101), UINT8_C(104), UINT8_C(171), UINT8_C(194), UINT8_C(188), UINT8_C(231),
        UINT8_C(133), UINT8_C(147), UINT8_C(139), UINT8_C(219), UINT8_C( 17), UINT8_C( 78), UINT8_C(222), UINT8_C(126),
        UINT8_C( 81), UINT8_C(167), UINT8_C(190), UINT8_C(215), UINT8_C(109), UINT8_C(206), UINT8_C(158), UINT8_C( 19),
        UINT8_C(246), UINT8_C( 11), UINT8_C( 52), UINT8_C( 72), UINT8_C(157), UINT8_C(201), UINT8_C(164), UINT8_C( 66),
        UINT8_C( 58), UINT8_C(  9), UINT8_C(170), UINT8_C(229), UINT8_C(203), UINT8_C(103), UINT8_C(205), UINT8_C( 81),
        UINT8_C(250), UINT8_C( 88), UINT8_C( 44), UINT8_C( 12), UINT8_C(166), UINT8_C( 10), UINT8_C(138), UINT8_C(247),
        UINT8_C(177), UINT8_C( 73), UINT8_C(207), UINT8_C( 30), UINT8_C( 23), UINT8_C(109), UINT8_C( 49), UINT8_C( 13),
        UINT8_C(120), UINT8_C(101), UINT8_C( 86), UINT8_C( 21), UINT8_C( 47), UINT8_C(250), UINT8_C( 87), UINT8_C(105) },
      { UINT8_C(249), UINT8_C(  0), UINT8_C(239), UINT8_C(104), UINT8_C(171), UINT8_C(194), UINT8_C(188), UINT8_C(231),
        UINT8_C(  0), UINT8_C(  0), UINT8_C(139), UINT8_C(219), UINT8_C(103), UINT8_C(146), UINT8_C(  0), UINT8_C(126),
        UINT8_C(  0), UINT8_C(  0), UINT8_C(190), UINT8_C(  0), UINT8_C(  0), UINT8_C(206), UINT8_C(252), UINT8_C(208),
        UINT8_C(246), UINT8_C(224), UINT8_C( 52), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(164), UINT8_C(  0),
        UINT8_C( 58), UINT8_C( 19), UINT8_C(219), UINT8_C(  0), UINT8_C(  0), UINT8_C(103), UINT8_C(205), UINT8_C(  0),
        UINT8_C(  0), UINT8_C(195), UINT8_C(  0), UINT8_C(163), UINT8_C(166), UINT8_C(  0), UINT8_C(  0), UINT8_C(247),
        UINT8_C(177), UINT8_C( 73), UINT8_C(  0), UINT8_C(  0), UINT8_C(134), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
        UINT8_C(166), UINT8_C(  0), UINT8_C(109), UINT8_C( 33), UINT8_C( 82), UINT8_C(250), UINT8_C(149), UINT8_C(  0) } },
    { UINT64_C( 7142740249784812035),
      { UINT8_C(116), UINT8_C( 76), UINT8_C(111), UINT8_C( 26), UINT8_C( 86), UINT8_C(250), UINT8_C( 18), UINT8_C(  7),
        UINT8_C( 67), UINT8_C(225), UINT8_C( 38), UINT8_C( 90), UINT8_C( 78), UINT8_C( 87), UINT8_C(104), UINT8_C(198),
        UINT8_C(189), UINT8_C(190), UINT8_C(220), UINT8_C(236), UINT8_C(184), UINT8_C( 51), UINT8_C( 85), UINT8_C(187),
        UINT8_C( 53), UINT8_C(164), UINT8_C(138), UINT8_C(158), UINT8_C(192), UINT8_C(170), UINT8_C(  2), UINT8_C( 52),
        UINT8_C(246), UINT8_C(113), UINT8_C( 79), UINT8_C( 76), UINT8_C(107), UINT8_C( 97), UINT8_C( 84), UINT8_C(174),
        UINT8_C( 66), UINT8_C(122), UINT8_C(  9), UINT8_C(144), UINT8_C(209), UINT8_C(113), UINT8_C( 86), UINT8_C(142),
        UINT8_C( 47), UINT8_C( 50), UINT8_C(122), UINT8_C(231), UINT8_C(102), UINT8_C(208), UINT8_C(162), UINT8_C(155),
        UINT8_C(116), UINT8_C( 45), UINT8_C( 58), UINT8_C( 53), UINT8_C(215), UINT8_C( 60), UINT8_C(105), UINT8_C(206) },
      { UINT8_C(173), UINT8_C(184), UINT8_C( 26), UINT8_C( 25), UINT8_C( 25), UINT8_C(110), UINT8_C(199), UINT8_C( 91),
        UINT8_C(232), UINT8_C(208), UINT8_C(235), UINT8_C(186), UINT8_C( 65), UINT8_C( 66), UINT8_C( 72), UINT8_C(112),
        UINT8_C(116), UINT8_C(195), UINT8_C( 87), UINT8_C(218), UINT8_C(147), UINT8_C(250), UINT8_C(118), UINT8_C(  7),
        UINT8_C( 39), UINT8_C(176), UINT8_C( 60), UINT8_C(254), UINT8_C(236), UINT8_C(166), UINT8_C(204), UINT8_C(153),
        UINT8_C( 94), UINT8_C(231), UINT8_C(178), UINT8_C(120), UINT8_C( 85), UINT8_C(122), UINT8_C(211), UINT8_C( 62),
        UINT8_C( 74), UINT8_C(191), UINT8_C(248), UINT8_C(140), UINT8_C(  1), UINT8_C( 64), UINT8_C(252), UINT8_C(117),
        UINT8_C(  3), UINT8_C( 84), UINT8_C( 80), UINT8_C(150), UINT8_C( 78), UINT8_C(198), UINT8_C(158), UINT8_C(117),
        UINT8_C(118), UINT8_C(218), UINT8_C(115), UINT8_C( 98), UINT8_C(128), UINT8_C( 64), UINT8_C(251), UINT8_C(223) },
      { UINT8_C(173), UINT8_C(184), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
        UINT8_C(  0), UINT8_C(225), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
        UINT8_C(189), UINT8_C(195), UINT8_C(220), UINT8_C(236), UINT8_C(  0), UINT8_C(  0), UINT8_C(118), UINT8_C(  0),
        UINT8_C( 53), UINT8_C(176), UINT8_C(138), UINT8_C(254), UINT8_C(  0), UINT8_C(  0), UINT8_C(204), UINT8_C(153),
        UINT8_C(246), UINT8_C(  0), UINT8_C(  0), UINT8_C(120), UINT8_C(  0), UINT8_C(122), UINT8_C(211), UINT8_C(  0),
        UINT8_C(  0), UINT8_C(  0), UINT8_C(248), UINT8_C(144), UINT8_C(209), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
        UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(208), UINT8_C(  0), UINT8_C(  0),
        UINT8_C(118), UINT8_C(218), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C( 64), UINT8_C(251), UINT8_C(  0) } },
    { UINT64_C( 8266966419365146151),
      { UINT8_C(233), UINT8_C(178), UINT8_C(254), UINT8_C(234), UINT8_C(243), UINT8_C(251), UINT8_C( 96), UINT8_C(246),
        UINT8_C( 79), UINT8_C(176), UINT8_C(141), UINT8_C(157), UINT8_C(118), UINT8_C( 43), UINT8_C( 18), UINT8_C(236),
        UINT8_C(  5), UINT8_C(133), UINT8_C( 78), UINT8_C(134), UINT8_C(197), UINT8_C( 73), UINT8_C(101), UINT8_C(236),
        UINT8_C(247), UINT8_C(188), UINT8_C(105), UINT8_C( 31), UINT8_C(230), UINT8_C( 35), UINT8_C(146), UINT8_C(208),
        UINT8_C(214), UINT8_C(144), UINT8_C(186), UINT8_C(201), UINT8_C(139), UINT8_C( 26), UINT8_C(191), UINT8_C(218),
        UINT8_C(202), UINT8_C( 76), UINT8_C(119), UINT8_C( 64), UINT8_C(119), UINT8_C(137), UINT8_C( 44), UINT8_C(125),
        UINT8_C( 15), UINT8_C(122), UINT8_C(  3), UINT8_C(212), UINT8_C(196), UINT8_C(104), UINT8_C(193), UINT8_C(187),
        UINT8_C( 36), UINT8_C( 42), UINT8_C(219), UINT8_C( 10), UINT8_C( 77), UINT8_C(109), UINT8_C(218), UINT8_C( 35) },
      { UINT8_C(253), UINT8_C(149), UINT8_C(236), UINT8_C(137), UINT8_C(175), UINT8_C(172), UINT8_C( 99), UINT8_C(122),
        UINT8_C(248), UINT8_C(219), UINT8_C(186), UINT8_C(112), UINT8_C(100), UINT8_C(231), UINT8_C(237), UINT8_C(115),
        UINT8_C( 97), UINT8_C(240), UINT8_C( 72), UINT8_C( 37), UINT8_C( 88), UINT8_C(  9), UINT8_C(225), UINT8_C(124),
        UINT8_C( 51), UINT8_C(188), UINT8_C(134), UINT8_C(128), UINT8_C( 41), UINT8_C( 97), UINT8_C(164), UINT8_C( 38),
        UINT8_C(246), UINT8_C(144), UINT8_C(175), UINT8_C(165), UINT8_C( 60), UINT8_C( 19), UINT8_C( 31), UINT8_C( 53),
        UINT8_C(238), UINT8_C(218), UINT8_C(165), UINT8_C( 82), UINT8_C(193), UINT8_C(146), UINT8_C(198), UINT8_C( 34),
        UINT8_C(130), UINT8_C( 14), UINT8_C( 72), UINT8_C(218), UINT8_C( 23), UINT8_C( 41), UINT8_C( 86), UINT8_C( 74),
        UINT8_C(229), UINT8_C(220), UINT8_C(202), UINT8_C( 14), UINT8_C( 61), UINT8_C(110), UINT8_C( 52), UINT8_C( 51) },
      { UINT8_C(253), UINT8_C(178), UINT8_C(254), UINT8_C(  0), UINT8_C(  0), UINT8_C(251), UINT8_C(  0), UINT8_C(  0),
        UINT8_C(  0), UINT8_C(219), UINT8_C(186), UINT8_C(157), UINT8_C(  0), UINT8_C(231), UINT8_C(  0), UINT8_C(236),
        UINT8_C( 97), UINT8_C(240), UINT8_C( 78), UINT8_C(  0), UINT8_C(197), UINT8_C(  0), UINT8_C(225), UINT8_C(  0),
        UINT8_C(  0), UINT8_C(  0), UINT8_C(134), UINT8_C(128), UINT8_C(230), UINT8_C( 97), UINT8_C(164), UINT8_C(  0),
        UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(201), UINT8_C(  0), UINT8_C( 26), UINT8_C(  0), UINT8_C(  0),
        UINT8_C(  0), UINT8_C(218), UINT8_C(  0), UINT8_C( 82), UINT8_C(  0), UINT8_C(146), UINT8_C(  0), UINT8_C(  0),
        UINT8_C(  0), UINT8_C(122), UINT8_C(  0), UINT8_C(218), UINT8_C(196), UINT8_C(104), UINT8_C(  0), UINT8_C(187),
        UINT8_C(  0), UINT8_C(220), UINT8_C(  0), UINT8_C(  0), UINT8_C( 77), UINT8_C(110), UINT8_C(218), UINT8_C(  0) } },
    { UINT64_C(16532987972821837055),
      { UINT8_C(210), UINT8_C( 21), UINT8_C( 55), UINT8_C(147), UINT8_C(167), UINT8_C(253), UINT8_C(182), UINT8_C( 41),
        UINT8_C( 11), UINT8_C(254), UINT8_C(  3), UINT8_C( 34), UINT8_C( 39), UINT8_C( 89), UINT8_C(108), UINT8_C( 12),
        UINT8_C( 54), UINT8_C( 55), UINT8_C( 26), UINT8_C(115), UINT8_C(165), UINT8_C( 78), UINT8_C(167), UINT8_C(164),
        UINT8_C( 50), UINT8_C(128), UINT8_C(224), UINT8_C( 41), UINT8_C(120), UINT8_C( 80), UINT8_C( 14), UINT8_C( 75),
        UINT8_C(102), UINT8_C( 70), UINT8_C(222), UINT8_C( 13), UINT8_C( 67), UINT8_C(148), UINT8_C( 55), UINT8_C( 79),
        UINT8_C(146), UINT8_C( 58), UINT8_C(113), UINT8_C(185), UINT8_C(148), UINT8_C(222), UINT8_C(197), UINT8_C(202),
        UINT8_C( 21), UINT8_C(223), UINT8_C( 61), UINT8_C(186), UINT8_C( 46), UINT8_C(228), UINT8_C( 95), UINT8_C( 96),
        UINT8_C(100), UINT8_C( 63), UINT8_C(138), UINT8_C(221), UINT8_C(143), UINT8_C(152), UINT8_C( 40), UINT8_C(245) },
      { UINT8_C(222), UINT8_C(  6), UINT8_C(  3), UINT8_C( 34), UINT8_C(155), UINT8_C( 58), UINT8_C(113), UINT8_C( 45),
        UINT8_C(116), UINT8_C(226), UINT8_C(231), UINT8_C(  8), UINT8_C(192), UINT8_C(172), UINT8_C(210), UINT8_C(213),
        UINT8_C(140), UINT8_C( 16), UINT8_C(144), UINT8_C(186), UINT8_C(244), UINT8_C(239), UINT8_C( 26), UINT8_C( 89),
        UINT8_C( 46), UINT8_C(164), UINT8_C( 54), UINT8_C(189), UINT8_C( 61), UINT8_C( 94), UINT8_C(179), UINT8_C( 27),
        UINT8_C(100), UINT8_C(182), UINT8_C( 61),    UINT8_MAX, UINT8_C(240), UINT8_C(174), UINT8_C( 45), UINT8_C(100),
        UINT8_C(145), UINT8_C( 20), UINT8_C(109), UINT8_C( 81), UINT8_C(192), UINT8_C( 63), UINT8_C( 39), UINT8_C( 76),
        UINT8_C( 79), UINT8_C(183), UINT8_C(  6), UINT8_C( 68), UINT8_C(166), UINT8_C( 33), UINT8_C(157), UINT8_C(212),
        UINT8_C(197), UINT8_C(211), UINT8_C(145), UINT8_C(  2), UINT8_C( 49), UINT8_C( 68), UINT8_C( 30), UINT8_C(149) },
      { UINT8_C(222), UINT8_C( 21), UINT8_C( 55), UINT8_C(147), UINT8_C(167), UINT8_C(253), UINT8_C(182), UINT8_C( 45),
        UINT8_C(  0), UINT8_C(  0), UINT8_C(231), UINT8_C(  0), UINT8_C(  0), UINT8_C(172), UINT8_C(210), UINT8_C(213),
        UINT8_C(140), UINT8_C(  0), UINT8_C(  0), UINT8_C(186), UINT8_C(244), UINT8_C(  0), UINT8_C(167), UINT8_C(164),
        UINT8_C( 50), UINT8_C(164), UINT8_C(  0), UINT8_C(189), UINT8_C(120), UINT8_C( 94), UINT8_C(  0), UINT8_C(  0),
        UINT8_C(102), UINT8_C(182), UINT8_C(222), UINT8_C(  0), UINT8_C(240), UINT8_C(174), UINT8_C( 55), UINT8_C(100),
        UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(185), UINT8_C(192), UINT8_C(222), UINT8_C(197), UINT8_C(202),
        UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(166), UINT8_C(228), UINT8_C(157), UINT8_C(  0),
        UINT8_C(197), UINT8_C(  0), UINT8_C(145), UINT8_C(  0), UINT8_C(  0), UINT8_C(152), UINT8_C( 40), UINT8_C(245) } },
    { UINT64_C(11191376951180090362),
      { UINT8_C(214), UINT8_C(188), UINT8_C(236), UINT8_C(150), UINT8_C(251), UINT8_C( 19), UINT8_C(227), UINT8_C( 75),
        UINT8_C(202), UINT8_C(233), UINT8_C(143), UINT8_C(112), UINT8_C( 10), UINT8_C( 44), UINT8_C( 68), UINT8_C(208),
           UINT8_MAX, UINT8_C(214), UINT8_C(210), UINT8_C( 48), UINT8_C( 26), UINT8_C(240), UINT8_C(197), UINT8_C( 21),
        UINT8_C( 76), UINT8_C( 90),    UINT8_MAX, UINT8_C( 86), UINT8_C( 28), UINT8_C( 78), UINT8_C(241), UINT8_C(242),
        UINT8_C( 10), UINT8_C(221), UINT8_C(137), UINT8_C(  6), UINT8_C(241), UINT8_C(108), UINT8_C( 81), UINT8_C(187),
        UINT8_C( 85), UINT8_C(224), UINT8_C( 44), UINT8_C( 96), UINT8_C( 12), UINT8_C(112), UINT8_C( 48), UINT8_C( 11),
        UINT8_C( 70), UINT8_C(  2), UINT8_C( 59), UINT8_C( 97), UINT8_C(243), UINT8_C(  0), UINT8_C(118), UINT8_C( 63),
        UINT8_C( 91), UINT8_C(117), UINT8_C(149), UINT8_C(119), UINT8_C(196), UINT8_C(134), UINT8_C(106), UINT8_C(206) },
      { UINT8_C( 99), UINT8_C(243), UINT8_C(212), UINT8_C( 84), UINT8_C( 95), UINT8_C( 37), UINT8_C( 16), UINT8_C(180),
        UINT8_C(  5), UINT8_C( 60), UINT8_C( 20), UINT8_C( 17), UINT8_C(172), UINT8_C( 68), UINT8_C( 28), UINT8_C(243),
        UINT8_C( 71), UINT8_C( 87), UINT8_C( 84), UINT8_C( 58), UINT8_C( 88), UINT8_C(202), UINT8_C(121), UINT8_C(179),
        UINT8_C( 63), UINT8_C( 14), UINT8_C( 42), UINT8_C(  3), UINT8_C(148), UINT8_C(148), UINT8_C(210), UINT8_C(247),
        UINT8_C(135), UINT8_C(166), UINT8_C( 76), UINT8_C(230), UINT8_C(204), UINT8_C( 92), UINT8_C(155), UINT8_C(209),
        UINT8_C(152), UINT8_C(175), UINT8_C(227), UINT8_C( 68), UINT8_C(244),    UINT8_MAX, UINT8_C( 55), UINT8_C( 59),
        UINT8_C( 87), UINT8_C(139), UINT8_C(117), UINT8_C(175), UINT8_C( 85), UINT8_C(238), UINT8_C( 98), UINT8_C(149),
        UINT8_C(252), UINT8_C(140), UINT8_C(152), UINT8_C(144), UINT8_C( 33), UINT8_C(106), UINT8_C(135), UINT8_C(168) },
      { UINT8_C(  0), UINT8_C(243), UINT8_C(  0), UINT8_C(150), UINT8_C(251), UINT8_C( 37), UINT8_C(227), UINT8_C(180),
        UINT8_C(202), UINT8_C(233), UINT8_C(  0), UINT8_C(112), UINT8_C(172), UINT8_C(  0), UINT8_C( 68), UINT8_C(  0),
           UINT8_MAX, UINT8_C(  0), UINT8_C(210), UINT8_C(  0), UINT8_C( 88), UINT8_C(  0), UINT8_C(  0), UINT8_C(179),
        UINT8_C(  0), UINT8_C( 90), UINT8_C(  0), UINT8_C( 86), UINT8_C(  0), UINT8_C(148), UINT8_C(241), UINT8_C(247),
        UINT8_C(  0), UINT8_C(221), UINT8_C(  0), UINT8_C(230), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
        UINT8_C(  0), UINT8_C(224), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C( 55), UINT8_C( 59),
        UINT8_C( 87), UINT8_C(139), UINT8_C(117), UINT8_C(175), UINT8_C(  0), UINT8_C(  0), UINT8_C(118), UINT8_C(  0),
        UINT8_C(252), UINT8_C(140), UINT8_C(  0), UINT8_C(144), UINT8_C(196), UINT8_C(  0), UINT8_C(  0), UINT8_C(206) } },
    { UINT64_C(14388484244564333329),
      { UINT8_C(217), UINT8_C(145), UINT8_C( 12), UINT8_C(205), UINT8_C(145), UINT8_C( 67), UINT8_C(  8), UINT8_C(232),
        UINT8_C(207), UINT8_C(125), UINT8_C(151), UINT8_C( 36), UINT8_C(107), UINT8_C(249), UINT8_C(185), UINT8_C(103),
        UINT8_C(133), UINT8_C( 82), UINT8_C(247), UINT8_C(166), UINT8_C(188), UINT8_C(127), UINT8_C( 79), UINT8_C(205),
        UINT8_C( 82), UINT8_C(222), UINT8_C(170), UINT8_C(130), UINT8_C(  8), UINT8_C( 89), UINT8_C( 73), UINT8_C(225),
        UINT8_C(234), UINT8_C( 85), UINT8_C(175), UINT8_C(123), UINT8_C(153), UINT8_C(183), UINT8_C( 99), UINT8_C(104),
        UINT8_C( 53), UINT8_C(250), UINT8_C(140), UINT8_C(160), UINT8_C(243), UINT8_C( 70), UINT8_C(  8), UINT8_C(121),
        UINT8_C(152),    UINT8_MAX, UINT8_C( 31), UINT8_C( 84), UINT8_C(126), UINT8_C(110), UINT8_C( 34), UINT8_C(209),
        UINT8_C( 76), UINT8_C(204), UINT8_C( 83), UINT8_C( 84), UINT8_C( 37), UINT8_C(156), UINT8_C( 54), UINT8_C( 16) },
      { UINT8_C(242), UINT8_C(229), UINT8_C(139), UINT8_C(139), UINT8_C(156), UINT8_C(239), UINT8_C(243), UINT8_C(209),
        UINT8_C(233), UINT8_C(127), UINT8_C(114), UINT8_C(221), UINT8_C(197), UINT8_C(122), UINT8_C( 86), UINT8_C( 93),
        UINT8_C(121), UINT8_C(117), UINT8_C(178), UINT8_C(248), UINT8_C(228), UINT8_C(212), UINT8_C(201), UINT8_C( 48),
        UINT8_C(160), UINT8_C( 28), UINT8_C(133), UINT8_C(198), UINT8_C(184), UINT8_C(187), UINT8_C(214), UINT8_C(170),
        UINT8_C(160), UINT8_C( 97), UINT8_C( 53), UINT8_C( 60), UINT8_C( 80), UINT8_C( 40), UINT8_C( 14), UINT8_C( 58),
        UINT8_C(168), UINT8_C(128), UINT8_C( 23), UINT8_C(109), UINT8_C(250), UINT8_C(109), UINT8_C(203), UINT8_C(115),
        UINT8_C(226), UINT8_C(125), UINT8_C(107), UINT8_C(198), UINT8_C( 81), UINT8_C( 52), UINT8_C(247), UINT8_C(241),
        UINT8_C( 80), UINT8_C(124), UINT8_C(183), UINT8_C(  9), UINT8_C( 55), UINT8_C(141), UINT8_C(179), UINT8_C(215) },
      { UINT8_C(242), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(156), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
        UINT8_C(233), UINT8_C(127), UINT8_C(  0), UINT8_C(  0), UINT8_C(197), UINT8_C(  0), UINT8_C(185), UINT8_C(103),
        UINT8_C(133), UINT8_C(117), UINT8_C(247), UINT8_C(248), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(205),
        UINT8_C(160), UINT8_C(  0), UINT8_C(170), UINT8_C(198), UINT8_C(184), UINT8_C(  0), UINT8_C(214), UINT8_C(225),
        UINT8_C(234), UINT8_C( 97), UINT8_C(175), UINT8_C(123), UINT8_C(  0), UINT8_C(183), UINT8_C(  0), UINT8_C(  0),
        UINT8_C(  0), UINT8_C(250), UINT8_C(  0), UINT8_C(160), UINT8_C(  0), UINT8_C(109), UINT8_C(  0), UINT8_C(  0),
        UINT8_C(  0),    UINT8_MAX, UINT8_C(107), UINT8_C(198), UINT8_C(  0), UINT8_C(110), UINT8_C(  0), UINT8_C(241),
        UINT8_C( 80), UINT8_C(204), UINT8_C(183), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(179), UINT8_C(215) } }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
    simde__m512i a = simde_mm512_loadu_epi8(test_vec[i].a);
    simde__m512i b = simde_mm512_loadu_epi8(test_vec[i].b);
    simde__m512i r = simde_mm512_maskz_max_epu8(test_vec[i].k, a, b);
    simde_test_x86_assert_equal_u8x64(r, simde_mm512_loadu_epi8(test_vec[i].r));
  }

  return 0;
}

static int
test_simde_mm512_min_epi16 (SIMDE_MUNIT_TEST_ARGS) {
  static const struct {
    const int16_t a[32];
    const int16_t b[32];
    const int16_t r[32];
  } test_vec[] = {
    { {  INT16_C( 14691), -INT16_C(  2237),  INT16_C(  8698),  INT16_C(  9348),  INT16_C( 13857), -INT16_C( 10584),  INT16_C( 25854), -INT16_C(  6420),
         INT16_C( 17420),  INT16_C(  1517), -INT16_C(  5283),  INT16_C( 26495),  INT16_C(  7532), -INT16_C(  2781),  INT16_C(  9520), -INT16_C( 27403),
         INT16_C( 14430),  INT16_C( 22667),  INT16_C(  3929),  INT16_C( 31356),  INT16_C(  9541),  INT16_C( 17232),  INT16_C( 15497), -INT16_C( 27350),
         INT16_C(  6016), -INT16_C(  8550),  INT16_C(  6658),  INT16_C( 28485),  INT16_C( 26679),  INT16_C( 26724),  INT16_C( 22926), -INT16_C(  4868) },
      { -INT16_C( 30831), -INT16_C(  5563), -INT16_C( 15978), -INT16_C(  9371), -INT16_C( 18970),  INT16_C( 28447),  INT16_C( 18930),  INT16_C( 29188),
        -INT16_C( 24736),  INT16_C( 25168), -INT16_C( 26951), -INT16_C(  3887),  INT16_C( 14078), -INT16_C( 29608),  INT16_C( 21647),  INT16_C(  8569),
        -INT16_C( 16677),  INT16_C( 28939),  INT16_C( 28799),  INT16_C( 26189),  INT16_C( 27686),  INT16_C(  6357), -INT16_C(  9547),  INT16_C(  5514),
        -INT16_C(  9351),  INT16_C( 12919),  INT16_C( 18801),  INT16_C( 28450),  INT16_C( 31615),  INT16_C(  3836),  INT16_C( 30159), -INT16_C( 21713) },
      { -INT16_C( 30831), -INT16_C(  5563), -INT16_C( 15978), -INT16_C(  9371), -INT16_C( 18970), -INT16_C( 10584),  INT16_C( 18930), -INT16_C(  6420),
        -INT16_C( 24736),  INT16_C(  1517), -INT16_C( 26951), -INT16_C(  3887),  INT16_C(  7532), -INT16_C( 29608),  INT16_C(  9520), -INT16_C( 27403),
        -INT16_C( 16677),  INT16_C( 22667),  INT16_C(  3929),  INT16_C( 26189),  INT16_C(  9541),  INT16_C(  6357), -INT16_C(  9547), -INT16_C( 27350),
        -INT16_C(  9351), -INT16_C(  8550),  INT16_C(  6658),  INT16_C( 28450),  INT16_C( 26679),  INT16_C(  3836),  INT16_C( 22926), -INT16_C( 21713) } },
    { {  INT16_C( 15155), -INT16_C( 19940),  INT16_C( 27051), -INT16_C( 12008), -INT16_C(  4395), -INT16_C( 29975),  INT16_C( 29896),  INT16_C( 16799),
         INT16_C(  5967), -INT16_C( 16269), -INT16_C( 27296), -INT16_C(  8401),  INT16_C( 11024), -INT16_C(  7955),  INT16_C(  7584), -INT16_C( 11381),
        -INT16_C( 22696),  INT16_C(   902), -INT16_C( 25071), -INT16_C(  6443), -INT16_C( 16756),  INT16_C( 21617),  INT16_C(  4146), -INT16_C( 32363),
         INT16_C(  2087), -INT16_C( 30911),  INT16_C( 29086), -INT16_C( 20890),  INT16_C( 21660),  INT16_C( 15758),  INT16_C(  6513), -INT16_C( 14064) },
      { -INT16_C( 26943), -INT16_C( 11572), -INT16_C( 24267), -INT16_C( 15944),  INT16_C( 10592), -INT16_C( 28138), -INT16_C( 21702),  INT16_C( 24852),
         INT16_C( 21940),  INT16_C( 21225),  INT16_C( 20422),  INT16_C( 25344), -INT16_C( 28765),  INT16_C(  5280), -INT16_C( 20312),  INT16_C( 27101),
        -INT16_C( 21945),  INT16_C( 31803), -INT16_C(  2997), -INT16_C( 21699),  INT16_C( 21277),  INT16_C( 22334),  INT16_C( 21247), -INT16_C( 19527),
        -INT16_C( 23897),  INT16_C( 28165),  INT16_C(  1521), -INT16_C( 27183),  INT16_C( 29076),  INT16_C( 15785), -INT16_C( 30943),  INT16_C( 26790) },
      { -INT16_C( 26943), -INT16_C( 19940), -INT16_C( 24267), -INT16_C( 15944), -INT16_C(  4395), -INT16_C( 29975), -INT16_C( 21702),  INT16_C( 16799),
         INT16_C(  5967), -INT16_C( 16269), -INT16_C( 27296), -INT16_C(  8401), -INT16_C( 28765), -INT16_C(  7955), -INT16_C( 20312), -INT16_C( 11381),
        -INT16_C( 22696),  INT16_C(   902), -INT16_C( 25071), -INT16_C( 21699), -INT16_C( 16756),  INT16_C( 21617),  INT16_C(  4146), -INT16_C( 32363),
        -INT16_C( 23897), -INT16_C( 30911),  INT16_C(  1521), -INT16_C( 27183),  INT16_C( 21660),  INT16_C( 15758), -INT16_C( 30943), -INT16_C( 14064) } },
    { { -INT16_C(  7631),  INT16_C( 31972),  INT16_C(  8918), -INT16_C(  3288),  INT16_C( 26229),  INT16_C( 29771),  INT16_C(  1208),  INT16_C( 24359),
         INT16_C( 11430), -INT16_C( 26675), -INT16_C( 25038), -INT16_C( 14804), -INT16_C( 10737),  INT16_C( 12547), -INT16_C( 21923), -INT16_C( 29031),
         INT16_C( 32396),  INT16_C( 25098),  INT16_C( 12960),  INT16_C(  5461), -INT16_C( 24424),  INT16_C( 20618), -INT16_C( 20060),  INT16_C( 19120),
         INT16_C( 32222),  INT16_C(  4322),  INT16_C(  3612),  INT16_C( 11222), -INT16_C(  9500),  INT16_C( 16732), -INT16_C(  2428),  INT16_C(  4303) },
      { -INT16_C(  9612),  INT16_C(  5234), -INT16_C( 14580), -INT16_C( 23255), -INT16_C( 19608),  INT16_C(  3317), -INT16_C( 23195),  INT16_C( 17239),
         INT16_C( 14627),  INT16_C( 16211),  INT16_C( 10567),  INT16_C( 11370), -INT16_C( 14589), -INT16_C( 30867),  INT16_C( 15805),  INT16_C( 12695),
         INT16_C(  2327),  INT16_C(  9029),  INT16_C( 28369),  INT16_C( 14792), -INT16_C( 16862), -INT16_C( 30907), -INT16_C( 25501), -INT16_C( 31030),
         INT16_C(  7637),  INT16_C(  7621),  INT16_C( 12358),  INT16_C( 19017), -INT16_C( 18697), -INT16_C( 19247),  INT16_C( 27123),  INT16_C(  2789) },
      { -INT16_C(  9612),  INT16_C(  5234), -INT16_C( 14580), -INT16_C( 23255), -INT16_C( 19608),  INT16_C(  3317), -INT16_C( 23195),  INT16_C( 17239),
         INT16_C( 11430), -INT16_C( 26675), -INT16_C( 25038), -INT16_C( 14804), -INT16_C( 14589), -INT16_C( 30867), -INT16_C( 21923), -INT16_C( 29031),
         INT16_C(  2327),  INT16_C(  9029),  INT16_C( 12960),  INT16_C(  5461), -INT16_C( 24424), -INT16_C( 30907), -INT16_C( 25501), -INT16_C( 31030),
         INT16_C(  7637),  INT16_C(  4322),  INT16_C(  3612),  INT16_C( 11222), -INT16_C( 18697), -INT16_C( 19247), -INT16_C(  2428),  INT16_C(  2789) } },
    { {  INT16_C( 10866),  INT16_C( 17198), -INT16_C(  2408), -INT16_C( 17796), -INT16_C( 15692),  INT16_C(  6209),  INT16_C(  2910),  INT16_C( 13470),
         INT16_C( 25640),  INT16_C( 28497), -INT16_C( 25964), -INT16_C( 29767), -INT16_C( 30128),  INT16_C( 17471),  INT16_C(  9459),  INT16_C( 26190),
         INT16_C( 31822), -INT16_C(  6487),  INT16_C(  9843),  INT16_C( 10145), -INT16_C(  7448),  INT16_C( 17983), -INT16_C(  8466),  INT16_C(  5754),
        -INT16_C( 13502), -INT16_C( 10619),  INT16_C( 15973), -INT16_C( 18847), -INT16_C( 24375), -INT16_C( 17158),  INT16_C( 18628),  INT16_C(  4642) },
      { -INT16_C( 13115),  INT16_C( 14584), -INT16_C( 26126), -INT16_C(  9633), -INT16_C( 24708),  INT16_C( 27168), -INT16_C( 25731), -INT16_C( 16512),
         INT16_C(  1638), -INT16_C( 13163), -INT16_C(  2492),  INT16_C(  3458),  INT16_C( 31894),  INT16_C( 23242), -INT16_C(  4924), -INT16_C( 30356),
         INT16_C( 25784), -INT16_C( 21823),  INT16_C(  8702),  INT16_C( 31364), -INT16_C( 23104),  INT16_C( 15844),  INT16_C( 25664), -INT16_C( 22788),
        -INT16_C( 28310), -INT16_C( 20622), -INT16_C(  2937),  INT16_C(  7612), -INT16_C( 31120),  INT16_C( 13687), -INT16_C(  7309),  INT16_C( 11198) },
      { -INT16_C( 13115),  INT16_C( 14584), -INT16_C( 26126), -INT16_C( 17796), -INT16_C( 24708),  INT16_C(  6209), -INT16_C( 25731), -INT16_C( 16512),
         INT16_C(  1638), -INT16_C( 13163), -INT16_C( 25964), -INT16_C( 29767), -INT16_C( 30128),  INT16_C( 17471), -INT16_C(  4924), -INT16_C( 30356),
         INT16_C( 25784), -INT16_C( 21823),  INT16_C(  8702),  INT16_C( 10145), -INT16_C( 23104),  INT16_C( 15844), -INT16_C(  8466), -INT16_C( 22788),
        -INT16_C( 28310), -INT16_C( 20622), -INT16_C(  2937), -INT16_C( 18847), -INT16_C( 31120), -INT16_C( 17158), -INT16_C(  7309),  INT16_C(  4642) } },
    { { -INT16_C( 32697),  INT16_C( 17878),  INT16_C( 23201),  INT16_C( 25023), -INT16_C( 23553),  INT16_C( 16286), -INT16_C( 26104),  INT16_C( 29414),
         INT16_C( 22571), -INT16_C( 19935), -INT16_C(  8627), -INT16_C( 16945),  INT16_C( 18020), -INT16_C( 10254), -INT16_C( 20183),  INT16_C( 28675),
        -INT16_C(  9935), -INT16_C( 11594),  INT16_C( 30003),  INT16_C( 13107), -INT16_C( 12007),  INT16_C(  8562),  INT16_C( 22635), -INT16_C( 26989),
        -INT16_C( 19023), -INT16_C(   440),  INT16_C(  6035), -INT16_C(  2117), -INT16_C( 20899), -INT16_C( 31025), -INT16_C( 11681), -INT16_C( 28426) },
      { -INT16_C( 21333), -INT16_C(  8606), -INT16_C( 27358),  INT16_C( 15121), -INT16_C( 31642), -INT16_C( 11940), -INT16_C(  4132), -INT16_C( 29337),
        -INT16_C( 20572),  INT16_C( 14219),  INT16_C( 18374),  INT16_C(  9007), -INT16_C(   267),  INT16_C( 21673), -INT16_C( 24624),  INT16_C( 31716),
         INT16_C( 17996),  INT16_C( 28249),  INT16_C( 27611),  INT16_C( 16809),  INT16_C(  1519), -INT16_C( 13550),  INT16_C( 31220), -INT16_C( 26279),
        -INT16_C(  7128), -INT16_C(  4400), -INT16_C(   213),  INT16_C(  8209), -INT16_C( 17667), -INT16_C( 12940),  INT16_C( 22617), -INT16_C( 23224) },
      { -INT16_C( 32697), -INT16_C(  8606), -INT16_C( 27358),  INT16_C( 15121), -INT16_C( 31642), -INT16_C( 11940), -INT16_C( 26104), -INT16_C( 29337),
        -INT16_C( 20572), -INT16_C( 19935), -INT16_C(  8627), -INT16_C( 16945), -INT16_C(   267), -INT16_C( 10254), -INT16_C( 24624),  INT16_C( 28675),
        -INT16_C(  9935), -INT16_C( 11594),  INT16_C( 27611),  INT16_C( 13107), -INT16_C( 12007), -INT16_C( 13550),  INT16_C( 22635), -INT16_C( 26989),
        -INT16_C( 19023), -INT16_C(  4400), -INT16_C(   213), -INT16_C(  2117), -INT16_C( 20899), -INT16_C( 31025), -INT16_C( 11681), -INT16_C( 28426) } },
    { { -INT16_C( 23906),  INT16_C( 30995), -INT16_C( 17395), -INT16_C(   838), -INT16_C( 13119), -INT16_C( 18745),  INT16_C(  8261),  INT16_C( 27983),
         INT16_C(  7941),  INT16_C( 12379),  INT16_C( 27679),  INT16_C(  7249), -INT16_C( 15066), -INT16_C( 32534),  INT16_C( 12830), -INT16_C( 17371),
         INT16_C( 14804), -INT16_C(  7882), -INT16_C(  3851), -INT16_C( 18467), -INT16_C( 23107),  INT16_C(   621), -INT16_C( 17211), -INT16_C( 13712),
        -INT16_C( 13349), -INT16_C(  1285),  INT16_C( 19512),  INT16_C( 24087),  INT16_C(   273),  INT16_C( 12254),  INT16_C(  1075),  INT16_C(  2284) },
      {  INT16_C(  8765),  INT16_C( 13033), -INT16_C( 14574), -INT16_C( 12311),  INT16_C( 22124),  INT16_C( 12754),  INT16_C( 16914), -INT16_C(  4356),
        -INT16_C(  2291),  INT16_C( 17896), -INT16_C(   189),  INT16_C( 21668), -INT16_C( 32256),  INT16_C( 13444),  INT16_C( 28806), -INT16_C( 15556),
         INT16_C(  9618), -INT16_C( 23306), -INT16_C(  8212),  INT16_C( 22644),  INT16_C( 17974),  INT16_C( 18570), -INT16_C( 31096), -INT16_C( 27338),
         INT16_C(  8061), -INT16_C( 16165),  INT16_C( 32542),  INT16_C(  7956), -INT16_C( 26623), -INT16_C( 30637), -INT16_C( 28920), -INT16_C( 26037) },
      { -INT16_C( 23906),  INT16_C( 13033), -INT16_C( 17395), -INT16_C( 12311), -INT16_C( 13119), -INT16_C( 18745),  INT16_C(  8261), -INT16_C(  4356),
        -INT16_C(  2291),  INT16_C( 12379), -INT16_C(   189),  INT16_C(  7249), -INT16_C( 32256), -INT16_C( 32534),  INT16_C( 12830), -INT16_C( 17371),
         INT16_C(  9618), -INT16_C( 23306), -INT16_C(  8212), -INT16_C( 18467), -INT16_C( 23107),  INT16_C(   621), -INT16_C( 31096), -INT16_C( 27338),
        -INT16_C( 13349), -INT16_C( 16165),  INT16_C( 19512),  INT16_C(  7956), -INT16_C( 26623), -INT16_C( 30637), -INT16_C( 28920), -INT16_C( 26037) } },
    { {  INT16_C( 16820), -INT16_C( 24257), -INT16_C( 19679),  INT16_C( 22521), -INT16_C( 31751), -INT16_C( 32353), -INT16_C( 10743), -INT16_C( 31210),
        -INT16_C(  3595),  INT16_C(  4934),  INT16_C( 23408),  INT16_C( 29234), -INT16_C( 31245), -INT16_C(   774),  INT16_C( 17684), -INT16_C( 13930),
        -INT16_C( 10873), -INT16_C( 22422),  INT16_C( 25480), -INT16_C( 32257), -INT16_C( 24857), -INT16_C(  4094),  INT16_C(  6516),  INT16_C( 26999),
        -INT16_C( 17142),  INT16_C( 31613), -INT16_C( 20712),  INT16_C(  3309), -INT16_C(  6347),  INT16_C( 18696), -INT16_C( 25044), -INT16_C( 19694) },
      {  INT16_C( 31860), -INT16_C(   933),  INT16_C( 23264), -INT16_C( 14466), -INT16_C( 32519),  INT16_C( 28087),  INT16_C( 11929), -INT16_C( 23337),
         INT16_C( 21740),  INT16_C(  1055),  INT16_C(  3075),  INT16_C( 14352),  INT16_C(  6387),  INT16_C(  8066), -INT16_C( 27465),  INT16_C( 11219),
         INT16_C( 11793), -INT16_C(  3801), -INT16_C( 23159), -INT16_C( 32072),  INT16_C( 28454), -INT16_C( 16401), -INT16_C( 14690), -INT16_C( 30109),
        -INT16_C( 32230),  INT16_C(  7822), -INT16_C( 24690), -INT16_C( 32426), -INT16_C( 10057),  INT16_C( 28321),  INT16_C( 29805),  INT16_C( 32409) },
      {  INT16_C( 16820), -INT16_C( 24257), -INT16_C( 19679), -INT16_C( 14466), -INT16_C( 32519), -INT16_C( 32353), -INT16_C( 10743), -INT16_C( 31210),
        -INT16_C(  3595),  INT16_C(  1055),  INT16_C(  3075),  INT16_C( 14352), -INT16_C( 31245), -INT16_C(   774), -INT16_C( 27465), -INT16_C( 13930),
        -INT16_C( 10873), -INT16_C( 22422), -INT16_C( 23159), -INT16_C( 32257), -INT16_C( 24857), -INT16_C( 16401), -INT16_C( 14690), -INT16_C( 30109),
        -INT16_C( 32230),  INT16_C(  7822), -INT16_C( 24690), -INT16_C( 32426), -INT16_C( 10057),  INT16_C( 18696), -INT16_C( 25044), -INT16_C( 19694) } },
    { { -INT16_C( 15966),  INT16_C( 11119),  INT16_C( 10086), -INT16_C( 29523), -INT16_C( 25194),  INT16_C( 13388), -INT16_C( 20637),  INT16_C( 32446),
         INT16_C( 19762), -INT16_C( 16228), -INT16_C(  3348), -INT16_C( 23742), -INT16_C(  7221),  INT16_C( 14354), -INT16_C( 21673), -INT16_C(  1610),
         INT16_C(  9580), -INT16_C( 11483), -INT16_C( 11700), -INT16_C(  7585), -INT16_C( 21649), -INT16_C( 11497), -INT16_C( 10917), -INT16_C( 29359),
        -INT16_C(  4830),  INT16_C(  3661), -INT16_C( 28705), -INT16_C( 21838), -INT16_C( 15246), -INT16_C( 13854), -INT16_C( 26513), -INT16_C(  9021) },
      { -INT16_C(  5955),  INT16_C(  2479),  INT16_C(  3770),  INT16_C( 10988),  INT16_C(   954),  INT16_C(  5629),  INT16_C( 20184), -INT16_C(  1118),
        -INT16_C(  4293),  INT16_C(  6665), -INT16_C( 17537), -INT16_C(  3643), -INT16_C( 22657), -INT16_C(  4165),  INT16_C( 32320), -INT16_C(   565),
         INT16_C( 31334),  INT16_C(  8199), -INT16_C(  3192),  INT16_C( 16970),  INT16_C( 18422), -INT16_C( 12713), -INT16_C(  1643), -INT16_C( 12087),
        -INT16_C( 11287),  INT16_C( 26859), -INT16_C( 20338),  INT16_C(  3673),  INT16_C(  5207), -INT16_C( 26627), -INT16_C( 14190), -INT16_C(  1899) },
      { -INT16_C( 15966),  INT16_C(  2479),  INT16_C(  3770), -INT16_C( 29523), -INT16_C( 25194),  INT16_C(  5629), -INT16_C( 20637), -INT16_C(  1118),
        -INT16_C(  4293), -INT16_C( 16228), -INT16_C( 17537), -INT16_C( 23742), -INT16_C( 22657), -INT16_C(  4165), -INT16_C( 21673), -INT16_C(  1610),
         INT16_C(  9580), -INT16_C( 11483), -INT16_C( 11700), -INT16_C(  7585), -INT16_C( 21649), -INT16_C( 12713), -INT16_C( 10917), -INT16_C( 29359),
        -INT16_C( 11287),  INT16_C(  3661), -INT16_C( 28705), -INT16_C( 21838), -INT16_C( 15246), -INT16_C( 26627), -INT16_C( 26513), -INT16_C(  9021) } }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
    simde__m512i a = simde_mm512_loadu_epi16(test_vec[i].a);
    simde__m512i b = simde_mm512_loadu_epi16(test_vec[i].b);
    simde__m512i r = simde_mm512_min_epi16(a, b);
    simde_test_x86_assert_equal_i16x32(r, simde_mm512_loadu_epi16(test_vec[i].r));
  }

  return 0;
}

static int
test_simde_mm512_mask_min_epi16 (SIMDE_MUNIT_TEST_ARGS) {
  static const struct {
    const int16_t src[32];
    const simde__mmask32 k;
    const int16_t a[32];
    const int16_t b[32];
    const int16_t r[32];
  } test_vec[] = {
    { {  INT16_C(  9710),  INT16_C(  8237),  INT16_C( 26211),  INT16_C(  1978),  INT16_C( 14790),  INT16_C(  9775), -INT16_C( 11510), -INT16_C( 20158),
         INT16_C( 13508), -INT16_C( 18579),  INT16_C(  4844), -INT16_C(  4275), -INT16_C(  8222), -INT16_C( 28513),  INT16_C( 21293),  INT16_C(  7273),
        -INT16_C( 27015), -INT16_C(  9156), -INT16_C(  2308), -INT16_C( 15389),  INT16_C(  4911),  INT16_C( 14825),  INT16_C( 11238), -INT16_C( 21781),
         INT16_C( 22623),  INT16_C( 19298), -INT16_C( 20629),  INT16_C( 19770), -INT16_C(  9586), -INT16_C( 17187),  INT16_C( 17965), -INT16_C( 22824) },
      UINT32_C(3632403676),
      { -INT16_C( 31623),  INT16_C( 24436),  INT16_C( 24495),  INT16_C(  3593),  INT16_C( 27575),  INT16_C(  8794), -INT16_C( 27622), -INT16_C( 22161),
         INT16_C( 19566), -INT16_C( 25499),  INT16_C( 15762),  INT16_C( 28226), -INT16_C( 15023),  INT16_C( 23623), -INT16_C(  7637), -INT16_C( 23401),
         INT16_C(  2919),  INT16_C(  5635),  INT16_C(  3178),  INT16_C(  8485),  INT16_C( 32632), -INT16_C( 28092), -INT16_C( 19693), -INT16_C( 32197),
        -INT16_C( 24576), -INT16_C( 28130),  INT16_C( 24797),  INT16_C( 12033),  INT16_C( 18469),  INT16_C( 20619),  INT16_C(  8746), -INT16_C( 28172) },
      { -INT16_C(  2259), -INT16_C( 26712), -INT16_C( 13052),  INT16_C( 31929), -INT16_C(   692),  INT16_C( 24334),  INT16_C( 19120), -INT16_C( 20255),
        -INT16_C(    22), -INT16_C( 14269),  INT16_C( 17504), -INT16_C( 31241), -INT16_C( 32116), -INT16_C( 18730), -INT16_C( 13659), -INT16_C( 11704),
        -INT16_C(  3902), -INT16_C( 14742),  INT16_C(  9149),  INT16_C(  2370),  INT16_C( 20512), -INT16_C( 12184),  INT16_C( 19098), -INT16_C( 31359),
        -INT16_C( 15287), -INT16_C( 22195),  INT16_C( 17416), -INT16_C( 27601),  INT16_C(  1478),  INT16_C( 27466), -INT16_C( 27953), -INT16_C( 28354) },
      {  INT16_C(  9710),  INT16_C(  8237), -INT16_C( 13052),  INT16_C(  3593), -INT16_C(   692),  INT16_C(  9775), -INT16_C( 27622), -INT16_C( 22161),
         INT16_C( 13508), -INT16_C( 18579),  INT16_C( 15762), -INT16_C(  4275), -INT16_C( 32116), -INT16_C( 28513),  INT16_C( 21293),  INT16_C(  7273),
        -INT16_C( 27015), -INT16_C( 14742), -INT16_C(  2308), -INT16_C( 15389),  INT16_C(  4911),  INT16_C( 14825),  INT16_C( 11238), -INT16_C( 32197),
         INT16_C( 22623),  INT16_C( 19298), -INT16_C( 20629), -INT16_C( 27601),  INT16_C(  1478), -INT16_C( 17187), -INT16_C( 27953), -INT16_C( 28354) } },
    { { -INT16_C( 22398),  INT16_C( 16215), -INT16_C( 26165), -INT16_C(  5304), -INT16_C( 19990), -INT16_C( 31557),  INT16_C( 15611),  INT16_C( 17417),
         INT16_C( 22016),  INT16_C(  2286),  INT16_C(  7578),  INT16_C( 24988), -INT16_C(  6366), -INT16_C(  3636),  INT16_C(  2681), -INT16_C(   893),
        -INT16_C(  9550),  INT16_C( 32059), -INT16_C( 31628),  INT16_C( 24168),  INT16_C(  9269),  INT16_C( 12514), -INT16_C(  5024),  INT16_C( 24948),
         INT16_C( 25154), -INT16_C(  8855),  INT16_C(  1663), -INT16_C( 24258),  INT16_C(  2797),  INT16_C( 26259),  INT16_C(  5653), -INT16_C( 14494) },
      UINT32_C(1682284272),
      { -INT16_C( 23087),  INT16_C( 12935), -INT16_C(  1135), -INT16_C( 11373), -INT16_C(   930), -INT16_C(  8784), -INT16_C(  4606), -INT16_C(  4225),
         INT16_C(  4857),  INT16_C(  3670), -INT16_C( 18392),  INT16_C(  6357),  INT16_C(  6742),  INT16_C( 30845),  INT16_C( 16328), -INT16_C( 26161),
         INT16_C( 22244),  INT16_C( 30155),  INT16_C( 24146), -INT16_C( 20407), -INT16_C(  1701),  INT16_C( 23949),  INT16_C(  3304), -INT16_C(  7859),
        -INT16_C( 23778),  INT16_C( 18159), -INT16_C( 15269), -INT16_C( 19873), -INT16_C(  8993), -INT16_C( 22742), -INT16_C(  1509),  INT16_C(    64) },
      {  INT16_C(  3152), -INT16_C( 23947), -INT16_C( 16790), -INT16_C( 15022), -INT16_C(  8008), -INT16_C( 24541),  INT16_C( 28908),  INT16_C(  2945),
         INT16_C( 28691),  INT16_C( 28241), -INT16_C( 20428),  INT16_C(  4896),  INT16_C( 19340), -INT16_C( 22342), -INT16_C(  1211), -INT16_C( 27224),
         INT16_C(  7431),  INT16_C( 28984), -INT16_C( 29988), -INT16_C( 27593),  INT16_C( 23146),  INT16_C( 22324), -INT16_C( 18998), -INT16_C(  8862),
        -INT16_C( 19675),  INT16_C( 22859),  INT16_C( 27748), -INT16_C(  3987),  INT16_C( 10167), -INT16_C(   872),  INT16_C( 16418),  INT16_C( 10641) },
      { -INT16_C( 22398),  INT16_C( 16215), -INT16_C( 26165), -INT16_C(  5304), -INT16_C(  8008), -INT16_C( 24541), -INT16_C(  4606), -INT16_C(  4225),
         INT16_C( 22016),  INT16_C(  3670), -INT16_C( 20428),  INT16_C(  4896),  INT16_C(  6742), -INT16_C(  3636),  INT16_C(  2681), -INT16_C( 27224),
         INT16_C(  7431),  INT16_C( 32059), -INT16_C( 29988),  INT16_C( 24168),  INT16_C(  9269),  INT16_C( 12514), -INT16_C( 18998),  INT16_C( 24948),
         INT16_C( 25154), -INT16_C(  8855), -INT16_C( 15269), -INT16_C( 24258),  INT16_C(  2797), -INT16_C( 22742), -INT16_C(  1509), -INT16_C( 14494) } },
    { { -INT16_C( 13986),  INT16_C( 15003), -INT16_C( 11692), -INT16_C( 16690),  INT16_C(   556), -INT16_C(  2539),  INT16_C( 30647), -INT16_C(  9005),
         INT16_C(  7723), -INT16_C( 28875), -INT16_C( 23926),  INT16_C( 16767),  INT16_C(  6346), -INT16_C(  5059), -INT16_C( 12456), -INT16_C( 18922),
        -INT16_C( 20072), -INT16_C(  4880), -INT16_C( 16765), -INT16_C( 20565), -INT16_C( 16192),  INT16_C( 30629),  INT16_C( 30776),  INT16_C( 25427),
        -INT16_C( 30314),  INT16_C(  8690),  INT16_C( 28971), -INT16_C(  2718), -INT16_C( 24439), -INT16_C(  7454), -INT16_C(  1937),  INT16_C(  1944) },
      UINT32_C( 754223529),
      { -INT16_C( 32673), -INT16_C( 26753), -INT16_C( 11272), -INT16_C( 28934), -INT16_C(  5028), -INT16_C( 30801),  INT16_C(  4702), -INT16_C(  6275),
         INT16_C( 24498),  INT16_C(  8649),  INT16_C( 25175),  INT16_C(    40),  INT16_C(  7403),  INT16_C( 12844),  INT16_C(  1979),  INT16_C(  6970),
        -INT16_C( 17785),  INT16_C( 32690), -INT16_C( 21107), -INT16_C(  5875), -INT16_C( 16999), -INT16_C(  2192), -INT16_C(  4657), -INT16_C( 32289),
        -INT16_C( 22452), -INT16_C( 23646), -INT16_C( 13814), -INT16_C(  2653), -INT16_C( 12313), -INT16_C( 24024),  INT16_C( 25302),  INT16_C( 23997) },
      {  INT16_C( 28700), -INT16_C( 22052), -INT16_C(  5603), -INT16_C( 18798),  INT16_C(   935),  INT16_C( 30382), -INT16_C( 29200),  INT16_C( 15863),
        -INT16_C( 26315),  INT16_C( 16608), -INT16_C( 31645),  INT16_C( 18997),  INT16_C( 23891),  INT16_C( 10989), -INT16_C( 21824), -INT16_C(  9081),
         INT16_C( 25626),  INT16_C( 14214),  INT16_C(  6222), -INT16_C(  2578), -INT16_C( 25573),  INT16_C(  3179),  INT16_C( 25129),  INT16_C( 24137),
         INT16_C( 10747),  INT16_C( 24222), -INT16_C( 11091),  INT16_C(   425), -INT16_C( 27087), -INT16_C(  3797), -INT16_C( 19904),  INT16_C( 23502) },
      { -INT16_C( 32673),  INT16_C( 15003), -INT16_C( 11692), -INT16_C( 28934),  INT16_C(   556), -INT16_C( 30801),  INT16_C( 30647), -INT16_C(  6275),
        -INT16_C( 26315), -INT16_C( 28875), -INT16_C( 23926),  INT16_C(    40),  INT16_C(  6346), -INT16_C(  5059), -INT16_C( 12456), -INT16_C(  9081),
        -INT16_C( 20072), -INT16_C(  4880), -INT16_C( 21107), -INT16_C( 20565), -INT16_C( 25573), -INT16_C(  2192), -INT16_C(  4657), -INT16_C( 32289),
        -INT16_C( 30314),  INT16_C(  8690), -INT16_C( 13814), -INT16_C(  2653), -INT16_C( 24439), -INT16_C( 24024), -INT16_C(  1937),  INT16_C(  1944) } },
    { {  INT16_C( 21526),  INT16_C( 25746), -INT16_C( 32660), -INT16_C( 30631), -INT16_C( 15332),  INT16_C( 17812), -INT16_C(  8922),  INT16_C(  8612),
         INT16_C( 16902), -INT16_C( 19328),  INT16_C( 10518),  INT16_C( 18613), -INT16_C(  8001), -INT16_C(   199),  INT16_C(  1938), -INT16_C( 22182),
        -INT16_C(  4773), -INT16_C( 14323),  INT16_C( 26477), -INT16_C( 30128), -INT16_C(  7125),  INT16_C( 21199),  INT16_C( 29633), -INT16_C( 14477),
        -INT16_C(  3146), -INT16_C( 13189),  INT16_C( 12316), -INT16_C(  9452),  INT16_C( 19984), -INT16_C( 23589),  INT16_C( 13653), -INT16_C( 20148) },
      UINT32_C(2423871778),
      { -INT16_C(  5715),  INT16_C( 28222), -INT16_C( 20131),  INT16_C(  4917), -INT16_C( 20059), -INT16_C( 15905), -INT16_C(  2847), -INT16_C(  3427),
         INT16_C( 30786), -INT16_C( 26731), -INT16_C(  7763), -INT16_C( 12216), -INT16_C( 16070), -INT16_C(  1184),  INT16_C( 31370),  INT16_C( 14311),
         INT16_C(  9571), -INT16_C( 16219), -INT16_C(  9258),  INT16_C( 31699), -INT16_C( 19572),  INT16_C( 27965), -INT16_C(  9561), -INT16_C(  5793),
        -INT16_C(  2990), -INT16_C(   128), -INT16_C( 13867),  INT16_C(  4303),  INT16_C( 12170),  INT16_C(  5387), -INT16_C(  3415),  INT16_C(  3404) },
      { -INT16_C(  3561), -INT16_C(  4659), -INT16_C( 24115),  INT16_C( 22889), -INT16_C( 22956), -INT16_C(  1082),  INT16_C(  9856), -INT16_C( 11548),
         INT16_C( 25626), -INT16_C(  3887), -INT16_C( 24275), -INT16_C( 18432),  INT16_C(  3024),  INT16_C( 31437),  INT16_C(  6653),  INT16_C(  5255),
         INT16_C( 21515), -INT16_C( 10239),  INT16_C( 27381),  INT16_C( 18737), -INT16_C(  2032), -INT16_C( 28604),  INT16_C( 10270),  INT16_C( 14434),
         INT16_C( 13453), -INT16_C( 17880),  INT16_C( 10453), -INT16_C( 23182),  INT16_C( 16179),  INT16_C( 12319), -INT16_C( 22951),  INT16_C( 25668) },
      {  INT16_C( 21526), -INT16_C(  4659), -INT16_C( 32660), -INT16_C( 30631), -INT16_C( 15332), -INT16_C( 15905), -INT16_C(  8922),  INT16_C(  8612),
         INT16_C( 25626), -INT16_C( 19328),  INT16_C( 10518), -INT16_C( 18432), -INT16_C( 16070), -INT16_C(   199),  INT16_C(  6653), -INT16_C( 22182),
         INT16_C(  9571), -INT16_C( 14323),  INT16_C( 26477),  INT16_C( 18737), -INT16_C( 19572), -INT16_C( 28604), -INT16_C(  9561), -INT16_C( 14477),
        -INT16_C(  3146), -INT16_C( 13189),  INT16_C( 12316), -INT16_C(  9452),  INT16_C( 12170), -INT16_C( 23589),  INT16_C( 13653),  INT16_C(  3404) } },
    { {  INT16_C( 18171), -INT16_C(  4035),  INT16_C( 28336), -INT16_C( 16070),  INT16_C( 32358), -INT16_C( 31663), -INT16_C( 19289),  INT16_C( 13501),
        -INT16_C(  6680), -INT16_C( 16914),  INT16_C( 24846),  INT16_C( 16738), -INT16_C( 32096), -INT16_C(  1678), -INT16_C( 18904),  INT16_C(  9054),
        -INT16_C( 25604), -INT16_C( 21228),  INT16_C( 19977),  INT16_C( 28782), -INT16_C( 16436),  INT16_C( 29684), -INT16_C( 20109),  INT16_C( 23463),
        -INT16_C( 26985), -INT16_C( 23272),  INT16_C( 31735), -INT16_C( 26650),  INT16_C( 22781),  INT16_C(  9617), -INT16_C(  4337),  INT16_C(  2889) },
      UINT32_C(2478333322),
      { -INT16_C(  1818),  INT16_C( 23019), -INT16_C( 27991),  INT16_C( 16565), -INT16_C( 13016),  INT16_C(  8165), -INT16_C( 13240),  INT16_C( 17847),
         INT16_C( 18468),  INT16_C( 13163), -INT16_C( 19401), -INT16_C( 16065), -INT16_C(  2287), -INT16_C( 17324),  INT16_C( 22558),  INT16_C(  1075),
         INT16_C(  7760), -INT16_C(  1699),  INT16_C(  4785), -INT16_C(  9926),  INT16_C(  8160),  INT16_C( 10489), -INT16_C( 20245),  INT16_C(  4206),
        -INT16_C(  9736),  INT16_C( 12099), -INT16_C( 32115), -INT16_C( 24848),  INT16_C( 17530), -INT16_C( 26534), -INT16_C( 29284), -INT16_C(  4964) },
      { -INT16_C(  1620),  INT16_C( 24038),  INT16_C(  8204), -INT16_C(  5066),  INT16_C( 12095),  INT16_C( 11028), -INT16_C( 32033), -INT16_C( 10437),
         INT16_C( 32347), -INT16_C(  6138), -INT16_C(  2559),  INT16_C( 31622), -INT16_C(  8133), -INT16_C( 10477), -INT16_C( 20626),  INT16_C(  6852),
        -INT16_C( 21848), -INT16_C( 19337), -INT16_C( 21046),  INT16_C(  2464), -INT16_C( 18979), -INT16_C( 17356),  INT16_C( 28471), -INT16_C( 27756),
        -INT16_C( 25874), -INT16_C(  4229),  INT16_C(   657), -INT16_C( 13206),  INT16_C( 32226),  INT16_C( 20643),  INT16_C( 26412), -INT16_C( 11158) },
      {  INT16_C( 18171),  INT16_C( 23019),  INT16_C( 28336), -INT16_C(  5066),  INT16_C( 32358), -INT16_C( 31663), -INT16_C( 19289), -INT16_C( 10437),
         INT16_C( 18468), -INT16_C( 16914), -INT16_C( 19401), -INT16_C( 16065), -INT16_C(  8133), -INT16_C(  1678), -INT16_C( 20626),  INT16_C(  9054),
        -INT16_C( 25604), -INT16_C( 21228),  INT16_C( 19977), -INT16_C(  9926), -INT16_C( 18979), -INT16_C( 17356), -INT16_C( 20109), -INT16_C( 27756),
        -INT16_C( 25874), -INT16_C(  4229),  INT16_C( 31735), -INT16_C( 26650),  INT16_C( 17530),  INT16_C(  9617), -INT16_C(  4337), -INT16_C( 11158) } },
    { { -INT16_C(  7919), -INT16_C(  9335),  INT16_C( 10639),  INT16_C( 27877),  INT16_C(  6622),  INT16_C(  5672), -INT16_C( 17271),  INT16_C( 30633),
         INT16_C(  9303), -INT16_C(  6042), -INT16_C( 12250),  INT16_C(  2484),  INT16_C( 22349),  INT16_C( 31065), -INT16_C( 15169), -INT16_C( 12211),
        -INT16_C( 10587),  INT16_C( 13484), -INT16_C( 28416), -INT16_C(  8544), -INT16_C( 13910),  INT16_C( 13300), -INT16_C( 25211), -INT16_C(  9046),
         INT16_C(  4290), -INT16_C(  5948),  INT16_C( 30944),  INT16_C( 11761),  INT16_C( 19408), -INT16_C( 28762), -INT16_C(  3057), -INT16_C( 19361) },
      UINT32_C(3404270538),
      { -INT16_C( 25262), -INT16_C( 10118),  INT16_C(  9531), -INT16_C(   588),  INT16_C( 31029),  INT16_C(  5861), -INT16_C( 10255), -INT16_C( 16061),
        -INT16_C(  5598),  INT16_C( 12624), -INT16_C( 20258), -INT16_C( 22299), -INT16_C( 12613),  INT16_C( 22643),  INT16_C(  7256), -INT16_C( 21857),
         INT16_C(  6585), -INT16_C(  2942),  INT16_C( 14142),  INT16_C( 29937), -INT16_C( 10320), -INT16_C( 24182), -INT16_C( 12882), -INT16_C( 12189),
        -INT16_C( 19529), -INT16_C( 27391), -INT16_C(  6557),  INT16_C(  7998), -INT16_C( 20043),  INT16_C(  3447),  INT16_C(  5837), -INT16_C( 31049) },
      {  INT16_C( 14895),  INT16_C( 28283),  INT16_C( 27761),  INT16_C(  8674),  INT16_C( 27715), -INT16_C(  3646),  INT16_C(  9529), -INT16_C(  3647),
        -INT16_C( 15655),  INT16_C( 15494), -INT16_C( 15191),  INT16_C( 24155), -INT16_C( 11659),  INT16_C( 17003),  INT16_C(  8936),  INT16_C(  6345),
         INT16_C( 17500), -INT16_C( 12922),  INT16_C( 26800), -INT16_C(  2834), -INT16_C( 20012),  INT16_C(  3557), -INT16_C( 22570), -INT16_C( 20482),
        -INT16_C( 31383),  INT16_C(  4844),  INT16_C( 18249), -INT16_C( 16528), -INT16_C(  9446),  INT16_C(   513), -INT16_C( 13570),  INT16_C( 23066) },
      { -INT16_C(  7919), -INT16_C( 10118),  INT16_C( 10639), -INT16_C(   588),  INT16_C(  6622),  INT16_C(  5672), -INT16_C( 10255), -INT16_C( 16061),
        -INT16_C( 15655),  INT16_C( 12624), -INT16_C( 12250), -INT16_C( 22299),  INT16_C( 22349),  INT16_C( 31065), -INT16_C( 15169), -INT16_C( 12211),
         INT16_C(  6585),  INT16_C( 13484), -INT16_C( 28416), -INT16_C(  2834), -INT16_C( 13910), -INT16_C( 24182), -INT16_C( 22570), -INT16_C( 20482),
         INT16_C(  4290), -INT16_C( 27391),  INT16_C( 30944), -INT16_C( 16528),  INT16_C( 19408), -INT16_C( 28762), -INT16_C( 13570), -INT16_C( 31049) } },
    { { -INT16_C( 24562), -INT16_C( 16600),  INT16_C(  5640), -INT16_C(  9037), -INT16_C( 26425), -INT16_C( 24854), -INT16_C(  6081), -INT16_C( 22195),
         INT16_C( 14701), -INT16_C( 18501),  INT16_C( 11393), -INT16_C( 25738),  INT16_C( 30471),  INT16_C(  1437), -INT16_C( 18366),  INT16_C( 20576),
        -INT16_C( 30632),  INT16_C( 24847), -INT16_C( 15714),  INT16_C( 26173),  INT16_C( 10075), -INT16_C( 26108),  INT16_C( 20752),  INT16_C( 32067),
        -INT16_C(   117),  INT16_C(  3124), -INT16_C( 21973),  INT16_C( 12967),  INT16_C( 17442),  INT16_C( 25656), -INT16_C( 26372),  INT16_C( 21940) },
      UINT32_C(3199648800),
      {  INT16_C( 10267),  INT16_C( 11132), -INT16_C( 16518),  INT16_C(  1448), -INT16_C(  8770), -INT16_C(  5871), -INT16_C( 18297), -INT16_C( 22244),
         INT16_C( 21756), -INT16_C(  1779), -INT16_C( 15636),  INT16_C(  3150),  INT16_C(  1158),  INT16_C(  3274), -INT16_C(  4105),  INT16_C(  4846),
         INT16_C( 27159), -INT16_C( 28355), -INT16_C(  6615), -INT16_C(  5994), -INT16_C( 22589),  INT16_C( 19153), -INT16_C(  4769),  INT16_C( 23796),
         INT16_C(   321),  INT16_C( 11605), -INT16_C( 23613),  INT16_C( 18745),  INT16_C(  1191), -INT16_C( 25002),  INT16_C( 17651),  INT16_C(  2737) },
      { -INT16_C(  4434), -INT16_C( 10340),  INT16_C( 13012), -INT16_C( 26689), -INT16_C( 28198),  INT16_C( 14818), -INT16_C( 10626), -INT16_C( 16235),
        -INT16_C(  5417), -INT16_C( 25619),  INT16_C( 10125),  INT16_C( 13540),  INT16_C( 14891),  INT16_C(  7891), -INT16_C( 31618),  INT16_C( 11304),
        -INT16_C( 15246),  INT16_C( 18180), -INT16_C( 15369), -INT16_C( 11810), -INT16_C( 16300), -INT16_C( 11510), -INT16_C( 24426),  INT16_C( 28307),
        -INT16_C( 32630),  INT16_C(  6153), -INT16_C(  4697), -INT16_C( 11700),  INT16_C(  7976), -INT16_C( 22800),  INT16_C(  6563),  INT16_C(  5843) },
      { -INT16_C( 24562), -INT16_C( 16600),  INT16_C(  5640), -INT16_C(  9037), -INT16_C( 26425), -INT16_C(  5871), -INT16_C(  6081), -INT16_C( 22195),
         INT16_C( 14701), -INT16_C( 18501), -INT16_C( 15636), -INT16_C( 25738),  INT16_C( 30471),  INT16_C(  1437), -INT16_C( 31618),  INT16_C(  4846),
        -INT16_C( 30632), -INT16_C( 28355), -INT16_C( 15369),  INT16_C( 26173), -INT16_C( 22589), -INT16_C( 11510),  INT16_C( 20752),  INT16_C( 23796),
        -INT16_C(   117),  INT16_C(  6153), -INT16_C( 23613), -INT16_C( 11700),  INT16_C(  1191), -INT16_C( 25002), -INT16_C( 26372),  INT16_C(  2737) } },
    { { -INT16_C( 10275), -INT16_C( 11171),  INT16_C( 15258), -INT16_C(  4187), -INT16_C( 20228), -INT16_C( 27966),  INT16_C( 21840), -INT16_C(  9728),
         INT16_C(  2517),  INT16_C( 32242),  INT16_C( 16375),  INT16_C(  8015),  INT16_C( 16478),  INT16_C(   709), -INT16_C( 26535),  INT16_C( 13848),
         INT16_C( 30063),  INT16_C(  2571), -INT16_C( 20304), -INT16_C( 21255), -INT16_C( 17568), -INT16_C( 20417),  INT16_C( 16144), -INT16_C(  6773),
         INT16_C( 32073),  INT16_C( 16482), -INT16_C( 19780),  INT16_C(  7007),  INT16_C(  9458),  INT16_C( 19229),  INT16_C( 13757),  INT16_C( 11393) },
      UINT32_C(1513524394),
      {  INT16_C( 18154), -INT16_C(  1458), -INT16_C(  9851), -INT16_C( 12576),  INT16_C( 16982),  INT16_C(  4878),  INT16_C( 28148), -INT16_C(  6610),
         INT16_C( 19346),  INT16_C( 20273), -INT16_C( 19584),  INT16_C( 10875), -INT16_C( 19905),  INT16_C( 31876), -INT16_C( 29727), -INT16_C( 13286),
         INT16_C( 26833),  INT16_C( 22470), -INT16_C( 22975), -INT16_C( 26843),  INT16_C( 13545), -INT16_C(  8790), -INT16_C( 10079),  INT16_C( 13252),
        -INT16_C(  2781), -INT16_C( 23678), -INT16_C(   344), -INT16_C(  5939),  INT16_C( 21168), -INT16_C( 28316),  INT16_C( 32477), -INT16_C( 20643) },
      {  INT16_C(  9446),  INT16_C(  9990),  INT16_C( 11210), -INT16_C( 19521),  INT16_C( 26975),  INT16_C(   401),  INT16_C( 21826),  INT16_C( 25908),
        -INT16_C( 18614), -INT16_C(  3319), -INT16_C( 10571),  INT16_C( 26075),  INT16_C( 16168),  INT16_C(  1782),  INT16_C( 21694), -INT16_C( 23371),
        -INT16_C( 17544),  INT16_C( 17100), -INT16_C( 29722),  INT16_C( 18166), -INT16_C( 30732),  INT16_C( 13895),  INT16_C( 31708),  INT16_C(  9884),
        -INT16_C( 23246), -INT16_C(  6375), -INT16_C(  2949), -INT16_C( 23476),  INT16_C( 17204), -INT16_C(  3414),  INT16_C( 24471),  INT16_C(  3990) },
      { -INT16_C( 10275), -INT16_C(  1458),  INT16_C( 15258), -INT16_C( 19521), -INT16_C( 20228),  INT16_C(   401),  INT16_C( 21840), -INT16_C(  6610),
         INT16_C(  2517),  INT16_C( 32242), -INT16_C( 19584),  INT16_C( 10875),  INT16_C( 16478),  INT16_C(   709), -INT16_C( 26535), -INT16_C( 23371),
         INT16_C( 30063),  INT16_C( 17100), -INT16_C( 29722), -INT16_C( 21255), -INT16_C( 30732), -INT16_C(  8790),  INT16_C( 16144), -INT16_C(  6773),
         INT16_C( 32073), -INT16_C( 23678), -INT16_C( 19780), -INT16_C( 23476),  INT16_C( 17204),  INT16_C( 19229),  INT16_C( 24471),  INT16_C( 11393) } }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
    simde__m512i src = simde_mm512_loadu_epi16(test_vec[i].src);
    simde__m512i a = simde_mm512_loadu_epi16(test_vec[i].a);
    simde__m512i b = simde_mm512_loadu_epi16(test_vec[i].b);
    simde__m512i r = simde_mm512_mask_min_epi16(src, test_vec[i].k, a, b);
    simde_test_x86_assert_equal_i16x32(r, simde_mm512_loadu_epi16(test_vec[i].r));
  }

  return 0;
}

static int
test_simde_mm512_maskz_min_epi16 (SIMDE_MUNIT_TEST_ARGS) {
  static const struct {
    const simde__mmask32 k;
    const int16_t a[32];
    const int16_t b[32];
    const int16_t r[32];
  } test_vec[] = {
    { UINT32_C(2426184294),
      {  INT16_C( 31879),  INT16_C( 10074),  INT16_C(  3945),  INT16_C( 30364),  INT16_C(  4967), -INT16_C( 14898), -INT16_C( 23290), -INT16_C( 27628),
        -INT16_C( 28502),  INT16_C( 18211),  INT16_C( 31392),  INT16_C(  1793), -INT16_C( 25315), -INT16_C(  2409), -INT16_C( 26870), -INT16_C( 28355),
        -INT16_C( 26861),  INT16_C( 31928),  INT16_C( 21670),  INT16_C(  3570), -INT16_C( 16281),  INT16_C( 28114), -INT16_C(  6298),  INT16_C(  4098),
         INT16_C(  9591),  INT16_C(  6231),  INT16_C( 22943), -INT16_C( 17377), -INT16_C( 18698),  INT16_C(   178), -INT16_C(  4275),  INT16_C( 24721) },
      {  INT16_C( 18823),  INT16_C( 11740), -INT16_C( 12387),  INT16_C(  1083),  INT16_C(  3471), -INT16_C(  2702),  INT16_C( 29940),  INT16_C( 27653),
         INT16_C( 23961),  INT16_C( 14468), -INT16_C( 23626), -INT16_C( 21259), -INT16_C( 22695), -INT16_C( 22611),  INT16_C( 16023),  INT16_C(  7687),
        -INT16_C(  7032),  INT16_C(  9547), -INT16_C( 31053),  INT16_C( 16938), -INT16_C( 25452), -INT16_C( 30664),  INT16_C( 15632), -INT16_C( 22028),
         INT16_C( 30874),  INT16_C( 20705), -INT16_C( 10725),  INT16_C( 30205), -INT16_C( 21890),  INT16_C(  5404),  INT16_C(  9192),  INT16_C( 28723) },
      {  INT16_C(     0),  INT16_C( 10074), -INT16_C( 12387),  INT16_C(     0),  INT16_C(     0), -INT16_C( 14898), -INT16_C( 23290),  INT16_C(     0),
         INT16_C(     0),  INT16_C( 14468),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0), -INT16_C( 22611),  INT16_C(     0), -INT16_C( 28355),
         INT16_C(     0),  INT16_C(     0), -INT16_C( 31053),  INT16_C(  3570), -INT16_C( 25452),  INT16_C(     0),  INT16_C(     0), -INT16_C( 22028),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0), -INT16_C( 21890),  INT16_C(     0),  INT16_C(     0),  INT16_C( 24721) } },
    { UINT32_C(3130424839),
      {  INT16_C( 13660),  INT16_C( 27681),  INT16_C(  5746),  INT16_C(  3349), -INT16_C(  2418), -INT16_C( 21923),  INT16_C( 23245),  INT16_C( 19231),
         INT16_C( 15108), -INT16_C(  4768), -INT16_C( 27810),  INT16_C( 26205), -INT16_C(  3311),  INT16_C(  5664),  INT16_C(  7603),  INT16_C(  4015),
        -INT16_C( 11950), -INT16_C( 14981), -INT16_C( 28441),  INT16_C( 30162),  INT16_C( 12167),  INT16_C( 21535),  INT16_C( 16010), -INT16_C( 29025),
        -INT16_C(   135), -INT16_C( 10117), -INT16_C(  9838), -INT16_C( 23746),  INT16_C( 24268), -INT16_C( 32582),  INT16_C( 27004), -INT16_C( 12657) },
      {  INT16_C(  2874),  INT16_C(  8595),  INT16_C( 26011),  INT16_C(  8855), -INT16_C( 18795),  INT16_C(  8054),  INT16_C(  5621),  INT16_C( 28333),
         INT16_C( 10516), -INT16_C( 22970), -INT16_C( 31742), -INT16_C( 12726),  INT16_C(  1251),  INT16_C( 24398), -INT16_C(  8595), -INT16_C( 22483),
        -INT16_C( 15895), -INT16_C( 31543),  INT16_C( 24614), -INT16_C( 17497),  INT16_C(  7447),  INT16_C(  3290), -INT16_C( 30669),  INT16_C( 18298),
        -INT16_C( 15951), -INT16_C( 19474),  INT16_C( 14405),  INT16_C( 10369), -INT16_C( 12228), -INT16_C( 22137), -INT16_C( 19026), -INT16_C( 26799) },
      {  INT16_C(  2874),  INT16_C(  8595),  INT16_C(  5746),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0), -INT16_C( 22970), -INT16_C( 31742), -INT16_C( 12726), -INT16_C(  3311),  INT16_C(  5664), -INT16_C(  8595),  INT16_C(     0),
         INT16_C(     0), -INT16_C( 31543), -INT16_C( 28441),  INT16_C(     0),  INT16_C(  7447),  INT16_C(     0),  INT16_C(     0), -INT16_C( 29025),
         INT16_C(     0), -INT16_C( 19474),  INT16_C(     0), -INT16_C( 23746), -INT16_C( 12228), -INT16_C( 32582),  INT16_C(     0), -INT16_C( 26799) } },
    { UINT32_C(2619022198),
      {  INT16_C( 13024),  INT16_C(  5022),  INT16_C(  6586),  INT16_C( 27482),  INT16_C( 18650),  INT16_C(  7966), -INT16_C( 24448), -INT16_C( 17336),
        -INT16_C( 12432),  INT16_C(  7782), -INT16_C( 18556), -INT16_C(  1355), -INT16_C( 12078),  INT16_C( 20119), -INT16_C(  4205),  INT16_C( 29664),
         INT16_C( 32545), -INT16_C(  9082), -INT16_C(  8040),  INT16_C( 29255),  INT16_C( 26153), -INT16_C( 22127), -INT16_C(  9978),  INT16_C( 30310),
        -INT16_C( 13143),  INT16_C( 11668),  INT16_C( 18819),  INT16_C( 22056), -INT16_C( 16615), -INT16_C( 21340), -INT16_C( 31570), -INT16_C( 12513) },
      { -INT16_C( 23293), -INT16_C( 25685), -INT16_C(  3194), -INT16_C( 20723), -INT16_C( 24743),  INT16_C( 24408), -INT16_C( 16776),  INT16_C(  8661),
         INT16_C( 27018),  INT16_C(  3663),  INT16_C( 30642), -INT16_C( 13468),  INT16_C(  2102), -INT16_C(  7048), -INT16_C( 26740), -INT16_C( 28493),
         INT16_C( 24381), -INT16_C( 15573),  INT16_C( 14674), -INT16_C( 21646), -INT16_C( 13608),  INT16_C( 20490), -INT16_C(  8311),  INT16_C(  4978),
        -INT16_C( 16056), -INT16_C(  1503), -INT16_C( 31432),  INT16_C( 28357),  INT16_C( 15757),  INT16_C(  6738),  INT16_C(  1493),  INT16_C(  4778) },
      {  INT16_C(     0), -INT16_C( 25685), -INT16_C(  3194),  INT16_C(     0), -INT16_C( 24743),  INT16_C(  7966), -INT16_C( 24448),  INT16_C(     0),
        -INT16_C( 12432),  INT16_C(  3663),  INT16_C(     0), -INT16_C( 13468), -INT16_C( 12078),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C( 24381), -INT16_C( 15573),  INT16_C(     0), -INT16_C( 21646), -INT16_C( 13608),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0), -INT16_C( 31432),  INT16_C( 22056), -INT16_C( 16615),  INT16_C(     0),  INT16_C(     0), -INT16_C( 12513) } },
    { UINT32_C(3067467108),
      {  INT16_C( 27409), -INT16_C( 26057), -INT16_C( 22198), -INT16_C( 27986), -INT16_C( 12438), -INT16_C( 23924),  INT16_C( 21077), -INT16_C(  7664),
         INT16_C( 25231),  INT16_C( 25852), -INT16_C( 22937), -INT16_C( 13194),  INT16_C( 19324), -INT16_C( 30078), -INT16_C(  7022), -INT16_C( 23439),
        -INT16_C( 22449), -INT16_C( 26050), -INT16_C(  5039), -INT16_C( 17620), -INT16_C( 17988),  INT16_C(  4445),  INT16_C( 27915), -INT16_C( 25869),
        -INT16_C(  3889),  INT16_C( 14079),  INT16_C( 30102),  INT16_C(  4610), -INT16_C( 31295),  INT16_C( 21405),  INT16_C(  3689), -INT16_C( 18185) },
      {  INT16_C( 14006),  INT16_C(  1874),  INT16_C( 32546), -INT16_C(  8510),  INT16_C(  7992),  INT16_C( 17391), -INT16_C(  7284),  INT16_C( 23517),
        -INT16_C(  9005),  INT16_C( 27025), -INT16_C( 27566),  INT16_C(  4988),  INT16_C(  6425), -INT16_C( 32154),  INT16_C( 24103), -INT16_C(  8902),
        -INT16_C( 29292), -INT16_C( 18716), -INT16_C( 23028),  INT16_C( 17557), -INT16_C( 31547),  INT16_C( 20871),  INT16_C( 25703),  INT16_C( 15020),
         INT16_C( 15681), -INT16_C( 27740),  INT16_C(  8401), -INT16_C(  5466),  INT16_C(  3129),  INT16_C( 24684), -INT16_C( 22678), -INT16_C(   451) },
      {  INT16_C(     0),  INT16_C(     0), -INT16_C( 22198),  INT16_C(     0),  INT16_C(     0), -INT16_C( 23924), -INT16_C(  7284),  INT16_C(     0),
        -INT16_C(  9005),  INT16_C(     0), -INT16_C( 27566),  INT16_C(     0),  INT16_C(  6425),  INT16_C(     0), -INT16_C(  7022), -INT16_C( 23439),
        -INT16_C( 29292),  INT16_C(     0), -INT16_C( 23028),  INT16_C(     0), -INT16_C( 31547),  INT16_C(     0),  INT16_C( 25703), -INT16_C( 25869),
         INT16_C(     0), -INT16_C( 27740),  INT16_C(  8401),  INT16_C(     0), -INT16_C( 31295),  INT16_C( 21405),  INT16_C(     0), -INT16_C( 18185) } },
    { UINT32_C(1085612340),
      {  INT16_C(  3022),  INT16_C( 14045), -INT16_C( 30353), -INT16_C( 20368),  INT16_C(  5318), -INT16_C( 26557), -INT16_C(  5836),  INT16_C( 28034),
        -INT16_C(  4106),  INT16_C( 24781),  INT16_C(  2710), -INT16_C( 13729),  INT16_C(  5163), -INT16_C(  3574), -INT16_C( 29090),  INT16_C( 11390),
         INT16_C( 23449),  INT16_C(  2146), -INT16_C( 11292), -INT16_C( 21575), -INT16_C(   793),  INT16_C(  7235), -INT16_C( 14874), -INT16_C(  9079),
         INT16_C( 22452),  INT16_C( 19004), -INT16_C( 25759), -INT16_C( 29420),  INT16_C(  7855),  INT16_C(  3455), -INT16_C(   340),  INT16_C( 17722) },
      { -INT16_C( 25511),  INT16_C( 15950),  INT16_C(  1903),  INT16_C( 22505),  INT16_C( 11267), -INT16_C(  5773), -INT16_C(   783), -INT16_C( 22843),
         INT16_C(   595), -INT16_C( 18960),  INT16_C(  1437),  INT16_C( 19778), -INT16_C( 16093), -INT16_C( 12198), -INT16_C( 27457),  INT16_C(  6421),
         INT16_C( 25393), -INT16_C( 24489),  INT16_C( 16490),  INT16_C( 28407),  INT16_C( 27244),  INT16_C( 23895),  INT16_C(  7527), -INT16_C( 17917),
        -INT16_C(  3041), -INT16_C( 17297), -INT16_C( 19975),  INT16_C(  7177),  INT16_C( 25715),  INT16_C( 13036),  INT16_C(   760),  INT16_C( 10571) },
      {  INT16_C(     0),  INT16_C(     0), -INT16_C( 30353),  INT16_C(     0),  INT16_C(  5318), -INT16_C( 26557),  INT16_C(     0),  INT16_C(     0),
        -INT16_C(  4106),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0), -INT16_C( 12198),  INT16_C(     0),  INT16_C(     0),
         INT16_C( 23449),  INT16_C(     0), -INT16_C( 11292),  INT16_C(     0), -INT16_C(   793),  INT16_C(  7235),  INT16_C(     0), -INT16_C( 17917),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0), -INT16_C(   340),  INT16_C(     0) } },
    { UINT32_C(3502940773),
      { -INT16_C( 27348), -INT16_C( 27732), -INT16_C( 20558), -INT16_C( 11955), -INT16_C( 16989), -INT16_C( 25458), -INT16_C( 26770), -INT16_C(  7751),
        -INT16_C( 23045), -INT16_C(  3052),  INT16_C( 24487),  INT16_C(  3357), -INT16_C(  6398), -INT16_C(  6947),  INT16_C(  7081), -INT16_C( 10957),
        -INT16_C(  8272),  INT16_C( 25448), -INT16_C( 19058),  INT16_C( 12852), -INT16_C( 15758), -INT16_C(  7730), -INT16_C( 30886),  INT16_C( 21954),
        -INT16_C( 10707), -INT16_C( 11191),  INT16_C( 26422),  INT16_C( 14561), -INT16_C( 16818), -INT16_C(  2276),  INT16_C( 20441), -INT16_C( 30004) },
      {  INT16_C( 13358), -INT16_C( 16915),  INT16_C(  8682),  INT16_C( 23791), -INT16_C( 16924),  INT16_C( 15933),  INT16_C(    69),  INT16_C( 29331),
        -INT16_C(  8746),  INT16_C(  3142),  INT16_C( 10308), -INT16_C( 28092),  INT16_C( 25062), -INT16_C( 16246),  INT16_C( 22192), -INT16_C(  8374),
         INT16_C( 14219),  INT16_C( 30108), -INT16_C( 29864),  INT16_C( 15569),  INT16_C(  3912), -INT16_C( 29318),  INT16_C(  3599), -INT16_C(  6657),
         INT16_C( 18155),  INT16_C( 12274),  INT16_C( 13934),  INT16_C( 21697),  INT16_C( 19351),  INT16_C( 18452),  INT16_C( 24226),  INT16_C( 11559) },
      { -INT16_C( 27348),  INT16_C(     0), -INT16_C( 20558),  INT16_C(     0),  INT16_C(     0), -INT16_C( 25458), -INT16_C( 26770),  INT16_C(     0),
         INT16_C(     0), -INT16_C(  3052),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0), -INT16_C( 16246),  INT16_C(     0), -INT16_C( 10957),
         INT16_C(     0),  INT16_C( 25448),  INT16_C(     0),  INT16_C( 12852),  INT16_C(     0),  INT16_C(     0), -INT16_C( 30886), -INT16_C(  6657),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0), -INT16_C( 16818),  INT16_C(     0),  INT16_C( 20441), -INT16_C( 30004) } },
    { UINT32_C(4003644309),
      { -INT16_C( 23166), -INT16_C( 28380),  INT16_C(  9139), -INT16_C( 24969),  INT16_C( 26985), -INT16_C( 10291), -INT16_C( 29025),  INT16_C( 14124),
         INT16_C( 16602),  INT16_C( 31871), -INT16_C( 22881),  INT16_C( 13481),  INT16_C( 19305), -INT16_C( 18654),  INT16_C( 19902),  INT16_C( 16717),
         INT16_C( 29170), -INT16_C( 23086),  INT16_C( 18837), -INT16_C(   445),  INT16_C(  4274),  INT16_C( 21206),  INT16_C(   670),  INT16_C( 30857),
         INT16_C(  2114), -INT16_C(  7692), -INT16_C( 25170),  INT16_C(  5910),  INT16_C( 14568), -INT16_C( 22578),  INT16_C(  7045),  INT16_C( 30696) },
      { -INT16_C( 17779),  INT16_C(  8732),  INT16_C( 24324), -INT16_C( 18912), -INT16_C(  2449),  INT16_C(  3592), -INT16_C( 28168),  INT16_C( 15238),
         INT16_C( 31641),  INT16_C( 18204),  INT16_C( 12824),  INT16_C(   350),  INT16_C( 11371), -INT16_C(  3928), -INT16_C( 28600), -INT16_C( 10904),
        -INT16_C( 31670),  INT16_C( 20215),  INT16_C(  6116),  INT16_C( 21253),  INT16_C(  3342),  INT16_C(  1633), -INT16_C(  5985),  INT16_C( 14401),
         INT16_C( 24163),  INT16_C( 31616), -INT16_C(  8560), -INT16_C(  1156),  INT16_C(  9227),  INT16_C( 21484),  INT16_C( 21684), -INT16_C(   216) },
      { -INT16_C( 23166),  INT16_C(     0),  INT16_C(  9139),  INT16_C(     0), -INT16_C(  2449),  INT16_C(     0),  INT16_C(     0),  INT16_C( 14124),
         INT16_C( 16602),  INT16_C( 18204),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0), -INT16_C( 28600), -INT16_C( 10904),
         INT16_C(     0), -INT16_C( 23086),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(  1633),  INT16_C(     0),  INT16_C( 14401),
         INT16_C(     0), -INT16_C(  7692), -INT16_C( 25170), -INT16_C(  1156),  INT16_C(     0), -INT16_C( 22578),  INT16_C(  7045), -INT16_C(   216) } },
    { UINT32_C(3159171032),
      {  INT16_C( 29024), -INT16_C(   181), -INT16_C( 29607), -INT16_C( 17353), -INT16_C( 18454),  INT16_C( 31544), -INT16_C( 19306), -INT16_C( 24202),
         INT16_C( 25305), -INT16_C( 29196),  INT16_C(  7350), -INT16_C( 28788), -INT16_C(  9669),  INT16_C( 29003),  INT16_C( 23340), -INT16_C( 29514),
         INT16_C(   461),  INT16_C(  9867), -INT16_C( 15475),  INT16_C( 30947),  INT16_C(  7034),  INT16_C(  4339),  INT16_C( 27087), -INT16_C( 22351),
        -INT16_C( 23092), -INT16_C( 32202), -INT16_C( 15679), -INT16_C(  1007),  INT16_C( 23964), -INT16_C( 13970),  INT16_C(  9400), -INT16_C( 31403) },
      { -INT16_C(  7899), -INT16_C( 19796), -INT16_C( 28764),  INT16_C(  7722),  INT16_C(  7594),  INT16_C( 31023), -INT16_C(  8057),  INT16_C( 21282),
         INT16_C( 22662),  INT16_C( 18389), -INT16_C(  6374), -INT16_C( 18620), -INT16_C( 19900), -INT16_C(   896), -INT16_C( 10794), -INT16_C(  1150),
         INT16_C( 11958),  INT16_C( 23213), -INT16_C( 10051),  INT16_C( 26489), -INT16_C( 22283),  INT16_C( 31968),  INT16_C(   648),  INT16_C(  3791),
        -INT16_C( 23206),  INT16_C( 30038), -INT16_C( 25972), -INT16_C( 12244), -INT16_C( 21428),  INT16_C(  8908),  INT16_C( 20097),  INT16_C( 14365) },
      {  INT16_C(     0),  INT16_C(     0),  INT16_C(     0), -INT16_C( 17353), -INT16_C( 18454),  INT16_C(     0), -INT16_C( 19306), -INT16_C( 24202),
         INT16_C( 22662), -INT16_C( 29196), -INT16_C(  6374), -INT16_C( 28788), -INT16_C( 19900),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C(   461),  INT16_C(     0), -INT16_C( 15475),  INT16_C( 26489),  INT16_C(     0),  INT16_C(     0),  INT16_C(   648),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0), -INT16_C( 25972), -INT16_C( 12244), -INT16_C( 21428), -INT16_C( 13970),  INT16_C(     0), -INT16_C( 31403) } }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
    simde__m512i a = simde_mm512_loadu_epi16(test_vec[i].a);
    simde__m512i b = simde_mm512_loadu_epi16(test_vec[i].b);
    simde__m512i r = simde_mm512_maskz_min_epi16(test_vec[i].k, a, b);
    simde_test_x86_assert_equal_i16x32(r, simde_mm512_loadu_epi16(test_vec[i].r));
  }

  return 0;
}

static int
test_simde_mm512_min_epu16 (SIMDE_MUNIT_TEST_ARGS) {
  static const struct {
    const uint16_t a[32];
    const uint16_t b[32];
    const uint16_t r[32];
  } test_vec[] = {
    { { UINT16_C( 1431), UINT16_C(60088), UINT16_C(59670), UINT16_C(46197), UINT16_C(28207), UINT16_C(42628), UINT16_C(38831), UINT16_C( 7804),
        UINT16_C(27384), UINT16_C(63519), UINT16_C(45488), UINT16_C(32855), UINT16_C(60315), UINT16_C(36942), UINT16_C(33367), UINT16_C(61079),
        UINT16_C(20616), UINT16_C(40664), UINT16_C(19769), UINT16_C(26706), UINT16_C(54972), UINT16_C(27406), UINT16_C(35693), UINT16_C(25993),
        UINT16_C(43253), UINT16_C(42333), UINT16_C(46425), UINT16_C(62502), UINT16_C(29856), UINT16_C(63365), UINT16_C( 7415), UINT16_C(32741) },
      { UINT16_C(48748), UINT16_C(42525), UINT16_C(28427), UINT16_C(50958), UINT16_C( 7494), UINT16_C(45875), UINT16_C(48296), UINT16_C(40217),
        UINT16_C(30309), UINT16_C(48706), UINT16_C(26667), UINT16_C(52403), UINT16_C(14557), UINT16_C(54467), UINT16_C(43348), UINT16_C(49491),
        UINT16_C(28775), UINT16_C(29287), UINT16_C(30175), UINT16_C( 9530), UINT16_C(28050), UINT16_C(15065), UINT16_C(61993), UINT16_C(36567),
        UINT16_C( 6760), UINT16_C(37965), UINT16_C(  130), UINT16_C(24416), UINT16_C( 9016), UINT16_C(35891), UINT16_C(34508), UINT16_C(13133) },
      { UINT16_C( 1431), UINT16_C(42525), UINT16_C(28427), UINT16_C(46197), UINT16_C( 7494), UINT16_C(42628), UINT16_C(38831), UINT16_C( 7804),
        UINT16_C(27384), UINT16_C(48706), UINT16_C(26667), UINT16_C(32855), UINT16_C(14557), UINT16_C(36942), UINT16_C(33367), UINT16_C(49491),
        UINT16_C(20616), UINT16_C(29287), UINT16_C(19769), UINT16_C( 9530), UINT16_C(28050), UINT16_C(15065), UINT16_C(35693), UINT16_C(25993),
        UINT16_C( 6760), UINT16_C(37965), UINT16_C(  130), UINT16_C(24416), UINT16_C( 9016), UINT16_C(35891), UINT16_C( 7415), UINT16_C(13133) } },
    { { UINT16_C(46326), UINT16_C(54950), UINT16_C(57386), UINT16_C(48379), UINT16_C(54349), UINT16_C(30455), UINT16_C(52934), UINT16_C(12037),
        UINT16_C(21224), UINT16_C(27587), UINT16_C( 9042), UINT16_C(35530), UINT16_C(65094), UINT16_C( 4886), UINT16_C(25732), UINT16_C(31558),
        UINT16_C(60440), UINT16_C(16977), UINT16_C(19660), UINT16_C( 6655), UINT16_C(63009), UINT16_C(59280), UINT16_C(38340), UINT16_C(44310),
        UINT16_C(55783), UINT16_C(14616), UINT16_C(58108), UINT16_C(17347), UINT16_C(55776), UINT16_C(25942), UINT16_C(39997), UINT16_C(22240) },
      { UINT16_C(12681), UINT16_C(21912), UINT16_C(38781), UINT16_C(40559), UINT16_C(65421), UINT16_C(21126), UINT16_C(40084), UINT16_C(31743),
        UINT16_C( 6006), UINT16_C(29364), UINT16_C(30713), UINT16_C(55989), UINT16_C( 2896), UINT16_C(36415), UINT16_C( 8104), UINT16_C(12772),
        UINT16_C(31824), UINT16_C(52614), UINT16_C(62740), UINT16_C(41324), UINT16_C(62196), UINT16_C(35059), UINT16_C(62094), UINT16_C( 1027),
        UINT16_C(46857), UINT16_C(  887), UINT16_C(11310), UINT16_C(32733), UINT16_C( 7224), UINT16_C(57357), UINT16_C(61755), UINT16_C(35601) },
      { UINT16_C(12681), UINT16_C(21912), UINT16_C(38781), UINT16_C(40559), UINT16_C(54349), UINT16_C(21126), UINT16_C(40084), UINT16_C(12037),
        UINT16_C( 6006), UINT16_C(27587), UINT16_C( 9042), UINT16_C(35530), UINT16_C( 2896), UINT16_C( 4886), UINT16_C( 8104), UINT16_C(12772),
        UINT16_C(31824), UINT16_C(16977), UINT16_C(19660), UINT16_C( 6655), UINT16_C(62196), UINT16_C(35059), UINT16_C(38340), UINT16_C( 1027),
        UINT16_C(46857), UINT16_C(  887), UINT16_C(11310), UINT16_C(17347), UINT16_C( 7224), UINT16_C(25942), UINT16_C(39997), UINT16_C(22240) } },
    { { UINT16_C(38765), UINT16_C(33112), UINT16_C(50317), UINT16_C(33059), UINT16_C( 5814), UINT16_C(17674), UINT16_C( 3337), UINT16_C( 4681),
        UINT16_C(49349), UINT16_C(62229), UINT16_C(62189), UINT16_C( 9586), UINT16_C(32526), UINT16_C(18693), UINT16_C( 5744), UINT16_C(57044),
        UINT16_C(11693), UINT16_C(14943), UINT16_C(33521), UINT16_C(43196), UINT16_C(50841), UINT16_C(41709), UINT16_C(14035), UINT16_C(39092),
        UINT16_C(51959), UINT16_C(58508), UINT16_C(65212), UINT16_C(51977), UINT16_C( 3710), UINT16_C(60948), UINT16_C(59684), UINT16_C(53708) },
      { UINT16_C(11286), UINT16_C( 1804), UINT16_C(51374), UINT16_C(18351), UINT16_C(40078), UINT16_C(25065), UINT16_C(40659), UINT16_C(51962),
        UINT16_C(34408), UINT16_C( 9390), UINT16_C(46980), UINT16_C(  751), UINT16_C( 1221), UINT16_C(59889), UINT16_C(48621), UINT16_C(  954),
        UINT16_C(50921), UINT16_C(38922), UINT16_C(47758), UINT16_C( 7391), UINT16_C(51542), UINT16_C(10622), UINT16_C(30823), UINT16_C(53235),
        UINT16_C(41470), UINT16_C(33523), UINT16_C(58200), UINT16_C( 7557), UINT16_C(30439), UINT16_C(54278), UINT16_C(49459), UINT16_C( 7639) },
      { UINT16_C(11286), UINT16_C( 1804), UINT16_C(50317), UINT16_C(18351), UINT16_C( 5814), UINT16_C(17674), UINT16_C( 3337), UINT16_C( 4681),
        UINT16_C(34408), UINT16_C( 9390), UINT16_C(46980), UINT16_C(  751), UINT16_C( 1221), UINT16_C(18693), UINT16_C( 5744), UINT16_C(  954),
        UINT16_C(11693), UINT16_C(14943), UINT16_C(33521), UINT16_C( 7391), UINT16_C(50841), UINT16_C(10622), UINT16_C(14035), UINT16_C(39092),
        UINT16_C(41470), UINT16_C(33523), UINT16_C(58200), UINT16_C( 7557), UINT16_C( 3710), UINT16_C(54278), UINT16_C(49459), UINT16_C( 7639) } },
    { { UINT16_C(57735), UINT16_C( 5813), UINT16_C(38043), UINT16_C(62002), UINT16_C(45149), UINT16_C(50203), UINT16_C( 3880), UINT16_C( 9875),
        UINT16_C(34736), UINT16_C( 2473), UINT16_C(11882), UINT16_C(20774), UINT16_C(11684), UINT16_C(55077), UINT16_C(64750), UINT16_C(30196),
        UINT16_C(43485), UINT16_C(31115), UINT16_C(48702), UINT16_C(39787), UINT16_C(34414), UINT16_C(38752), UINT16_C(62357), UINT16_C(18109),
        UINT16_C(26234), UINT16_C(58447), UINT16_C(30100), UINT16_C(14389), UINT16_C(23202), UINT16_C(36880), UINT16_C( 1110), UINT16_C(13318) },
      { UINT16_C(37294), UINT16_C(60589), UINT16_C( 6223), UINT16_C(48775), UINT16_C(59294), UINT16_C(13397), UINT16_C( 4827), UINT16_C(21882),
        UINT16_C(51577), UINT16_C( 3386), UINT16_C(28478), UINT16_C(57670), UINT16_C(22218), UINT16_C( 8305), UINT16_C(30554), UINT16_C( 2132),
        UINT16_C(  265), UINT16_C(22772), UINT16_C(31769), UINT16_C(47126), UINT16_C(27491), UINT16_C(16108), UINT16_C(26238), UINT16_C(63380),
        UINT16_C(52783), UINT16_C(27908), UINT16_C(19005), UINT16_C( 1870), UINT16_C(49312), UINT16_C(64296), UINT16_C(31799), UINT16_C(16387) },
      { UINT16_C(37294), UINT16_C( 5813), UINT16_C( 6223), UINT16_C(48775), UINT16_C(45149), UINT16_C(13397), UINT16_C( 3880), UINT16_C( 9875),
        UINT16_C(34736), UINT16_C( 2473), UINT16_C(11882), UINT16_C(20774), UINT16_C(11684), UINT16_C( 8305), UINT16_C(30554), UINT16_C( 2132),
        UINT16_C(  265), UINT16_C(22772), UINT16_C(31769), UINT16_C(39787), UINT16_C(27491), UINT16_C(16108), UINT16_C(26238), UINT16_C(18109),
        UINT16_C(26234), UINT16_C(27908), UINT16_C(19005), UINT16_C( 1870), UINT16_C(23202), UINT16_C(36880), UINT16_C( 1110), UINT16_C(13318) } },
    { { UINT16_C(63614), UINT16_C(38809), UINT16_C(44916), UINT16_C(55119), UINT16_C(15131), UINT16_C(39190), UINT16_C(43681), UINT16_C(53392),
        UINT16_C(38008), UINT16_C(46398), UINT16_C(36063), UINT16_C(32701), UINT16_C(58700), UINT16_C(33914), UINT16_C(32353), UINT16_C(57284),
        UINT16_C(23926), UINT16_C(60023), UINT16_C(50701), UINT16_C(10433), UINT16_C(55042), UINT16_C(41921), UINT16_C(20865), UINT16_C(63860),
        UINT16_C(45797), UINT16_C(50351), UINT16_C(27710), UINT16_C(35652), UINT16_C(48721), UINT16_C(45583), UINT16_C(54076), UINT16_C(45714) },
      { UINT16_C( 2353), UINT16_C(16028), UINT16_C(24271), UINT16_C(53606), UINT16_C(10037), UINT16_C(46965), UINT16_C(59768), UINT16_C(23984),
        UINT16_C(24475), UINT16_C(55586), UINT16_C(26315), UINT16_C( 7268), UINT16_C(29476), UINT16_C(25039), UINT16_C(24903), UINT16_C(30739),
        UINT16_C(45162), UINT16_C(14774), UINT16_C( 7182), UINT16_C(17163), UINT16_C(32835), UINT16_C(48122), UINT16_C(43881), UINT16_C( 1048),
        UINT16_C(14858), UINT16_C(55005), UINT16_C(17056), UINT16_C(50674), UINT16_C(49589), UINT16_C(64550), UINT16_C(14626), UINT16_C(35956) },
      { UINT16_C( 2353), UINT16_C(16028), UINT16_C(24271), UINT16_C(53606), UINT16_C(10037), UINT16_C(39190), UINT16_C(43681), UINT16_C(23984),
        UINT16_C(24475), UINT16_C(46398), UINT16_C(26315), UINT16_C( 7268), UINT16_C(29476), UINT16_C(25039), UINT16_C(24903), UINT16_C(30739),
        UINT16_C(23926), UINT16_C(14774), UINT16_C( 7182), UINT16_C(10433), UINT16_C(32835), UINT16_C(41921), UINT16_C(20865), UINT16_C( 1048),
        UINT16_C(14858), UINT16_C(50351), UINT16_C(17056), UINT16_C(35652), UINT16_C(48721), UINT16_C(45583), UINT16_C(14626), UINT16_C(35956) } },
    { { UINT16_C(10985), UINT16_C(63430), UINT16_C(53574), UINT16_C(35131), UINT16_C(13649), UINT16_C(47684), UINT16_C(24032), UINT16_C(60350),
        UINT16_C(39831), UINT16_C(14529), UINT16_C(46045), UINT16_C(37885), UINT16_C( 9077), UINT16_C(38799), UINT16_C( 1116), UINT16_C(17956),
        UINT16_C(59950), UINT16_C(30013), UINT16_C(30907), UINT16_C( 3326), UINT16_C(17326), UINT16_C(36550), UINT16_C(33952), UINT16_C(14201),
        UINT16_C(14879), UINT16_C(64879), UINT16_C(27886), UINT16_C(25488), UINT16_C( 8079), UINT16_C(60666), UINT16_C( 7715), UINT16_C(21042) },
      { UINT16_C(28424), UINT16_C(50119), UINT16_C(50664), UINT16_C(38607), UINT16_C(38152), UINT16_C(43044), UINT16_C(40473), UINT16_C(14816),
        UINT16_C(20440), UINT16_C(50742), UINT16_C(50876), UINT16_C(19241), UINT16_C( 9445), UINT16_C( 2359), UINT16_C(26946), UINT16_C(19291),
        UINT16_C( 8921), UINT16_C(49422), UINT16_C(57063), UINT16_C(61527), UINT16_C(31603), UINT16_C(36248), UINT16_C(30745), UINT16_C(62150),
        UINT16_C(64712), UINT16_C(33976), UINT16_C(58050), UINT16_C(42959), UINT16_C( 1798), UINT16_C(18608), UINT16_C( 2928), UINT16_C(18835) },
      { UINT16_C(10985), UINT16_C(50119), UINT16_C(50664), UINT16_C(35131), UINT16_C(13649), UINT16_C(43044), UINT16_C(24032), UINT16_C(14816),
        UINT16_C(20440), UINT16_C(14529), UINT16_C(46045), UINT16_C(19241), UINT16_C( 9077), UINT16_C( 2359), UINT16_C( 1116), UINT16_C(17956),
        UINT16_C( 8921), UINT16_C(30013), UINT16_C(30907), UINT16_C( 3326), UINT16_C(17326), UINT16_C(36248), UINT16_C(30745), UINT16_C(14201),
        UINT16_C(14879), UINT16_C(33976), UINT16_C(27886), UINT16_C(25488), UINT16_C( 1798), UINT16_C(18608), UINT16_C( 2928), UINT16_C(18835) } },
    { { UINT16_C(41517), UINT16_C( 5386), UINT16_C(24960), UINT16_C(62213), UINT16_C(40413), UINT16_C(63104), UINT16_C(17942), UINT16_C(57064),
        UINT16_C(41282), UINT16_C( 1122), UINT16_C(12675), UINT16_C(35244), UINT16_C(23608), UINT16_C(43473), UINT16_C(25960), UINT16_C(38386),
        UINT16_C(64775), UINT16_C(34730), UINT16_C(44894), UINT16_C(15226), UINT16_C(64333), UINT16_C(25394), UINT16_C( 6721), UINT16_C(33857),
        UINT16_C(41915), UINT16_C(16008), UINT16_C(13524), UINT16_C( 3527), UINT16_C(39313), UINT16_C(63926), UINT16_C(43262), UINT16_C( 1422) },
      { UINT16_C(14757), UINT16_C( 1164), UINT16_C( 1768), UINT16_C(13631), UINT16_C(28929), UINT16_C(17304), UINT16_C(55692), UINT16_C(18375),
        UINT16_C(20348), UINT16_C(20870), UINT16_C(19844), UINT16_C( 5470), UINT16_C( 5350), UINT16_C(58382), UINT16_C(40124), UINT16_C(25321),
        UINT16_C(30165), UINT16_C(48742), UINT16_C(42364), UINT16_C(32243), UINT16_C(35863), UINT16_C(41920), UINT16_C(34661), UINT16_C(58090),
        UINT16_C(28887), UINT16_C(23347), UINT16_C(37310), UINT16_C(42096), UINT16_C(32421), UINT16_C(24969), UINT16_C(29210), UINT16_C(61635) },
      { UINT16_C(14757), UINT16_C( 1164), UINT16_C( 1768), UINT16_C(13631), UINT16_C(28929), UINT16_C(17304), UINT16_C(17942), UINT16_C(18375),
        UINT16_C(20348), UINT16_C( 1122), UINT16_C(12675), UINT16_C( 5470), UINT16_C( 5350), UINT16_C(43473), UINT16_C(25960), UINT16_C(25321),
        UINT16_C(30165), UINT16_C(34730), UINT16_C(42364), UINT16_C(15226), UINT16_C(35863), UINT16_C(25394), UINT16_C( 6721), UINT16_C(33857),
        UINT16_C(28887), UINT16_C(16008), UINT16_C(13524), UINT16_C( 3527), UINT16_C(32421), UINT16_C(24969), UINT16_C(29210), UINT16_C( 1422) } },
    { { UINT16_C(10728), UINT16_C(25774), UINT16_C(41423), UINT16_C(59105), UINT16_C(41517), UINT16_C(37769), UINT16_C(29481), UINT16_C(  117),
        UINT16_C(43236), UINT16_C(41563), UINT16_C(52025), UINT16_C(56902), UINT16_C(53065), UINT16_C(25663), UINT16_C(  834), UINT16_C(10836),
        UINT16_C(  556), UINT16_C(64398), UINT16_C(28579), UINT16_C(53729), UINT16_C(27153), UINT16_C(15204), UINT16_C(55774), UINT16_C(49723),
        UINT16_C(38785), UINT16_C(47716), UINT16_C(43618), UINT16_C(44184), UINT16_C(55162), UINT16_C(48144), UINT16_C(25818), UINT16_C( 2022) },
      { UINT16_C(29798), UINT16_C( 2306), UINT16_C(58595), UINT16_C(62938), UINT16_C(15950), UINT16_C(11312), UINT16_C(27415), UINT16_C(39150),
        UINT16_C(20994), UINT16_C(25938), UINT16_C(60157), UINT16_C(30481), UINT16_C( 8642), UINT16_C(39987), UINT16_C( 6533), UINT16_C(60323),
        UINT16_C(42637), UINT16_C(28916), UINT16_C(53130), UINT16_C(55397), UINT16_C(38157), UINT16_C( 9477), UINT16_C(62209), UINT16_C(  957),
        UINT16_C( 4166), UINT16_C(17256), UINT16_C(31226), UINT16_C(48314), UINT16_C(60826), UINT16_C( 8025), UINT16_C(64518), UINT16_C(37642) },
      { UINT16_C(10728), UINT16_C( 2306), UINT16_C(41423), UINT16_C(59105), UINT16_C(15950), UINT16_C(11312), UINT16_C(27415), UINT16_C(  117),
        UINT16_C(20994), UINT16_C(25938), UINT16_C(52025), UINT16_C(30481), UINT16_C( 8642), UINT16_C(25663), UINT16_C(  834), UINT16_C(10836),
        UINT16_C(  556), UINT16_C(28916), UINT16_C(28579), UINT16_C(53729), UINT16_C(27153), UINT16_C( 9477), UINT16_C(55774), UINT16_C(  957),
        UINT16_C( 4166), UINT16_C(17256), UINT16_C(31226), UINT16_C(44184), UINT16_C(55162), UINT16_C( 8025), UINT16_C(25818), UINT16_C( 2022) } }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
    simde__m512i a = simde_mm512_loadu_epi16(test_vec[i].a);
    simde__m512i b = simde_mm512_loadu_epi16(test_vec[i].b);
    simde__m512i r = simde_mm512_min_epu16(a, b);
    simde_test_x86_assert_equal_u16x32(r, simde_mm512_loadu_epi16(test_vec[i].r));
  }

  return 0;
}

static int
test_simde_mm512_mask_min_epu16 (SIMDE_MUNIT_TEST_ARGS) {
  static const struct {
    const int16_t src[32];
    const simde__mmask32 k;
    const uint16_t a[32];
    const uint16_t b[32];
    const uint16_t r[32];
  } test_vec[] = {
    { { -INT16_C(  3079),  INT16_C(  8612), -INT16_C( 25643),  INT16_C( 29615), -INT16_C( 23644),  INT16_C( 18229),  INT16_C( 13600),  INT16_C( 16573),
         INT16_C( 11343),  INT16_C( 21901), -INT16_C( 11893), -INT16_C(  6952), -INT16_C( 26016),  INT16_C( 21084),  INT16_C(  1957), -INT16_C( 25055),
        -INT16_C( 14854), -INT16_C( 12097),  INT16_C( 28256),  INT16_C(  1347),  INT16_C( 30737),  INT16_C( 12620),  INT16_C(  2734), -INT16_C(   655),
        -INT16_C(   458), -INT16_C( 15790),  INT16_C( 11215),  INT16_C( 12454),  INT16_C(   709),  INT16_C( 27266), -INT16_C( 23798),  INT16_C(  1032) },
      UINT32_C(3386165097),
      { UINT16_C( 7056), UINT16_C(15993), UINT16_C(59941), UINT16_C(23355), UINT16_C(36585), UINT16_C(47133), UINT16_C(50361), UINT16_C(32488),
        UINT16_C(27590), UINT16_C(53481), UINT16_C(61710), UINT16_C(30677), UINT16_C(43449), UINT16_C(61249), UINT16_C( 4033), UINT16_C(21046),
        UINT16_C(44842), UINT16_C(20368), UINT16_C(52378), UINT16_C(33707), UINT16_C(51290), UINT16_C( 4923), UINT16_C( 9356), UINT16_C(21393),
        UINT16_C(31375), UINT16_C(40227), UINT16_C(63596), UINT16_C( 9493), UINT16_C(22178), UINT16_C(25364), UINT16_C(19045), UINT16_C(37045) },
      { UINT16_C(18170), UINT16_C(38111), UINT16_C(35346), UINT16_C(27671), UINT16_C(21075), UINT16_C(57215), UINT16_C( 4214), UINT16_C( 1330),
        UINT16_C(22155), UINT16_C(63395), UINT16_C(47182), UINT16_C(61468), UINT16_C(12302), UINT16_C(29524), UINT16_C( 2426), UINT16_C(29699),
        UINT16_C(58191), UINT16_C(24840), UINT16_C( 8045), UINT16_C(49357), UINT16_C(19570), UINT16_C(59552), UINT16_C(53853), UINT16_C(59630),
        UINT16_C(37160), UINT16_C(30687), UINT16_C(64329), UINT16_C(22375), UINT16_C(47915), UINT16_C(42442), UINT16_C(52933), UINT16_C( 5146) },
      { UINT16_C( 7056), UINT16_C( 8612), UINT16_C(39893), UINT16_C(23355), UINT16_C(41892), UINT16_C(47133), UINT16_C( 4214), UINT16_C(16573),
        UINT16_C(22155), UINT16_C(53481), UINT16_C(47182), UINT16_C(58584), UINT16_C(39520), UINT16_C(21084), UINT16_C( 2426), UINT16_C(21046),
        UINT16_C(50682), UINT16_C(53439), UINT16_C( 8045), UINT16_C( 1347), UINT16_C(19570), UINT16_C(12620), UINT16_C( 9356), UINT16_C(21393),
        UINT16_C(31375), UINT16_C(49746), UINT16_C(11215), UINT16_C( 9493), UINT16_C(  709), UINT16_C(27266), UINT16_C(19045), UINT16_C( 5146) } },
    { {  INT16_C(  8881),  INT16_C(  7798),  INT16_C( 17218), -INT16_C( 19233),  INT16_C( 32656), -INT16_C(  4708), -INT16_C( 30127),  INT16_C( 31445),
        -INT16_C( 19429),  INT16_C( 25841),  INT16_C( 22703), -INT16_C(  9541), -INT16_C( 31212), -INT16_C(  9857), -INT16_C( 26284),  INT16_C(  1517),
         INT16_C( 25532), -INT16_C(   477),  INT16_C(   679),  INT16_C( 14258),  INT16_C( 20097), -INT16_C( 11484), -INT16_C(  1575), -INT16_C(  2995),
         INT16_C( 16045),  INT16_C( 23641),  INT16_C(  5270), -INT16_C( 21962), -INT16_C( 19046), -INT16_C(  4477),  INT16_C( 29007),  INT16_C(  3059) },
      UINT32_C(2064193492),
      { UINT16_C(54793), UINT16_C(57966), UINT16_C(48079), UINT16_C(31959), UINT16_C(12537), UINT16_C(36824), UINT16_C( 3652), UINT16_C(57146),
        UINT16_C(48580), UINT16_C( 5069), UINT16_C(49454), UINT16_C(  798), UINT16_C(10200), UINT16_C(61822), UINT16_C(12770), UINT16_C(60300),
        UINT16_C(64007), UINT16_C(55246), UINT16_C(42421), UINT16_C(44627), UINT16_C(11477), UINT16_C( 6462), UINT16_C(30778), UINT16_C(65272),
        UINT16_C(50741), UINT16_C(25617), UINT16_C(12167), UINT16_C(24423), UINT16_C(58710), UINT16_C(14416), UINT16_C(56598), UINT16_C( 7716) },
      { UINT16_C(62167), UINT16_C(36341), UINT16_C(18583), UINT16_C(27707), UINT16_C(31092), UINT16_C(44933), UINT16_C(32497), UINT16_C(10157),
        UINT16_C(48964), UINT16_C(52107), UINT16_C(62190), UINT16_C(17706), UINT16_C(31447), UINT16_C(61053), UINT16_C(41303), UINT16_C(12044),
        UINT16_C(  403), UINT16_C(10940), UINT16_C(63305), UINT16_C(48790), UINT16_C( 7281), UINT16_C(25197), UINT16_C( 6810), UINT16_C(56969),
        UINT16_C( 5337), UINT16_C(51369), UINT16_C(54022), UINT16_C(56845), UINT16_C(35405), UINT16_C(42444), UINT16_C(55340), UINT16_C(49108) },
      { UINT16_C( 8881), UINT16_C( 7798), UINT16_C(18583), UINT16_C(46303), UINT16_C(12537), UINT16_C(60828), UINT16_C( 3652), UINT16_C(10157),
        UINT16_C(48580), UINT16_C( 5069), UINT16_C(49454), UINT16_C(55995), UINT16_C(10200), UINT16_C(55679), UINT16_C(39252), UINT16_C( 1517),
        UINT16_C(  403), UINT16_C(65059), UINT16_C(  679), UINT16_C(44627), UINT16_C(20097), UINT16_C(54052), UINT16_C(63961), UINT16_C(62541),
        UINT16_C( 5337), UINT16_C(25617), UINT16_C( 5270), UINT16_C(24423), UINT16_C(35405), UINT16_C(14416), UINT16_C(55340), UINT16_C( 3059) } },
    { { -INT16_C( 28455),  INT16_C(  8938), -INT16_C( 32633), -INT16_C(  1824),  INT16_C( 19868),  INT16_C( 13915), -INT16_C(  7064),  INT16_C( 16660),
        -INT16_C( 16903), -INT16_C(   247),  INT16_C(  5776), -INT16_C(  8483), -INT16_C( 22111), -INT16_C( 12925),  INT16_C( 22401),  INT16_C( 23180),
         INT16_C( 30439),  INT16_C( 28285),  INT16_C( 24055), -INT16_C( 27801), -INT16_C( 15701),  INT16_C(  5066), -INT16_C(  8538), -INT16_C( 24748),
         INT16_C( 24220),  INT16_C( 11423),  INT16_C( 31860),  INT16_C(  5386), -INT16_C( 29402), -INT16_C( 22558),  INT16_C( 28644), -INT16_C( 13566) },
      UINT32_C(3694821349),
      { UINT16_C(14947), UINT16_C( 2458), UINT16_C(61208), UINT16_C(46249), UINT16_C(18509), UINT16_C(49633), UINT16_C(60356), UINT16_C(60119),
        UINT16_C(47481), UINT16_C(23954), UINT16_C(37928), UINT16_C( 3625), UINT16_C(25363), UINT16_C(61418), UINT16_C(23044), UINT16_C(26487),
        UINT16_C( 4500), UINT16_C(44400), UINT16_C( 6400), UINT16_C(19809), UINT16_C(16993), UINT16_C( 9743), UINT16_C(58926), UINT16_C(42768),
        UINT16_C(41631), UINT16_C(51204), UINT16_C(11574), UINT16_C(18902), UINT16_C(49296), UINT16_C(37945), UINT16_C(45083), UINT16_C(45051) },
      { UINT16_C(27841), UINT16_C(49756), UINT16_C(48773), UINT16_C(59151), UINT16_C( 7680), UINT16_C(11789), UINT16_C( 7428), UINT16_C(42197),
        UINT16_C(56000), UINT16_C(63084), UINT16_C(16903), UINT16_C(38976), UINT16_C(30978), UINT16_C( 7468), UINT16_C(10281), UINT16_C(60109),
        UINT16_C(10644), UINT16_C( 6572), UINT16_C(48359), UINT16_C(59392), UINT16_C( 3546), UINT16_C(57110), UINT16_C(60459), UINT16_C(60291),
        UINT16_C(61382), UINT16_C(52705), UINT16_C( 8497), UINT16_C(13157), UINT16_C(37530), UINT16_C(50001), UINT16_C( 7866), UINT16_C(20142) },
      { UINT16_C(14947), UINT16_C( 8938), UINT16_C(48773), UINT16_C(63712), UINT16_C(19868), UINT16_C(11789), UINT16_C( 7428), UINT16_C(42197),
        UINT16_C(47481), UINT16_C(23954), UINT16_C(16903), UINT16_C( 3625), UINT16_C(25363), UINT16_C( 7468), UINT16_C(10281), UINT16_C(23180),
        UINT16_C(30439), UINT16_C( 6572), UINT16_C(24055), UINT16_C(19809), UINT16_C( 3546), UINT16_C( 9743), UINT16_C(56998), UINT16_C(40788),
        UINT16_C(24220), UINT16_C(11423), UINT16_C( 8497), UINT16_C(13157), UINT16_C(37530), UINT16_C(42978), UINT16_C( 7866), UINT16_C(20142) } },
    { {  INT16_C( 23111),  INT16_C( 12135),  INT16_C( 26646), -INT16_C(  3817),  INT16_C( 11637), -INT16_C( 24368),  INT16_C( 21273), -INT16_C(  8309),
         INT16_C( 27970),  INT16_C( 29613),  INT16_C(  4750),  INT16_C( 10662), -INT16_C(  2140),  INT16_C( 24300), -INT16_C( 26091),  INT16_C( 23980),
         INT16_C(  5365),  INT16_C(  2956), -INT16_C( 23684), -INT16_C(  3588), -INT16_C( 13104), -INT16_C(  5486),  INT16_C(  7455),  INT16_C( 25033),
         INT16_C( 30346),  INT16_C(  6612),  INT16_C( 31625),  INT16_C( 11586),  INT16_C( 11890), -INT16_C( 30580),  INT16_C( 14537), -INT16_C( 16667) },
      UINT32_C(3368644940),
      { UINT16_C(19602), UINT16_C(45774), UINT16_C(39017), UINT16_C(62483), UINT16_C(59406), UINT16_C(38669), UINT16_C(20323), UINT16_C(54725),
        UINT16_C(20861), UINT16_C(18013), UINT16_C(17033), UINT16_C(54788), UINT16_C(52915), UINT16_C(51102), UINT16_C(22676), UINT16_C( 9900),
        UINT16_C(31396), UINT16_C( 3800), UINT16_C(60434), UINT16_C( 8450), UINT16_C( 4052), UINT16_C(14264), UINT16_C(32094), UINT16_C(56076),
        UINT16_C(27342), UINT16_C(22562), UINT16_C( 9900), UINT16_C(24622), UINT16_C(52468), UINT16_C(34855), UINT16_C(54053), UINT16_C(51631) },
      { UINT16_C(34638), UINT16_C(24791), UINT16_C(55667), UINT16_C(18305), UINT16_C(15080), UINT16_C(18046), UINT16_C(35767), UINT16_C(34338),
        UINT16_C(17653), UINT16_C(41438), UINT16_C( 3178), UINT16_C(24321), UINT16_C(10712), UINT16_C(64999), UINT16_C(38652), UINT16_C(19143),
        UINT16_C(40478), UINT16_C(37291), UINT16_C(11384), UINT16_C(24793), UINT16_C(22374), UINT16_C( 7847), UINT16_C(51682), UINT16_C(55204),
        UINT16_C(33293), UINT16_C(30585), UINT16_C(31374), UINT16_C(26326), UINT16_C(48803), UINT16_C(41060), UINT16_C(11092), UINT16_C(29418) },
      { UINT16_C(23111), UINT16_C(12135), UINT16_C(39017), UINT16_C(18305), UINT16_C(11637), UINT16_C(41168), UINT16_C(20323), UINT16_C(57227),
        UINT16_C(17653), UINT16_C(29613), UINT16_C( 4750), UINT16_C(10662), UINT16_C(10712), UINT16_C(51102), UINT16_C(22676), UINT16_C(23980),
        UINT16_C(31396), UINT16_C( 2956), UINT16_C(41852), UINT16_C( 8450), UINT16_C(52432), UINT16_C(60050), UINT16_C(32094), UINT16_C(55204),
        UINT16_C(30346), UINT16_C( 6612), UINT16_C(31625), UINT16_C(24622), UINT16_C(11890), UINT16_C(34956), UINT16_C(11092), UINT16_C(29418) } },
    { { -INT16_C( 27191),  INT16_C( 16644), -INT16_C(  8766),  INT16_C( 10402),  INT16_C( 18740),  INT16_C(  5958), -INT16_C(  5614),  INT16_C(  8174),
         INT16_C( 26476), -INT16_C(  1386),  INT16_C( 28130), -INT16_C( 31391), -INT16_C( 15061),  INT16_C( 32549),  INT16_C(  4336), -INT16_C( 17934),
        -INT16_C(  2395),  INT16_C( 26619), -INT16_C( 25133),  INT16_C(  1936), -INT16_C( 10522), -INT16_C(  2018),  INT16_C(  3521),  INT16_C( 11543),
        -INT16_C( 21132),  INT16_C( 22056), -INT16_C( 30438),  INT16_C( 17884),  INT16_C(   334),  INT16_C( 16069), -INT16_C( 18671), -INT16_C( 18441) },
      UINT32_C(2149511853),
      { UINT16_C(42629), UINT16_C(18029), UINT16_C(33971), UINT16_C(10099), UINT16_C(39730), UINT16_C(19582), UINT16_C(23076), UINT16_C(29330),
        UINT16_C(22363), UINT16_C(28080), UINT16_C(43022), UINT16_C(47908), UINT16_C(17050), UINT16_C(10811), UINT16_C(49905), UINT16_C(30367),
        UINT16_C( 3432), UINT16_C( 7100), UINT16_C(12177), UINT16_C(49987), UINT16_C(49611), UINT16_C(61200), UINT16_C(41499), UINT16_C(30306),
        UINT16_C( 4857), UINT16_C( 2019), UINT16_C( 1978), UINT16_C(21954), UINT16_C(64842), UINT16_C(15231), UINT16_C( 7871), UINT16_C(10417) },
      { UINT16_C(27947), UINT16_C(48451), UINT16_C(34460), UINT16_C(26496), UINT16_C(36935), UINT16_C(25175), UINT16_C(47410), UINT16_C(11225),
        UINT16_C(48331), UINT16_C(34354), UINT16_C(62660), UINT16_C( 3803), UINT16_C(23281), UINT16_C(45385), UINT16_C(64120), UINT16_C(42201),
        UINT16_C( 7271), UINT16_C(  865), UINT16_C(57763), UINT16_C(60011), UINT16_C(49778), UINT16_C(42061), UINT16_C( 9851), UINT16_C(18128),
        UINT16_C(  738), UINT16_C(42700), UINT16_C(42999), UINT16_C(59572), UINT16_C(64769), UINT16_C(31385), UINT16_C(29431), UINT16_C(24094) },
      { UINT16_C(27947), UINT16_C(16644), UINT16_C(33971), UINT16_C(10099), UINT16_C(18740), UINT16_C(19582), UINT16_C(59922), UINT16_C(11225),
        UINT16_C(26476), UINT16_C(28080), UINT16_C(28130), UINT16_C(34145), UINT16_C(17050), UINT16_C(10811), UINT16_C(49905), UINT16_C(30367),
        UINT16_C(63141), UINT16_C(  865), UINT16_C(12177), UINT16_C(49987), UINT16_C(49611), UINT16_C(63518), UINT16_C( 3521), UINT16_C(11543),
        UINT16_C(44404), UINT16_C(22056), UINT16_C(35098), UINT16_C(17884), UINT16_C(  334), UINT16_C(16069), UINT16_C(46865), UINT16_C(10417) } },
    { {  INT16_C( 32655),  INT16_C( 12898), -INT16_C( 12960), -INT16_C( 11748),  INT16_C( 27023),  INT16_C(  2679),  INT16_C( 18319),  INT16_C( 29264),
         INT16_C(  7497),  INT16_C( 16408), -INT16_C( 12860), -INT16_C( 14807), -INT16_C( 15670), -INT16_C( 15808),  INT16_C( 24117), -INT16_C( 15328),
        -INT16_C( 32035),  INT16_C( 15862),  INT16_C(  4687), -INT16_C(  8688), -INT16_C( 30852),  INT16_C(  3048),  INT16_C( 14798),  INT16_C(  6013),
        -INT16_C( 27050),  INT16_C(  6744), -INT16_C( 32413),  INT16_C( 11744),  INT16_C(  8259),  INT16_C( 30959),  INT16_C(  4222),  INT16_C( 23356) },
      UINT32_C(3801690770),
      { UINT16_C(43312), UINT16_C(65228), UINT16_C(19170), UINT16_C(14357), UINT16_C(28128), UINT16_C(17234), UINT16_C(13294), UINT16_C(12912),
        UINT16_C(24659), UINT16_C(53930), UINT16_C(59248), UINT16_C(  557), UINT16_C(50713), UINT16_C(24292), UINT16_C(42351), UINT16_C(40735),
        UINT16_C(60494), UINT16_C(12445), UINT16_C(45878), UINT16_C( 5736), UINT16_C(47648), UINT16_C( 3929), UINT16_C(51693), UINT16_C(16705),
        UINT16_C(60201), UINT16_C(39187), UINT16_C(16594), UINT16_C(60572), UINT16_C(32775), UINT16_C(30282), UINT16_C(27173), UINT16_C(29462) },
      { UINT16_C(45910), UINT16_C(36003), UINT16_C( 2918), UINT16_C(34722), UINT16_C(64454), UINT16_C(45974), UINT16_C(55236), UINT16_C(61172),
        UINT16_C( 1986), UINT16_C(38279), UINT16_C( 9032), UINT16_C(20353), UINT16_C(52132), UINT16_C(51653), UINT16_C(56117), UINT16_C(35645),
        UINT16_C(57487), UINT16_C(62743), UINT16_C(47596), UINT16_C(45692), UINT16_C( 4788), UINT16_C(31077), UINT16_C(23273), UINT16_C(44135),
        UINT16_C(61025), UINT16_C(43329), UINT16_C(49682), UINT16_C(46840), UINT16_C(48781), UINT16_C(50047), UINT16_C(48281), UINT16_C(10318) },
      { UINT16_C(32655), UINT16_C(36003), UINT16_C(52576), UINT16_C(53788), UINT16_C(28128), UINT16_C( 2679), UINT16_C(18319), UINT16_C(12912),
        UINT16_C( 7497), UINT16_C(38279), UINT16_C(52676), UINT16_C(50729), UINT16_C(50713), UINT16_C(24292), UINT16_C(24117), UINT16_C(50208),
        UINT16_C(57487), UINT16_C(15862), UINT16_C( 4687), UINT16_C( 5736), UINT16_C( 4788), UINT16_C( 3048), UINT16_C(14798), UINT16_C(16705),
        UINT16_C(38486), UINT16_C(39187), UINT16_C(33123), UINT16_C(11744), UINT16_C( 8259), UINT16_C(30282), UINT16_C(27173), UINT16_C(10318) } },
    { {  INT16_C( 26269), -INT16_C( 30434), -INT16_C( 26081), -INT16_C( 11205), -INT16_C( 24403), -INT16_C( 27059), -INT16_C( 19206),  INT16_C( 23618),
        -INT16_C( 31838), -INT16_C( 19451), -INT16_C(   443), -INT16_C( 11414), -INT16_C(  5444),  INT16_C( 21910), -INT16_C(  7002),  INT16_C( 17278),
        -INT16_C( 25526),  INT16_C( 27340),  INT16_C(  1846), -INT16_C(  7362), -INT16_C( 29784), -INT16_C( 23942), -INT16_C( 17345), -INT16_C(  7682),
         INT16_C(  1088), -INT16_C( 31338),  INT16_C(     2), -INT16_C( 16808), -INT16_C(  4374), -INT16_C( 28397), -INT16_C( 28205),  INT16_C(  7636) },
      UINT32_C(1686610221),
      { UINT16_C(49488), UINT16_C(36851), UINT16_C(61822), UINT16_C(48753), UINT16_C( 2037), UINT16_C(63299), UINT16_C(39943), UINT16_C(62133),
        UINT16_C(51594), UINT16_C(23939), UINT16_C(22362), UINT16_C(34939), UINT16_C(  760), UINT16_C(41452), UINT16_C(13256), UINT16_C( 6385),
        UINT16_C(58613), UINT16_C(29608), UINT16_C( 6614), UINT16_C(52017), UINT16_C(29728), UINT16_C(10179), UINT16_C(30736), UINT16_C(39705),
        UINT16_C(40001), UINT16_C(40184), UINT16_C(29684), UINT16_C(60452), UINT16_C( 4214), UINT16_C(16013), UINT16_C(32579), UINT16_C(14422) },
      { UINT16_C(65123), UINT16_C(14763), UINT16_C(56343), UINT16_C(14085), UINT16_C(51281), UINT16_C(24927), UINT16_C(30784), UINT16_C(33532),
        UINT16_C(62741), UINT16_C( 2334), UINT16_C(17000), UINT16_C(57077), UINT16_C(33618), UINT16_C(38172), UINT16_C(29442), UINT16_C(26062),
        UINT16_C(31089), UINT16_C(35231), UINT16_C(42070), UINT16_C(42944), UINT16_C( 8044), UINT16_C(44040), UINT16_C( 1432), UINT16_C(44334),
        UINT16_C(19706), UINT16_C(25270), UINT16_C(43918), UINT16_C(57409), UINT16_C(23854), UINT16_C(12406), UINT16_C(17616), UINT16_C(17046) },
      { UINT16_C(49488), UINT16_C(35102), UINT16_C(56343), UINT16_C(14085), UINT16_C(41133), UINT16_C(24927), UINT16_C(46330), UINT16_C(23618),
        UINT16_C(51594), UINT16_C(46085), UINT16_C(65093), UINT16_C(54122), UINT16_C(60092), UINT16_C(38172), UINT16_C(58534), UINT16_C( 6385),
        UINT16_C(31089), UINT16_C(29608), UINT16_C( 6614), UINT16_C(58174), UINT16_C(35752), UINT16_C(41594), UINT16_C(48191), UINT16_C(39705),
        UINT16_C( 1088), UINT16_C(34198), UINT16_C(29684), UINT16_C(48728), UINT16_C(61162), UINT16_C(12406), UINT16_C(17616), UINT16_C( 7636) } },
    { {  INT16_C( 13757),  INT16_C(  5067), -INT16_C( 29735),  INT16_C( 17850), -INT16_C( 15445),  INT16_C( 17393),  INT16_C(  8392), -INT16_C( 15632),
        -INT16_C( 22932), -INT16_C(  1244),  INT16_C( 25937), -INT16_C( 32549),  INT16_C( 20931), -INT16_C( 27728),  INT16_C( 18069),  INT16_C( 21461),
        -INT16_C( 24453),  INT16_C( 21606),  INT16_C(  8492), -INT16_C( 10343), -INT16_C( 29724), -INT16_C( 21478),  INT16_C(  2731),  INT16_C(  5998),
        -INT16_C( 27984),  INT16_C(   274), -INT16_C(  4360), -INT16_C( 17535),  INT16_C( 12863), -INT16_C( 10930),  INT16_C(  9336), -INT16_C(  3032) },
      UINT32_C(4031286980),
      { UINT16_C(57709), UINT16_C( 6207), UINT16_C(44523), UINT16_C(39727), UINT16_C(16960), UINT16_C(14493), UINT16_C( 7728), UINT16_C(28659),
        UINT16_C(16720), UINT16_C(51524), UINT16_C(27749), UINT16_C(10941), UINT16_C( 1531), UINT16_C(43546), UINT16_C(58087), UINT16_C(21566),
        UINT16_C(32195), UINT16_C(44908), UINT16_C(39979), UINT16_C(27466), UINT16_C(59358), UINT16_C( 3747), UINT16_C(38406), UINT16_C(22141),
        UINT16_C(49879), UINT16_C(15647), UINT16_C(56366), UINT16_C(10599), UINT16_C(33250), UINT16_C(51668), UINT16_C( 4707), UINT16_C(10014) },
      { UINT16_C(35471), UINT16_C(47830), UINT16_C( 8230), UINT16_C( 1061), UINT16_C(51208), UINT16_C( 3602), UINT16_C(36958), UINT16_C(13924),
        UINT16_C(33874), UINT16_C(32883), UINT16_C(55904), UINT16_C(17066), UINT16_C(32347), UINT16_C(48908), UINT16_C(10896), UINT16_C( 8166),
        UINT16_C(48308), UINT16_C(56282), UINT16_C(65500), UINT16_C(58591), UINT16_C(62152), UINT16_C( 9970), UINT16_C(22402), UINT16_C(54364),
        UINT16_C(53211), UINT16_C(15188), UINT16_C(65193), UINT16_C( 1406), UINT16_C(35452), UINT16_C( 3268), UINT16_C(43700), UINT16_C(26668) },
      { UINT16_C(13757), UINT16_C( 5067), UINT16_C( 8230), UINT16_C(17850), UINT16_C(50091), UINT16_C(17393), UINT16_C( 7728), UINT16_C(13924),
        UINT16_C(42604), UINT16_C(32883), UINT16_C(27749), UINT16_C(10941), UINT16_C(20931), UINT16_C(37808), UINT16_C(18069), UINT16_C( 8166),
        UINT16_C(41083), UINT16_C(21606), UINT16_C( 8492), UINT16_C(27466), UINT16_C(35812), UINT16_C(44058), UINT16_C(22402), UINT16_C( 5998),
        UINT16_C(37552), UINT16_C(  274), UINT16_C(61176), UINT16_C(48001), UINT16_C(33250), UINT16_C( 3268), UINT16_C( 4707), UINT16_C(10014) } }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
    simde__m512i src = simde_mm512_loadu_epi16(test_vec[i].src);
    simde__m512i a = simde_mm512_loadu_epi16(test_vec[i].a);
    simde__m512i b = simde_mm512_loadu_epi16(test_vec[i].b);
    simde__m512i r = simde_mm512_mask_min_epu16(src, test_vec[i].k, a, b);
    simde_test_x86_assert_equal_u16x32(r, simde_mm512_loadu_epi16(test_vec[i].r));
  }

  return 0;
}

static int
test_simde_mm512_maskz_min_epu16 (SIMDE_MUNIT_TEST_ARGS) {
  static const struct {
    const simde__mmask32 k;
    const uint16_t a[32];
    const uint16_t b[32];
    const uint16_t r[32];
  } test_vec[] = {
    { UINT32_C(2325775073),
      { UINT16_C(31861), UINT16_C(36471), UINT16_C( 6552), UINT16_C(33113), UINT16_C(15773), UINT16_C(39996), UINT16_C(39459), UINT16_C( 8945),
        UINT16_C(22730), UINT16_C( 7867), UINT16_C(31654), UINT16_C(34707), UINT16_C(13565), UINT16_C(10514), UINT16_C(50106), UINT16_C(12078),
        UINT16_C(42303), UINT16_C(55230), UINT16_C( 6078), UINT16_C(23385), UINT16_C(38228), UINT16_C(30711), UINT16_C(59439), UINT16_C(64154),
        UINT16_C(21824), UINT16_C(58904), UINT16_C(44241), UINT16_C(52846), UINT16_C(32992), UINT16_C(39672), UINT16_C( 9795), UINT16_C(33481) },
      { UINT16_C(34763), UINT16_C(35162), UINT16_C(45982), UINT16_C(62436), UINT16_C(56136), UINT16_C(30570), UINT16_C( 1219), UINT16_C( 1137),
        UINT16_C(35418), UINT16_C(11242), UINT16_C(22582), UINT16_C( 5881), UINT16_C(61912), UINT16_C( 7088), UINT16_C(30999), UINT16_C(58014),
        UINT16_C(63489), UINT16_C(40811), UINT16_C(20395), UINT16_C(62354), UINT16_C(64810), UINT16_C(61034), UINT16_C(56321), UINT16_C(23538),
        UINT16_C(56422), UINT16_C(40070), UINT16_C(32821), UINT16_C( 3506), UINT16_C(25201), UINT16_C(35113), UINT16_C(51163), UINT16_C(56427) },
      { UINT16_C(31861), UINT16_C(    0), UINT16_C(    0), UINT16_C(    0), UINT16_C(    0), UINT16_C(30570), UINT16_C( 1219), UINT16_C( 1137),
        UINT16_C(    0), UINT16_C( 7867), UINT16_C(    0), UINT16_C(    0), UINT16_C(    0), UINT16_C(    0), UINT16_C(    0), UINT16_C(12078),
        UINT16_C(    0), UINT16_C(    0), UINT16_C(    0), UINT16_C(    0), UINT16_C(    0), UINT16_C(30711), UINT16_C(    0), UINT16_C(23538),
        UINT16_C(    0), UINT16_C(40070), UINT16_C(    0), UINT16_C( 3506), UINT16_C(    0), UINT16_C(    0), UINT16_C(    0), UINT16_C(33481) } },
    { UINT32_C(1786566591),
      { UINT16_C(50955), UINT16_C( 3391), UINT16_C(12707), UINT16_C( 2408), UINT16_C(61197), UINT16_C(17061), UINT16_C(22383), UINT16_C(57424),
        UINT16_C(31161), UINT16_C(38249), UINT16_C(54592), UINT16_C(65393), UINT16_C(60844), UINT16_C(53865), UINT16_C(50940), UINT16_C( 1827),
        UINT16_C(25229), UINT16_C(12564), UINT16_C(32147), UINT16_C(41274), UINT16_C(57452), UINT16_C(56291), UINT16_C(13111), UINT16_C(61883),
        UINT16_C( 9644), UINT16_C(60550), UINT16_C(63482), UINT16_C(42731), UINT16_C(21733), UINT16_C(57720), UINT16_C(39962), UINT16_C(43240) },
      { UINT16_C(65022), UINT16_C(37593), UINT16_C( 4986), UINT16_C(58931), UINT16_C( 5875), UINT16_C(11201), UINT16_C(31818), UINT16_C(63004),
        UINT16_C(41633), UINT16_C(39907), UINT16_C(52889), UINT16_C(32321), UINT16_C(47651), UINT16_C(15711), UINT16_C(18518), UINT16_C(21733),
        UINT16_C(48709), UINT16_C(49126), UINT16_C( 6610), UINT16_C(50597), UINT16_C(26160), UINT16_C(31472), UINT16_C( 3298), UINT16_C(33904),
        UINT16_C(21422), UINT16_C(18463), UINT16_C(24866), UINT16_C(17862), UINT16_C( 9755), UINT16_C(29058), UINT16_C(26734), UINT16_C(46021) },
      { UINT16_C(50955), UINT16_C( 3391), UINT16_C( 4986), UINT16_C( 2408), UINT16_C( 5875), UINT16_C(11201), UINT16_C(    0), UINT16_C(57424),
        UINT16_C(31161), UINT16_C(38249), UINT16_C(52889), UINT16_C(    0), UINT16_C(47651), UINT16_C(    0), UINT16_C(18518), UINT16_C( 1827),
        UINT16_C(    0), UINT16_C(    0), UINT16_C( 6610), UINT16_C(41274), UINT16_C(26160), UINT16_C(31472), UINT16_C( 3298), UINT16_C(    0),
        UINT16_C(    0), UINT16_C(18463), UINT16_C(    0), UINT16_C(17862), UINT16_C(    0), UINT16_C(29058), UINT16_C(26734), UINT16_C(    0) } },
    { UINT32_C(4168264742),
      { UINT16_C(44669), UINT16_C(24431), UINT16_C(57531), UINT16_C(27107), UINT16_C(  819), UINT16_C(21937), UINT16_C(30820), UINT16_C(32666),
        UINT16_C( 7582), UINT16_C( 3312), UINT16_C(46469), UINT16_C(43967), UINT16_C(12641), UINT16_C(10148), UINT16_C(25160), UINT16_C(50460),
        UINT16_C(35856), UINT16_C(52004), UINT16_C( 2156), UINT16_C(40757), UINT16_C(58891), UINT16_C(28661), UINT16_C(36702), UINT16_C(64750),
        UINT16_C(57004), UINT16_C(12552), UINT16_C(51091), UINT16_C(62941), UINT16_C(33272), UINT16_C(16412), UINT16_C(14563), UINT16_C(62213) },
      { UINT16_C(10948), UINT16_C(12479), UINT16_C(62514), UINT16_C(15824), UINT16_C(50650), UINT16_C(14764), UINT16_C(39508), UINT16_C(  309),
        UINT16_C(15992), UINT16_C( 2866), UINT16_C( 3845), UINT16_C(65024), UINT16_C( 7312), UINT16_C(29502), UINT16_C(17493), UINT16_C( 6503),
        UINT16_C( 9838), UINT16_C(41034), UINT16_C( 6682), UINT16_C(62685), UINT16_C(35295), UINT16_C(13101), UINT16_C(25379), UINT16_C(39732),
        UINT16_C(26529), UINT16_C(42662), UINT16_C(42870), UINT16_C( 1956), UINT16_C(58307), UINT16_C( 6266), UINT16_C(57639), UINT16_C(38194) },
      { UINT16_C(    0), UINT16_C(12479), UINT16_C(57531), UINT16_C(    0), UINT16_C(    0), UINT16_C(14764), UINT16_C(    0), UINT16_C(    0),
        UINT16_C(    0), UINT16_C(    0), UINT16_C( 3845), UINT16_C(43967), UINT16_C(    0), UINT16_C(10148), UINT16_C(    0), UINT16_C( 6503),
        UINT16_C(    0), UINT16_C(41034), UINT16_C(    0), UINT16_C(    0), UINT16_C(35295), UINT16_C(13101), UINT16_C(25379), UINT16_C(    0),
        UINT16_C(    0), UINT16_C(    0), UINT16_C(    0), UINT16_C( 1956), UINT16_C(33272), UINT16_C( 6266), UINT16_C(14563), UINT16_C(38194) } },
    { UINT32_C( 557153287),
      { UINT16_C(17307), UINT16_C(48808), UINT16_C(56742), UINT16_C(18265), UINT16_C(65348), UINT16_C(47854), UINT16_C(37542), UINT16_C(27329),
        UINT16_C(15477), UINT16_C(40066), UINT16_C(46109), UINT16_C( 9521), UINT16_C(26160), UINT16_C(50758), UINT16_C(23672), UINT16_C( 4923),
        UINT16_C(58528), UINT16_C(18129), UINT16_C(10945), UINT16_C( 1422), UINT16_C(31786), UINT16_C(53439), UINT16_C(33038), UINT16_C(33850),
        UINT16_C(48573), UINT16_C(55840), UINT16_C(21105), UINT16_C(41727), UINT16_C(18104), UINT16_C(12648), UINT16_C(42146), UINT16_C(16964) },
      { UINT16_C( 5768), UINT16_C(18825), UINT16_C( 5952), UINT16_C(27214), UINT16_C( 3475), UINT16_C(41275), UINT16_C(30094), UINT16_C(19237),
        UINT16_C(17970), UINT16_C(42022), UINT16_C( 9624), UINT16_C(20550), UINT16_C(44651), UINT16_C( 3713), UINT16_C(50770), UINT16_C(55888),
        UINT16_C(55772), UINT16_C( 7203), UINT16_C(29168), UINT16_C(33671), UINT16_C(49791), UINT16_C( 3365), UINT16_C(18999), UINT16_C(27225),
        UINT16_C(32656), UINT16_C(10254), UINT16_C(21668), UINT16_C( 4217), UINT16_C(64002), UINT16_C(21790), UINT16_C(28352), UINT16_C(39983) },
      { UINT16_C( 5768), UINT16_C(18825), UINT16_C( 5952), UINT16_C(    0), UINT16_C(    0), UINT16_C(    0), UINT16_C(    0), UINT16_C(    0),
        UINT16_C(    0), UINT16_C(    0), UINT16_C( 9624), UINT16_C( 9521), UINT16_C(26160), UINT16_C( 3713), UINT16_C(23672), UINT16_C(    0),
        UINT16_C(55772), UINT16_C(    0), UINT16_C(10945), UINT16_C(    0), UINT16_C(31786), UINT16_C( 3365), UINT16_C(    0), UINT16_C(    0),
        UINT16_C(32656), UINT16_C(    0), UINT16_C(    0), UINT16_C(    0), UINT16_C(    0), UINT16_C(12648), UINT16_C(    0), UINT16_C(    0) } },
    { UINT32_C( 951669576),
      { UINT16_C(57602), UINT16_C(14673), UINT16_C(43563), UINT16_C(48291), UINT16_C(45353), UINT16_C(52708), UINT16_C(23813), UINT16_C( 2269),
        UINT16_C(64344), UINT16_C( 6237), UINT16_C(35946), UINT16_C(45749), UINT16_C(28383), UINT16_C(42218), UINT16_C(42670), UINT16_C(45287),
        UINT16_C(14471), UINT16_C(46057), UINT16_C(36322), UINT16_C( 2927), UINT16_C(21310), UINT16_C(17625), UINT16_C(46769), UINT16_C( 2380),
        UINT16_C(43442), UINT16_C( 7201), UINT16_C(54837), UINT16_C( 5582), UINT16_C(47172), UINT16_C(62137), UINT16_C(41055), UINT16_C(59042) },
      { UINT16_C(36057), UINT16_C(48025), UINT16_C( 2073), UINT16_C(22471), UINT16_C(41052), UINT16_C( 3483), UINT16_C(59222), UINT16_C( 2070),
        UINT16_C(14224), UINT16_C(50724), UINT16_C(61966), UINT16_C(21211), UINT16_C(38059), UINT16_C( 2629), UINT16_C(59188), UINT16_C( 3568),
        UINT16_C(35443), UINT16_C(36041), UINT16_C(37010), UINT16_C(61156), UINT16_C(32560), UINT16_C(34555), UINT16_C( 4455), UINT16_C(63375),
        UINT16_C(45897), UINT16_C(22461), UINT16_C(39078), UINT16_C(20905), UINT16_C(60972), UINT16_C(24923), UINT16_C(19414), UINT16_C(18798) },
      { UINT16_C(    0), UINT16_C(    0), UINT16_C(    0), UINT16_C(22471), UINT16_C(    0), UINT16_C(    0), UINT16_C(23813), UINT16_C(    0),
        UINT16_C(14224), UINT16_C( 6237), UINT16_C(    0), UINT16_C(    0), UINT16_C(28383), UINT16_C(    0), UINT16_C(42670), UINT16_C(    0),
        UINT16_C(14471), UINT16_C(    0), UINT16_C(    0), UINT16_C( 2927), UINT16_C(21310), UINT16_C(17625), UINT16_C(    0), UINT16_C( 2380),
        UINT16_C(    0), UINT16_C(    0), UINT16_C(    0), UINT16_C( 5582), UINT16_C(47172), UINT16_C(24923), UINT16_C(    0), UINT16_C(    0) } },
    { UINT32_C(1758869461),
      { UINT16_C(21049), UINT16_C(41086), UINT16_C( 3427), UINT16_C(44184), UINT16_C(21952), UINT16_C(26115), UINT16_C(44526), UINT16_C( 6839),
        UINT16_C( 4763), UINT16_C(29051), UINT16_C(59998), UINT16_C(13243), UINT16_C(37153), UINT16_C(59803), UINT16_C(62027), UINT16_C(34016),
        UINT16_C(24132), UINT16_C(42789), UINT16_C(48491), UINT16_C(11348), UINT16_C(22290), UINT16_C(  146), UINT16_C(18948), UINT16_C(40987),
        UINT16_C(38492), UINT16_C(47633), UINT16_C(52352), UINT16_C(41710), UINT16_C(35165), UINT16_C(43147), UINT16_C(27515), UINT16_C(48941) },
      { UINT16_C(21194), UINT16_C(13671), UINT16_C(47887), UINT16_C( 8545), UINT16_C(62482), UINT16_C( 5922), UINT16_C(15678), UINT16_C(39607),
        UINT16_C(51411), UINT16_C(21589), UINT16_C(17301), UINT16_C(62198), UINT16_C(33228), UINT16_C(18587), UINT16_C(51436), UINT16_C(46599),
        UINT16_C(28186), UINT16_C(10732), UINT16_C(19753), UINT16_C(15434), UINT16_C(27713), UINT16_C(32595), UINT16_C( 2729), UINT16_C(32026),
        UINT16_C(28626), UINT16_C(26577), UINT16_C(51122), UINT16_C(32346), UINT16_C(62792), UINT16_C(13510), UINT16_C(52925), UINT16_C(55275) },
      { UINT16_C(21049), UINT16_C(    0), UINT16_C( 3427), UINT16_C(    0), UINT16_C(21952), UINT16_C(    0), UINT16_C(15678), UINT16_C( 6839),
        UINT16_C( 4763), UINT16_C(21589), UINT16_C(17301), UINT16_C(    0), UINT16_C(33228), UINT16_C(18587), UINT16_C(    0), UINT16_C(    0),
        UINT16_C(    0), UINT16_C(10732), UINT16_C(19753), UINT16_C(    0), UINT16_C(22290), UINT16_C(    0), UINT16_C( 2729), UINT16_C(32026),
        UINT16_C(    0), UINT16_C(    0), UINT16_C(    0), UINT16_C(32346), UINT16_C(    0), UINT16_C(13510), UINT16_C(27515), UINT16_C(    0) } },
    { UINT32_C(1711331132),
      { UINT16_C(62903), UINT16_C(24805),      UINT16_MAX, UINT16_C(53725), UINT16_C(44654), UINT16_C( 8249), UINT16_C(37749), UINT16_C(48543),
        UINT16_C(25992), UINT16_C(17906), UINT16_C(56627), UINT16_C(28700), UINT16_C( 7348), UINT16_C(55510), UINT16_C(30822), UINT16_C( 7486),
        UINT16_C( 9325), UINT16_C(27774), UINT16_C(23331), UINT16_C(37437), UINT16_C(30218), UINT16_C(32690), UINT16_C(20745), UINT16_C(37181),
        UINT16_C(12215), UINT16_C(60118), UINT16_C(61964), UINT16_C(49242), UINT16_C(12302), UINT16_C(30104), UINT16_C(55208), UINT16_C( 5522) },
      { UINT16_C( 4347), UINT16_C( 7809), UINT16_C(49004), UINT16_C(30384), UINT16_C(25397), UINT16_C(16373), UINT16_C(12980), UINT16_C(27600),
        UINT16_C(42849), UINT16_C(27990), UINT16_C(45209), UINT16_C(43053), UINT16_C(50913), UINT16_C(35101), UINT16_C(44957), UINT16_C(39071),
        UINT16_C( 8384), UINT16_C(11446), UINT16_C(26591), UINT16_C( 5538), UINT16_C(38858), UINT16_C(32340), UINT16_C( 9418), UINT16_C(11242),
        UINT16_C(16587), UINT16_C(26009), UINT16_C(50928), UINT16_C(53517), UINT16_C(10892), UINT16_C(10587), UINT16_C(64217), UINT16_C(39361) },
      { UINT16_C(    0), UINT16_C(    0), UINT16_C(49004), UINT16_C(30384), UINT16_C(25397), UINT16_C( 8249), UINT16_C(    0), UINT16_C(    0),
        UINT16_C(25992), UINT16_C(17906), UINT16_C(45209), UINT16_C(    0), UINT16_C( 7348), UINT16_C(    0), UINT16_C(30822), UINT16_C( 7486),
        UINT16_C(    0), UINT16_C(    0), UINT16_C(    0), UINT16_C(    0), UINT16_C(    0), UINT16_C(    0), UINT16_C(    0), UINT16_C(    0),
        UINT16_C(    0), UINT16_C(26009), UINT16_C(50928), UINT16_C(    0), UINT16_C(    0), UINT16_C(10587), UINT16_C(55208), UINT16_C(    0) } },
    { UINT32_C(4207245338),
      { UINT16_C(25599), UINT16_C(51495), UINT16_C( 4487), UINT16_C(21492), UINT16_C(36177), UINT16_C(17080), UINT16_C(50516), UINT16_C(57363),
        UINT16_C(28399), UINT16_C(51210), UINT16_C(52072), UINT16_C(33634), UINT16_C(10051), UINT16_C( 8829), UINT16_C(35983), UINT16_C(36555),
        UINT16_C(62447), UINT16_C(30295), UINT16_C(19204), UINT16_C(22217), UINT16_C(33241), UINT16_C(11672), UINT16_C(43846), UINT16_C(13581),
        UINT16_C( 5914), UINT16_C(33534), UINT16_C(24803), UINT16_C( 9733), UINT16_C(33415), UINT16_C( 5705), UINT16_C( 5134), UINT16_C(64932) },
      { UINT16_C(64263), UINT16_C( 3188), UINT16_C(15687), UINT16_C( 8290), UINT16_C(64191), UINT16_C( 1357), UINT16_C(23205), UINT16_C(48955),
        UINT16_C(14706), UINT16_C(21826), UINT16_C(18329), UINT16_C( 8315), UINT16_C(50378), UINT16_C(55351), UINT16_C(56281), UINT16_C(57558),
        UINT16_C(19159), UINT16_C( 7916), UINT16_C(20103), UINT16_C(17982), UINT16_C(35656), UINT16_C(61004), UINT16_C(34789), UINT16_C(22445),
        UINT16_C(61376), UINT16_C(22956), UINT16_C(10295), UINT16_C(  377), UINT16_C(45292), UINT16_C(50649), UINT16_C(44940), UINT16_C(25510) },
      { UINT16_C(    0), UINT16_C( 3188), UINT16_C(    0), UINT16_C( 8290), UINT16_C(36177), UINT16_C(    0), UINT16_C(    0), UINT16_C(    0),
        UINT16_C(    0), UINT16_C(    0), UINT16_C(    0), UINT16_C( 8315), UINT16_C(10051), UINT16_C( 8829), UINT16_C(35983), UINT16_C(    0),
        UINT16_C(19159), UINT16_C(    0), UINT16_C(19204), UINT16_C(    0), UINT16_C(    0), UINT16_C(    0), UINT16_C(34789), UINT16_C(13581),
        UINT16_C(    0), UINT16_C(22956), UINT16_C(    0), UINT16_C(  377), UINT16_C(33415), UINT16_C( 5705), UINT16_C( 5134), UINT16_C(25510) } }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
    simde__m512i a = simde_mm512_loadu_epi16(test_vec[i].a);
    simde__m512i b = simde_mm512_loadu_epi16(test_vec[i].b);
    simde__m512i r = simde_mm512_maskz_min_epu16(test_vec[i].k, a, b);
    simde_test_x86_assert_equal_u16x32(r, simde_mm512_loadu_epi16(test_vec[i].r));
  }

  return 0;
}

static int
test_simde_mm512_max_epi16 (SIMDE_MUNIT_TEST_ARGS) {
  static const struct {
    const int16_t a[32];
    const int16_t b[32];
    const int16_t r[32];
  } test_vec[] = {
    { {  INT16_C( 14691), -INT16_C(  2237),  INT16_C(  8698),  INT16_C(  9348),  INT16_C( 13857), -INT16_C( 10584),  INT16_C( 25854), -INT16_C(  6420),
         INT16_C( 17420),  INT16_C(  1517), -INT16_C(  5283),  INT16_C( 26495),  INT16_C(  7532), -INT16_C(  2781),  INT16_C(  9520), -INT16_C( 27403),
         INT16_C( 14430),  INT16_C( 22667),  INT16_C(  3929),  INT16_C( 31356),  INT16_C(  9541),  INT16_C( 17232),  INT16_C( 15497), -INT16_C( 27350),
         INT16_C(  6016), -INT16_C(  8550),  INT16_C(  6658),  INT16_C( 28485),  INT16_C( 26679),  INT16_C( 26724),  INT16_C( 22926), -INT16_C(  4868) },
      { -INT16_C( 30831), -INT16_C(  5563), -INT16_C( 15978), -INT16_C(  9371), -INT16_C( 18970),  INT16_C( 28447),  INT16_C( 18930),  INT16_C( 29188),
        -INT16_C( 24736),  INT16_C( 25168), -INT16_C( 26951), -INT16_C(  3887),  INT16_C( 14078), -INT16_C( 29608),  INT16_C( 21647),  INT16_C(  8569),
        -INT16_C( 16677),  INT16_C( 28939),  INT16_C( 28799),  INT16_C( 26189),  INT16_C( 27686),  INT16_C(  6357), -INT16_C(  9547),  INT16_C(  5514),
        -INT16_C(  9351),  INT16_C( 12919),  INT16_C( 18801),  INT16_C( 28450),  INT16_C( 31615),  INT16_C(  3836),  INT16_C( 30159), -INT16_C( 21713) },
      {  INT16_C( 14691), -INT16_C(  2237),  INT16_C(  8698),  INT16_C(  9348),  INT16_C( 13857),  INT16_C( 28447),  INT16_C( 25854),  INT16_C( 29188),
         INT16_C( 17420),  INT16_C( 25168), -INT16_C(  5283),  INT16_C( 26495),  INT16_C( 14078), -INT16_C(  2781),  INT16_C( 21647),  INT16_C(  8569),
         INT16_C( 14430),  INT16_C( 28939),  INT16_C( 28799),  INT16_C( 31356),  INT16_C( 27686),  INT16_C( 17232),  INT16_C( 15497),  INT16_C(  5514),
         INT16_C(  6016),  INT16_C( 12919),  INT16_C( 18801),  INT16_C( 28485),  INT16_C( 31615),  INT16_C( 26724),  INT16_C( 30159), -INT16_C(  4868) } },
    { {  INT16_C( 15155), -INT16_C( 19940),  INT16_C( 27051), -INT16_C( 12008), -INT16_C(  4395), -INT16_C( 29975),  INT16_C( 29896),  INT16_C( 16799),
         INT16_C(  5967), -INT16_C( 16269), -INT16_C( 27296), -INT16_C(  8401),  INT16_C( 11024), -INT16_C(  7955),  INT16_C(  7584), -INT16_C( 11381),
        -INT16_C( 22696),  INT16_C(   902), -INT16_C( 25071), -INT16_C(  6443), -INT16_C( 16756),  INT16_C( 21617),  INT16_C(  4146), -INT16_C( 32363),
         INT16_C(  2087), -INT16_C( 30911),  INT16_C( 29086), -INT16_C( 20890),  INT16_C( 21660),  INT16_C( 15758),  INT16_C(  6513), -INT16_C( 14064) },
      { -INT16_C( 26943), -INT16_C( 11572), -INT16_C( 24267), -INT16_C( 15944),  INT16_C( 10592), -INT16_C( 28138), -INT16_C( 21702),  INT16_C( 24852),
         INT16_C( 21940),  INT16_C( 21225),  INT16_C( 20422),  INT16_C( 25344), -INT16_C( 28765),  INT16_C(  5280), -INT16_C( 20312),  INT16_C( 27101),
        -INT16_C( 21945),  INT16_C( 31803), -INT16_C(  2997), -INT16_C( 21699),  INT16_C( 21277),  INT16_C( 22334),  INT16_C( 21247), -INT16_C( 19527),
        -INT16_C( 23897),  INT16_C( 28165),  INT16_C(  1521), -INT16_C( 27183),  INT16_C( 29076),  INT16_C( 15785), -INT16_C( 30943),  INT16_C( 26790) },
      {  INT16_C( 15155), -INT16_C( 11572),  INT16_C( 27051), -INT16_C( 12008),  INT16_C( 10592), -INT16_C( 28138),  INT16_C( 29896),  INT16_C( 24852),
         INT16_C( 21940),  INT16_C( 21225),  INT16_C( 20422),  INT16_C( 25344),  INT16_C( 11024),  INT16_C(  5280),  INT16_C(  7584),  INT16_C( 27101),
        -INT16_C( 21945),  INT16_C( 31803), -INT16_C(  2997), -INT16_C(  6443),  INT16_C( 21277),  INT16_C( 22334),  INT16_C( 21247), -INT16_C( 19527),
         INT16_C(  2087),  INT16_C( 28165),  INT16_C( 29086), -INT16_C( 20890),  INT16_C( 29076),  INT16_C( 15785),  INT16_C(  6513),  INT16_C( 26790) } },
    { { -INT16_C(  7631),  INT16_C( 31972),  INT16_C(  8918), -INT16_C(  3288),  INT16_C( 26229),  INT16_C( 29771),  INT16_C(  1208),  INT16_C( 24359),
         INT16_C( 11430), -INT16_C( 26675), -INT16_C( 25038), -INT16_C( 14804), -INT16_C( 10737),  INT16_C( 12547), -INT16_C( 21923), -INT16_C( 29031),
         INT16_C( 32396),  INT16_C( 25098),  INT16_C( 12960),  INT16_C(  5461), -INT16_C( 24424),  INT16_C( 20618), -INT16_C( 20060),  INT16_C( 19120),
         INT16_C( 32222),  INT16_C(  4322),  INT16_C(  3612),  INT16_C( 11222), -INT16_C(  9500),  INT16_C( 16732), -INT16_C(  2428),  INT16_C(  4303) },
      { -INT16_C(  9612),  INT16_C(  5234), -INT16_C( 14580), -INT16_C( 23255), -INT16_C( 19608),  INT16_C(  3317), -INT16_C( 23195),  INT16_C( 17239),
         INT16_C( 14627),  INT16_C( 16211),  INT16_C( 10567),  INT16_C( 11370), -INT16_C( 14589), -INT16_C( 30867),  INT16_C( 15805),  INT16_C( 12695),
         INT16_C(  2327),  INT16_C(  9029),  INT16_C( 28369),  INT16_C( 14792), -INT16_C( 16862), -INT16_C( 30907), -INT16_C( 25501), -INT16_C( 31030),
         INT16_C(  7637),  INT16_C(  7621),  INT16_C( 12358),  INT16_C( 19017), -INT16_C( 18697), -INT16_C( 19247),  INT16_C( 27123),  INT16_C(  2789) },
      { -INT16_C(  7631),  INT16_C( 31972),  INT16_C(  8918), -INT16_C(  3288),  INT16_C( 26229),  INT16_C( 29771),  INT16_C(  1208),  INT16_C( 24359),
         INT16_C( 14627),  INT16_C( 16211),  INT16_C( 10567),  INT16_C( 11370), -INT16_C( 10737),  INT16_C( 12547),  INT16_C( 15805),  INT16_C( 12695),
         INT16_C( 32396),  INT16_C( 25098),  INT16_C( 28369),  INT16_C( 14792), -INT16_C( 16862),  INT16_C( 20618), -INT16_C( 20060),  INT16_C( 19120),
         INT16_C( 32222),  INT16_C(  7621),  INT16_C( 12358),  INT16_C( 19017), -INT16_C(  9500),  INT16_C( 16732),  INT16_C( 27123),  INT16_C(  4303) } },
    { {  INT16_C( 10866),  INT16_C( 17198), -INT16_C(  2408), -INT16_C( 17796), -INT16_C( 15692),  INT16_C(  6209),  INT16_C(  2910),  INT16_C( 13470),
         INT16_C( 25640),  INT16_C( 28497), -INT16_C( 25964), -INT16_C( 29767), -INT16_C( 30128),  INT16_C( 17471),  INT16_C(  9459),  INT16_C( 26190),
         INT16_C( 31822), -INT16_C(  6487),  INT16_C(  9843),  INT16_C( 10145), -INT16_C(  7448),  INT16_C( 17983), -INT16_C(  8466),  INT16_C(  5754),
        -INT16_C( 13502), -INT16_C( 10619),  INT16_C( 15973), -INT16_C( 18847), -INT16_C( 24375), -INT16_C( 17158),  INT16_C( 18628),  INT16_C(  4642) },
      { -INT16_C( 13115),  INT16_C( 14584), -INT16_C( 26126), -INT16_C(  9633), -INT16_C( 24708),  INT16_C( 27168), -INT16_C( 25731), -INT16_C( 16512),
         INT16_C(  1638), -INT16_C( 13163), -INT16_C(  2492),  INT16_C(  3458),  INT16_C( 31894),  INT16_C( 23242), -INT16_C(  4924), -INT16_C( 30356),
         INT16_C( 25784), -INT16_C( 21823),  INT16_C(  8702),  INT16_C( 31364), -INT16_C( 23104),  INT16_C( 15844),  INT16_C( 25664), -INT16_C( 22788),
        -INT16_C( 28310), -INT16_C( 20622), -INT16_C(  2937),  INT16_C(  7612), -INT16_C( 31120),  INT16_C( 13687), -INT16_C(  7309),  INT16_C( 11198) },
      {  INT16_C( 10866),  INT16_C( 17198), -INT16_C(  2408), -INT16_C(  9633), -INT16_C( 15692),  INT16_C( 27168),  INT16_C(  2910),  INT16_C( 13470),
         INT16_C( 25640),  INT16_C( 28497), -INT16_C(  2492),  INT16_C(  3458),  INT16_C( 31894),  INT16_C( 23242),  INT16_C(  9459),  INT16_C( 26190),
         INT16_C( 31822), -INT16_C(  6487),  INT16_C(  9843),  INT16_C( 31364), -INT16_C(  7448),  INT16_C( 17983),  INT16_C( 25664),  INT16_C(  5754),
        -INT16_C( 13502), -INT16_C( 10619),  INT16_C( 15973),  INT16_C(  7612), -INT16_C( 24375),  INT16_C( 13687),  INT16_C( 18628),  INT16_C( 11198) } },
    { { -INT16_C( 32697),  INT16_C( 17878),  INT16_C( 23201),  INT16_C( 25023), -INT16_C( 23553),  INT16_C( 16286), -INT16_C( 26104),  INT16_C( 29414),
         INT16_C( 22571), -INT16_C( 19935), -INT16_C(  8627), -INT16_C( 16945),  INT16_C( 18020), -INT16_C( 10254), -INT16_C( 20183),  INT16_C( 28675),
        -INT16_C(  9935), -INT16_C( 11594),  INT16_C( 30003),  INT16_C( 13107), -INT16_C( 12007),  INT16_C(  8562),  INT16_C( 22635), -INT16_C( 26989),
        -INT16_C( 19023), -INT16_C(   440),  INT16_C(  6035), -INT16_C(  2117), -INT16_C( 20899), -INT16_C( 31025), -INT16_C( 11681), -INT16_C( 28426) },
      { -INT16_C( 21333), -INT16_C(  8606), -INT16_C( 27358),  INT16_C( 15121), -INT16_C( 31642), -INT16_C( 11940), -INT16_C(  4132), -INT16_C( 29337),
        -INT16_C( 20572),  INT16_C( 14219),  INT16_C( 18374),  INT16_C(  9007), -INT16_C(   267),  INT16_C( 21673), -INT16_C( 24624),  INT16_C( 31716),
         INT16_C( 17996),  INT16_C( 28249),  INT16_C( 27611),  INT16_C( 16809),  INT16_C(  1519), -INT16_C( 13550),  INT16_C( 31220), -INT16_C( 26279),
        -INT16_C(  7128), -INT16_C(  4400), -INT16_C(   213),  INT16_C(  8209), -INT16_C( 17667), -INT16_C( 12940),  INT16_C( 22617), -INT16_C( 23224) },
      { -INT16_C( 21333),  INT16_C( 17878),  INT16_C( 23201),  INT16_C( 25023), -INT16_C( 23553),  INT16_C( 16286), -INT16_C(  4132),  INT16_C( 29414),
         INT16_C( 22571),  INT16_C( 14219),  INT16_C( 18374),  INT16_C(  9007),  INT16_C( 18020),  INT16_C( 21673), -INT16_C( 20183),  INT16_C( 31716),
         INT16_C( 17996),  INT16_C( 28249),  INT16_C( 30003),  INT16_C( 16809),  INT16_C(  1519),  INT16_C(  8562),  INT16_C( 31220), -INT16_C( 26279),
        -INT16_C(  7128), -INT16_C(   440),  INT16_C(  6035),  INT16_C(  8209), -INT16_C( 17667), -INT16_C( 12940),  INT16_C( 22617), -INT16_C( 23224) } },
    { { -INT16_C( 23906),  INT16_C( 30995), -INT16_C( 17395), -INT16_C(   838), -INT16_C( 13119), -INT16_C( 18745),  INT16_C(  8261),  INT16_C( 27983),
         INT16_C(  7941),  INT16_C( 12379),  INT16_C( 27679),  INT16_C(  7249), -INT16_C( 15066), -INT16_C( 32534),  INT16_C( 12830), -INT16_C( 17371),
         INT16_C( 14804), -INT16_C(  7882), -INT16_C(  3851), -INT16_C( 18467), -INT16_C( 23107),  INT16_C(   621), -INT16_C( 17211), -INT16_C( 13712),
        -INT16_C( 13349), -INT16_C(  1285),  INT16_C( 19512),  INT16_C( 24087),  INT16_C(   273),  INT16_C( 12254),  INT16_C(  1075),  INT16_C(  2284) },
      {  INT16_C(  8765),  INT16_C( 13033), -INT16_C( 14574), -INT16_C( 12311),  INT16_C( 22124),  INT16_C( 12754),  INT16_C( 16914), -INT16_C(  4356),
        -INT16_C(  2291),  INT16_C( 17896), -INT16_C(   189),  INT16_C( 21668), -INT16_C( 32256),  INT16_C( 13444),  INT16_C( 28806), -INT16_C( 15556),
         INT16_C(  9618), -INT16_C( 23306), -INT16_C(  8212),  INT16_C( 22644),  INT16_C( 17974),  INT16_C( 18570), -INT16_C( 31096), -INT16_C( 27338),
         INT16_C(  8061), -INT16_C( 16165),  INT16_C( 32542),  INT16_C(  7956), -INT16_C( 26623), -INT16_C( 30637), -INT16_C( 28920), -INT16_C( 26037) },
      {  INT16_C(  8765),  INT16_C( 30995), -INT16_C( 14574), -INT16_C(   838),  INT16_C( 22124),  INT16_C( 12754),  INT16_C( 16914),  INT16_C( 27983),
         INT16_C(  7941),  INT16_C( 17896),  INT16_C( 27679),  INT16_C( 21668), -INT16_C( 15066),  INT16_C( 13444),  INT16_C( 28806), -INT16_C( 15556),
         INT16_C( 14804), -INT16_C(  7882), -INT16_C(  3851),  INT16_C( 22644),  INT16_C( 17974),  INT16_C( 18570), -INT16_C( 17211), -INT16_C( 13712),
         INT16_C(  8061), -INT16_C(  1285),  INT16_C( 32542),  INT16_C( 24087),  INT16_C(   273),  INT16_C( 12254),  INT16_C(  1075),  INT16_C(  2284) } },
    { {  INT16_C( 16820), -INT16_C( 24257), -INT16_C( 19679),  INT16_C( 22521), -INT16_C( 31751), -INT16_C( 32353), -INT16_C( 10743), -INT16_C( 31210),
        -INT16_C(  3595),  INT16_C(  4934),  INT16_C( 23408),  INT16_C( 29234), -INT16_C( 31245), -INT16_C(   774),  INT16_C( 17684), -INT16_C( 13930),
        -INT16_C( 10873), -INT16_C( 22422),  INT16_C( 25480), -INT16_C( 32257), -INT16_C( 24857), -INT16_C(  4094),  INT16_C(  6516),  INT16_C( 26999),
        -INT16_C( 17142),  INT16_C( 31613), -INT16_C( 20712),  INT16_C(  3309), -INT16_C(  6347),  INT16_C( 18696), -INT16_C( 25044), -INT16_C( 19694) },
      {  INT16_C( 31860), -INT16_C(   933),  INT16_C( 23264), -INT16_C( 14466), -INT16_C( 32519),  INT16_C( 28087),  INT16_C( 11929), -INT16_C( 23337),
         INT16_C( 21740),  INT16_C(  1055),  INT16_C(  3075),  INT16_C( 14352),  INT16_C(  6387),  INT16_C(  8066), -INT16_C( 27465),  INT16_C( 11219),
         INT16_C( 11793), -INT16_C(  3801), -INT16_C( 23159), -INT16_C( 32072),  INT16_C( 28454), -INT16_C( 16401), -INT16_C( 14690), -INT16_C( 30109),
        -INT16_C( 32230),  INT16_C(  7822), -INT16_C( 24690), -INT16_C( 32426), -INT16_C( 10057),  INT16_C( 28321),  INT16_C( 29805),  INT16_C( 32409) },
      {  INT16_C( 31860), -INT16_C(   933),  INT16_C( 23264),  INT16_C( 22521), -INT16_C( 31751),  INT16_C( 28087),  INT16_C( 11929), -INT16_C( 23337),
         INT16_C( 21740),  INT16_C(  4934),  INT16_C( 23408),  INT16_C( 29234),  INT16_C(  6387),  INT16_C(  8066),  INT16_C( 17684),  INT16_C( 11219),
         INT16_C( 11793), -INT16_C(  3801),  INT16_C( 25480), -INT16_C( 32072),  INT16_C( 28454), -INT16_C(  4094),  INT16_C(  6516),  INT16_C( 26999),
        -INT16_C( 17142),  INT16_C( 31613), -INT16_C( 20712),  INT16_C(  3309), -INT16_C(  6347),  INT16_C( 28321),  INT16_C( 29805),  INT16_C( 32409) } },
    { { -INT16_C( 15966),  INT16_C( 11119),  INT16_C( 10086), -INT16_C( 29523), -INT16_C( 25194),  INT16_C( 13388), -INT16_C( 20637),  INT16_C( 32446),
         INT16_C( 19762), -INT16_C( 16228), -INT16_C(  3348), -INT16_C( 23742), -INT16_C(  7221),  INT16_C( 14354), -INT16_C( 21673), -INT16_C(  1610),
         INT16_C(  9580), -INT16_C( 11483), -INT16_C( 11700), -INT16_C(  7585), -INT16_C( 21649), -INT16_C( 11497), -INT16_C( 10917), -INT16_C( 29359),
        -INT16_C(  4830),  INT16_C(  3661), -INT16_C( 28705), -INT16_C( 21838), -INT16_C( 15246), -INT16_C( 13854), -INT16_C( 26513), -INT16_C(  9021) },
      { -INT16_C(  5955),  INT16_C(  2479),  INT16_C(  3770),  INT16_C( 10988),  INT16_C(   954),  INT16_C(  5629),  INT16_C( 20184), -INT16_C(  1118),
        -INT16_C(  4293),  INT16_C(  6665), -INT16_C( 17537), -INT16_C(  3643), -INT16_C( 22657), -INT16_C(  4165),  INT16_C( 32320), -INT16_C(   565),
         INT16_C( 31334),  INT16_C(  8199), -INT16_C(  3192),  INT16_C( 16970),  INT16_C( 18422), -INT16_C( 12713), -INT16_C(  1643), -INT16_C( 12087),
        -INT16_C( 11287),  INT16_C( 26859), -INT16_C( 20338),  INT16_C(  3673),  INT16_C(  5207), -INT16_C( 26627), -INT16_C( 14190), -INT16_C(  1899) },
      { -INT16_C(  5955),  INT16_C( 11119),  INT16_C( 10086),  INT16_C( 10988),  INT16_C(   954),  INT16_C( 13388),  INT16_C( 20184),  INT16_C( 32446),
         INT16_C( 19762),  INT16_C(  6665), -INT16_C(  3348), -INT16_C(  3643), -INT16_C(  7221),  INT16_C( 14354),  INT16_C( 32320), -INT16_C(   565),
         INT16_C( 31334),  INT16_C(  8199), -INT16_C(  3192),  INT16_C( 16970),  INT16_C( 18422), -INT16_C( 11497), -INT16_C(  1643), -INT16_C( 12087),
        -INT16_C(  4830),  INT16_C( 26859), -INT16_C( 20338),  INT16_C(  3673),  INT16_C(  5207), -INT16_C( 13854), -INT16_C( 14190), -INT16_C(  1899) } }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
    simde__m512i a = simde_mm512_loadu_epi16(test_vec[i].a);
    simde__m512i b = simde_mm512_loadu_epi16(test_vec[i].b);
    simde__m512i r = simde_mm512_max_epi16(a, b);
    simde_test_x86_assert_equal_i16x32(r, simde_mm512_loadu_epi16(test_vec[i].r));
  }

  return 0;
}

static int
test_simde_mm512_mask_max_epi16 (SIMDE_MUNIT_TEST_ARGS) {
  static const struct {
    const int16_t src[32];
    const simde__mmask32 k;
    const int16_t a[32];
    const int16_t b[32];
    const int16_t r[32];
  } test_vec[] = {
    { { -INT16_C( 31856),  INT16_C( 27575),  INT16_C( 18767),  INT16_C( 28047),  INT16_C( 25446), -INT16_C( 31139),  INT16_C(  7112),  INT16_C( 14683),
         INT16_C(  7442), -INT16_C(  5599),  INT16_C( 11607),  INT16_C( 12590),  INT16_C(  4923),  INT16_C( 25627),  INT16_C(  2220),  INT16_C( 15731),
         INT16_C( 11147), -INT16_C(  9560),  INT16_C( 14196), -INT16_C(  9657), -INT16_C( 23142),  INT16_C( 25441), -INT16_C( 17216), -INT16_C( 11620),
        -INT16_C( 16935),  INT16_C( 12733), -INT16_C(  5142),  INT16_C(  9826),  INT16_C( 32254), -INT16_C( 21622), -INT16_C(   379),  INT16_C(  4328) },
      UINT32_C(2649395241),
      { -INT16_C( 10026), -INT16_C( 26684),  INT16_C( 24980),  INT16_C( 28265),  INT16_C(  9758),  INT16_C(  2463),  INT16_C(   273),  INT16_C(  4143),
        -INT16_C( 18050),  INT16_C(   955), -INT16_C( 23625), -INT16_C(  8173), -INT16_C(   717), -INT16_C(  1411), -INT16_C(  2770),  INT16_C(  1371),
         INT16_C(  8397),  INT16_C( 25244),  INT16_C(  1409), -INT16_C( 24624),  INT16_C( 28460),  INT16_C( 15784), -INT16_C( 10384), -INT16_C(  4531),
         INT16_C(  2193),  INT16_C( 18673),  INT16_C(  1195), -INT16_C(  8663), -INT16_C( 23039),  INT16_C( 12248),  INT16_C( 13467),  INT16_C( 26932) },
      { -INT16_C( 12204), -INT16_C( 10805), -INT16_C( 25642),  INT16_C(   628),  INT16_C(  7434),  INT16_C( 31295), -INT16_C( 29196), -INT16_C( 31384),
         INT16_C( 22933),  INT16_C( 16846), -INT16_C(  2211),  INT16_C( 24095), -INT16_C(  1891),  INT16_C( 14733), -INT16_C( 15828), -INT16_C( 32606),
         INT16_C( 28050),  INT16_C( 26709), -INT16_C( 14072),  INT16_C(  4714), -INT16_C( 21786), -INT16_C(  9332), -INT16_C(  3017), -INT16_C( 13216),
         INT16_C( 11853), -INT16_C( 22003),  INT16_C( 11557), -INT16_C( 15608), -INT16_C( 27355),  INT16_C( 20988), -INT16_C( 25001), -INT16_C(  5423) },
      { -INT16_C( 10026),  INT16_C( 27575),  INT16_C( 18767),  INT16_C( 28265),  INT16_C( 25446),  INT16_C( 31295),  INT16_C(  7112),  INT16_C( 14683),
         INT16_C(  7442), -INT16_C(  5599),  INT16_C( 11607),  INT16_C( 12590), -INT16_C(   717),  INT16_C( 25627),  INT16_C(  2220),  INT16_C(  1371),
         INT16_C( 11147),  INT16_C( 26709),  INT16_C( 14196),  INT16_C(  4714), -INT16_C( 23142),  INT16_C( 15784), -INT16_C(  3017), -INT16_C(  4531),
         INT16_C( 11853),  INT16_C( 12733),  INT16_C( 11557), -INT16_C(  8663), -INT16_C( 23039), -INT16_C( 21622), -INT16_C(   379),  INT16_C( 26932) } },
    { {  INT16_C(  9739),  INT16_C(  4946), -INT16_C( 16913), -INT16_C( 10715), -INT16_C( 20121), -INT16_C( 24911),  INT16_C(  4517), -INT16_C(  3478),
         INT16_C( 30784),  INT16_C( 26012), -INT16_C( 23387), -INT16_C( 13784),  INT16_C(  9273), -INT16_C( 28389), -INT16_C(  4926), -INT16_C( 12933),
        -INT16_C( 13038),  INT16_C(   480),  INT16_C(  1418), -INT16_C(  3625), -INT16_C( 30538),  INT16_C( 23439), -INT16_C(  1382), -INT16_C(  9651),
        -INT16_C(  5774),  INT16_C(  5951),  INT16_C( 26765), -INT16_C( 14367), -INT16_C(   884),  INT16_C( 20312), -INT16_C( 11288), -INT16_C(  1508) },
      UINT32_C( 737934752),
      { -INT16_C( 21413), -INT16_C(  2796),  INT16_C( 25254),  INT16_C(  6351),  INT16_C(  3915), -INT16_C(  9937),  INT16_C(  4215),  INT16_C(   928),
        -INT16_C(  2036), -INT16_C(  2990),  INT16_C( 28619),  INT16_C( 27630), -INT16_C(  5780),  INT16_C( 28310), -INT16_C( 19524),  INT16_C(  6183),
         INT16_C( 15455),  INT16_C(  1293), -INT16_C(  8802), -INT16_C(  5859),  INT16_C( 19692),  INT16_C( 25538),  INT16_C( 25180),  INT16_C( 26726),
        -INT16_C( 18086),  INT16_C(  9564),  INT16_C( 18984), -INT16_C( 27503),  INT16_C( 10035), -INT16_C(  4094),  INT16_C( 10970),  INT16_C( 14600) },
      {  INT16_C(  5478),  INT16_C(  1086),  INT16_C( 23538), -INT16_C(  8467), -INT16_C( 20313),  INT16_C(   833), -INT16_C( 22510),  INT16_C( 28011),
        -INT16_C( 14495), -INT16_C( 30318),  INT16_C(  8977),  INT16_C( 17693),  INT16_C(  8011),  INT16_C(  9525),  INT16_C( 15689), -INT16_C( 20641),
        -INT16_C( 25262),  INT16_C( 17843), -INT16_C( 24071), -INT16_C( 24541),  INT16_C( 25937),  INT16_C( 25508),  INT16_C(  3853),  INT16_C( 28368),
         INT16_C( 25559), -INT16_C(  5897),  INT16_C(  5254), -INT16_C( 11987),  INT16_C( 25139),  INT16_C( 32247),  INT16_C( 22175), -INT16_C(  3540) },
      {  INT16_C(  9739),  INT16_C(  4946), -INT16_C( 16913), -INT16_C( 10715), -INT16_C( 20121),  INT16_C(   833),  INT16_C(  4517),  INT16_C( 28011),
        -INT16_C(  2036),  INT16_C( 26012),  INT16_C( 28619),  INT16_C( 27630),  INT16_C(  8011),  INT16_C( 28310),  INT16_C( 15689),  INT16_C(  6183),
         INT16_C( 15455),  INT16_C( 17843),  INT16_C(  1418), -INT16_C(  5859),  INT16_C( 25937),  INT16_C( 25538),  INT16_C( 25180),  INT16_C( 28368),
         INT16_C( 25559),  INT16_C(  9564),  INT16_C( 26765), -INT16_C( 11987), -INT16_C(   884),  INT16_C( 32247), -INT16_C( 11288), -INT16_C(  1508) } },
    { { -INT16_C(  7949), -INT16_C(  5065),  INT16_C( 23169), -INT16_C( 11635),  INT16_C( 12735), -INT16_C( 13259),  INT16_C(  1600),  INT16_C(  5946),
         INT16_C( 12649), -INT16_C(  4352),  INT16_C( 11589),  INT16_C( 31169), -INT16_C( 18288),  INT16_C( 12278),  INT16_C(  8718),  INT16_C(   289),
         INT16_C( 22530), -INT16_C( 31762),  INT16_C( 31667),  INT16_C( 29269), -INT16_C( 29780), -INT16_C(  5057),  INT16_C( 31121), -INT16_C(  1532),
         INT16_C(  1195), -INT16_C(  3863), -INT16_C( 21967), -INT16_C( 16023),  INT16_C( 24418),  INT16_C( 28913),  INT16_C(  4738), -INT16_C( 31630) },
      UINT32_C( 503865451),
      { -INT16_C( 12312),  INT16_C( 31091),  INT16_C( 30537), -INT16_C(  2957),  INT16_C( 23931), -INT16_C( 21020),  INT16_C( 19975),  INT16_C( 27246),
         INT16_C( 24493),  INT16_C( 12250),  INT16_C( 19570), -INT16_C(  8780), -INT16_C( 17236), -INT16_C( 30725), -INT16_C( 29927),  INT16_C(   526),
        -INT16_C( 32165), -INT16_C( 23429), -INT16_C(  4103),  INT16_C( 30104),  INT16_C( 31820),  INT16_C( 21282), -INT16_C( 28470),  INT16_C( 30909),
        -INT16_C( 26384),  INT16_C( 25255),  INT16_C( 23524), -INT16_C( 28353),  INT16_C( 14871),  INT16_C( 12568),  INT16_C( 10181),  INT16_C(  8243) },
      { -INT16_C( 20823), -INT16_C( 23868),  INT16_C( 23709), -INT16_C(  5865),  INT16_C( 14809), -INT16_C( 23747), -INT16_C(  1334), -INT16_C( 17893),
        -INT16_C( 15470),  INT16_C( 30492),  INT16_C( 23326),  INT16_C( 13832),  INT16_C(  8341),  INT16_C( 23143), -INT16_C( 26041), -INT16_C(  3973),
         INT16_C( 16200), -INT16_C(  6509), -INT16_C( 21860),  INT16_C( 30159),  INT16_C(  3300), -INT16_C( 20968),  INT16_C( 13319), -INT16_C( 26264),
        -INT16_C( 31497),  INT16_C(  5392),  INT16_C(  6367),  INT16_C( 29771), -INT16_C( 19911), -INT16_C( 32562),  INT16_C( 18764), -INT16_C( 27279) },
      { -INT16_C( 12312),  INT16_C( 31091),  INT16_C( 23169), -INT16_C(  2957),  INT16_C( 12735), -INT16_C( 21020),  INT16_C( 19975),  INT16_C(  5946),
         INT16_C( 12649), -INT16_C(  4352),  INT16_C( 11589),  INT16_C( 31169), -INT16_C( 18288),  INT16_C( 23143), -INT16_C( 26041),  INT16_C(   289),
         INT16_C( 22530), -INT16_C( 31762),  INT16_C( 31667),  INT16_C( 30159), -INT16_C( 29780), -INT16_C(  5057),  INT16_C( 31121), -INT16_C(  1532),
         INT16_C(  1195),  INT16_C( 25255),  INT16_C( 23524),  INT16_C( 29771),  INT16_C( 14871),  INT16_C( 28913),  INT16_C(  4738), -INT16_C( 31630) } },
    { {  INT16_C(  1161),  INT16_C(  9595),  INT16_C( 19118), -INT16_C( 28006), -INT16_C( 19881),  INT16_C( 24128), -INT16_C( 22298), -INT16_C(  8713),
         INT16_C(  2092),  INT16_C(  3059),  INT16_C( 15904),  INT16_C( 22911),  INT16_C( 20209),  INT16_C( 15834),  INT16_C( 19351),  INT16_C(  8402),
         INT16_C( 19791), -INT16_C(   699), -INT16_C(  8296), -INT16_C(  4208), -INT16_C( 12142),  INT16_C( 30797),  INT16_C( 17529), -INT16_C( 23210),
         INT16_C( 18764),  INT16_C( 28081),  INT16_C( 12423),  INT16_C( 30918), -INT16_C( 24450),  INT16_C(  5814), -INT16_C( 30485),  INT16_C( 14902) },
      UINT32_C(1849195734),
      { -INT16_C( 21864),  INT16_C(  4454), -INT16_C( 17170),  INT16_C( 15287),  INT16_C( 26629), -INT16_C( 29528),  INT16_C( 28312),  INT16_C(  5893),
        -INT16_C( 17649), -INT16_C(  1491),  INT16_C( 25411),  INT16_C(  6453),  INT16_C( 28127),  INT16_C( 15239), -INT16_C(  7115), -INT16_C( 13016),
        -INT16_C( 29042),  INT16_C( 32223), -INT16_C( 27062),  INT16_C( 20408),  INT16_C( 24830), -INT16_C( 26916), -INT16_C(  7730), -INT16_C(  8787),
        -INT16_C(  9572), -INT16_C(  8232),  INT16_C(  3390),  INT16_C(  7673), -INT16_C( 32646), -INT16_C( 20648), -INT16_C( 32411), -INT16_C(  3204) },
      {  INT16_C( 23311),  INT16_C( 23152),  INT16_C( 10481), -INT16_C(  4183), -INT16_C( 31352),  INT16_C( 22406),  INT16_C( 13158),  INT16_C(   564),
         INT16_C(  3086),  INT16_C( 19682), -INT16_C(  9447), -INT16_C( 27799), -INT16_C( 15781), -INT16_C( 16318), -INT16_C( 16573),  INT16_C( 21172),
         INT16_C(  9242),  INT16_C(  3244),  INT16_C( 22093), -INT16_C( 10757), -INT16_C( 32293),  INT16_C( 16940),  INT16_C( 25013), -INT16_C( 15548),
         INT16_C(  9837), -INT16_C( 30961),  INT16_C( 30721),  INT16_C( 23834),  INT16_C( 23866),  INT16_C( 32029), -INT16_C( 12004),  INT16_C( 14032) },
      {  INT16_C(  1161),  INT16_C( 23152),  INT16_C( 10481), -INT16_C( 28006),  INT16_C( 26629),  INT16_C( 24128),  INT16_C( 28312),  INT16_C(  5893),
         INT16_C(  2092),  INT16_C(  3059),  INT16_C( 25411),  INT16_C(  6453),  INT16_C( 28127),  INT16_C( 15239), -INT16_C(  7115),  INT16_C(  8402),
         INT16_C( 19791), -INT16_C(   699), -INT16_C(  8296),  INT16_C( 20408),  INT16_C( 24830),  INT16_C( 16940),  INT16_C( 17529), -INT16_C( 23210),
         INT16_C( 18764), -INT16_C(  8232),  INT16_C( 30721),  INT16_C( 23834), -INT16_C( 24450),  INT16_C( 32029), -INT16_C( 12004),  INT16_C( 14902) } },
    { {  INT16_C( 31990),  INT16_C( 17218),  INT16_C( 16082), -INT16_C( 20968),  INT16_C( 17855),  INT16_C( 29936),  INT16_C( 13478),  INT16_C(  4919),
         INT16_C( 18011),  INT16_C( 23706), -INT16_C( 19009), -INT16_C(  1607), -INT16_C( 10478),  INT16_C( 11895),  INT16_C( 18344), -INT16_C( 24988),
        -INT16_C( 22589), -INT16_C( 26911), -INT16_C(  1307), -INT16_C( 23484),  INT16_C( 13375), -INT16_C(  6887),  INT16_C( 20584), -INT16_C( 15368),
        -INT16_C( 27753),  INT16_C( 22048), -INT16_C(  9912),  INT16_C( 23119), -INT16_C( 14672),  INT16_C( 22920), -INT16_C(  5107), -INT16_C( 11785) },
      UINT32_C(2020071827),
      {  INT16_C( 14047),  INT16_C( 18423), -INT16_C(  4218),  INT16_C(  7435),  INT16_C( 11138), -INT16_C( 13709), -INT16_C( 15612), -INT16_C( 19164),
        -INT16_C( 21367), -INT16_C( 26866),  INT16_C(  1433),  INT16_C( 11368), -INT16_C( 12322), -INT16_C( 20059), -INT16_C( 15750),  INT16_C( 22979),
        -INT16_C( 17672),  INT16_C( 32416), -INT16_C( 21590),  INT16_C( 11420),  INT16_C(  4054), -INT16_C(  9225),  INT16_C(  7122),  INT16_C( 23696),
        -INT16_C( 24888),  INT16_C( 25075),  INT16_C( 23459), -INT16_C( 32115),  INT16_C( 12842), -INT16_C( 23501), -INT16_C(  2060), -INT16_C(  4867) },
      { -INT16_C( 25167),  INT16_C( 23403),  INT16_C(  1865),  INT16_C(  8072),  INT16_C( 32534), -INT16_C(  5638), -INT16_C( 30054),  INT16_C( 25157),
         INT16_C( 14376), -INT16_C( 13117),  INT16_C( 20883), -INT16_C( 17074), -INT16_C( 32381),  INT16_C( 30817),  INT16_C( 24184),  INT16_C( 10852),
        -INT16_C( 12293),  INT16_C( 17541),  INT16_C(  3542), -INT16_C(  4764),  INT16_C( 24204),  INT16_C( 10198),  INT16_C(  7145),  INT16_C(  4489),
         INT16_C( 19795), -INT16_C(  6435),  INT16_C( 11166),  INT16_C(  8611),  INT16_C(  1197),  INT16_C(  9625), -INT16_C(   414),  INT16_C( 23887) },
      {  INT16_C( 14047),  INT16_C( 23403),  INT16_C( 16082), -INT16_C( 20968),  INT16_C( 32534),  INT16_C( 29936),  INT16_C( 13478),  INT16_C( 25157),
         INT16_C( 14376),  INT16_C( 23706), -INT16_C( 19009),  INT16_C( 11368), -INT16_C( 12322),  INT16_C( 11895),  INT16_C( 24184),  INT16_C( 22979),
        -INT16_C( 12293),  INT16_C( 32416),  INT16_C(  3542), -INT16_C( 23484),  INT16_C( 13375),  INT16_C( 10198),  INT16_C(  7145), -INT16_C( 15368),
        -INT16_C( 27753),  INT16_C( 22048), -INT16_C(  9912),  INT16_C(  8611),  INT16_C( 12842),  INT16_C(  9625), -INT16_C(   414), -INT16_C( 11785) } },
    { { -INT16_C( 10803), -INT16_C( 23390),  INT16_C(  1762),  INT16_C( 28561),  INT16_C( 26468),  INT16_C( 19862),  INT16_C(  8066), -INT16_C( 10913),
         INT16_C( 15468),  INT16_C(  2747),  INT16_C( 24168),  INT16_C(  5420), -INT16_C( 15006), -INT16_C( 15302), -INT16_C( 30013), -INT16_C( 28383),
        -INT16_C( 15521),  INT16_C( 16693), -INT16_C( 14647),  INT16_C( 11952),  INT16_C( 17965), -INT16_C( 20613), -INT16_C(  9626), -INT16_C( 11644),
         INT16_C( 16151),  INT16_C( 32733),  INT16_C(  2461), -INT16_C(   108), -INT16_C( 12594), -INT16_C( 27965), -INT16_C(  7080), -INT16_C( 18653) },
      UINT32_C(1912166568),
      {  INT16_C(  7152),  INT16_C( 22266),  INT16_C( 32501),  INT16_C(  3112),  INT16_C(  1469),  INT16_C( 23179),  INT16_C(  7950), -INT16_C(  8871),
         INT16_C(  7406),  INT16_C( 18031), -INT16_C( 28160), -INT16_C( 22274), -INT16_C(  2070),  INT16_C(  2074), -INT16_C( 18016), -INT16_C( 28589),
         INT16_C( 19924), -INT16_C( 13594),  INT16_C(  4043), -INT16_C( 30506),  INT16_C( 25108),  INT16_C(  9186),  INT16_C( 15233),  INT16_C( 28416),
         INT16_C( 28503),  INT16_C( 22454), -INT16_C( 19455), -INT16_C(  5376),  INT16_C(  6827),  INT16_C( 19443),  INT16_C( 18131), -INT16_C( 22308) },
      { -INT16_C( 15725),  INT16_C( 24178),  INT16_C( 18641), -INT16_C(  6426), -INT16_C( 14166),  INT16_C( 11273),  INT16_C(  2307),  INT16_C( 23195),
         INT16_C( 20856),  INT16_C( 31153), -INT16_C( 20219), -INT16_C( 20380),  INT16_C( 22475), -INT16_C( 24580), -INT16_C( 10083),  INT16_C( 12359),
        -INT16_C( 18022),  INT16_C( 27790),  INT16_C( 29697), -INT16_C( 21422),  INT16_C( 23356),  INT16_C( 16344),  INT16_C( 29540), -INT16_C(  9063),
         INT16_C( 19141), -INT16_C( 13739), -INT16_C( 17924), -INT16_C( 14469),  INT16_C( 30480), -INT16_C( 21146), -INT16_C( 21169), -INT16_C(  5667) },
      { -INT16_C( 10803), -INT16_C( 23390),  INT16_C(  1762),  INT16_C(  3112),  INT16_C( 26468),  INT16_C( 23179),  INT16_C(  8066),  INT16_C( 23195),
         INT16_C( 15468),  INT16_C(  2747),  INT16_C( 24168), -INT16_C( 20380),  INT16_C( 22475), -INT16_C( 15302), -INT16_C( 10083), -INT16_C( 28383),
         INT16_C( 19924),  INT16_C( 16693), -INT16_C( 14647), -INT16_C( 21422),  INT16_C( 25108),  INT16_C( 16344),  INT16_C( 29540),  INT16_C( 28416),
         INT16_C( 28503),  INT16_C( 32733),  INT16_C(  2461), -INT16_C(   108),  INT16_C( 30480),  INT16_C( 19443),  INT16_C( 18131), -INT16_C( 18653) } },
    { {  INT16_C( 27494),  INT16_C( 26709), -INT16_C( 22561),  INT16_C(  6932), -INT16_C(  5118),  INT16_C( 26202), -INT16_C(  3233),  INT16_C(  9282),
        -INT16_C( 26819),  INT16_C( 14831),  INT16_C( 27216),  INT16_C( 24577),  INT16_C( 26593),  INT16_C( 12301), -INT16_C(  5611),  INT16_C( 31513),
         INT16_C( 28501),  INT16_C( 13539), -INT16_C(  2282),  INT16_C(  6479), -INT16_C( 22045),  INT16_C( 17279), -INT16_C( 15716), -INT16_C(  9625),
         INT16_C( 22105), -INT16_C( 21997),  INT16_C(  5312), -INT16_C( 24310),  INT16_C(  6268), -INT16_C( 28207), -INT16_C(  5374),  INT16_C( 22540) },
      UINT32_C(1888284762),
      {  INT16_C(  2437),  INT16_C(  8718),  INT16_C( 30155),  INT16_C(  9468),  INT16_C(  4044), -INT16_C( 29490), -INT16_C(  9948), -INT16_C( 24530),
        -INT16_C(    15), -INT16_C(  3279),  INT16_C( 15850),  INT16_C( 17483), -INT16_C( 10195),  INT16_C(  5557),  INT16_C( 16052),  INT16_C( 14816),
        -INT16_C(  4537),  INT16_C(  4699),  INT16_C( 22371),  INT16_C( 12087),  INT16_C(  1383), -INT16_C( 29764), -INT16_C(  5410), -INT16_C( 12501),
         INT16_C( 23785), -INT16_C( 11069),  INT16_C(  3737), -INT16_C( 14568), -INT16_C( 12826), -INT16_C( 25892), -INT16_C( 17396),  INT16_C( 21460) },
      {  INT16_C( 12202),  INT16_C(  3430), -INT16_C( 25209), -INT16_C(  4547), -INT16_C(  1630), -INT16_C( 32391), -INT16_C( 23325), -INT16_C( 13232),
         INT16_C(  4864), -INT16_C( 26208), -INT16_C( 18142),  INT16_C(  2144),  INT16_C( 15494), -INT16_C( 27997),  INT16_C( 30712), -INT16_C( 23834),
         INT16_C( 19622),  INT16_C( 11696), -INT16_C(  4631), -INT16_C( 29925), -INT16_C( 27418), -INT16_C( 14068),  INT16_C( 23864),  INT16_C( 14485),
         INT16_C( 13936), -INT16_C( 27950),  INT16_C( 13039),  INT16_C( 30107),  INT16_C( 15983),  INT16_C( 26376), -INT16_C(  4427),  INT16_C( 23306) },
      {  INT16_C( 27494),  INT16_C(  8718), -INT16_C( 22561),  INT16_C(  9468),  INT16_C(  4044),  INT16_C( 26202), -INT16_C(  9948),  INT16_C(  9282),
        -INT16_C( 26819),  INT16_C( 14831),  INT16_C( 27216),  INT16_C( 24577),  INT16_C( 15494),  INT16_C(  5557),  INT16_C( 30712),  INT16_C( 14816),
         INT16_C( 28501),  INT16_C( 13539),  INT16_C( 22371),  INT16_C( 12087), -INT16_C( 22045),  INT16_C( 17279), -INT16_C( 15716),  INT16_C( 14485),
         INT16_C( 22105), -INT16_C( 21997),  INT16_C(  5312), -INT16_C( 24310),  INT16_C( 15983),  INT16_C( 26376), -INT16_C(  4427),  INT16_C( 22540) } },
    { { -INT16_C( 17862),  INT16_C(  9097), -INT16_C( 23385), -INT16_C( 29266), -INT16_C( 17607),  INT16_C( 29014), -INT16_C(  5352), -INT16_C( 30550),
         INT16_C( 31777),  INT16_C(  4123), -INT16_C( 18770),  INT16_C(  7558), -INT16_C( 28940), -INT16_C( 22139), -INT16_C( 28804), -INT16_C( 18940),
        -INT16_C( 29367), -INT16_C(  3879), -INT16_C( 30926),  INT16_C( 27517), -INT16_C( 11454),  INT16_C( 23260), -INT16_C( 31042), -INT16_C(  7965),
        -INT16_C(   510), -INT16_C( 19984),  INT16_C( 30388), -INT16_C( 22322),  INT16_C( 21252), -INT16_C( 32687),  INT16_C( 21986),  INT16_C( 11062) },
      UINT32_C( 354095075),
      {  INT16_C( 23659),  INT16_C( 10804),  INT16_C(  6115), -INT16_C(  6902), -INT16_C(  1515), -INT16_C( 13930),  INT16_C( 25969),  INT16_C( 30065),
        -INT16_C( 15688), -INT16_C( 25610),  INT16_C( 11287), -INT16_C(  1338), -INT16_C(  7620), -INT16_C( 11505), -INT16_C( 28806), -INT16_C(  6484),
        -INT16_C(  7956), -INT16_C( 12528),  INT16_C(  6903),  INT16_C(  3252),  INT16_C( 19220), -INT16_C( 31275),  INT16_C( 18096),  INT16_C( 26875),
        -INT16_C(  3832),  INT16_C(  8195), -INT16_C( 13795),  INT16_C( 22810),  INT16_C( 10924),  INT16_C(  9772), -INT16_C(  9799), -INT16_C( 23284) },
      {  INT16_C(  7353), -INT16_C( 20108),  INT16_C( 10550),  INT16_C( 19389), -INT16_C( 27788),  INT16_C(  9424), -INT16_C( 13351), -INT16_C(  7540),
        -INT16_C( 28484), -INT16_C(  9726),  INT16_C(  7258),  INT16_C(  1587),  INT16_C( 24646),  INT16_C(    44),  INT16_C( 14649), -INT16_C(  3419),
         INT16_C(  6741), -INT16_C( 29533),  INT16_C( 24899), -INT16_C( 18473), -INT16_C( 22540), -INT16_C( 12837),  INT16_C( 26483),  INT16_C( 12207),
        -INT16_C( 19977),  INT16_C( 20745),  INT16_C( 15822),  INT16_C(  5207), -INT16_C( 31587), -INT16_C( 10732), -INT16_C( 17731),  INT16_C(  4808) },
      {  INT16_C( 23659),  INT16_C( 10804), -INT16_C( 23385), -INT16_C( 29266), -INT16_C( 17607),  INT16_C(  9424),  INT16_C( 25969),  INT16_C( 30065),
        -INT16_C( 15688), -INT16_C(  9726),  INT16_C( 11287),  INT16_C(  1587), -INT16_C( 28940), -INT16_C( 22139), -INT16_C( 28804), -INT16_C( 18940),
         INT16_C(  6741), -INT16_C( 12528), -INT16_C( 30926),  INT16_C(  3252),  INT16_C( 19220),  INT16_C( 23260), -INT16_C( 31042), -INT16_C(  7965),
        -INT16_C(  3832), -INT16_C( 19984),  INT16_C( 15822), -INT16_C( 22322),  INT16_C( 10924), -INT16_C( 32687),  INT16_C( 21986),  INT16_C( 11062) } }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
    simde__m512i src = simde_mm512_loadu_epi16(test_vec[i].src);
    simde__m512i a = simde_mm512_loadu_epi16(test_vec[i].a);
    simde__m512i b = simde_mm512_loadu_epi16(test_vec[i].b);
    simde__m512i r = simde_mm512_mask_max_epi16(src, test_vec[i].k, a, b);
    simde_test_x86_assert_equal_i16x32(r, simde_mm512_loadu_epi16(test_vec[i].r));
  }

  return 0;
}

static int
test_simde_mm512_maskz_max_epi16 (SIMDE_MUNIT_TEST_ARGS) {
  static const struct {
    const simde__mmask32 k;
    const int16_t a[32];
    const int16_t b[32];
    const int16_t r[32];
  } test_vec[] = {
    { UINT32_C(3465174033),
      {  INT16_C(   193), -INT16_C( 29734), -INT16_C( 20936),  INT16_C(    94),  INT16_C( 26271),  INT16_C( 26954), -INT16_C( 16407),  INT16_C( 11234),
        -INT16_C( 22766), -INT16_C( 30451),  INT16_C(   983), -INT16_C(  6005),  INT16_C(  5471),  INT16_C( 22967), -INT16_C( 24720),  INT16_C( 12840),
         INT16_C(   672), -INT16_C( 10051),  INT16_C(  7088),  INT16_C( 20697),  INT16_C(  9089),  INT16_C( 27577), -INT16_C( 25374), -INT16_C(  2666),
        -INT16_C( 23741),  INT16_C(  6782),  INT16_C(  2470),  INT16_C(  1283), -INT16_C( 17889), -INT16_C( 28834), -INT16_C( 30887), -INT16_C(  1599) },
      {  INT16_C( 32393),  INT16_C( 15058), -INT16_C( 21607),  INT16_C(  7050),  INT16_C( 17358), -INT16_C( 20346),  INT16_C(  7391),  INT16_C(  9125),
         INT16_C(  9152),  INT16_C( 26173),  INT16_C( 16429),  INT16_C( 19564), -INT16_C( 13574),  INT16_C( 21723), -INT16_C( 25263), -INT16_C(  9395),
         INT16_C(  7963), -INT16_C( 19179), -INT16_C( 24630), -INT16_C( 26416),  INT16_C( 22242), -INT16_C( 15799), -INT16_C(  4494),  INT16_C( 13029),
         INT16_C(  8722),  INT16_C( 16281),  INT16_C(  1379),  INT16_C( 23947),  INT16_C( 26319),  INT16_C(  8625), -INT16_C(   253),  INT16_C(  8188) },
      {  INT16_C( 32393),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C( 26271),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0),  INT16_C( 16429),  INT16_C( 19564),  INT16_C(  5471),  INT16_C(     0), -INT16_C( 24720),  INT16_C(     0),
         INT16_C(     0), -INT16_C( 10051),  INT16_C(     0),  INT16_C( 20697),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C( 13029),
         INT16_C(     0),  INT16_C( 16281),  INT16_C(  2470),  INT16_C( 23947),  INT16_C(     0),  INT16_C(     0), -INT16_C(   253),  INT16_C(  8188) } },
    { UINT32_C(3922989342),
      { -INT16_C( 13574),  INT16_C( 27732),  INT16_C( 14777), -INT16_C( 13409),  INT16_C( 14428), -INT16_C( 16630), -INT16_C( 27331),  INT16_C(  3100),
        -INT16_C( 12549), -INT16_C(   211),  INT16_C( 10701), -INT16_C(  5346), -INT16_C(  3526), -INT16_C(  5420),  INT16_C( 22166), -INT16_C( 28547),
        -INT16_C( 12000), -INT16_C(  9732), -INT16_C( 25845),  INT16_C( 26532), -INT16_C( 20781),  INT16_C(  4134),  INT16_C( 16963),  INT16_C( 16157),
         INT16_C( 18960), -INT16_C(  8898),  INT16_C( 23668), -INT16_C( 20791), -INT16_C( 25266), -INT16_C(  7015),  INT16_C(  5875),  INT16_C(  5236) },
      {  INT16_C( 28903), -INT16_C(  3347), -INT16_C( 28148), -INT16_C(  8359),  INT16_C( 32576), -INT16_C( 31504),  INT16_C(  3522), -INT16_C( 11581),
         INT16_C(   343), -INT16_C( 13392),  INT16_C( 31069), -INT16_C( 21638),  INT16_C(  4886),  INT16_C(  2703),  INT16_C(   809),  INT16_C(  4126),
         INT16_C(  2931),  INT16_C( 32515),  INT16_C( 23709), -INT16_C(  8609),  INT16_C( 20444), -INT16_C( 24990),  INT16_C(  9564), -INT16_C( 19600),
         INT16_C(  8230), -INT16_C( 31873), -INT16_C(  1639), -INT16_C( 20434), -INT16_C( 17140),  INT16_C( 13754), -INT16_C( 10048),  INT16_C( 13125) },
      {  INT16_C(     0),  INT16_C( 27732),  INT16_C( 14777), -INT16_C(  8359),  INT16_C( 32576),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C(   343),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(  4886),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0),  INT16_C( 23709),  INT16_C(     0),  INT16_C( 20444),  INT16_C(     0),  INT16_C( 16963),  INT16_C( 16157),
         INT16_C( 18960),  INT16_C(     0),  INT16_C(     0), -INT16_C( 20434),  INT16_C(     0),  INT16_C( 13754),  INT16_C(  5875),  INT16_C( 13125) } },
    { UINT32_C(2176010467),
      { -INT16_C( 16031), -INT16_C( 17121), -INT16_C( 28698),  INT16_C(  3184), -INT16_C(  4176),  INT16_C( 18831), -INT16_C( 16920), -INT16_C(  2823),
        -INT16_C( 19590),  INT16_C( 14889),  INT16_C( 28555),  INT16_C( 28525),  INT16_C(  8375),  INT16_C( 23792),  INT16_C( 20274), -INT16_C( 27683),
        -INT16_C(  1008), -INT16_C(  2480), -INT16_C( 15988),  INT16_C( 15362), -INT16_C( 28240), -INT16_C( 26235),  INT16_C( 32590), -INT16_C( 14195),
        -INT16_C( 18638), -INT16_C( 16894),  INT16_C( 28454), -INT16_C(  8915),  INT16_C(  7568), -INT16_C( 15814),  INT16_C(  5996),  INT16_C( 31830) },
      { -INT16_C( 23020), -INT16_C( 24462),  INT16_C( 29799),  INT16_C(  6364),  INT16_C( 24837),  INT16_C( 21425),  INT16_C( 16096),  INT16_C(  4891),
         INT16_C(  7669),  INT16_C(  7121), -INT16_C(   372),  INT16_C(  7417),  INT16_C( 13083), -INT16_C( 30753),  INT16_C( 13642),  INT16_C( 24067),
         INT16_C( 30171),  INT16_C( 17406), -INT16_C(  9495), -INT16_C(  4517),  INT16_C(  3132),  INT16_C(  7233),  INT16_C( 23626),  INT16_C( 16431),
         INT16_C(   121),  INT16_C(  1371),  INT16_C( 21758),  INT16_C(  6434),  INT16_C(   391), -INT16_C( 11616), -INT16_C( 23754),  INT16_C(  4400) },
      { -INT16_C( 16031), -INT16_C( 17121),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C( 21425),  INT16_C( 16096),  INT16_C(  4891),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C( 28525),  INT16_C(     0),  INT16_C(     0),  INT16_C( 20274),  INT16_C(     0),
         INT16_C( 30171),  INT16_C( 17406),  INT16_C(     0),  INT16_C(     0),  INT16_C(  3132),  INT16_C(  7233),  INT16_C(     0),  INT16_C( 16431),
         INT16_C(   121),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C( 31830) } },
    { UINT32_C(  22294296),
      {  INT16_C( 12475),  INT16_C(  1634), -INT16_C( 28276),  INT16_C(  1350), -INT16_C( 24174), -INT16_C( 28661),  INT16_C( 11766),  INT16_C( 32170),
         INT16_C( 18990),  INT16_C( 25679), -INT16_C( 32530),  INT16_C(  1653), -INT16_C( 13649), -INT16_C( 18424), -INT16_C(  2183),  INT16_C( 13822),
         INT16_C( 24616), -INT16_C( 19397), -INT16_C( 32271), -INT16_C( 31814), -INT16_C( 15070),  INT16_C(  6164), -INT16_C( 16654),  INT16_C(  8342),
        -INT16_C(  6904), -INT16_C(  2428), -INT16_C(  1691),  INT16_C(  5373),  INT16_C(  1475),  INT16_C( 15821), -INT16_C( 13316),  INT16_C(  9330) },
      { -INT16_C( 21205),  INT16_C(  7385), -INT16_C( 27858),  INT16_C( 20640), -INT16_C( 19368),  INT16_C( 19049), -INT16_C(   142),  INT16_C( 31338),
        -INT16_C(  4380),  INT16_C( 19057),  INT16_C( 28391), -INT16_C( 21666),  INT16_C( 11123),  INT16_C( 28648),  INT16_C( 23286),  INT16_C(  8596),
         INT16_C( 27911),  INT16_C( 13630), -INT16_C(  8704),  INT16_C( 22661), -INT16_C(  4462),  INT16_C(  1186),  INT16_C(  3309), -INT16_C( 11650),
        -INT16_C(  4102), -INT16_C(  7908),  INT16_C( 31325), -INT16_C( 12148),  INT16_C( 29862), -INT16_C( 25536), -INT16_C( 11058), -INT16_C( 10818) },
      {  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C( 20640), -INT16_C( 19368),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C( 18990),  INT16_C( 25679),  INT16_C( 28391),  INT16_C(  1653),  INT16_C(     0),  INT16_C( 28648),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0), -INT16_C(  8704),  INT16_C(     0), -INT16_C(  4462),  INT16_C(     0),  INT16_C(  3309),  INT16_C(     0),
        -INT16_C(  4102),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0) } },
    { UINT32_C(1091238977),
      {  INT16_C( 15230),  INT16_C( 27760), -INT16_C(  4537),  INT16_C( 16702),  INT16_C( 23262),  INT16_C( 15138), -INT16_C( 20524),  INT16_C( 31244),
         INT16_C( 19491), -INT16_C(  3561), -INT16_C( 10976),  INT16_C( 25031), -INT16_C( 11567), -INT16_C( 21598),  INT16_C( 15202), -INT16_C(  8169),
        -INT16_C( 30858), -INT16_C( 17076), -INT16_C( 30091),  INT16_C( 21502),  INT16_C(  8420), -INT16_C( 18033), -INT16_C( 25649), -INT16_C(  3277),
         INT16_C( 19175),  INT16_C(  2021), -INT16_C( 21473), -INT16_C(  3992),  INT16_C(  2686), -INT16_C(  8037), -INT16_C( 19899), -INT16_C( 17471) },
      {  INT16_C(  3385), -INT16_C( 20616),  INT16_C( 30360),  INT16_C( 31746), -INT16_C( 28266),  INT16_C( 26165),  INT16_C( 26924),  INT16_C(  4953),
         INT16_C( 16051), -INT16_C( 11494), -INT16_C( 32022),  INT16_C( 27075),  INT16_C( 24460), -INT16_C( 11959),  INT16_C(  2577),  INT16_C( 19340),
         INT16_C(  1048), -INT16_C( 20230), -INT16_C(   902),  INT16_C(  4396),  INT16_C( 25230), -INT16_C( 17801), -INT16_C( 12085),  INT16_C( 32462),
        -INT16_C(  6130), -INT16_C(  1967),  INT16_C(  5483), -INT16_C(  2207), -INT16_C( 21644), -INT16_C( 31287),  INT16_C( 21941), -INT16_C( 12848) },
      {  INT16_C( 15230),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C( 26924),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0), -INT16_C( 10976),  INT16_C( 27075),  INT16_C( 24460), -INT16_C( 11959),  INT16_C( 15202),  INT16_C( 19340),
         INT16_C(     0), -INT16_C( 17076),  INT16_C(     0),  INT16_C( 21502),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C( 19175),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C( 21941),  INT16_C(     0) } },
    { UINT32_C(3565013594),
      {  INT16_C( 23564), -INT16_C( 10481), -INT16_C(  8916),  INT16_C( 14933), -INT16_C( 22586),  INT16_C( 12595), -INT16_C( 27460),  INT16_C( 12328),
        -INT16_C(  3777), -INT16_C(  2635), -INT16_C( 31161), -INT16_C( 24126),  INT16_C( 16464),  INT16_C(  6005),  INT16_C( 23530), -INT16_C(  2452),
         INT16_C( 31927), -INT16_C(  6963),  INT16_C(  8793),  INT16_C(  7966),  INT16_C( 20937), -INT16_C( 31408),  INT16_C( 31206),  INT16_C(  9653),
         INT16_C( 27498), -INT16_C( 20198), -INT16_C(  8719),  INT16_C( 16722), -INT16_C( 14307),  INT16_C(  1881), -INT16_C( 15069), -INT16_C(  9475) },
      { -INT16_C( 13759), -INT16_C( 25666), -INT16_C(  8724), -INT16_C( 18758),  INT16_C(  2862),  INT16_C(  5179), -INT16_C(  3708), -INT16_C(  4550),
         INT16_C( 21596),  INT16_C( 19872), -INT16_C(  3535),  INT16_C( 20110), -INT16_C(  6214), -INT16_C(  8875),  INT16_C( 21165), -INT16_C(  4424),
         INT16_C( 30236),  INT16_C(  2441),  INT16_C( 17491), -INT16_C( 32065), -INT16_C(  1457), -INT16_C( 11370), -INT16_C( 12053),  INT16_C( 18369),
         INT16_C( 24869),  INT16_C( 22164),  INT16_C(  9044),  INT16_C(  3749), -INT16_C(  1526), -INT16_C( 18452), -INT16_C( 23475),  INT16_C( 27046) },
      {  INT16_C(     0), -INT16_C( 10481),  INT16_C(     0),  INT16_C( 14933),  INT16_C(  2862),  INT16_C(     0), -INT16_C(  3708),  INT16_C(     0),
         INT16_C(     0),  INT16_C( 19872),  INT16_C(     0),  INT16_C( 20110),  INT16_C(     0),  INT16_C(     0),  INT16_C( 23530), -INT16_C(  2452),
         INT16_C( 31927),  INT16_C(     0),  INT16_C( 17491),  INT16_C(  7966),  INT16_C( 20937), -INT16_C( 11370),  INT16_C( 31206),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0),  INT16_C(  9044),  INT16_C(     0), -INT16_C(  1526),  INT16_C(     0), -INT16_C( 15069),  INT16_C( 27046) } },
    { UINT32_C(1852976922),
      { -INT16_C( 31188),  INT16_C(  6037),  INT16_C( 22359),  INT16_C( 31839), -INT16_C(  3144),  INT16_C(  3282),  INT16_C( 30486),  INT16_C(  8475),
         INT16_C(  1906), -INT16_C( 16424),  INT16_C( 32427), -INT16_C( 15064), -INT16_C( 25682),  INT16_C(  8499),  INT16_C(  9164), -INT16_C(  1820),
         INT16_C( 31146),  INT16_C(   272),  INT16_C( 28624), -INT16_C( 30339),  INT16_C( 20322),  INT16_C( 31125), -INT16_C( 20281),  INT16_C( 14746),
         INT16_C( 29367),  INT16_C( 25336),  INT16_C(  8433), -INT16_C( 24792),  INT16_C( 23483), -INT16_C( 30528), -INT16_C( 23425),  INT16_C( 10624) },
      { -INT16_C( 28642), -INT16_C(  4566), -INT16_C( 22529),  INT16_C( 25207),  INT16_C(  3574), -INT16_C( 16933),  INT16_C( 30141),  INT16_C( 30198),
        -INT16_C(  4377), -INT16_C( 10025), -INT16_C(   241), -INT16_C( 13705),  INT16_C( 14427), -INT16_C(  9646), -INT16_C( 11300), -INT16_C(  1533),
         INT16_C( 11619),  INT16_C( 25577),  INT16_C( 24788), -INT16_C( 13627), -INT16_C( 24467),  INT16_C( 11144),  INT16_C( 32277), -INT16_C(   864),
         INT16_C( 30573),  INT16_C( 31957),  INT16_C( 19575), -INT16_C( 11706), -INT16_C( 26236),  INT16_C( 25004), -INT16_C( 20628), -INT16_C( 12453) },
      {  INT16_C(     0),  INT16_C(  6037),  INT16_C(     0),  INT16_C( 31839),  INT16_C(  3574),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C(  1906), -INT16_C( 10025),  INT16_C( 32427), -INT16_C( 13705),  INT16_C(     0),  INT16_C(  8499),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C( 25577),  INT16_C(     0),  INT16_C(     0),  INT16_C( 20322),  INT16_C( 31125),  INT16_C( 32277),  INT16_C(     0),
         INT16_C(     0),  INT16_C( 31957),  INT16_C( 19575), -INT16_C( 11706),  INT16_C(     0),  INT16_C( 25004), -INT16_C( 20628),  INT16_C(     0) } },
    { UINT32_C(2956084444),
      {  INT16_C(   663), -INT16_C( 21443), -INT16_C(  8831), -INT16_C(  4439),  INT16_C( 32341), -INT16_C( 13206), -INT16_C( 20278),  INT16_C( 20382),
         INT16_C( 19017), -INT16_C( 19024),  INT16_C(  3065), -INT16_C( 10875), -INT16_C( 18608), -INT16_C(  2683), -INT16_C(    81),  INT16_C( 17927),
         INT16_C( 17666), -INT16_C( 31757), -INT16_C( 25566),  INT16_C( 30577), -INT16_C(  9446), -INT16_C(  7101), -INT16_C(  7797), -INT16_C( 10957),
        -INT16_C(  7381),  INT16_C(  9354),  INT16_C(  4079),  INT16_C( 16377),  INT16_C( 32455),  INT16_C( 30260),  INT16_C( 15230), -INT16_C( 32580) },
      { -INT16_C( 20608), -INT16_C( 23805),  INT16_C( 29771),  INT16_C( 25882),  INT16_C( 24143), -INT16_C(  9654),  INT16_C( 32063),  INT16_C( 27567),
         INT16_C( 14945),  INT16_C( 20623), -INT16_C( 30391),  INT16_C(  4239), -INT16_C( 15609), -INT16_C( 31354),  INT16_C( 17406),  INT16_C( 32517),
         INT16_C(  2290),  INT16_C( 15906),  INT16_C( 15484), -INT16_C( 13405), -INT16_C(  4710), -INT16_C(  9562),  INT16_C( 21867), -INT16_C( 13243),
        -INT16_C( 11121), -INT16_C(  9956), -INT16_C( 21667),  INT16_C( 26089),  INT16_C( 28782),  INT16_C( 27882), -INT16_C(  3917), -INT16_C( 23061) },
      {  INT16_C(     0),  INT16_C(     0),  INT16_C( 29771),  INT16_C( 25882),  INT16_C( 32341),  INT16_C(     0),  INT16_C( 32063),  INT16_C( 27567),
         INT16_C(     0),  INT16_C(     0),  INT16_C(  3065),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C( 17406),  INT16_C(     0),
         INT16_C(     0),  INT16_C( 15906),  INT16_C(     0),  INT16_C(     0), -INT16_C(  4710), -INT16_C(  7101),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C( 32455),  INT16_C( 30260),  INT16_C(     0), -INT16_C( 23061) } }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
    simde__m512i a = simde_mm512_loadu_epi16(test_vec[i].a);
    simde__m512i b = simde_mm512_loadu_epi16(test_vec[i].b);
    simde__m512i r = simde_mm512_maskz_max_epi16(test_vec[i].k, a, b);
    simde_test_x86_assert_equal_i16x32(r, simde_mm512_loadu_epi16(test_vec[i].r));
  }

  return 0;
}

static int
test_simde_mm512_max_epu16 (SIMDE_MUNIT_TEST_ARGS) {
  static const struct {
    const uint16_t a[32];
    const uint16_t b[32];
    const uint16_t r[32];
  } test_vec[] = {
    { { UINT16_C(39893), UINT16_C(12168), UINT16_C(15734), UINT16_C(45768), UINT16_C( 4464), UINT16_C(63629), UINT16_C(35362), UINT16_C(32306),
        UINT16_C(62286), UINT16_C(19220), UINT16_C(14705), UINT16_C(45343), UINT16_C(57947), UINT16_C(40021), UINT16_C(16202), UINT16_C( 8136),
        UINT16_C(20699), UINT16_C(20814), UINT16_C( 5774), UINT16_C(65027), UINT16_C(37160), UINT16_C(19190), UINT16_C(10523), UINT16_C(27080),
        UINT16_C(56604), UINT16_C(36276), UINT16_C(54038), UINT16_C(28990), UINT16_C(37813), UINT16_C(65293), UINT16_C(54739), UINT16_C(44574) },
      { UINT16_C(27686), UINT16_C(46335), UINT16_C(  898), UINT16_C(43698), UINT16_C(43412), UINT16_C(45045), UINT16_C(48594), UINT16_C(60952),
        UINT16_C(52378), UINT16_C(45435), UINT16_C(47775), UINT16_C(21538), UINT16_C(12365), UINT16_C( 8275), UINT16_C(28933), UINT16_C(11214),
        UINT16_C(52957), UINT16_C(24543), UINT16_C(37585), UINT16_C(25866), UINT16_C(65339), UINT16_C( 3348), UINT16_C(11452), UINT16_C(22523),
        UINT16_C(30456), UINT16_C(38664), UINT16_C(10800), UINT16_C(32491), UINT16_C(15962), UINT16_C(24734), UINT16_C(28079), UINT16_C(35979) },
      { UINT16_C(39893), UINT16_C(46335), UINT16_C(15734), UINT16_C(45768), UINT16_C(43412), UINT16_C(63629), UINT16_C(48594), UINT16_C(60952),
        UINT16_C(62286), UINT16_C(45435), UINT16_C(47775), UINT16_C(45343), UINT16_C(57947), UINT16_C(40021), UINT16_C(28933), UINT16_C(11214),
        UINT16_C(52957), UINT16_C(24543), UINT16_C(37585), UINT16_C(65027), UINT16_C(65339), UINT16_C(19190), UINT16_C(11452), UINT16_C(27080),
        UINT16_C(56604), UINT16_C(38664), UINT16_C(54038), UINT16_C(32491), UINT16_C(37813), UINT16_C(65293), UINT16_C(54739), UINT16_C(44574) } },
    { { UINT16_C(27451), UINT16_C( 3307), UINT16_C(62973), UINT16_C(14449), UINT16_C(34292), UINT16_C(45381), UINT16_C(16561), UINT16_C(43272),
        UINT16_C( 4278), UINT16_C(59200), UINT16_C(11066), UINT16_C(38245), UINT16_C(  873), UINT16_C( 6389), UINT16_C(32880), UINT16_C(43940),
        UINT16_C(36843), UINT16_C(59575), UINT16_C(10373), UINT16_C(31008), UINT16_C(26029), UINT16_C(24106), UINT16_C(12965), UINT16_C(23559),
        UINT16_C(18242), UINT16_C(32067), UINT16_C(43122), UINT16_C(56082), UINT16_C( 1963), UINT16_C( 7411), UINT16_C(38791), UINT16_C(29639) },
      { UINT16_C(32551), UINT16_C(44123), UINT16_C(31911), UINT16_C(21797), UINT16_C(20705), UINT16_C(34739), UINT16_C(48002), UINT16_C(50659),
        UINT16_C( 9730), UINT16_C(30018), UINT16_C(21710), UINT16_C(31056), UINT16_C(17499), UINT16_C(58005), UINT16_C(24027), UINT16_C(  597),
        UINT16_C(45532), UINT16_C(33710), UINT16_C(54317), UINT16_C( 3800), UINT16_C(35876), UINT16_C(42645), UINT16_C(30791), UINT16_C(18795),
        UINT16_C(44446), UINT16_C(27838), UINT16_C( 3841), UINT16_C(23782), UINT16_C(31571), UINT16_C(11839), UINT16_C(38104), UINT16_C(46129) },
      { UINT16_C(32551), UINT16_C(44123), UINT16_C(62973), UINT16_C(21797), UINT16_C(34292), UINT16_C(45381), UINT16_C(48002), UINT16_C(50659),
        UINT16_C( 9730), UINT16_C(59200), UINT16_C(21710), UINT16_C(38245), UINT16_C(17499), UINT16_C(58005), UINT16_C(32880), UINT16_C(43940),
        UINT16_C(45532), UINT16_C(59575), UINT16_C(54317), UINT16_C(31008), UINT16_C(35876), UINT16_C(42645), UINT16_C(30791), UINT16_C(23559),
        UINT16_C(44446), UINT16_C(32067), UINT16_C(43122), UINT16_C(56082), UINT16_C(31571), UINT16_C(11839), UINT16_C(38791), UINT16_C(46129) } },
    { { UINT16_C(57157), UINT16_C(29240), UINT16_C( 4275), UINT16_C(55169), UINT16_C( 5788), UINT16_C(58238), UINT16_C(59791), UINT16_C(11565),
        UINT16_C(60311), UINT16_C(39066), UINT16_C(33018), UINT16_C(19957), UINT16_C(13563), UINT16_C(54396), UINT16_C(44488), UINT16_C( 3720),
        UINT16_C(49292), UINT16_C(16512), UINT16_C(  465), UINT16_C(27927), UINT16_C(38168), UINT16_C(42833), UINT16_C(32383), UINT16_C( 5844),
        UINT16_C(28265), UINT16_C(25774), UINT16_C(41966), UINT16_C(60081), UINT16_C(11735), UINT16_C(41150), UINT16_C(18138), UINT16_C(26542) },
      { UINT16_C(11783), UINT16_C(55463), UINT16_C(48688), UINT16_C(18501), UINT16_C(38484), UINT16_C(54255), UINT16_C(49940), UINT16_C(32489),
        UINT16_C(38706), UINT16_C( 8418), UINT16_C(37691), UINT16_C( 4618), UINT16_C(51393), UINT16_C(39858), UINT16_C(24591), UINT16_C( 5634),
        UINT16_C(43407), UINT16_C(49134), UINT16_C(13160), UINT16_C(48135), UINT16_C(63178), UINT16_C(56975), UINT16_C(30905), UINT16_C(60252),
        UINT16_C(15887), UINT16_C(18956), UINT16_C( 5842), UINT16_C(37725), UINT16_C( 4063), UINT16_C(60974), UINT16_C(12656), UINT16_C(65284) },
      { UINT16_C(57157), UINT16_C(55463), UINT16_C(48688), UINT16_C(55169), UINT16_C(38484), UINT16_C(58238), UINT16_C(59791), UINT16_C(32489),
        UINT16_C(60311), UINT16_C(39066), UINT16_C(37691), UINT16_C(19957), UINT16_C(51393), UINT16_C(54396), UINT16_C(44488), UINT16_C( 5634),
        UINT16_C(49292), UINT16_C(49134), UINT16_C(13160), UINT16_C(48135), UINT16_C(63178), UINT16_C(56975), UINT16_C(32383), UINT16_C(60252),
        UINT16_C(28265), UINT16_C(25774), UINT16_C(41966), UINT16_C(60081), UINT16_C(11735), UINT16_C(60974), UINT16_C(18138), UINT16_C(65284) } },
    { { UINT16_C(62170), UINT16_C(17086), UINT16_C(50469), UINT16_C(61438), UINT16_C(36283), UINT16_C(29902), UINT16_C(10757), UINT16_C( 5472),
        UINT16_C(27753), UINT16_C(15199), UINT16_C(48258), UINT16_C(25038), UINT16_C(64716), UINT16_C(15439), UINT16_C(21293), UINT16_C( 2107),
        UINT16_C(63813), UINT16_C(27466), UINT16_C(18878), UINT16_C(31066), UINT16_C(10454), UINT16_C(56557), UINT16_C(19795), UINT16_C(48369),
        UINT16_C(20665), UINT16_C(15607), UINT16_C(50445), UINT16_C(55709), UINT16_C(60865), UINT16_C(61205), UINT16_C(20544), UINT16_C(34551) },
      { UINT16_C(16713), UINT16_C( 2033), UINT16_C(19338), UINT16_C(24960), UINT16_C(28020), UINT16_C(51005), UINT16_C(11963), UINT16_C(29827),
        UINT16_C(31358), UINT16_C(35760), UINT16_C(20031), UINT16_C(  100), UINT16_C(31035), UINT16_C(31727), UINT16_C(59081), UINT16_C( 4609),
        UINT16_C(61992), UINT16_C(45593), UINT16_C(39230), UINT16_C(45587), UINT16_C(20487), UINT16_C(49785), UINT16_C(64638), UINT16_C(64822),
        UINT16_C(59254), UINT16_C(46472), UINT16_C(60725), UINT16_C(28853), UINT16_C(42342), UINT16_C(12523), UINT16_C(60811), UINT16_C(45890) },
      { UINT16_C(62170), UINT16_C(17086), UINT16_C(50469), UINT16_C(61438), UINT16_C(36283), UINT16_C(51005), UINT16_C(11963), UINT16_C(29827),
        UINT16_C(31358), UINT16_C(35760), UINT16_C(48258), UINT16_C(25038), UINT16_C(64716), UINT16_C(31727), UINT16_C(59081), UINT16_C( 4609),
        UINT16_C(63813), UINT16_C(45593), UINT16_C(39230), UINT16_C(45587), UINT16_C(20487), UINT16_C(56557), UINT16_C(64638), UINT16_C(64822),
        UINT16_C(59254), UINT16_C(46472), UINT16_C(60725), UINT16_C(55709), UINT16_C(60865), UINT16_C(61205), UINT16_C(60811), UINT16_C(45890) } },
    { { UINT16_C(23775), UINT16_C( 7526), UINT16_C(31221), UINT16_C(64719), UINT16_C(18634), UINT16_C(18622), UINT16_C(62788), UINT16_C(47685),
        UINT16_C(52956), UINT16_C( 4463), UINT16_C( 9659), UINT16_C( 8577), UINT16_C(27850), UINT16_C(21841), UINT16_C(37977), UINT16_C(14601),
        UINT16_C(28656), UINT16_C(58710), UINT16_C( 9960), UINT16_C(45794), UINT16_C(41070), UINT16_C(46075), UINT16_C(16533), UINT16_C(29037),
        UINT16_C(56590), UINT16_C(51586), UINT16_C(  770), UINT16_C(52459), UINT16_C(15472), UINT16_C(51489), UINT16_C(10960), UINT16_C(49154) },
      { UINT16_C(22937), UINT16_C(33446), UINT16_C(34943), UINT16_C(60724), UINT16_C(12072), UINT16_C(48800), UINT16_C( 3696), UINT16_C(32303),
        UINT16_C(45803), UINT16_C(60744), UINT16_C(13237), UINT16_C( 9657), UINT16_C(55919), UINT16_C(16623), UINT16_C(61701), UINT16_C(40448),
        UINT16_C(42570), UINT16_C(51488), UINT16_C(21806), UINT16_C(22455), UINT16_C(22404), UINT16_C(62485), UINT16_C(17509), UINT16_C(20595),
        UINT16_C(48118), UINT16_C(44093), UINT16_C(63214), UINT16_C(24017), UINT16_C(49361), UINT16_C(54941), UINT16_C(40626), UINT16_C(64628) },
      { UINT16_C(23775), UINT16_C(33446), UINT16_C(34943), UINT16_C(64719), UINT16_C(18634), UINT16_C(48800), UINT16_C(62788), UINT16_C(47685),
        UINT16_C(52956), UINT16_C(60744), UINT16_C(13237), UINT16_C( 9657), UINT16_C(55919), UINT16_C(21841), UINT16_C(61701), UINT16_C(40448),
        UINT16_C(42570), UINT16_C(58710), UINT16_C(21806), UINT16_C(45794), UINT16_C(41070), UINT16_C(62485), UINT16_C(17509), UINT16_C(29037),
        UINT16_C(56590), UINT16_C(51586), UINT16_C(63214), UINT16_C(52459), UINT16_C(49361), UINT16_C(54941), UINT16_C(40626), UINT16_C(64628) } },
    { { UINT16_C(38212), UINT16_C(29638), UINT16_C(32234), UINT16_C(28362), UINT16_C(57300), UINT16_C(14947), UINT16_C(54819), UINT16_C( 6794),
        UINT16_C(51345), UINT16_C(32710), UINT16_C(38846), UINT16_C(36828), UINT16_C(31320), UINT16_C( 2661), UINT16_C(55832), UINT16_C(23558),
        UINT16_C(52335), UINT16_C(22991), UINT16_C(39241), UINT16_C( 7879), UINT16_C(10872), UINT16_C(40024), UINT16_C(57856), UINT16_C(37302),
        UINT16_C(31914), UINT16_C(26896), UINT16_C(60691), UINT16_C(27640), UINT16_C(24167), UINT16_C(32629), UINT16_C(31800), UINT16_C(42971) },
      { UINT16_C(43848), UINT16_C(37376), UINT16_C(51012), UINT16_C(48560), UINT16_C( 2290), UINT16_C(62041), UINT16_C( 4074), UINT16_C(38276),
        UINT16_C(38027), UINT16_C(40702), UINT16_C(63105), UINT16_C(59402), UINT16_C(32596), UINT16_C(35943), UINT16_C(17403), UINT16_C(17459),
        UINT16_C(13294), UINT16_C(13014), UINT16_C(34555), UINT16_C(60911), UINT16_C(18574), UINT16_C(30943), UINT16_C(25431), UINT16_C(57869),
        UINT16_C( 3064), UINT16_C(31105), UINT16_C(35586), UINT16_C(22114), UINT16_C(51466), UINT16_C( 1763), UINT16_C( 5644), UINT16_C(64074) },
      { UINT16_C(43848), UINT16_C(37376), UINT16_C(51012), UINT16_C(48560), UINT16_C(57300), UINT16_C(62041), UINT16_C(54819), UINT16_C(38276),
        UINT16_C(51345), UINT16_C(40702), UINT16_C(63105), UINT16_C(59402), UINT16_C(32596), UINT16_C(35943), UINT16_C(55832), UINT16_C(23558),
        UINT16_C(52335), UINT16_C(22991), UINT16_C(39241), UINT16_C(60911), UINT16_C(18574), UINT16_C(40024), UINT16_C(57856), UINT16_C(57869),
        UINT16_C(31914), UINT16_C(31105), UINT16_C(60691), UINT16_C(27640), UINT16_C(51466), UINT16_C(32629), UINT16_C(31800), UINT16_C(64074) } },
    { { UINT16_C( 8266), UINT16_C(17709), UINT16_C( 7334), UINT16_C(13362), UINT16_C( 4453), UINT16_C(48300), UINT16_C(47733), UINT16_C(28063),
        UINT16_C( 8389), UINT16_C(51174), UINT16_C(18603), UINT16_C(46366), UINT16_C(  274), UINT16_C( 7867), UINT16_C( 1303), UINT16_C(24857),
        UINT16_C(17957), UINT16_C(52134), UINT16_C(55394), UINT16_C(51199), UINT16_C(44266), UINT16_C(24452), UINT16_C( 9062), UINT16_C(11212),
        UINT16_C(45635), UINT16_C(61171), UINT16_C( 4603), UINT16_C( 3491), UINT16_C(24338), UINT16_C(10539), UINT16_C(17508), UINT16_C(35467) },
      { UINT16_C(12682), UINT16_C(60757), UINT16_C(21770), UINT16_C(62644), UINT16_C(14337), UINT16_C(26451), UINT16_C( 8027), UINT16_C(40594),
        UINT16_C(34257), UINT16_C(52364), UINT16_C(12438), UINT16_C(43225), UINT16_C( 1423), UINT16_C(62418), UINT16_C(23881), UINT16_C(54397),
        UINT16_C(54158), UINT16_C(39105), UINT16_C(29992), UINT16_C(10636), UINT16_C(57262), UINT16_C( 2448), UINT16_C( 8958), UINT16_C(53416),
        UINT16_C(13480), UINT16_C(16028), UINT16_C(30308), UINT16_C(62439), UINT16_C(47483), UINT16_C(50407), UINT16_C(25622), UINT16_C(42136) },
      { UINT16_C(12682), UINT16_C(60757), UINT16_C(21770), UINT16_C(62644), UINT16_C(14337), UINT16_C(48300), UINT16_C(47733), UINT16_C(40594),
        UINT16_C(34257), UINT16_C(52364), UINT16_C(18603), UINT16_C(46366), UINT16_C( 1423), UINT16_C(62418), UINT16_C(23881), UINT16_C(54397),
        UINT16_C(54158), UINT16_C(52134), UINT16_C(55394), UINT16_C(51199), UINT16_C(57262), UINT16_C(24452), UINT16_C( 9062), UINT16_C(53416),
        UINT16_C(45635), UINT16_C(61171), UINT16_C(30308), UINT16_C(62439), UINT16_C(47483), UINT16_C(50407), UINT16_C(25622), UINT16_C(42136) } },
    { { UINT16_C(22839), UINT16_C(24381), UINT16_C(51663), UINT16_C(32136), UINT16_C( 6313), UINT16_C(42886), UINT16_C(11835), UINT16_C(58231),
        UINT16_C( 5219), UINT16_C(50977), UINT16_C( 2186), UINT16_C( 1467), UINT16_C(41665), UINT16_C(55241), UINT16_C(25094), UINT16_C(15996),
        UINT16_C(47547), UINT16_C(35485), UINT16_C( 9858), UINT16_C(11015), UINT16_C(36414), UINT16_C(31187), UINT16_C(19132), UINT16_C( 8028),
        UINT16_C(32350), UINT16_C(59623), UINT16_C(41606), UINT16_C(18669), UINT16_C(46916), UINT16_C(18975), UINT16_C(39705), UINT16_C(54408) },
      { UINT16_C( 9812), UINT16_C(55135), UINT16_C(26188), UINT16_C(35330), UINT16_C(54772), UINT16_C(45316), UINT16_C(24608), UINT16_C(32464),
        UINT16_C(47070), UINT16_C(25959), UINT16_C(21593), UINT16_C(40365), UINT16_C(52235), UINT16_C( 9448), UINT16_C(28776), UINT16_C(48377),
        UINT16_C(22678), UINT16_C(58003), UINT16_C(38590), UINT16_C(45933), UINT16_C(29035), UINT16_C(35684), UINT16_C(13521), UINT16_C(45066),
        UINT16_C(29164), UINT16_C(17685), UINT16_C(49861), UINT16_C(53731), UINT16_C(52110), UINT16_C(63221), UINT16_C(60987), UINT16_C(53939) },
      { UINT16_C(22839), UINT16_C(55135), UINT16_C(51663), UINT16_C(35330), UINT16_C(54772), UINT16_C(45316), UINT16_C(24608), UINT16_C(58231),
        UINT16_C(47070), UINT16_C(50977), UINT16_C(21593), UINT16_C(40365), UINT16_C(52235), UINT16_C(55241), UINT16_C(28776), UINT16_C(48377),
        UINT16_C(47547), UINT16_C(58003), UINT16_C(38590), UINT16_C(45933), UINT16_C(36414), UINT16_C(35684), UINT16_C(19132), UINT16_C(45066),
        UINT16_C(32350), UINT16_C(59623), UINT16_C(49861), UINT16_C(53731), UINT16_C(52110), UINT16_C(63221), UINT16_C(60987), UINT16_C(54408) } }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
    simde__m512i a = simde_mm512_loadu_epi16(test_vec[i].a);
    simde__m512i b = simde_mm512_loadu_epi16(test_vec[i].b);
    simde__m512i r = simde_mm512_max_epu16(a, b);
    simde_test_x86_assert_equal_u16x32(r, simde_mm512_loadu_epi16(test_vec[i].r));
  }

  return 0;
}

static int
test_simde_mm512_mask_max_epu16 (SIMDE_MUNIT_TEST_ARGS) {
  static const struct {
    const int16_t src[32];
    const simde__mmask32 k;
    const uint16_t a[32];
    const uint16_t b[32];
    const uint16_t r[32];
  } test_vec[] = {
    { { -INT16_C( 17970), -INT16_C( 32047),  INT16_C( 11126),  INT16_C( 18607),  INT16_C( 28846), -INT16_C( 15027),  INT16_C( 10228),  INT16_C(  3519),
        -INT16_C(  3833), -INT16_C(  8977), -INT16_C( 12540), -INT16_C(  4980), -INT16_C( 26471), -INT16_C(  1341),  INT16_C( 26461),  INT16_C( 11071),
         INT16_C(  4128), -INT16_C( 26962),  INT16_C( 23868), -INT16_C(  5409),  INT16_C( 11469), -INT16_C( 15953),  INT16_C( 28243),  INT16_C( 23246),
        -INT16_C( 17056),  INT16_C( 25654), -INT16_C( 15732),  INT16_C(  9808),  INT16_C(  5210), -INT16_C( 18400),  INT16_C( 24443), -INT16_C( 25629) },
      UINT32_C(2872217967),
      { UINT16_C(17469), UINT16_C(36990), UINT16_C(19635), UINT16_C( 5098), UINT16_C( 8458), UINT16_C(38519), UINT16_C(51171), UINT16_C(16060),
        UINT16_C(56539), UINT16_C(22262), UINT16_C(55611), UINT16_C(44018), UINT16_C( 9323), UINT16_C(23126), UINT16_C(60469), UINT16_C(29206),
        UINT16_C(37936), UINT16_C(58114), UINT16_C(60641), UINT16_C(60406), UINT16_C(27917), UINT16_C(61825), UINT16_C(15925), UINT16_C( 4143),
        UINT16_C( 9498), UINT16_C(22119), UINT16_C(23038), UINT16_C(26881), UINT16_C(22397), UINT16_C(45763), UINT16_C(55875), UINT16_C(29732) },
      { UINT16_C( 9838), UINT16_C(20311), UINT16_C(19986), UINT16_C( 8250), UINT16_C(48315), UINT16_C(61457), UINT16_C(16634), UINT16_C( 5121),
        UINT16_C(26725), UINT16_C(25450), UINT16_C(27585), UINT16_C(16077), UINT16_C(37059), UINT16_C( 1776), UINT16_C( 5226), UINT16_C(55674),
        UINT16_C(53818), UINT16_C(19496), UINT16_C(25376), UINT16_C(56172), UINT16_C(32031), UINT16_C( 6604), UINT16_C(52669), UINT16_C( 8749),
        UINT16_C(38965), UINT16_C(63110), UINT16_C(21251), UINT16_C(50740), UINT16_C( 9443), UINT16_C(20173), UINT16_C(18232), UINT16_C(29223) },
      { UINT16_C(17469), UINT16_C(36990), UINT16_C(19986), UINT16_C( 8250), UINT16_C(28846), UINT16_C(61457), UINT16_C(51171), UINT16_C( 3519),
        UINT16_C(56539), UINT16_C(56559), UINT16_C(52996), UINT16_C(60556), UINT16_C(37059), UINT16_C(64195), UINT16_C(26461), UINT16_C(55674),
        UINT16_C( 4128), UINT16_C(58114), UINT16_C(23868), UINT16_C(60127), UINT16_C(32031), UINT16_C(61825), UINT16_C(28243), UINT16_C(23246),
        UINT16_C(38965), UINT16_C(63110), UINT16_C(49804), UINT16_C(50740), UINT16_C( 5210), UINT16_C(45763), UINT16_C(24443), UINT16_C(29732) } },
    { {  INT16_C( 20249),  INT16_C( 14782),  INT16_C( 11186), -INT16_C( 12011), -INT16_C(  7768),  INT16_C( 26346),  INT16_C(  6318), -INT16_C(  7288),
         INT16_C(  3760), -INT16_C( 19495),  INT16_C(  3425),  INT16_C( 17786),  INT16_C( 18225),  INT16_C( 27027), -INT16_C( 17778), -INT16_C( 22309),
        -INT16_C( 26359), -INT16_C( 17183), -INT16_C(  2364),  INT16_C( 28045),  INT16_C( 30935), -INT16_C( 31277),  INT16_C( 23440),  INT16_C( 16488),
         INT16_C( 16746), -INT16_C( 13325),  INT16_C( 27982),  INT16_C( 32528), -INT16_C( 23628),  INT16_C( 17384), -INT16_C( 15523),  INT16_C( 26603) },
      UINT32_C( 555994205),
      { UINT16_C(24872), UINT16_C(47136), UINT16_C(35005), UINT16_C(10232), UINT16_C(60618), UINT16_C( 6386), UINT16_C(  857), UINT16_C( 3736),
        UINT16_C(32934), UINT16_C( 1105), UINT16_C(15428), UINT16_C(41323), UINT16_C(36360), UINT16_C(52162), UINT16_C(20798), UINT16_C(26470),
        UINT16_C(34482), UINT16_C(28447), UINT16_C( 6158), UINT16_C(55446), UINT16_C(35076), UINT16_C(24049), UINT16_C(35212), UINT16_C(12907),
        UINT16_C(48137), UINT16_C(19766), UINT16_C(41464), UINT16_C(  494), UINT16_C(45359), UINT16_C(28364), UINT16_C(12802), UINT16_C(46293) },
      { UINT16_C(62648), UINT16_C(50980), UINT16_C(47628), UINT16_C( 4255), UINT16_C(36931), UINT16_C(53102), UINT16_C(55577), UINT16_C( 8962),
        UINT16_C(14486), UINT16_C(36464), UINT16_C(24538), UINT16_C( 2447), UINT16_C(23568), UINT16_C( 4727), UINT16_C(19598), UINT16_C(18374),
        UINT16_C(59969), UINT16_C(19726), UINT16_C(44453), UINT16_C(59486), UINT16_C(52286), UINT16_C(22456), UINT16_C(47781), UINT16_C(15226),
        UINT16_C(60402), UINT16_C(52426), UINT16_C(22858), UINT16_C(23254), UINT16_C(19893), UINT16_C(17516), UINT16_C(12954), UINT16_C(56203) },
      { UINT16_C(62648), UINT16_C(14782), UINT16_C(47628), UINT16_C(10232), UINT16_C(60618), UINT16_C(26346), UINT16_C(55577), UINT16_C(58248),
        UINT16_C( 3760), UINT16_C(46041), UINT16_C(24538), UINT16_C(41323), UINT16_C(18225), UINT16_C(27027), UINT16_C(20798), UINT16_C(26470),
        UINT16_C(59969), UINT16_C(28447), UINT16_C(63172), UINT16_C(28045), UINT16_C(30935), UINT16_C(24049), UINT16_C(23440), UINT16_C(16488),
        UINT16_C(60402), UINT16_C(52211), UINT16_C(27982), UINT16_C(32528), UINT16_C(41908), UINT16_C(28364), UINT16_C(50013), UINT16_C(26603) } },
    { { -INT16_C( 26339), -INT16_C( 15832), -INT16_C( 31162), -INT16_C( 31574),  INT16_C( 25170), -INT16_C(  1828),  INT16_C( 22044),  INT16_C(  3891),
        -INT16_C(   703), -INT16_C( 29733), -INT16_C( 20137),  INT16_C(  3301),  INT16_C( 20991), -INT16_C( 26288), -INT16_C(  9340), -INT16_C( 24204),
        -INT16_C( 25484), -INT16_C( 17565),  INT16_C(  3363),  INT16_C( 30015),  INT16_C(  7024), -INT16_C( 29587), -INT16_C( 24206), -INT16_C( 19557),
         INT16_C( 30622), -INT16_C(  2753),  INT16_C(  9256),  INT16_C(  9986),  INT16_C( 21110), -INT16_C(  1344),  INT16_C( 13358), -INT16_C( 23909) },
      UINT32_C(4099800785),
      { UINT16_C(55224), UINT16_C(10760), UINT16_C(41848), UINT16_C( 5854), UINT16_C( 7450), UINT16_C(17164), UINT16_C( 3649), UINT16_C(46954),
        UINT16_C(11104), UINT16_C(36529), UINT16_C(19551), UINT16_C(12337), UINT16_C(36426), UINT16_C(22052), UINT16_C(36395), UINT16_C(58577),
        UINT16_C(55653), UINT16_C(56590), UINT16_C(60541), UINT16_C(38899), UINT16_C(65289), UINT16_C(19418), UINT16_C(17677), UINT16_C(28162),
        UINT16_C(46192), UINT16_C(53244), UINT16_C(11520), UINT16_C(19200), UINT16_C( 9404), UINT16_C(59297), UINT16_C(29362), UINT16_C( 6091) },
      { UINT16_C(55884), UINT16_C(51700), UINT16_C(59590), UINT16_C(53344), UINT16_C(15335), UINT16_C(62747), UINT16_C( 7552), UINT16_C(61539),
        UINT16_C(24529), UINT16_C(53951), UINT16_C(49037), UINT16_C(18717), UINT16_C(48868), UINT16_C(38448), UINT16_C(64560), UINT16_C(31918),
        UINT16_C(41686), UINT16_C(40005), UINT16_C(42634), UINT16_C(29292), UINT16_C(34785), UINT16_C(24935), UINT16_C(51877), UINT16_C(30289),
        UINT16_C( 4137), UINT16_C(46664), UINT16_C(26064), UINT16_C(46335), UINT16_C(12323), UINT16_C(21578), UINT16_C(63532), UINT16_C(  720) },
      { UINT16_C(55884), UINT16_C(49704), UINT16_C(34374), UINT16_C(33962), UINT16_C(15335), UINT16_C(63708), UINT16_C( 7552), UINT16_C(61539),
        UINT16_C(64833), UINT16_C(53951), UINT16_C(49037), UINT16_C(18717), UINT16_C(48868), UINT16_C(38448), UINT16_C(64560), UINT16_C(58577),
        UINT16_C(55653), UINT16_C(47971), UINT16_C(60541), UINT16_C(38899), UINT16_C(65289), UINT16_C(35949), UINT16_C(51877), UINT16_C(45979),
        UINT16_C(30622), UINT16_C(62783), UINT16_C(26064), UINT16_C( 9986), UINT16_C(12323), UINT16_C(59297), UINT16_C(63532), UINT16_C( 6091) } },
    { {  INT16_C(  5787),  INT16_C(  9630),  INT16_C(  3004), -INT16_C( 25193), -INT16_C(   366),  INT16_C( 14334),  INT16_C( 20424), -INT16_C(  3410),
        -INT16_C(  2465),  INT16_C( 12200), -INT16_C( 22436),  INT16_C( 32739),  INT16_C( 11992),  INT16_C(  1235), -INT16_C( 23514), -INT16_C( 16122),
        -INT16_C( 23366),  INT16_C( 30439),  INT16_C( 32431),  INT16_C( 16915),  INT16_C(  4477),  INT16_C( 17785),  INT16_C( 10080), -INT16_C( 16585),
        -INT16_C(  8162),  INT16_C( 31471), -INT16_C( 11640),  INT16_C( 24825), -INT16_C( 13056),  INT16_C( 10084),  INT16_C( 27249),  INT16_C( 11240) },
      UINT32_C(3198275342),
      { UINT16_C(31173), UINT16_C( 9488), UINT16_C(18593), UINT16_C(49124), UINT16_C(54056), UINT16_C(45113), UINT16_C(12966), UINT16_C(42512),
        UINT16_C(29951), UINT16_C(28877), UINT16_C(46814), UINT16_C(60571), UINT16_C(15493), UINT16_C(54186), UINT16_C(43760), UINT16_C(46494),
        UINT16_C(44836), UINT16_C(50650), UINT16_C(49143), UINT16_C( 8068), UINT16_C(48530), UINT16_C(14543), UINT16_C(57327), UINT16_C(61407),
        UINT16_C(44115), UINT16_C(12639), UINT16_C(64354), UINT16_C(59421), UINT16_C(51255), UINT16_C(10427), UINT16_C(23154), UINT16_C(38621) },
      { UINT16_C(47113), UINT16_C(   91), UINT16_C(57207), UINT16_C( 2335), UINT16_C(61084), UINT16_C(35906), UINT16_C( 8653), UINT16_C( 8315),
        UINT16_C(56013), UINT16_C(12369), UINT16_C(28373), UINT16_C( 3352), UINT16_C(54070), UINT16_C(43317), UINT16_C( 4653), UINT16_C(13887),
        UINT16_C(39882), UINT16_C(16694), UINT16_C(21882), UINT16_C( 5963), UINT16_C(36163), UINT16_C( 4259), UINT16_C( 7854), UINT16_C(31536),
        UINT16_C(33272), UINT16_C(52907), UINT16_C(50160), UINT16_C( 9947), UINT16_C( 4247), UINT16_C(50383), UINT16_C( 3874), UINT16_C(60923) },
      { UINT16_C( 5787), UINT16_C( 9488), UINT16_C(57207), UINT16_C(49124), UINT16_C(65170), UINT16_C(14334), UINT16_C(20424), UINT16_C(62126),
        UINT16_C(56013), UINT16_C(28877), UINT16_C(46814), UINT16_C(60571), UINT16_C(11992), UINT16_C( 1235), UINT16_C(43760), UINT16_C(46494),
        UINT16_C(44836), UINT16_C(30439), UINT16_C(32431), UINT16_C(16915), UINT16_C( 4477), UINT16_C(14543), UINT16_C(10080), UINT16_C(61407),
        UINT16_C(57374), UINT16_C(52907), UINT16_C(64354), UINT16_C(59421), UINT16_C(51255), UINT16_C(50383), UINT16_C(27249), UINT16_C(60923) } },
    { {  INT16_C( 12714),  INT16_C(  9262),  INT16_C( 31111), -INT16_C( 13765), -INT16_C(  8698), -INT16_C( 19237),  INT16_C(  3068), -INT16_C(  2768),
        -INT16_C(  9331),  INT16_C( 32195), -INT16_C( 24929),  INT16_C( 13987),  INT16_C( 29614), -INT16_C( 12038), -INT16_C(  2686),  INT16_C( 11453),
        -INT16_C(  5081), -INT16_C( 20912), -INT16_C( 29595),  INT16_C( 27768),  INT16_C( 21354),  INT16_C( 26400),  INT16_C( 20575), -INT16_C(  5028),
         INT16_C(  7980), -INT16_C( 13463),  INT16_C(  3261),  INT16_C( 27393), -INT16_C(  1153),  INT16_C(   315), -INT16_C(  1551),  INT16_C(  6189) },
      UINT32_C(1254522597),
      { UINT16_C(55186), UINT16_C(61915), UINT16_C(14119), UINT16_C(21469), UINT16_C(18006), UINT16_C( 4894), UINT16_C( 8018), UINT16_C(53886),
        UINT16_C(47643), UINT16_C( 3283), UINT16_C(  435), UINT16_C(38948), UINT16_C(60031), UINT16_C(35298), UINT16_C(39208), UINT16_C(47869),
        UINT16_C(55664), UINT16_C(38827), UINT16_C(34832), UINT16_C(26603), UINT16_C( 2510), UINT16_C( 8570), UINT16_C(63785), UINT16_C(17651),
        UINT16_C(50867), UINT16_C(26192), UINT16_C(29895), UINT16_C(18174), UINT16_C(57438), UINT16_C(34511), UINT16_C(52601), UINT16_C(59713) },
      { UINT16_C(60582), UINT16_C(46721), UINT16_C(27765), UINT16_C(17181), UINT16_C(39029), UINT16_C(40548), UINT16_C(22417), UINT16_C(17634),
        UINT16_C(12830), UINT16_C(58794), UINT16_C(43174), UINT16_C( 1068), UINT16_C(64392), UINT16_C(  651), UINT16_C(52424), UINT16_C(28395),
        UINT16_C(27832), UINT16_C(11557), UINT16_C(17112), UINT16_C(20081), UINT16_C(54746), UINT16_C(27628), UINT16_C(53037), UINT16_C(19375),
        UINT16_C(22785), UINT16_C(43056), UINT16_C(23553), UINT16_C(35500), UINT16_C(14168), UINT16_C( 8332), UINT16_C(30467), UINT16_C(48271) },
      { UINT16_C(60582), UINT16_C( 9262), UINT16_C(27765), UINT16_C(51771), UINT16_C(56838), UINT16_C(40548), UINT16_C(22417), UINT16_C(53886),
        UINT16_C(56205), UINT16_C(58794), UINT16_C(43174), UINT16_C(38948), UINT16_C(64392), UINT16_C(35298), UINT16_C(52424), UINT16_C(11453),
        UINT16_C(60455), UINT16_C(38827), UINT16_C(34832), UINT16_C(27768), UINT16_C(21354), UINT16_C(26400), UINT16_C(63785), UINT16_C(19375),
        UINT16_C( 7980), UINT16_C(43056), UINT16_C( 3261), UINT16_C(35500), UINT16_C(64383), UINT16_C(  315), UINT16_C(52601), UINT16_C( 6189) } },
    { { -INT16_C( 19228), -INT16_C( 17175),  INT16_C( 23286), -INT16_C( 12022), -INT16_C(  2256),  INT16_C( 23868), -INT16_C(  4922), -INT16_C( 14424),
        -INT16_C( 10171),  INT16_C( 18287),  INT16_C(  7221), -INT16_C( 29231),  INT16_C( 23891),  INT16_C( 22445),  INT16_C( 15572), -INT16_C( 18413),
        -INT16_C(   784), -INT16_C(  6283),  INT16_C( 32599), -INT16_C( 30792), -INT16_C(  2954),  INT16_C( 15588), -INT16_C( 29472),  INT16_C(  9732),
         INT16_C( 29540), -INT16_C( 26259),  INT16_C( 16015), -INT16_C(  7386), -INT16_C( 11109),  INT16_C( 28474),  INT16_C( 19728),  INT16_C(   296) },
      UINT32_C(2699599177),
      { UINT16_C( 2964), UINT16_C(30159), UINT16_C(54167), UINT16_C(64667), UINT16_C( 2119), UINT16_C(54933), UINT16_C(48198), UINT16_C(57785),
        UINT16_C(62352), UINT16_C(41040), UINT16_C(30784), UINT16_C(35489), UINT16_C(35093), UINT16_C(12842), UINT16_C(21033), UINT16_C(48837),
        UINT16_C(37981), UINT16_C(62771), UINT16_C(52840), UINT16_C(45041), UINT16_C(34518), UINT16_C( 7301), UINT16_C(16194), UINT16_C(54013),
        UINT16_C(19762), UINT16_C(29555), UINT16_C( 5318), UINT16_C(56317), UINT16_C(10142), UINT16_C(50957), UINT16_C(53881), UINT16_C(55173) },
      { UINT16_C(47207), UINT16_C(53196), UINT16_C(48518), UINT16_C(23678), UINT16_C(  835), UINT16_C(34424), UINT16_C(30018), UINT16_C(30040),
        UINT16_C(52163), UINT16_C(35304), UINT16_C(58848), UINT16_C(32356), UINT16_C(29196), UINT16_C(34373), UINT16_C(52036), UINT16_C(43869),
        UINT16_C(10627), UINT16_C( 2682), UINT16_C(63718), UINT16_C(10598), UINT16_C(57340), UINT16_C(16047), UINT16_C( 2132), UINT16_C( 6067),
        UINT16_C(39891), UINT16_C(45984), UINT16_C( 1408), UINT16_C(36145), UINT16_C(30583), UINT16_C(47891), UINT16_C(28738), UINT16_C(50535) },
      { UINT16_C(47207), UINT16_C(48361), UINT16_C(23286), UINT16_C(64667), UINT16_C(63280), UINT16_C(23868), UINT16_C(48198), UINT16_C(51112),
        UINT16_C(62352), UINT16_C(18287), UINT16_C(58848), UINT16_C(35489), UINT16_C(35093), UINT16_C(22445), UINT16_C(15572), UINT16_C(48837),
        UINT16_C(64752), UINT16_C(59253), UINT16_C(32599), UINT16_C(45041), UINT16_C(62582), UINT16_C(16047), UINT16_C(16194), UINT16_C(54013),
        UINT16_C(29540), UINT16_C(39277), UINT16_C(16015), UINT16_C(58150), UINT16_C(54427), UINT16_C(50957), UINT16_C(19728), UINT16_C(55173) } },
    { { -INT16_C(  7783),  INT16_C( 32719),  INT16_C( 14042), -INT16_C( 10584),  INT16_C( 22549),  INT16_C( 26900), -INT16_C( 14240),  INT16_C( 13185),
         INT16_C(  8547), -INT16_C(  6937),  INT16_C(  6182), -INT16_C( 25231), -INT16_C( 31601), -INT16_C( 11943), -INT16_C( 16140), -INT16_C( 29289),
         INT16_C( 26273),  INT16_C( 31500), -INT16_C( 19300), -INT16_C( 20143),  INT16_C( 26124),  INT16_C( 27675), -INT16_C( 25554), -INT16_C( 28256),
        -INT16_C( 30787), -INT16_C(  7051), -INT16_C(  6497),  INT16_C( 12161), -INT16_C(  9622),  INT16_C( 24064), -INT16_C( 26726),  INT16_C( 15595) },
      UINT32_C(2595747838),
      { UINT16_C(26479), UINT16_C(40229), UINT16_C(50435), UINT16_C(49198), UINT16_C(42060), UINT16_C(60324), UINT16_C( 9866), UINT16_C(62746),
        UINT16_C( 6912), UINT16_C(39763), UINT16_C(16306), UINT16_C(45271), UINT16_C(36406), UINT16_C(57931), UINT16_C(38807), UINT16_C( 1691),
        UINT16_C(49406), UINT16_C(  419), UINT16_C(53893), UINT16_C(53697), UINT16_C(26230), UINT16_C(  188), UINT16_C(55180), UINT16_C(36085),
        UINT16_C(18930), UINT16_C(42023), UINT16_C(65160), UINT16_C(48725), UINT16_C(41101), UINT16_C( 9377), UINT16_C(15415), UINT16_C(13611) },
      { UINT16_C(52988), UINT16_C(33078), UINT16_C(63392), UINT16_C( 5714), UINT16_C( 3677), UINT16_C(59671), UINT16_C( 3301), UINT16_C(55158),
        UINT16_C(40277), UINT16_C(56700), UINT16_C(53660), UINT16_C(10652), UINT16_C(15729), UINT16_C(43085), UINT16_C(30841), UINT16_C(30173),
        UINT16_C( 4935), UINT16_C(59382), UINT16_C(18442), UINT16_C(26878), UINT16_C( 5462), UINT16_C(15441), UINT16_C(50977), UINT16_C(30483),
        UINT16_C(36709), UINT16_C(  340), UINT16_C(61536), UINT16_C(53546), UINT16_C(30509), UINT16_C(42617), UINT16_C(22256), UINT16_C(14107) },
      { UINT16_C(57753), UINT16_C(40229), UINT16_C(63392), UINT16_C(49198), UINT16_C(42060), UINT16_C(60324), UINT16_C( 9866), UINT16_C(62746),
        UINT16_C(40277), UINT16_C(56700), UINT16_C(53660), UINT16_C(40305), UINT16_C(36406), UINT16_C(57931), UINT16_C(38807), UINT16_C(30173),
        UINT16_C(49406), UINT16_C(59382), UINT16_C(53893), UINT16_C(45393), UINT16_C(26230), UINT16_C(15441), UINT16_C(39982), UINT16_C(36085),
        UINT16_C(34749), UINT16_C(42023), UINT16_C(59039), UINT16_C(53546), UINT16_C(41101), UINT16_C(24064), UINT16_C(38810), UINT16_C(14107) } },
    { {  INT16_C(  4457),  INT16_C( 29726),  INT16_C(  7257), -INT16_C( 20260),  INT16_C( 11569),  INT16_C( 21484), -INT16_C(    11),  INT16_C( 23242),
         INT16_C(  7823), -INT16_C(  4261), -INT16_C( 31473),  INT16_C( 15553),  INT16_C( 15100), -INT16_C(  4893), -INT16_C(   367), -INT16_C(  1501),
         INT16_C( 16912),  INT16_C( 26990),  INT16_C( 19038), -INT16_C( 28647),  INT16_C(  1400),  INT16_C( 28131), -INT16_C( 21243), -INT16_C( 27449),
         INT16_C(  8907), -INT16_C(  9597),  INT16_C( 17575), -INT16_C( 23785), -INT16_C(  1409),  INT16_C(  4240), -INT16_C( 19464),  INT16_C(  2058) },
      UINT32_C(1416788469),
      { UINT16_C(51089), UINT16_C(38568), UINT16_C(28532), UINT16_C(16170), UINT16_C(44433), UINT16_C(14362), UINT16_C(12786), UINT16_C(29148),
        UINT16_C(27691), UINT16_C( 9089), UINT16_C(35615), UINT16_C( 5420), UINT16_C(40452), UINT16_C(51305), UINT16_C(19753), UINT16_C(47619),
        UINT16_C(44052), UINT16_C(34896), UINT16_C(31259), UINT16_C(44487), UINT16_C(57640), UINT16_C( 6885), UINT16_C(49426), UINT16_C(15755),
        UINT16_C( 3117), UINT16_C(19809), UINT16_C(36247), UINT16_C(40034), UINT16_C(52011), UINT16_C(21604), UINT16_C(26392), UINT16_C(11279) },
      { UINT16_C(24339), UINT16_C(12212), UINT16_C(31706), UINT16_C(  732), UINT16_C(49501), UINT16_C(28444), UINT16_C(42883), UINT16_C(45229),
        UINT16_C( 3763), UINT16_C(19197), UINT16_C(24475), UINT16_C(50918), UINT16_C(18986), UINT16_C(16922), UINT16_C(10674), UINT16_C(50542),
        UINT16_C( 8841), UINT16_C(25588), UINT16_C(53406), UINT16_C(64357), UINT16_C(33170), UINT16_C( 5482), UINT16_C( 5928), UINT16_C(56261),
        UINT16_C(49957), UINT16_C(49189), UINT16_C( 3106), UINT16_C(19846), UINT16_C(41302), UINT16_C( 2191), UINT16_C(65226), UINT16_C(21454) },
      { UINT16_C(51089), UINT16_C(29726), UINT16_C(31706), UINT16_C(45276), UINT16_C(49501), UINT16_C(28444), UINT16_C(42883), UINT16_C(45229),
        UINT16_C(27691), UINT16_C(61275), UINT16_C(34063), UINT16_C(50918), UINT16_C(40452), UINT16_C(51305), UINT16_C(19753), UINT16_C(64035),
        UINT16_C(16912), UINT16_C(34896), UINT16_C(19038), UINT16_C(36889), UINT16_C(57640), UINT16_C( 6885), UINT16_C(49426), UINT16_C(38087),
        UINT16_C( 8907), UINT16_C(55939), UINT16_C(36247), UINT16_C(41751), UINT16_C(52011), UINT16_C( 4240), UINT16_C(65226), UINT16_C( 2058) } }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
    simde__m512i src = simde_mm512_loadu_epi16(test_vec[i].src);
    simde__m512i a = simde_mm512_loadu_epi16(test_vec[i].a);
    simde__m512i b = simde_mm512_loadu_epi16(test_vec[i].b);
    simde__m512i r = simde_mm512_mask_max_epu16(src, test_vec[i].k, a, b);
    simde_test_x86_assert_equal_u16x32(r, simde_mm512_loadu_epi16(test_vec[i].r));
  }

  return 0;
}

static int
test_simde_mm512_maskz_max_epu16 (SIMDE_MUNIT_TEST_ARGS) {
  static const struct {
    const simde__mmask32 k;
    const uint16_t a[32];
    const uint16_t b[32];
    const uint16_t r[32];
  } test_vec[] = {
    { UINT32_C(2682918652),
      { UINT16_C( 3360), UINT16_C(28585), UINT16_C(34194), UINT16_C(19929), UINT16_C(64935), UINT16_C(52907), UINT16_C( 3569), UINT16_C(10171),
        UINT16_C( 8743), UINT16_C(32403), UINT16_C(16511), UINT16_C(31580), UINT16_C(18006), UINT16_C( 5403), UINT16_C( 9109), UINT16_C(46787),
        UINT16_C(27697), UINT16_C(49957), UINT16_C(65265), UINT16_C(38928), UINT16_C(48380), UINT16_C(60774), UINT16_C( 8649), UINT16_C(61460),
        UINT16_C(42820), UINT16_C(50031), UINT16_C(52200), UINT16_C(15934), UINT16_C(22801), UINT16_C(42580), UINT16_C( 6013), UINT16_C(44636) },
      { UINT16_C(33155), UINT16_C(29809), UINT16_C(33408), UINT16_C(31756), UINT16_C(29246), UINT16_C( 1897), UINT16_C(32147), UINT16_C(55287),
        UINT16_C(26148), UINT16_C( 3226), UINT16_C(55601), UINT16_C(16971), UINT16_C(40754), UINT16_C(45033), UINT16_C(17846), UINT16_C(14685),
        UINT16_C(53191), UINT16_C(18349), UINT16_C(47441), UINT16_C(36803), UINT16_C(11307), UINT16_C(48790), UINT16_C(36265), UINT16_C(52630),
        UINT16_C(12532), UINT16_C( 9690), UINT16_C( 9481), UINT16_C(15464), UINT16_C(20932), UINT16_C(31467), UINT16_C(18838), UINT16_C(23987) },
      { UINT16_C(    0), UINT16_C(    0), UINT16_C(34194), UINT16_C(31756), UINT16_C(64935), UINT16_C(52907), UINT16_C(32147), UINT16_C(55287),
        UINT16_C(    0), UINT16_C(32403), UINT16_C(55601), UINT16_C(    0), UINT16_C(40754), UINT16_C(    0), UINT16_C(    0), UINT16_C(    0),
        UINT16_C(    0), UINT16_C(49957), UINT16_C(    0), UINT16_C(38928), UINT16_C(    0), UINT16_C(60774), UINT16_C(36265), UINT16_C(61460),
        UINT16_C(42820), UINT16_C(50031), UINT16_C(52200), UINT16_C(15934), UINT16_C(22801), UINT16_C(    0), UINT16_C(    0), UINT16_C(44636) } },
    { UINT32_C(1772380184),
      { UINT16_C(36499), UINT16_C(15362), UINT16_C(38939), UINT16_C( 3850), UINT16_C(58569), UINT16_C(53813), UINT16_C(40201), UINT16_C(52494),
        UINT16_C(64238), UINT16_C(33863), UINT16_C(64067), UINT16_C(23522), UINT16_C(34394), UINT16_C(29636), UINT16_C(48366), UINT16_C(33207),
        UINT16_C(47434), UINT16_C(26046), UINT16_C(51282), UINT16_C( 7029), UINT16_C(43692), UINT16_C(46573), UINT16_C(64583), UINT16_C(13698),
        UINT16_C(51702), UINT16_C(14777), UINT16_C(39875), UINT16_C( 7572), UINT16_C(22562), UINT16_C( 4240), UINT16_C(18196), UINT16_C(24209) },
      { UINT16_C(20224), UINT16_C(21187), UINT16_C(14359), UINT16_C(50029), UINT16_C(23522), UINT16_C(10616), UINT16_C(64087), UINT16_C(19806),
        UINT16_C( 6339), UINT16_C(34438), UINT16_C( 6835), UINT16_C(54691), UINT16_C(13170), UINT16_C(34533), UINT16_C(30586), UINT16_C(31716),
        UINT16_C(42950), UINT16_C(57037), UINT16_C(15328), UINT16_C(49825), UINT16_C( 6806), UINT16_C(60908), UINT16_C(18964), UINT16_C(55354),
        UINT16_C(49250), UINT16_C( 5726), UINT16_C(  730), UINT16_C(19691), UINT16_C(53557), UINT16_C(45266), UINT16_C(46664), UINT16_C( 3627) },
      { UINT16_C(    0), UINT16_C(    0), UINT16_C(    0), UINT16_C(50029), UINT16_C(58569), UINT16_C(    0), UINT16_C(    0), UINT16_C(    0),
        UINT16_C(    0), UINT16_C(    0), UINT16_C(    0), UINT16_C(    0), UINT16_C(    0), UINT16_C(34533), UINT16_C(48366), UINT16_C(    0),
        UINT16_C(    0), UINT16_C(    0), UINT16_C(51282), UINT16_C(    0), UINT16_C(    0), UINT16_C(60908), UINT16_C(    0), UINT16_C(55354),
        UINT16_C(51702), UINT16_C(    0), UINT16_C(    0), UINT16_C(19691), UINT16_C(    0), UINT16_C(45266), UINT16_C(46664), UINT16_C(    0) } },
    { UINT32_C(1038940253),
      { UINT16_C(60584), UINT16_C(48310), UINT16_C(61494), UINT16_C(39316), UINT16_C(62384), UINT16_C(35503), UINT16_C(39669), UINT16_C(10966),
        UINT16_C(43115), UINT16_C(46042), UINT16_C( 1374), UINT16_C(48322), UINT16_C(44798), UINT16_C(12793), UINT16_C(63804), UINT16_C(58619),
        UINT16_C(45541), UINT16_C( 7329), UINT16_C(13730), UINT16_C(21173), UINT16_C(25640), UINT16_C( 7645), UINT16_C(46078), UINT16_C(27208),
        UINT16_C( 8796), UINT16_C(47645), UINT16_C(57128), UINT16_C( 9846), UINT16_C(28814), UINT16_C(51799), UINT16_C(21097), UINT16_C(20399) },
      { UINT16_C(20484), UINT16_C(42603), UINT16_C( 8325), UINT16_C(44792), UINT16_C(54660), UINT16_C(33483), UINT16_C( 5001), UINT16_C(58860),
        UINT16_C( 2614), UINT16_C(24223), UINT16_C( 5865), UINT16_C(30596), UINT16_C(56198), UINT16_C(61250), UINT16_C(61742), UINT16_C(12862),
        UINT16_C(43329), UINT16_C(50904), UINT16_C(53449), UINT16_C(19828), UINT16_C(16550), UINT16_C(12240), UINT16_C(48211), UINT16_C(35092),
        UINT16_C(46022), UINT16_C(45287), UINT16_C(27593), UINT16_C(20263), UINT16_C(26951), UINT16_C(30015), UINT16_C(32090), UINT16_C(39847) },
      { UINT16_C(60584), UINT16_C(    0), UINT16_C(61494), UINT16_C(44792), UINT16_C(62384), UINT16_C(    0), UINT16_C(39669), UINT16_C(    0),
        UINT16_C(    0), UINT16_C(    0), UINT16_C(    0), UINT16_C(48322), UINT16_C(56198), UINT16_C(61250), UINT16_C(63804), UINT16_C(58619),
        UINT16_C(    0), UINT16_C(    0), UINT16_C(53449), UINT16_C(21173), UINT16_C(    0), UINT16_C(12240), UINT16_C(48211), UINT16_C(35092),
        UINT16_C(46022), UINT16_C(    0), UINT16_C(57128), UINT16_C(20263), UINT16_C(28814), UINT16_C(51799), UINT16_C(    0), UINT16_C(    0) } },
    { UINT32_C(4032986919),
      { UINT16_C( 3606), UINT16_C(27172), UINT16_C(14538), UINT16_C(37363), UINT16_C(56300), UINT16_C(46401), UINT16_C(26694), UINT16_C(36101),
        UINT16_C(17618), UINT16_C(11266), UINT16_C(43457), UINT16_C(59592), UINT16_C(10792), UINT16_C(30937), UINT16_C( 5888), UINT16_C( 5997),
        UINT16_C(37413), UINT16_C(61313), UINT16_C(29898), UINT16_C(46720), UINT16_C(49487), UINT16_C(38508), UINT16_C(28970), UINT16_C(64547),
        UINT16_C( 9909), UINT16_C(30248), UINT16_C(61647), UINT16_C(63583), UINT16_C(14362), UINT16_C( 7024), UINT16_C(56655), UINT16_C(29746) },
      { UINT16_C(45935), UINT16_C(14947), UINT16_C(58407), UINT16_C(30704), UINT16_C(23717), UINT16_C(53005), UINT16_C(12493), UINT16_C(33483),
        UINT16_C(62550), UINT16_C( 9977), UINT16_C(22756), UINT16_C(65310), UINT16_C(36496), UINT16_C(57114), UINT16_C(19563), UINT16_C(56147),
        UINT16_C(46847), UINT16_C( 9749), UINT16_C( 1434), UINT16_C(16541), UINT16_C(43618), UINT16_C(12047), UINT16_C(56283), UINT16_C(12722),
        UINT16_C(43983), UINT16_C(45911), UINT16_C(29955), UINT16_C(37810), UINT16_C(52227), UINT16_C(28530), UINT16_C(50456), UINT16_C( 5962) },
      { UINT16_C(45935), UINT16_C(27172), UINT16_C(58407), UINT16_C(    0), UINT16_C(    0), UINT16_C(53005), UINT16_C(    0), UINT16_C(    0),
        UINT16_C(62550), UINT16_C(11266), UINT16_C(43457), UINT16_C(65310), UINT16_C(36496), UINT16_C(57114), UINT16_C(19563), UINT16_C(    0),
        UINT16_C(    0), UINT16_C(61313), UINT16_C(    0), UINT16_C(    0), UINT16_C(    0), UINT16_C(38508), UINT16_C(56283), UINT16_C(    0),
        UINT16_C(    0), UINT16_C(    0), UINT16_C(    0), UINT16_C(    0), UINT16_C(52227), UINT16_C(28530), UINT16_C(56655), UINT16_C(29746) } },
    { UINT32_C( 373186427),
      { UINT16_C(25990), UINT16_C(25078), UINT16_C(43072), UINT16_C( 3986), UINT16_C(59987), UINT16_C(22211), UINT16_C(30047), UINT16_C(25577),
        UINT16_C(23362), UINT16_C(23250), UINT16_C( 7200), UINT16_C(39794), UINT16_C(45179), UINT16_C(57265), UINT16_C( 1931), UINT16_C( 4518),
        UINT16_C(40045), UINT16_C(44402), UINT16_C( 1348), UINT16_C(38845), UINT16_C(33007), UINT16_C(20205), UINT16_C(55029), UINT16_C(14257),
        UINT16_C(33585), UINT16_C(20882), UINT16_C( 1183), UINT16_C( 6892), UINT16_C(40628), UINT16_C(16378), UINT16_C(41125), UINT16_C( 4689) },
      { UINT16_C(49980), UINT16_C(32960), UINT16_C(32200), UINT16_C(46871), UINT16_C( 1277), UINT16_C(61958), UINT16_C(47066), UINT16_C( 2858),
        UINT16_C(48187), UINT16_C(55900), UINT16_C(18624), UINT16_C(29941), UINT16_C(61414), UINT16_C(36019), UINT16_C( 1167), UINT16_C(52126),
        UINT16_C(24264), UINT16_C(36939), UINT16_C(25307), UINT16_C(55368), UINT16_C(20070), UINT16_C(16587), UINT16_C(62725), UINT16_C(16459),
        UINT16_C(42929), UINT16_C(28955), UINT16_C( 4335), UINT16_C(55013), UINT16_C(39167), UINT16_C(36450), UINT16_C(  157), UINT16_C(25945) },
      { UINT16_C(49980), UINT16_C(32960), UINT16_C(    0), UINT16_C(46871), UINT16_C(59987), UINT16_C(61958), UINT16_C(47066), UINT16_C(    0),
        UINT16_C(48187), UINT16_C(55900), UINT16_C(18624), UINT16_C(39794), UINT16_C(61414), UINT16_C(    0), UINT16_C( 1931), UINT16_C(    0),
        UINT16_C(    0), UINT16_C(44402), UINT16_C(25307), UINT16_C(55368), UINT16_C(33007), UINT16_C(20205), UINT16_C(    0), UINT16_C(    0),
        UINT16_C(    0), UINT16_C(28955), UINT16_C( 4335), UINT16_C(    0), UINT16_C(40628), UINT16_C(    0), UINT16_C(    0), UINT16_C(    0) } },
    { UINT32_C( 989176927),
      { UINT16_C(56971), UINT16_C(37292), UINT16_C(63443), UINT16_C(34001), UINT16_C(60574), UINT16_C(36341), UINT16_C(56060), UINT16_C(64355),
        UINT16_C(50546), UINT16_C( 3977), UINT16_C(58054), UINT16_C( 9588), UINT16_C(27270), UINT16_C(35935), UINT16_C(29351), UINT16_C(13304),
        UINT16_C(42064), UINT16_C( 9156), UINT16_C(38299), UINT16_C(14759), UINT16_C(40066), UINT16_C(32455), UINT16_C(10870), UINT16_C(59770),
        UINT16_C( 1008), UINT16_C(46840), UINT16_C(28134), UINT16_C(27867), UINT16_C(15063), UINT16_C(32505), UINT16_C(61869), UINT16_C(64945) },
      { UINT16_C(30102), UINT16_C(12577), UINT16_C(51211), UINT16_C(36203), UINT16_C(12901), UINT16_C(56075), UINT16_C(34140), UINT16_C(19652),
        UINT16_C(48521), UINT16_C(28418), UINT16_C(56618), UINT16_C(  475), UINT16_C(54296), UINT16_C(50559), UINT16_C(12742), UINT16_C(23746),
        UINT16_C(58278), UINT16_C(45453), UINT16_C(63660), UINT16_C( 4414), UINT16_C(18986), UINT16_C(34796), UINT16_C(45519), UINT16_C(22739),
        UINT16_C(54894), UINT16_C(39111), UINT16_C(41907), UINT16_C(52121), UINT16_C( 6263), UINT16_C(15760), UINT16_C(21321), UINT16_C(61593) },
      { UINT16_C(56971), UINT16_C(37292), UINT16_C(63443), UINT16_C(36203), UINT16_C(60574), UINT16_C(    0), UINT16_C(56060), UINT16_C(    0),
        UINT16_C(    0), UINT16_C(    0), UINT16_C(58054), UINT16_C(    0), UINT16_C(    0), UINT16_C(50559), UINT16_C(    0), UINT16_C(23746),
        UINT16_C(58278), UINT16_C(    0), UINT16_C(63660), UINT16_C(    0), UINT16_C(40066), UINT16_C(34796), UINT16_C(45519), UINT16_C(59770),
        UINT16_C(    0), UINT16_C(46840), UINT16_C(    0), UINT16_C(52121), UINT16_C(15063), UINT16_C(32505), UINT16_C(    0), UINT16_C(    0) } },
    { UINT32_C(3802212150),
      { UINT16_C(57386), UINT16_C(63953), UINT16_C(42129), UINT16_C(65362), UINT16_C( 6522), UINT16_C(11927), UINT16_C(12476), UINT16_C(13561),
        UINT16_C(35400), UINT16_C(37489), UINT16_C( 3037), UINT16_C( 4994), UINT16_C( 9010), UINT16_C(20982), UINT16_C(59651), UINT16_C(11675),
        UINT16_C(27849), UINT16_C(23079), UINT16_C(30993), UINT16_C(35673), UINT16_C(61586), UINT16_C(20409), UINT16_C(45856), UINT16_C(27011),
        UINT16_C(62525), UINT16_C( 6907), UINT16_C(32255), UINT16_C(12589), UINT16_C( 9120), UINT16_C(42115), UINT16_C( 7693), UINT16_C(54993) },
      { UINT16_C(63627), UINT16_C(39985), UINT16_C(35441), UINT16_C( 1063), UINT16_C(57723), UINT16_C(39763), UINT16_C(54932), UINT16_C(53508),
        UINT16_C(65482), UINT16_C(51947), UINT16_C( 6268), UINT16_C( 7675), UINT16_C(32316), UINT16_C(18881), UINT16_C(37533), UINT16_C(10271),
        UINT16_C(20619), UINT16_C(64708), UINT16_C(60379), UINT16_C(22016), UINT16_C(21452), UINT16_C(24817), UINT16_C(63017), UINT16_C(62513),
        UINT16_C( 7413), UINT16_C(29374), UINT16_C(47413), UINT16_C(29071), UINT16_C(20536), UINT16_C(54714), UINT16_C(55778), UINT16_C(28157) },
      { UINT16_C(    0), UINT16_C(63953), UINT16_C(42129), UINT16_C(    0), UINT16_C(57723), UINT16_C(39763), UINT16_C(    0), UINT16_C(    0),
        UINT16_C(65482), UINT16_C(51947), UINT16_C( 6268), UINT16_C(    0), UINT16_C(    0), UINT16_C(20982), UINT16_C(    0), UINT16_C(    0),
        UINT16_C(27849), UINT16_C(    0), UINT16_C(    0), UINT16_C(    0), UINT16_C(    0), UINT16_C(24817), UINT16_C(    0), UINT16_C(62513),
        UINT16_C(    0), UINT16_C(29374), UINT16_C(    0), UINT16_C(    0), UINT16_C(    0), UINT16_C(54714), UINT16_C(55778), UINT16_C(54993) } },
    { UINT32_C(  90882346),
      { UINT16_C(19646), UINT16_C(59353), UINT16_C( 2882), UINT16_C(14555), UINT16_C(39207), UINT16_C(23722), UINT16_C(14675), UINT16_C(35789),
        UINT16_C(34697), UINT16_C(27488), UINT16_C(23905), UINT16_C(35801), UINT16_C(17182), UINT16_C(51856), UINT16_C(60333), UINT16_C(27459),
        UINT16_C( 7479), UINT16_C(31315), UINT16_C(11816), UINT16_C(20402), UINT16_C(23752), UINT16_C( 7084), UINT16_C(31125), UINT16_C( 7846),
        UINT16_C( 1537), UINT16_C(25225), UINT16_C(25187), UINT16_C(33261), UINT16_C(32165), UINT16_C(21323), UINT16_C(36712), UINT16_C(40894) },
      { UINT16_C( 4524), UINT16_C(54297), UINT16_C(52032), UINT16_C( 2083), UINT16_C(53031), UINT16_C(48163), UINT16_C(51529), UINT16_C(19162),
        UINT16_C(25807), UINT16_C(12972), UINT16_C(39366), UINT16_C(27827), UINT16_C(65046), UINT16_C(32447), UINT16_C(32141), UINT16_C(14621),
        UINT16_C(14223), UINT16_C(53005), UINT16_C(12546), UINT16_C(10967), UINT16_C(64000), UINT16_C(18918), UINT16_C(49603), UINT16_C(37523),
        UINT16_C(16165), UINT16_C(60356), UINT16_C(30680), UINT16_C(61015), UINT16_C( 5749), UINT16_C(  876), UINT16_C(35476), UINT16_C( 9020) },
      { UINT16_C(    0), UINT16_C(59353), UINT16_C(    0), UINT16_C(14555), UINT16_C(    0), UINT16_C(48163), UINT16_C(    0), UINT16_C(    0),
        UINT16_C(34697), UINT16_C(    0), UINT16_C(    0), UINT16_C(    0), UINT16_C(    0), UINT16_C(    0), UINT16_C(60333), UINT16_C(27459),
        UINT16_C(    0), UINT16_C(53005), UINT16_C(    0), UINT16_C(20402), UINT16_C(    0), UINT16_C(18918), UINT16_C(49603), UINT16_C(    0),
        UINT16_C(16165), UINT16_C(    0), UINT16_C(30680), UINT16_C(    0), UINT16_C(    0), UINT16_C(    0), UINT16_C(    0), UINT16_C(    0) } }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
    simde__m512i a = simde_mm512_loadu_epi16(test_vec[i].a);
    simde__m512i b = simde_mm512_loadu_epi16(test_vec[i].b);
    simde__m512i r = simde_mm512_maskz_max_epu16(test_vec[i].k, a, b);
    simde_test_x86_assert_equal_u16x32(r, simde_mm512_loadu_epi16(test_vec[i].r));
  }

  return 0;
}

static int
test_simde_mm512_mulhi_epi16 (SIMDE_MUNIT_TEST_ARGS) {
  static const struct {
    const int16_t a[32];
    const int16_t b[32];
    const int16_t r[32];
  } test_vec[] = {
    { { -INT16_C( 16752),  INT16_C(  3096),  INT16_C( 21789),  INT16_C( 27232), -INT16_C( 17038),  INT16_C( 13798), -INT16_C(  6599), -INT16_C( 28056),
        -INT16_C( 14632),  INT16_C( 22925), -INT16_C( 11459),  INT16_C( 11763),  INT16_C( 13417),  INT16_C( 15127),  INT16_C(  4707), -INT16_C(  3144),
        -INT16_C( 12079), -INT16_C(  4353),  INT16_C( 24613), -INT16_C( 26792),  INT16_C( 15901),  INT16_C( 22476),  INT16_C( 13349), -INT16_C(   535),
         INT16_C( 30459),  INT16_C( 14422),  INT16_C( 18761), -INT16_C( 19867),  INT16_C( 31870), -INT16_C(  7698), -INT16_C( 22898),  INT16_C( 24533) },
      { -INT16_C( 11145), -INT16_C( 25523), -INT16_C( 22988),  INT16_C( 21044),  INT16_C(   228),  INT16_C(  2473), -INT16_C( 28107),  INT16_C( 12294),
         INT16_C( 23560),  INT16_C( 20840), -INT16_C( 12890),  INT16_C(  9220), -INT16_C(  3511), -INT16_C( 10491), -INT16_C(  9576),  INT16_C(  3895),
        -INT16_C( 31569), -INT16_C(  7252), -INT16_C(  8150),  INT16_C(  3893), -INT16_C(  8480),  INT16_C(  5400),  INT16_C(  8048),  INT16_C( 30789),
        -INT16_C( 21125),  INT16_C(  8650), -INT16_C( 12678), -INT16_C( 15547),  INT16_C( 19392),  INT16_C( 22683), -INT16_C( 11739), -INT16_C( 11160) },
      {  INT16_C(  2848), -INT16_C(  1206), -INT16_C(  7643),  INT16_C(  8744), -INT16_C(    60),  INT16_C(   520),  INT16_C(  2830), -INT16_C(  5264),
        -INT16_C(  5261),  INT16_C(  7289),  INT16_C(  2253),  INT16_C(  1654), -INT16_C(   719), -INT16_C(  2422), -INT16_C(   688), -INT16_C(   187),
         INT16_C(  5818),  INT16_C(   481), -INT16_C(  3061), -INT16_C(  1592), -INT16_C(  2058),  INT16_C(  1851),  INT16_C(  1639), -INT16_C(   252),
        -INT16_C(  9819),  INT16_C(  1903), -INT16_C(  3630),  INT16_C(  4713),  INT16_C(  9430), -INT16_C(  2665),  INT16_C(  4101), -INT16_C(  4178) } },
    { {  INT16_C(  5206), -INT16_C( 32328), -INT16_C(  4620), -INT16_C( 11120), -INT16_C( 22324),  INT16_C( 15594),  INT16_C( 12231),  INT16_C( 17333),
         INT16_C( 32733),  INT16_C( 22372), -INT16_C( 21939),  INT16_C(  3355), -INT16_C( 18699),  INT16_C(  6757), -INT16_C( 12920), -INT16_C(  8465),
        -INT16_C( 22559), -INT16_C( 10913), -INT16_C(  4204),  INT16_C( 24746), -INT16_C( 27496),  INT16_C( 24477),  INT16_C( 21187), -INT16_C( 24414),
         INT16_C(  2001),  INT16_C(  7928),  INT16_C(  5041), -INT16_C( 22997), -INT16_C( 28471),  INT16_C( 20928), -INT16_C( 20642),  INT16_C( 16175) },
      { -INT16_C( 28842), -INT16_C(  5355), -INT16_C( 16514),  INT16_C(  5707), -INT16_C(  6061),  INT16_C(  5750),  INT16_C(  6202),  INT16_C(  2999),
        -INT16_C( 20705), -INT16_C( 12247),  INT16_C( 21698), -INT16_C( 29834),  INT16_C( 14309),  INT16_C( 17372),  INT16_C(  3046),  INT16_C( 15746),
        -INT16_C( 26726),  INT16_C(  6440),  INT16_C( 29526), -INT16_C( 22225), -INT16_C( 23204), -INT16_C( 26944),  INT16_C( 30654), -INT16_C(  8798),
        -INT16_C( 13530), -INT16_C(  5970),  INT16_C(  9248),  INT16_C(  1395),  INT16_C( 20315),  INT16_C( 16968), -INT16_C( 13734), -INT16_C(  2689) },
      { -INT16_C(  2292),  INT16_C(  2641),  INT16_C(  1164), -INT16_C(   969),  INT16_C(  2064),  INT16_C(  1368),  INT16_C(  1157),  INT16_C(   793),
        -INT16_C( 10342), -INT16_C(  4181), -INT16_C(  7264), -INT16_C(  1528), -INT16_C(  4083),  INT16_C(  1791), -INT16_C(   601), -INT16_C(  2034),
         INT16_C(  9199), -INT16_C(  1073), -INT16_C(  1895), -INT16_C(  8393),  INT16_C(  9735), -INT16_C( 10064),  INT16_C(  9910),  INT16_C(  3277),
        -INT16_C(   414), -INT16_C(   723),  INT16_C(   711), -INT16_C(   490), -INT16_C(  8826),  INT16_C(  5418),  INT16_C(  4325), -INT16_C(   664) } },
    { { -INT16_C( 22686), -INT16_C( 18418),  INT16_C( 15642),  INT16_C( 30306),  INT16_C(  8931), -INT16_C( 24307), -INT16_C( 20583), -INT16_C( 16514),
         INT16_C( 11386), -INT16_C( 25945),  INT16_C(  6737), -INT16_C( 21345), -INT16_C(  6295), -INT16_C( 15378),  INT16_C( 28082),  INT16_C(  5304),
        -INT16_C( 14828),  INT16_C( 12236),  INT16_C( 11780), -INT16_C(  6235), -INT16_C( 19888), -INT16_C(  5752),  INT16_C(  1633), -INT16_C(  9048),
         INT16_C( 20275), -INT16_C( 31626),  INT16_C(  5737), -INT16_C( 11728),  INT16_C(  8189), -INT16_C( 20586),  INT16_C( 20108), -INT16_C( 24125) },
      { -INT16_C( 28651),  INT16_C(  6608),  INT16_C( 30142),  INT16_C(  3840), -INT16_C( 30680), -INT16_C( 30216), -INT16_C( 24178), -INT16_C( 16027),
        -INT16_C(  8976),  INT16_C( 23109),  INT16_C( 30450), -INT16_C(  4308), -INT16_C( 15723),  INT16_C(  8607),  INT16_C( 25105),  INT16_C(  9922),
        -INT16_C( 27918), -INT16_C( 20161),  INT16_C( 16136),  INT16_C( 12480), -INT16_C( 18233),  INT16_C( 21945),  INT16_C(  8025),  INT16_C( 18967),
         INT16_C( 23803), -INT16_C(  4700), -INT16_C( 12078),  INT16_C( 26588),  INT16_C( 31635), -INT16_C( 23415),  INT16_C( 19422), -INT16_C( 12086) },
      {  INT16_C(  9917), -INT16_C(  1858),  INT16_C(  7194),  INT16_C(  1775), -INT16_C(  4181),  INT16_C( 11206),  INT16_C(  7593),  INT16_C(  4038),
        -INT16_C(  1560), -INT16_C(  9149),  INT16_C(  3130),  INT16_C(  1403),  INT16_C(  1510), -INT16_C(  2020),  INT16_C( 10757),  INT16_C(   803),
         INT16_C(  6316), -INT16_C(  3765),  INT16_C(  2900), -INT16_C(  1188),  INT16_C(  5533), -INT16_C(  1927),  INT16_C(   199), -INT16_C(  2619),
         INT16_C(  7363),  INT16_C(  2268), -INT16_C(  1058), -INT16_C(  4759),  INT16_C(  3952),  INT16_C(  7355),  INT16_C(  5959),  INT16_C(  4449) } },
    { {  INT16_C(  2526), -INT16_C(  6527),  INT16_C( 16712),  INT16_C(  3862), -INT16_C( 12294),  INT16_C( 21348),  INT16_C( 31726), -INT16_C(  5731),
         INT16_C( 16856), -INT16_C( 21802), -INT16_C( 19694), -INT16_C( 23278), -INT16_C( 25810),  INT16_C(  3145),  INT16_C(  5094), -INT16_C( 15139),
         INT16_C( 24092),  INT16_C( 25770), -INT16_C( 16224), -INT16_C( 25997), -INT16_C( 10352),  INT16_C( 32493), -INT16_C( 29869),  INT16_C( 11112),
         INT16_C( 16076), -INT16_C(  8491), -INT16_C(  6159),  INT16_C(  8323), -INT16_C( 13182),  INT16_C( 26924),  INT16_C(  2527), -INT16_C(  1235) },
      { -INT16_C( 10136),  INT16_C(  2143), -INT16_C( 11624),  INT16_C( 10402), -INT16_C( 28758), -INT16_C(   601),  INT16_C(  3866), -INT16_C(  6360),
        -INT16_C(   691),  INT16_C( 16325),  INT16_C( 18917),  INT16_C( 26463), -INT16_C( 29931), -INT16_C(  2608), -INT16_C(   363), -INT16_C(   528),
         INT16_C( 20694),  INT16_C( 28165), -INT16_C( 22750), -INT16_C( 13161),  INT16_C( 15926),  INT16_C( 20937), -INT16_C(  3763), -INT16_C( 26056),
        -INT16_C(   529), -INT16_C( 11047),  INT16_C( 14406),  INT16_C( 23611),  INT16_C(  3268),  INT16_C( 22865),  INT16_C( 16650), -INT16_C(  8106) },
      { -INT16_C(   391), -INT16_C(   214), -INT16_C(  2965),  INT16_C(   612),  INT16_C(  5394), -INT16_C(   196),  INT16_C(  1871),  INT16_C(   556),
        -INT16_C(   178), -INT16_C(  5431), -INT16_C(  5685), -INT16_C(  9400),  INT16_C( 11787), -INT16_C(   126), -INT16_C(    29),  INT16_C(   121),
         INT16_C(  7607),  INT16_C( 11075),  INT16_C(  5631),  INT16_C(  5220), -INT16_C(  2516),  INT16_C( 10380),  INT16_C(  1715), -INT16_C(  4418),
        -INT16_C(   130),  INT16_C(  1431), -INT16_C(  1354),  INT16_C(  2998), -INT16_C(   658),  INT16_C(  9393),  INT16_C(   642),  INT16_C(   152) } },
    { {  INT16_C( 23441), -INT16_C( 19378), -INT16_C(  6910),  INT16_C( 14464),  INT16_C( 18979),  INT16_C( 28809), -INT16_C( 16069),  INT16_C( 10763),
        -INT16_C(  6977),  INT16_C(  1534),  INT16_C( 14877), -INT16_C(  7839), -INT16_C( 19898),  INT16_C( 20538), -INT16_C( 28428), -INT16_C( 31440),
         INT16_C( 32491), -INT16_C(  4807), -INT16_C( 17820), -INT16_C( 30939), -INT16_C( 20732),  INT16_C( 16376),  INT16_C(   880),  INT16_C( 12138),
         INT16_C( 26855),  INT16_C(  1077), -INT16_C( 26974), -INT16_C(  5915),  INT16_C(  8009),  INT16_C( 15672),  INT16_C( 26799), -INT16_C( 25918) },
      { -INT16_C(   793),  INT16_C( 19335), -INT16_C( 21066), -INT16_C( 17710), -INT16_C( 13732), -INT16_C( 13063),  INT16_C( 25549), -INT16_C( 18948),
         INT16_C( 12748),  INT16_C( 28345), -INT16_C( 24633),  INT16_C(  4183), -INT16_C( 28738),  INT16_C( 28237),  INT16_C(  4344), -INT16_C(  8440),
        -INT16_C( 28660), -INT16_C( 15830), -INT16_C(   963), -INT16_C( 26244),  INT16_C( 30151), -INT16_C( 27547),  INT16_C( 25049), -INT16_C( 23223),
         INT16_C(   914),  INT16_C( 23059),  INT16_C( 27298),  INT16_C( 24682), -INT16_C( 18182), -INT16_C(  3378), -INT16_C( 10296), -INT16_C( 11055) },
      { -INT16_C(   284), -INT16_C(  5718),  INT16_C(  2221), -INT16_C(  3909), -INT16_C(  3977), -INT16_C(  5743), -INT16_C(  6265), -INT16_C(  3112),
        -INT16_C(  1358),  INT16_C(   663), -INT16_C(  5592), -INT16_C(   501),  INT16_C(  8725),  INT16_C(  8849), -INT16_C(  1885),  INT16_C(  4048),
        -INT16_C( 14209),  INT16_C(  1161),  INT16_C(   261),  INT16_C( 12389), -INT16_C(  9539), -INT16_C(  6884),  INT16_C(   336), -INT16_C(  4302),
         INT16_C(   374),  INT16_C(   378), -INT16_C( 11236), -INT16_C(  2228), -INT16_C(  2222), -INT16_C(   808), -INT16_C(  4211),  INT16_C(  4372) } },
    { { -INT16_C(  1177), -INT16_C( 23402),  INT16_C(  4855), -INT16_C( 16835), -INT16_C( 23929),  INT16_C( 24659), -INT16_C( 25596), -INT16_C( 27131),
         INT16_C(  6559),  INT16_C( 16880),  INT16_C( 23427),  INT16_C( 32162),  INT16_C( 28691), -INT16_C(  9361),  INT16_C( 16455), -INT16_C( 20817),
         INT16_C( 17723),  INT16_C( 13138), -INT16_C( 28841), -INT16_C(  8463),  INT16_C( 17458),  INT16_C( 13887),  INT16_C( 17633), -INT16_C( 32564),
        -INT16_C( 17059), -INT16_C(  7742),  INT16_C( 25624),  INT16_C( 11102), -INT16_C( 12588),  INT16_C(  7174), -INT16_C( 19186),  INT16_C( 19146) },
      {  INT16_C(  7674),  INT16_C( 20861),  INT16_C( 28332), -INT16_C(  8657),  INT16_C( 28339), -INT16_C( 27628), -INT16_C(  7757),  INT16_C(  4116),
        -INT16_C( 10594), -INT16_C( 18703),  INT16_C( 20538),  INT16_C(  4065), -INT16_C(  6370),  INT16_C( 11307), -INT16_C(  2660), -INT16_C( 27018),
        -INT16_C(  3310), -INT16_C( 16409),  INT16_C(  5730),  INT16_C(  5533), -INT16_C( 19835),  INT16_C( 14505), -INT16_C( 17005),  INT16_C( 12616),
         INT16_C( 14996), -INT16_C( 12569), -INT16_C( 14198), -INT16_C( 22307),  INT16_C(  2223),  INT16_C( 19412),  INT16_C( 19454),  INT16_C(  4321) },
      { -INT16_C(   138), -INT16_C(  7450),  INT16_C(  2098),  INT16_C(  2223), -INT16_C( 10348), -INT16_C( 10396),  INT16_C(  3029), -INT16_C(  1704),
        -INT16_C(  1061), -INT16_C(  4818),  INT16_C(  7341),  INT16_C(  1994), -INT16_C(  2789), -INT16_C(  1616), -INT16_C(   668),  INT16_C(  8582),
        -INT16_C(   896), -INT16_C(  3290), -INT16_C(  2522), -INT16_C(   715), -INT16_C(  5284),  INT16_C(  3073), -INT16_C(  4576), -INT16_C(  6269),
        -INT16_C(  3904),  INT16_C(  1484), -INT16_C(  5552), -INT16_C(  3779), -INT16_C(   427),  INT16_C(  2124), -INT16_C(  5696),  INT16_C(  1262) } },
    { { -INT16_C( 14274), -INT16_C( 24369),  INT16_C( 28126),  INT16_C( 25525),  INT16_C( 24095), -INT16_C( 19813), -INT16_C(  7140), -INT16_C( 20253),
        -INT16_C( 13794), -INT16_C( 22402),  INT16_C( 23698),  INT16_C( 16720),  INT16_C(  9316),  INT16_C( 25228),  INT16_C( 28015), -INT16_C( 20877),
         INT16_C( 16949),  INT16_C(  4942),  INT16_C(  1199), -INT16_C( 12681),  INT16_C(  4706),  INT16_C( 32384),  INT16_C( 25590),  INT16_C(  5166),
        -INT16_C( 21203), -INT16_C( 16452),  INT16_C(  3081),  INT16_C( 27904), -INT16_C( 29647), -INT16_C( 24368),  INT16_C( 17401),  INT16_C( 11854) },
      { -INT16_C( 25211),  INT16_C( 13634), -INT16_C( 18015),  INT16_C(   771), -INT16_C( 31541), -INT16_C( 15742), -INT16_C( 20249),  INT16_C(  5590),
        -INT16_C( 27811),  INT16_C( 26324), -INT16_C( 10849), -INT16_C( 12076), -INT16_C( 23455),  INT16_C( 23409), -INT16_C( 16409),  INT16_C( 27785),
        -INT16_C( 13476), -INT16_C(   607), -INT16_C( 23164),  INT16_C( 20481), -INT16_C( 31959),  INT16_C(  4114), -INT16_C(  6093), -INT16_C( 28379),
        -INT16_C(  1413),  INT16_C(  7159), -INT16_C( 13361),  INT16_C( 12523),  INT16_C( 23663),  INT16_C( 22155),  INT16_C(  5404),  INT16_C( 30915) },
      {  INT16_C(  5491), -INT16_C(  5070), -INT16_C(  7732),  INT16_C(   300), -INT16_C( 11597),  INT16_C(  4759),  INT16_C(  2206), -INT16_C(  1728),
         INT16_C(  5853), -INT16_C(  8999), -INT16_C(  3924), -INT16_C(  3081), -INT16_C(  3335),  INT16_C(  9011), -INT16_C(  7015), -INT16_C(  8852),
        -INT16_C(  3486), -INT16_C(    46), -INT16_C(   424), -INT16_C(  3964), -INT16_C(  2295),  INT16_C(  2032), -INT16_C(  2380), -INT16_C(  2238),
         INT16_C(   457), -INT16_C(  1798), -INT16_C(   629),  INT16_C(  5332), -INT16_C( 10705), -INT16_C(  8238),  INT16_C(  1434),  INT16_C(  5591) } },
    { {  INT16_C( 25824),  INT16_C( 25974),  INT16_C( 30473),  INT16_C( 12981), -INT16_C( 14342),  INT16_C( 11587),  INT16_C( 26799),  INT16_C( 11198),
        -INT16_C( 18846),  INT16_C( 12614),  INT16_C( 12673), -INT16_C(  3742), -INT16_C(  4722), -INT16_C( 21945),  INT16_C(  2562), -INT16_C(  7390),
        -INT16_C( 26513),  INT16_C( 30792), -INT16_C(   753),  INT16_C(  2475), -INT16_C(  4412),  INT16_C( 29495), -INT16_C(  2730), -INT16_C( 18018),
        -INT16_C(  6997),  INT16_C( 11754),  INT16_C( 19478), -INT16_C( 23522),  INT16_C( 25914),  INT16_C( 15438),  INT16_C( 28784), -INT16_C(  8417) },
      {  INT16_C( 26377),  INT16_C(  6231),  INT16_C(   612),  INT16_C( 10274),  INT16_C( 23024),  INT16_C( 18332),  INT16_C( 14926), -INT16_C(  1536),
        -INT16_C(  5601),  INT16_C( 13607),  INT16_C( 17719),  INT16_C( 29145),  INT16_C( 10154),  INT16_C(  6829), -INT16_C( 12905), -INT16_C( 24327),
         INT16_C( 20788), -INT16_C( 26183), -INT16_C(  9389),  INT16_C( 17601),  INT16_C( 23860), -INT16_C( 32117), -INT16_C( 29800), -INT16_C( 18564),
        -INT16_C( 23691), -INT16_C( 21268), -INT16_C( 14872), -INT16_C( 27875), -INT16_C( 13332), -INT16_C( 31827), -INT16_C( 22632), -INT16_C( 13276) },
      {  INT16_C( 10393),  INT16_C(  2469),  INT16_C(   284),  INT16_C(  2035), -INT16_C(  5039),  INT16_C(  3241),  INT16_C(  6103), -INT16_C(   263),
         INT16_C(  1610),  INT16_C(  2618),  INT16_C(  3426), -INT16_C(  1665), -INT16_C(   732), -INT16_C(  2287), -INT16_C(   505),  INT16_C(  2743),
        -INT16_C(  8410), -INT16_C( 12303),  INT16_C(   107),  INT16_C(   664), -INT16_C(  1607), -INT16_C( 14455),  INT16_C(  1241),  INT16_C(  5103),
         INT16_C(  2529), -INT16_C(  3815), -INT16_C(  4421),  INT16_C( 10004), -INT16_C(  5272), -INT16_C(  7498), -INT16_C(  9941),  INT16_C(  1705) } }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
    simde__m512i a = simde_mm512_loadu_epi16(test_vec[i].a);
    simde__m512i b = simde_mm512_loadu_epi16(test_vec[i].b);
    simde__m512i r = simde_mm512_mulhi_epi16(a, b);
    simde_test_x86_assert_equal_i16x32(r, simde_mm512_loadu_epi16(test_vec[i].r));
  }

  return 0;
}

static int
test_simde_mm512_mulhrs_epi16 (SIMDE_MUNIT_TEST_ARGS) {
  static const struct {
    const int16_t a[32];
    const int16_t b[32];
    const int16_t r[32];
  } test_vec[] = {
    { {  INT16_C(  2012), -INT16_C( 16441), -INT16_C(  5959),  INT16_C( 17687),  INT16_C( 27737), -INT16_C( 25181), -INT16_C(  3282),  INT16_C( 22705),
         INT16_C( 13185),  INT16_C(  4437),  INT16_C( 13761), -INT16_C(  8944),  INT16_C( 19921), -INT16_C( 21079), -INT16_C( 20071),  INT16_C( 30226),
        -INT16_C(  9544),  INT16_C( 29237),  INT16_C( 19650),  INT16_C(  7095),  INT16_C( 23224), -INT16_C(  6471),  INT16_C( 27214), -INT16_C( 12481),
        -INT16_C( 27491),  INT16_C( 24544), -INT16_C(  3895), -INT16_C( 25796), -INT16_C(  6851), -INT16_C( 10424),  INT16_C( 23446),  INT16_C( 20301) },
      { -INT16_C( 32203), -INT16_C(  2111),  INT16_C( 30926), -INT16_C( 31214), -INT16_C( 13358),  INT16_C(  8300), -INT16_C( 21707), -INT16_C( 11281),
        -INT16_C( 12481),  INT16_C(  2354),  INT16_C( 28352), -INT16_C(   604), -INT16_C(  5036), -INT16_C(  5420),  INT16_C(  8519),  INT16_C( 31801),
        -INT16_C(  1373),  INT16_C( 29043), -INT16_C( 31118),  INT16_C( 17911),  INT16_C( 25681), -INT16_C( 30875),  INT16_C( 21775),  INT16_C( 20314),
        -INT16_C( 29660), -INT16_C(  7080), -INT16_C(   774),  INT16_C( 20194), -INT16_C( 18712),  INT16_C( 12345),  INT16_C( 29400),  INT16_C( 31660) },
      { -INT16_C(  1977),  INT16_C(  1059), -INT16_C(  5624), -INT16_C( 16848), -INT16_C( 11307), -INT16_C(  6378),  INT16_C(  2174), -INT16_C(  7817),
        -INT16_C(  5022),  INT16_C(   319),  INT16_C( 11906),  INT16_C(   165), -INT16_C(  3062),  INT16_C(  3487), -INT16_C(  5218),  INT16_C( 29334),
         INT16_C(   400),  INT16_C( 25913), -INT16_C( 18661),  INT16_C(  3878),  INT16_C( 18201),  INT16_C(  6097),  INT16_C( 18084), -INT16_C(  7737),
         INT16_C( 24884), -INT16_C(  5303),  INT16_C(    92), -INT16_C( 15897),  INT16_C(  3912), -INT16_C(  3927),  INT16_C( 21036),  INT16_C( 19615) } },
    { {  INT16_C(  8301), -INT16_C(  8211), -INT16_C(  7002), -INT16_C(  2268), -INT16_C( 30136),  INT16_C( 22654), -INT16_C( 10017),  INT16_C(   935),
        -INT16_C(   156),  INT16_C( 24552), -INT16_C( 13573), -INT16_C(  7251), -INT16_C(  6528),  INT16_C( 22547), -INT16_C( 16295), -INT16_C( 14636),
        -INT16_C( 15904), -INT16_C( 31067), -INT16_C( 13659), -INT16_C(  4483), -INT16_C(   940),  INT16_C( 13126), -INT16_C(  4652),  INT16_C( 14646),
         INT16_C(  7916), -INT16_C(  6248),  INT16_C( 17896),  INT16_C( 27082), -INT16_C(  8660), -INT16_C( 31295), -INT16_C( 27234),  INT16_C( 32331) },
      { -INT16_C(  4010), -INT16_C(  1020), -INT16_C( 32326),  INT16_C(  3818),  INT16_C( 12413),  INT16_C( 21057),  INT16_C( 30749),  INT16_C(  2443),
         INT16_C(  9110),  INT16_C( 32752), -INT16_C( 17816), -INT16_C( 27416), -INT16_C( 22120),  INT16_C( 13849),  INT16_C( 25663), -INT16_C( 27212),
        -INT16_C( 18347),  INT16_C(  3985),  INT16_C( 31546), -INT16_C( 18658),  INT16_C( 24491), -INT16_C( 14327), -INT16_C( 27433),  INT16_C( 28369),
        -INT16_C( 15945),  INT16_C(  8429), -INT16_C( 10884),  INT16_C(  5300), -INT16_C( 12674), -INT16_C( 17077), -INT16_C(   206), -INT16_C( 30893) },
      { -INT16_C(  1016),  INT16_C(   256),  INT16_C(  6908), -INT16_C(   264), -INT16_C( 11416),  INT16_C( 14558), -INT16_C(  9400),  INT16_C(    70),
        -INT16_C(    43),  INT16_C( 24540),  INT16_C(  7380),  INT16_C(  6067),  INT16_C(  4407),  INT16_C(  9529), -INT16_C( 12762),  INT16_C( 12154),
         INT16_C(  8905), -INT16_C(  3778), -INT16_C( 13150),  INT16_C(  2553), -INT16_C(   703), -INT16_C(  5739),  INT16_C(  3895),  INT16_C( 12680),
        -INT16_C(  3852), -INT16_C(  1607), -INT16_C(  5944),  INT16_C(  4380),  INT16_C(  3350),  INT16_C( 16309),  INT16_C(   171), -INT16_C( 30481) } },
    { { -INT16_C(  6984), -INT16_C(  3433), -INT16_C( 19104),  INT16_C(  2985), -INT16_C( 19692), -INT16_C(  4908), -INT16_C( 23225), -INT16_C(   166),
         INT16_C( 18279), -INT16_C(  7393), -INT16_C( 11492), -INT16_C( 25865),  INT16_C( 17057), -INT16_C( 11176), -INT16_C( 21694), -INT16_C(  1445),
        -INT16_C(  3441), -INT16_C(  4116), -INT16_C( 27225), -INT16_C( 17157), -INT16_C( 12472), -INT16_C( 28504),  INT16_C(   628), -INT16_C(  9329),
        -INT16_C( 20919),  INT16_C( 26046), -INT16_C( 18815),  INT16_C(  9215),  INT16_C( 22520),  INT16_C( 15095),  INT16_C( 20994), -INT16_C( 28108) },
      {  INT16_C(  8261), -INT16_C(  4991),  INT16_C( 31926), -INT16_C(   344),  INT16_C( 20555), -INT16_C( 16242),  INT16_C(  7506), -INT16_C( 25701),
         INT16_C( 23243),  INT16_C( 19712),  INT16_C(    16),  INT16_C(  2160),  INT16_C( 26455),  INT16_C( 23107),  INT16_C( 30649), -INT16_C(   276),
         INT16_C( 28056),  INT16_C( 20203), -INT16_C( 27670),  INT16_C( 13644), -INT16_C(  9244),  INT16_C( 14069), -INT16_C( 28168), -INT16_C( 15150),
        -INT16_C( 11541), -INT16_C(  1263), -INT16_C( 32302),  INT16_C( 10755),  INT16_C( 18152), -INT16_C( 24188),  INT16_C( 28862),  INT16_C( 22176) },
      { -INT16_C(  1761),  INT16_C(   523), -INT16_C( 18613), -INT16_C(    31), -INT16_C( 12353),  INT16_C(  2433), -INT16_C(  5320),  INT16_C(   130),
         INT16_C( 12966), -INT16_C(  4447), -INT16_C(     6), -INT16_C(  1705),  INT16_C( 13771), -INT16_C(  7881), -INT16_C( 20291),  INT16_C(    12),
        -INT16_C(  2946), -INT16_C(  2538),  INT16_C( 22989), -INT16_C(  7144),  INT16_C(  3518), -INT16_C( 12238), -INT16_C(   540),  INT16_C(  4313),
         INT16_C(  7368), -INT16_C(  1004),  INT16_C( 18547),  INT16_C(  3025),  INT16_C( 12475), -INT16_C( 11143),  INT16_C( 18491), -INT16_C( 19022) } },
    { { -INT16_C( 29731), -INT16_C( 14428), -INT16_C(  4066),  INT16_C(   765), -INT16_C(  3381), -INT16_C( 15303),  INT16_C(  2947),  INT16_C( 28296),
        -INT16_C( 26147), -INT16_C( 20375),  INT16_C( 27930),  INT16_C(   730),  INT16_C( 24243),  INT16_C( 29091),  INT16_C( 17358), -INT16_C( 21561),
         INT16_C( 27598), -INT16_C(  4749),  INT16_C( 28764),  INT16_C( 10223),  INT16_C( 10338), -INT16_C(  6421),  INT16_C( 29491),  INT16_C(  4436),
        -INT16_C( 16884),  INT16_C(  9921), -INT16_C( 25813), -INT16_C(  8664), -INT16_C( 13063), -INT16_C( 14512),  INT16_C(  5903), -INT16_C(  8590) },
      { -INT16_C(  6781), -INT16_C(  8245), -INT16_C( 17835), -INT16_C( 18426), -INT16_C(  3357),  INT16_C(  5790), -INT16_C(  3483),  INT16_C( 29223),
        -INT16_C(  5968), -INT16_C(  9320), -INT16_C( 15997),  INT16_C( 31930),  INT16_C(  2701), -INT16_C( 25533), -INT16_C( 18911), -INT16_C( 23430),
         INT16_C( 17819), -INT16_C(  3709), -INT16_C( 30208), -INT16_C(  7255),  INT16_C( 18300), -INT16_C(  7687),  INT16_C(  8505), -INT16_C(  5549),
        -INT16_C(  5111), -INT16_C( 29243),  INT16_C( 32685),  INT16_C( 14857),  INT16_C( 19849), -INT16_C( 21546),  INT16_C( 20739), -INT16_C( 25009) },
      {  INT16_C(  6153),  INT16_C(  3630),  INT16_C(  2213), -INT16_C(   430),  INT16_C(   346), -INT16_C(  2704), -INT16_C(   313),  INT16_C( 25235),
         INT16_C(  4762),  INT16_C(  5795), -INT16_C( 13635),  INT16_C(   711),  INT16_C(  1998), -INT16_C( 22668), -INT16_C( 10018),  INT16_C( 15417),
         INT16_C( 15008),  INT16_C(   538), -INT16_C( 26517), -INT16_C(  2263),  INT16_C(  5773),  INT16_C(  1506),  INT16_C(  7654), -INT16_C(   751),
         INT16_C(  2633), -INT16_C(  8854), -INT16_C( 25748), -INT16_C(  3928), -INT16_C(  7913),  INT16_C(  9542),  INT16_C(  3736),  INT16_C(  6556) } },
    { { -INT16_C( 11370), -INT16_C( 26993),  INT16_C( 14429), -INT16_C(  9863),  INT16_C( 29567), -INT16_C( 17990),  INT16_C(  3732), -INT16_C( 25181),
         INT16_C( 26874), -INT16_C( 22742),  INT16_C( 13544),  INT16_C( 29153), -INT16_C( 18559), -INT16_C( 31716),  INT16_C( 27656), -INT16_C( 24798),
        -INT16_C( 19905), -INT16_C( 25547), -INT16_C( 20502),  INT16_C( 27253),  INT16_C( 12066), -INT16_C( 18909), -INT16_C( 14787),  INT16_C( 14163),
         INT16_C( 32302),  INT16_C(  5854), -INT16_C( 16462),  INT16_C( 13192), -INT16_C( 23433),  INT16_C( 32695), -INT16_C(  9968),  INT16_C( 20254) },
      {  INT16_C( 21643),  INT16_C( 30443),  INT16_C( 24579),  INT16_C(  9696),  INT16_C(   912), -INT16_C( 12837),  INT16_C( 11977), -INT16_C(  2299),
        -INT16_C(  7252),  INT16_C( 24078), -INT16_C( 26973),  INT16_C(  6801),  INT16_C( 18490),  INT16_C( 19353), -INT16_C( 18398), -INT16_C( 21094),
        -INT16_C( 31220),  INT16_C(  3875),  INT16_C(   998),  INT16_C( 30260),  INT16_C(  3846), -INT16_C( 12476),  INT16_C( 18749), -INT16_C(  5433),
        -INT16_C( 10964), -INT16_C( 12472), -INT16_C(  9621), -INT16_C( 23063), -INT16_C( 31966),  INT16_C( 17648), -INT16_C( 29893),  INT16_C( 18418) },
      { -INT16_C(  7510), -INT16_C( 25078),  INT16_C( 10823), -INT16_C(  2918),  INT16_C(   823),  INT16_C(  7048),  INT16_C(  1364),  INT16_C(  1767),
        -INT16_C(  5948), -INT16_C( 16711), -INT16_C( 11149),  INT16_C(  6051), -INT16_C( 10472), -INT16_C( 18732), -INT16_C( 15528),  INT16_C( 15963),
         INT16_C( 18965), -INT16_C(  3021), -INT16_C(   624),  INT16_C( 25167),  INT16_C(  1416),  INT16_C(  7199), -INT16_C(  8461), -INT16_C(  2348),
        -INT16_C( 10808), -INT16_C(  2228),  INT16_C(  4833), -INT16_C(  9285),  INT16_C( 22859),  INT16_C( 17609),  INT16_C(  9093),  INT16_C( 11384) } },
    { {  INT16_C(  5393), -INT16_C(  2218), -INT16_C( 30183),  INT16_C(  8046), -INT16_C( 19815), -INT16_C( 10513), -INT16_C( 18693),  INT16_C( 10176),
         INT16_C(  2443), -INT16_C(  2313), -INT16_C(  7965),  INT16_C(  1435), -INT16_C( 29597), -INT16_C( 25014),  INT16_C( 15383),  INT16_C( 10469),
         INT16_C( 15185),  INT16_C( 27167), -INT16_C( 29243),  INT16_C( 24202),  INT16_C( 31039),  INT16_C( 14901), -INT16_C(  2769), -INT16_C( 17822),
         INT16_C( 23038), -INT16_C(  7760),  INT16_C( 19257), -INT16_C( 25113),  INT16_C( 12759), -INT16_C(  4549),  INT16_C(  8557), -INT16_C( 16874) },
      {  INT16_C( 13916),  INT16_C(  8745), -INT16_C( 19517),  INT16_C(   896), -INT16_C( 19156),  INT16_C( 23357), -INT16_C( 24661), -INT16_C( 22251),
        -INT16_C( 14856),  INT16_C( 12939),  INT16_C( 29200), -INT16_C(  5937),  INT16_C(  2723),  INT16_C(  4310), -INT16_C(  4821), -INT16_C( 30514),
        -INT16_C(  2269), -INT16_C(  6486),  INT16_C( 10922), -INT16_C( 10519),  INT16_C( 10208), -INT16_C( 29903),  INT16_C( 18118), -INT16_C( 16588),
        -INT16_C( 16629),  INT16_C(  7409), -INT16_C( 16335), -INT16_C( 11260), -INT16_C(  9526), -INT16_C(  2332), -INT16_C( 19513), -INT16_C(  5506) },
      {  INT16_C(  2290), -INT16_C(   592),  INT16_C( 17977),  INT16_C(   220),  INT16_C( 11584), -INT16_C(  7494),  INT16_C( 14068), -INT16_C(  6910),
        -INT16_C(  1108), -INT16_C(   913), -INT16_C(  7098), -INT16_C(   260), -INT16_C(  2459), -INT16_C(  3290), -INT16_C(  2263), -INT16_C(  9749),
        -INT16_C(  1051), -INT16_C(  5377), -INT16_C(  9747), -INT16_C(  7769),  INT16_C(  9669), -INT16_C( 13598), -INT16_C(  1531),  INT16_C(  9022),
        -INT16_C( 11691), -INT16_C(  1755), -INT16_C(  9600),  INT16_C(  8630), -INT16_C(  3709),  INT16_C(   324), -INT16_C(  5096),  INT16_C(  2835) } },
    { {  INT16_C( 10410),  INT16_C( 21969), -INT16_C( 17838),  INT16_C( 12843),  INT16_C( 24033), -INT16_C( 22339), -INT16_C(  3421), -INT16_C( 20633),
         INT16_C( 22705), -INT16_C(  7221), -INT16_C( 12520), -INT16_C(  7497), -INT16_C( 25431),  INT16_C( 29144),  INT16_C( 22095), -INT16_C(  1701),
         INT16_C( 11390), -INT16_C( 11954),  INT16_C( 31463), -INT16_C( 14333), -INT16_C( 15913),  INT16_C( 31344), -INT16_C( 10317),  INT16_C( 25641),
        -INT16_C(  3025),  INT16_C( 18247), -INT16_C(    61),  INT16_C( 27946),  INT16_C(   667), -INT16_C(  5410),  INT16_C( 14681), -INT16_C( 10269) },
      {  INT16_C( 12902),  INT16_C( 19880), -INT16_C( 21332), -INT16_C( 31979), -INT16_C( 31123),  INT16_C(  8445),  INT16_C( 10077), -INT16_C( 29308),
        -INT16_C( 13285), -INT16_C(  8236), -INT16_C(   309),  INT16_C( 26188),  INT16_C( 10753),  INT16_C( 23120),  INT16_C( 13155), -INT16_C( 14031),
        -INT16_C(  9627),  INT16_C(  4374),  INT16_C( 11398), -INT16_C(  3180), -INT16_C( 27982),  INT16_C(  3859), -INT16_C( 26695), -INT16_C( 11108),
         INT16_C( 29027),  INT16_C( 11955), -INT16_C(   145),  INT16_C( 28820), -INT16_C(  7127), -INT16_C( 29238), -INT16_C(  1000),  INT16_C( 32086) },
      {  INT16_C(  4099),  INT16_C( 13328),  INT16_C( 11613), -INT16_C( 12534), -INT16_C( 22827), -INT16_C(  5757), -INT16_C(  1052),  INT16_C( 18454),
        -INT16_C(  9205),  INT16_C(  1815),  INT16_C(   118), -INT16_C(  5992), -INT16_C(  8345),  INT16_C( 20563),  INT16_C(  8870),  INT16_C(   728),
        -INT16_C(  3346), -INT16_C(  1596),  INT16_C( 10944),  INT16_C(  1391),  INT16_C( 13589),  INT16_C(  3691),  INT16_C(  8405), -INT16_C(  8692),
        -INT16_C(  2680),  INT16_C(  6657),  INT16_C(     0),  INT16_C( 24579), -INT16_C(   145),  INT16_C(  4827), -INT16_C(   448), -INT16_C( 10055) } },
    { {  INT16_C( 28118),  INT16_C( 23695),  INT16_C(  9113),  INT16_C( 19279),  INT16_C( 25269),  INT16_C( 28250), -INT16_C(  2055),  INT16_C( 23875),
        -INT16_C(  2456), -INT16_C( 10357),  INT16_C(  8438),  INT16_C(  8008),  INT16_C(  4612),  INT16_C(  7340),  INT16_C(   782), -INT16_C(  7014),
         INT16_C( 10608),  INT16_C(  2368), -INT16_C( 28852),  INT16_C(   596), -INT16_C( 20751), -INT16_C(  5264), -INT16_C( 19547),  INT16_C(  3400),
        -INT16_C( 11350), -INT16_C( 24347),  INT16_C( 11763), -INT16_C(  1857),  INT16_C( 27711),  INT16_C( 19988), -INT16_C( 20881), -INT16_C(  8398) },
      {  INT16_C( 29655),  INT16_C(  9448),  INT16_C( 15362), -INT16_C(  3034), -INT16_C( 26902), -INT16_C( 28449),  INT16_C( 10058), -INT16_C(  2915),
        -INT16_C( 32006), -INT16_C(  4460),  INT16_C( 21423), -INT16_C(  4122), -INT16_C(  1345),  INT16_C( 11837),  INT16_C( 28585), -INT16_C( 32755),
        -INT16_C(  2590), -INT16_C(  6748), -INT16_C( 13775),  INT16_C(  7385), -INT16_C( 18335), -INT16_C( 21588),  INT16_C( 18911), -INT16_C(  9825),
         INT16_C( 13260),  INT16_C( 31687), -INT16_C( 21114),  INT16_C( 18026), -INT16_C( 22616),  INT16_C( 20852), -INT16_C( 32233), -INT16_C(  1583) },
      {  INT16_C( 25447),  INT16_C(  6832),  INT16_C(  4272), -INT16_C(  1785), -INT16_C( 20745), -INT16_C( 24526), -INT16_C(   631), -INT16_C(  2124),
         INT16_C(  2399),  INT16_C(  1410),  INT16_C(  5517), -INT16_C(  1007), -INT16_C(   189),  INT16_C(  2651),  INT16_C(   682),  INT16_C(  7011),
        -INT16_C(   838), -INT16_C(   488),  INT16_C( 12129),  INT16_C(   134),  INT16_C( 11611),  INT16_C(  3468), -INT16_C( 11281), -INT16_C(  1019),
        -INT16_C(  4593), -INT16_C( 23544), -INT16_C(  7579), -INT16_C(  1022), -INT16_C( 19126),  INT16_C( 12719),  INT16_C( 20540),  INT16_C(   406) } }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
    simde__m512i a = simde_mm512_loadu_epi16(test_vec[i].a);
    simde__m512i b = simde_mm512_loadu_epi16(test_vec[i].b);
    simde__m512i r = simde_mm512_mulhrs_epi16(a, b);
    simde_test_x86_assert_equal_i16x32(r, simde_mm512_loadu_epi16(test_vec[i].r));
  }

  return 0;
}

static int
test_simde_mm512_mullo_epi16 (SIMDE_MUNIT_TEST_ARGS) {
  static const struct {
    const int16_t a[32];
    const int16_t b[32];
    const int16_t r[32];
  } test_vec[] = {
    { { -INT16_C( 31159), -INT16_C( 12097),  INT16_C( 29918),  INT16_C(  1377),  INT16_C( 32398),  INT16_C(  6544), -INT16_C( 30801),  INT16_C( 30357),
         INT16_C( 14887),  INT16_C(  9940),  INT16_C(  3636), -INT16_C( 23516),  INT16_C( 28807), -INT16_C(  9340), -INT16_C( 22852),  INT16_C(  1558),
        -INT16_C( 10708),  INT16_C(  2774),  INT16_C( 14154), -INT16_C( 10224), -INT16_C( 24394),  INT16_C( 26098), -INT16_C( 30937),  INT16_C( 20444),
        -INT16_C( 20287), -INT16_C(  2699), -INT16_C( 26177),  INT16_C( 18073),  INT16_C(  7434), -INT16_C( 14815),  INT16_C( 14275), -INT16_C(  3892) },
      { -INT16_C( 23795),  INT16_C( 22778),  INT16_C(  2778), -INT16_C( 28624),  INT16_C(  8875), -INT16_C( 11530), -INT16_C( 11607),  INT16_C( 27169),
        -INT16_C( 26750),  INT16_C( 16736), -INT16_C(  1744),  INT16_C( 14983), -INT16_C( 22505), -INT16_C(  9727), -INT16_C( 12832), -INT16_C(  4662),
        -INT16_C( 14992),  INT16_C( 19269),  INT16_C( 30415),  INT16_C( 31451), -INT16_C( 11880),  INT16_C( 16973),  INT16_C( 28323),  INT16_C(  9900),
         INT16_C(  3077),  INT16_C( 13927), -INT16_C(  4346),  INT16_C(  7536),  INT16_C( 29079),  INT16_C( 30711), -INT16_C( 15809), -INT16_C( 20635) },
      {  INT16_C( 19637), -INT16_C( 32122),  INT16_C( 12556), -INT16_C( 28112),  INT16_C( 25818), -INT16_C( 20384),  INT16_C(  8327), -INT16_C(  1227),
        -INT16_C( 30514),  INT16_C( 25472),  INT16_C( 15808), -INT16_C( 18692), -INT16_C( 19423),  INT16_C( 17284),  INT16_C( 28800),  INT16_C( 11100),
        -INT16_C( 28864), -INT16_C( 25170), -INT16_C( 12074),  INT16_C( 30128),  INT16_C(   528),  INT16_C(  3530), -INT16_C( 12331),  INT16_C( 20432),
         INT16_C( 32709),  INT16_C( 28691), -INT16_C(  5254),  INT16_C( 14320), -INT16_C( 29978), -INT16_C( 32553),  INT16_C( 32509),  INT16_C( 29820) } },
    { { -INT16_C( 21881),  INT16_C( 22266), -INT16_C( 10720), -INT16_C( 17967),  INT16_C(  7847),  INT16_C( 19451), -INT16_C( 22644), -INT16_C( 28047),
        -INT16_C( 10060), -INT16_C( 17720),  INT16_C( 14535),  INT16_C( 24535), -INT16_C( 12630), -INT16_C(  5674),  INT16_C( 15248),  INT16_C(  6040),
        -INT16_C( 27674),  INT16_C(  1646),  INT16_C( 16233),  INT16_C(  4287), -INT16_C( 17827), -INT16_C(  5797), -INT16_C( 13214),  INT16_C(  5755),
         INT16_C( 17317),  INT16_C( 27856), -INT16_C( 22660),  INT16_C(  9931), -INT16_C( 23947),  INT16_C(  1551), -INT16_C( 22563), -INT16_C( 15587) },
      { -INT16_C( 29894), -INT16_C( 23606), -INT16_C( 30262),  INT16_C( 10164),  INT16_C(  3908), -INT16_C( 23023), -INT16_C( 29476), -INT16_C( 32324),
        -INT16_C( 29488),  INT16_C( 19693), -INT16_C( 18125), -INT16_C( 22414), -INT16_C( 32421),  INT16_C( 14510), -INT16_C( 13272),  INT16_C( 25596),
        -INT16_C( 14761),  INT16_C(  8710), -INT16_C( 17841), -INT16_C( 27831),  INT16_C( 23242), -INT16_C( 22983), -INT16_C(  2585), -INT16_C( 18649),
         INT16_C(  5249), -INT16_C( 19453),  INT16_C( 30157),  INT16_C( 10333),  INT16_C(  3062),  INT16_C(  7777),  INT16_C( 24023),  INT16_C( 12161) },
      { -INT16_C(  4202), -INT16_C( 12476),  INT16_C(  5440),  INT16_C( 32244), -INT16_C(  4772), -INT16_C( 12885), -INT16_C( 29616),  INT16_C( 31740),
        -INT16_C( 32192),  INT16_C( 19240),  INT16_C(  7845), -INT16_C( 14914),  INT16_C(  8302), -INT16_C( 16524),  INT16_C(  3712),  INT16_C(   416),
         INT16_C( 10026), -INT16_C( 15724), -INT16_C(  9369),  INT16_C( 29559), -INT16_C( 16542), -INT16_C(  2237),  INT16_C( 13934),  INT16_C( 22973),
        -INT16_C(  1499), -INT16_C( 31120), -INT16_C( 13748), -INT16_C( 12353),  INT16_C(  9070),  INT16_C(  3503),  INT16_C( 17307), -INT16_C( 23395) } },
    { { -INT16_C( 30685),  INT16_C( 29265), -INT16_C( 26046),  INT16_C(  3078),  INT16_C( 16373), -INT16_C(  9038), -INT16_C(  9931), -INT16_C( 18797),
        -INT16_C( 26898), -INT16_C( 17557), -INT16_C( 14325),  INT16_C(   484),  INT16_C( 17875), -INT16_C( 21729), -INT16_C( 24158), -INT16_C( 14886),
         INT16_C( 11049),  INT16_C( 27447),  INT16_C( 15813), -INT16_C( 17800),  INT16_C( 10877), -INT16_C( 19818),  INT16_C( 10500), -INT16_C(  3480),
        -INT16_C( 11329), -INT16_C( 13651), -INT16_C( 28261),  INT16_C( 28619), -INT16_C(  5162),  INT16_C( 30746), -INT16_C(  2932), -INT16_C( 19139) },
      {  INT16_C( 29983), -INT16_C(  7136), -INT16_C( 26446),  INT16_C( 12191),  INT16_C( 13763), -INT16_C( 14367),  INT16_C( 19039),  INT16_C(  7865),
         INT16_C( 26141), -INT16_C( 17943), -INT16_C( 19208), -INT16_C( 12760),  INT16_C( 17055),  INT16_C( 11079), -INT16_C( 31690),  INT16_C( 21984),
         INT16_C(   505), -INT16_C( 21447), -INT16_C( 10087),  INT16_C( 23771), -INT16_C( 17138),  INT16_C( 27939), -INT16_C(  9209),  INT16_C(  9355),
         INT16_C( 29763),  INT16_C( 15325),  INT16_C(  1321), -INT16_C( 14327),  INT16_C( 20551),  INT16_C( 32244), -INT16_C( 11051), -INT16_C( 12590) },
      {  INT16_C( 31549),  INT16_C( 28192),  INT16_C( 29156), -INT16_C( 28230),  INT16_C( 28831),  INT16_C( 22130), -INT16_C(  4949),  INT16_C( 10811),
        -INT16_C(  4874), -INT16_C(  6301), -INT16_C( 31064), -INT16_C( 15456), -INT16_C( 15347), -INT16_C( 21863), -INT16_C( 24532), -INT16_C( 32576),
         INT16_C(  9185), -INT16_C( 11457),  INT16_C(  8893), -INT16_C( 23384), -INT16_C( 25642),  INT16_C( 18562), -INT16_C( 28900),  INT16_C( 15992),
        -INT16_C(  2307), -INT16_C( 10663),  INT16_C( 22739), -INT16_C( 31197),  INT16_C( 18522),  INT16_C( 10952),  INT16_C( 26748), -INT16_C( 15862) } },
    { {  INT16_C(  3285),  INT16_C( 28538),  INT16_C( 22244), -INT16_C(  3381), -INT16_C(  4333),  INT16_C(  6751), -INT16_C(  5173),  INT16_C(  3646),
         INT16_C(  7263), -INT16_C( 30647),  INT16_C( 21281),  INT16_C( 26961),  INT16_C( 17827),  INT16_C( 30950), -INT16_C( 18151), -INT16_C(  4281),
        -INT16_C( 15931), -INT16_C( 22178),  INT16_C( 10519),  INT16_C( 10908), -INT16_C(  1256), -INT16_C(  7100), -INT16_C( 31770),  INT16_C( 18162),
         INT16_C( 15519), -INT16_C( 16178),  INT16_C(  8079),  INT16_C( 12841),  INT16_C(  4196),  INT16_C( 32427), -INT16_C(  3383), -INT16_C( 29075) },
      { -INT16_C( 13389), -INT16_C( 13513), -INT16_C( 11276),  INT16_C(  3573),  INT16_C( 15055), -INT16_C( 18959), -INT16_C(  7235),  INT16_C( 23803),
        -INT16_C( 13793), -INT16_C( 20964),  INT16_C( 18153),  INT16_C( 20193), -INT16_C( 29610),  INT16_C(  8140),  INT16_C( 14718),  INT16_C( 12717),
        -INT16_C(  7164), -INT16_C(  1796), -INT16_C(  3400), -INT16_C( 30971), -INT16_C(  2516), -INT16_C(  5828),  INT16_C( 14554), -INT16_C(  1723),
         INT16_C( 24834), -INT16_C(  5208), -INT16_C( 30297), -INT16_C(   711),  INT16_C(  1301), -INT16_C( 27876), -INT16_C( 14018),  INT16_C( 17092) },
      { -INT16_C(  8209), -INT16_C( 20170), -INT16_C( 17072), -INT16_C( 21689), -INT16_C( 24995), -INT16_C(   401),  INT16_C(  5599),  INT16_C( 16074),
         INT16_C( 25985), -INT16_C( 31236), -INT16_C( 20727),  INT16_C( 15921), -INT16_C( 30526),  INT16_C( 12616), -INT16_C( 21682),  INT16_C( 18939),
         INT16_C( 31508), -INT16_C( 14200),  INT16_C( 18056),  INT16_C(  6412),  INT16_C( 14368),  INT16_C( 25584), -INT16_C( 24100), -INT16_C( 32454),
        -INT16_C( 18370), -INT16_C( 24272),  INT16_C(  7497), -INT16_C( 20447),  INT16_C( 19508),  INT16_C(  2996), -INT16_C( 25170),  INT16_C(  9588) } },
    { { -INT16_C( 15954),  INT16_C( 26171),  INT16_C( 16563), -INT16_C(  8211),  INT16_C( 10551),  INT16_C(  4552),  INT16_C(  3425),  INT16_C( 25354),
        -INT16_C( 19858),  INT16_C(  5711), -INT16_C( 30661),  INT16_C( 20499),  INT16_C( 12430), -INT16_C( 13085), -INT16_C( 22279), -INT16_C( 22769),
         INT16_C( 19049),  INT16_C(  7181), -INT16_C(  1398), -INT16_C( 15877), -INT16_C( 15580), -INT16_C( 31278), -INT16_C(  8752),  INT16_C( 16105),
         INT16_C( 14479), -INT16_C( 13484),  INT16_C( 26816),  INT16_C( 19995), -INT16_C(   104), -INT16_C( 28389),  INT16_C( 10919),  INT16_C(  4153) },
      {  INT16_C( 18036), -INT16_C(   468),  INT16_C( 10049),  INT16_C( 26048), -INT16_C( 27926), -INT16_C( 17686), -INT16_C( 11409), -INT16_C(     8),
         INT16_C( 19723), -INT16_C( 13110), -INT16_C(  6731),  INT16_C( 19738),  INT16_C( 13796), -INT16_C( 29730),  INT16_C(  5983), -INT16_C( 11365),
        -INT16_C( 14498), -INT16_C( 24622), -INT16_C( 27922), -INT16_C( 10236), -INT16_C(  4572), -INT16_C( 27502), -INT16_C( 29758), -INT16_C( 12909),
         INT16_C( 24024), -INT16_C( 29287), -INT16_C( 19390),  INT16_C( 10202), -INT16_C( 18199),  INT16_C( 18866),  INT16_C( 20176),  INT16_C( 11804) },
      {  INT16_C( 22232),  INT16_C(  7204), -INT16_C( 19853),  INT16_C( 29376),  INT16_C(  2630), -INT16_C( 28464), -INT16_C( 16369), -INT16_C(  6224),
        -INT16_C( 16198), -INT16_C( 29098),  INT16_C(  6327), -INT16_C( 10002), -INT16_C( 23432), -INT16_C(  4646),  INT16_C(  4967), -INT16_C( 31979),
        -INT16_C(  3698),  INT16_C(  5546), -INT16_C( 24500), -INT16_C( 12308), -INT16_C(  5872), -INT16_C( 17980),  INT16_C(  1952), -INT16_C( 19253),
        -INT16_C( 21592), -INT16_C( 14028),  INT16_C(   384), -INT16_C( 24578), -INT16_C(  7848), -INT16_C( 26682), -INT16_C( 30288),  INT16_C(  1084) } },
    { { -INT16_C(  4587),  INT16_C(  1229), -INT16_C( 11904), -INT16_C( 23076),  INT16_C( 28607), -INT16_C( 32455), -INT16_C( 13062), -INT16_C( 11697),
        -INT16_C(  6103),  INT16_C( 27487),  INT16_C( 14748), -INT16_C( 31086),  INT16_C( 17905), -INT16_C( 15921), -INT16_C(  5229), -INT16_C( 22289),
        -INT16_C( 17190),  INT16_C( 23212), -INT16_C( 30323),  INT16_C( 19967),  INT16_C( 14584), -INT16_C(  3378),  INT16_C(  7428),  INT16_C( 11716),
         INT16_C(  8966), -INT16_C( 23911),  INT16_C( 11100),  INT16_C( 19752), -INT16_C(  2192),  INT16_C(   783), -INT16_C(   285), -INT16_C( 16980) },
      {  INT16_C( 22715),  INT16_C( 18455),  INT16_C(  6113), -INT16_C(  9835),  INT16_C( 25679),  INT16_C( 21707), -INT16_C( 28799), -INT16_C( 30847),
         INT16_C(  6834),  INT16_C(  3626),  INT16_C( 21062), -INT16_C( 18852),  INT16_C( 27466),  INT16_C( 11706),  INT16_C( 26217),  INT16_C(  9450),
         INT16_C(   446), -INT16_C( 24467),  INT16_C(   536),  INT16_C( 26745),  INT16_C( 17766), -INT16_C(  5956),  INT16_C( 15828), -INT16_C( 30865),
        -INT16_C( 26280), -INT16_C( 24939), -INT16_C(  3604),  INT16_C( 13908),  INT16_C(  3676), -INT16_C( 14749),  INT16_C( 19828),  INT16_C( 13290) },
      {  INT16_C(  8535),  INT16_C(  5739), -INT16_C( 24192),  INT16_C(  1292),  INT16_C(  6129),  INT16_C( 11315), -INT16_C(  4102), -INT16_C( 23857),
        -INT16_C( 27006), -INT16_C( 12394), -INT16_C( 18264),  INT16_C( 10360), -INT16_C(  3414),  INT16_C( 13158),  INT16_C( 12619),  INT16_C(  1654),
         INT16_C(   972),  INT16_C(  6972), -INT16_C(   200),  INT16_C( 30087), -INT16_C( 30000), -INT16_C(   184), -INT16_C(  1200),  INT16_C( 13308),
        -INT16_C( 24560),  INT16_C(  4365), -INT16_C( 27440), -INT16_C( 16096),  INT16_C(  3136), -INT16_C( 14131), -INT16_C( 14884), -INT16_C( 23752) } },
    { {  INT16_C( 22350),  INT16_C( 26579),  INT16_C( 19546), -INT16_C( 16177), -INT16_C( 29807),  INT16_C( 26280),  INT16_C(  6344),  INT16_C(  8429),
        -INT16_C( 32079), -INT16_C( 25154),  INT16_C(  4980), -INT16_C( 12077),  INT16_C( 13857), -INT16_C( 26986), -INT16_C( 32381), -INT16_C( 11575),
        -INT16_C( 25384),  INT16_C( 12857),  INT16_C(  2280),  INT16_C( 31475), -INT16_C( 25709),  INT16_C( 23520), -INT16_C( 12877),  INT16_C( 25980),
         INT16_C( 14927), -INT16_C( 15614), -INT16_C( 10675),  INT16_C( 28564),  INT16_C( 10764), -INT16_C( 28667), -INT16_C( 12629), -INT16_C( 31646) },
      { -INT16_C( 25750),  INT16_C( 21174), -INT16_C( 22109),  INT16_C( 14028), -INT16_C( 21435), -INT16_C(  1903),  INT16_C(  3449), -INT16_C( 13987),
         INT16_C( 24648), -INT16_C( 27252),  INT16_C(  8246),  INT16_C( 16900),  INT16_C(  2379), -INT16_C(  2350),  INT16_C( 13527),  INT16_C( 16762),
         INT16_C( 12751),  INT16_C( 29332),  INT16_C( 24794),  INT16_C(  8104),  INT16_C( 14861), -INT16_C( 31208),  INT16_C( 30023), -INT16_C( 28849),
        -INT16_C(  9003),  INT16_C(  2853),  INT16_C( 10748),  INT16_C( 18254),  INT16_C(  8243),  INT16_C(  2622), -INT16_C( 18347),  INT16_C(  9292) },
      {  INT16_C( 24652),  INT16_C( 26114),  INT16_C(  1870),  INT16_C( 20212),  INT16_C(  2581), -INT16_C(  6872), -INT16_C(  8568),  INT16_C(  2841),
         INT16_C(  8648), -INT16_C(  9752), -INT16_C( 25992), -INT16_C( 22196),  INT16_C(  1195), -INT16_C( 21748),  INT16_C( 24837),  INT16_C( 31946),
         INT16_C( 10920),  INT16_C( 27380), -INT16_C( 27248),  INT16_C(  7288),  INT16_C( 13431), -INT16_C(  8960), -INT16_C(  9307), -INT16_C( 27324),
         INT16_C( 26555),  INT16_C( 17738),  INT16_C( 18636),  INT16_C(  2840), -INT16_C(  8092),  INT16_C(  4918), -INT16_C( 31033),  INT16_C(  5400) } },
    { { -INT16_C(  7959), -INT16_C( 15209),  INT16_C( 16192),  INT16_C( 19939), -INT16_C(  1159), -INT16_C( 15916),  INT16_C(  9073),  INT16_C( 18000),
         INT16_C( 30207), -INT16_C(   942), -INT16_C( 24417), -INT16_C( 11709), -INT16_C( 32320),  INT16_C(  5596),  INT16_C( 10298),  INT16_C(  9018),
        -INT16_C( 12024),  INT16_C( 18919), -INT16_C( 13552), -INT16_C( 30058),  INT16_C( 27334),  INT16_C( 14155), -INT16_C( 25714), -INT16_C( 29314),
        -INT16_C( 12271), -INT16_C( 20343), -INT16_C( 12944),  INT16_C( 12418),  INT16_C( 24142), -INT16_C( 30650), -INT16_C( 32633), -INT16_C( 28756) },
      { -INT16_C( 27823),  INT16_C( 25048),  INT16_C( 28510),  INT16_C(  9707),  INT16_C( 14041),  INT16_C( 26460), -INT16_C(  9518), -INT16_C(  7179),
         INT16_C( 32426),  INT16_C(  6803),  INT16_C(  5451), -INT16_C( 26037), -INT16_C( 28301), -INT16_C(  1502), -INT16_C( 12783),  INT16_C( 25226),
         INT16_C( 25186), -INT16_C( 16189), -INT16_C( 20527), -INT16_C( 21531),  INT16_C( 17125), -INT16_C( 18670),  INT16_C(  1820), -INT16_C( 14438),
         INT16_C( 11654), -INT16_C( 11807),  INT16_C( 11330), -INT16_C( 18837), -INT16_C( 28995), -INT16_C( 12624),  INT16_C( 14940), -INT16_C( 16848) },
      { -INT16_C(  2887),  INT16_C(  5736), -INT16_C(  1664),  INT16_C( 20065), -INT16_C( 20591), -INT16_C(  3024),  INT16_C( 19634),  INT16_C( 14992),
        -INT16_C(  8874),  INT16_C( 14102),  INT16_C(  6549), -INT16_C(  6239),  INT16_C(  2368), -INT16_C( 16584),  INT16_C( 22490),  INT16_C( 12612),
         INT16_C(  5392), -INT16_C( 29963), -INT16_C( 18416),  INT16_C( 10798), -INT16_C( 28898), -INT16_C( 32698), -INT16_C(  6776),  INT16_C(  4044),
        -INT16_C(  6682),  INT16_C(   361),  INT16_C( 14048), -INT16_C( 19882), -INT16_C(  7274),  INT16_C(  1056), -INT16_C( 14716), -INT16_C( 26560) } }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
    simde__m512i a = simde_mm512_loadu_epi16(test_vec[i].a);
    simde__m512i b = simde_mm512_loadu_epi16(test_vec[i].b);
    simde__m512i r = simde_mm512_mullo_epi16(a, b);
    simde_test_x86_assert_equal_i16x32(r, simde_mm512_loadu_epi16(test_vec[i].r));
  }

  return 0;
}

static int
test_simde_mm512_packs_epi16 (SIMDE_MUNIT_TEST_ARGS) {
  static const struct {
    const int16_t a[32];
    const int16_t b[32];
    const int8_t r[64];
  } test_vec[] = {
    { {  INT16_C(   148),  INT16_C(    89),  INT16_C(    44),  INT16_C(   120),  INT16_C(   172),  INT16_C(    95),  INT16_C(   152),  INT16_C(    63),
         INT16_C(   158),  INT16_C(    87),  INT16_C(   102),  INT16_C(   236),  INT16_C(   153),  INT16_C(   222),  INT16_C(   143),  INT16_C(   196),
         INT16_C(   171),  INT16_C(   232),  INT16_C(    34),  INT16_C(   217),  INT16_C(   125),  INT16_C(   165),  INT16_C(   230),  INT16_C(     5),
         INT16_C(    46),  INT16_C(   252),  INT16_C(   228),  INT16_C(    53),  INT16_C(    41),  INT16_C(   126),  INT16_C(    57),  INT16_C(   220) },
      {  INT16_C( 25061), -INT16_C( 16956),  INT16_C(  9603),  INT16_C( 21142), -INT16_C( 12382), -INT16_C( 18441), -INT16_C(  9035),  INT16_C( 14780),
         INT16_C(  6155), -INT16_C( 24779),  INT16_C(  7677),  INT16_C( 31444), -INT16_C(  6074), -INT16_C(     7),  INT16_C( 15393),  INT16_C(  1755),
        -INT16_C( 24419),  INT16_C(  8387),  INT16_C( 23237),  INT16_C( 26482),  INT16_C( 27177), -INT16_C(  8674), -INT16_C(  9658),  INT16_C( 20759),
         INT16_C( 19954), -INT16_C(  4111), -INT16_C( 14998), -INT16_C( 20118),  INT16_C( 25517), -INT16_C( 12368), -INT16_C( 29793),  INT16_C( 15573) },
      {      INT8_MAX,  INT8_C(  89),  INT8_C(  44),  INT8_C( 120),      INT8_MAX,  INT8_C(  95),      INT8_MAX,  INT8_C(  63),
             INT8_MAX,      INT8_MIN,      INT8_MAX,      INT8_MAX,      INT8_MIN,      INT8_MIN,      INT8_MIN,      INT8_MAX,
             INT8_MAX,  INT8_C(  87),  INT8_C( 102),      INT8_MAX,      INT8_MAX,      INT8_MAX,      INT8_MAX,      INT8_MAX,
             INT8_MAX,      INT8_MIN,      INT8_MAX,      INT8_MAX,      INT8_MIN, -INT8_C(   7),      INT8_MAX,      INT8_MAX,
             INT8_MAX,      INT8_MAX,  INT8_C(  34),      INT8_MAX,  INT8_C( 125),      INT8_MAX,      INT8_MAX,  INT8_C(   5),
             INT8_MIN,      INT8_MAX,      INT8_MAX,      INT8_MAX,      INT8_MAX,      INT8_MIN,      INT8_MIN,      INT8_MAX,
         INT8_C(  46),      INT8_MAX,      INT8_MAX,  INT8_C(  53),  INT8_C(  41),  INT8_C( 126),  INT8_C(  57),      INT8_MAX,
             INT8_MAX,      INT8_MIN,      INT8_MIN,      INT8_MIN,      INT8_MAX,      INT8_MIN,      INT8_MIN,      INT8_MAX } },
    { {  INT16_C(   153),  INT16_C(   240),  INT16_C(   207),  INT16_C(    28),  INT16_C(   117),  INT16_C(   127),  INT16_C(    17),  INT16_C(    66),
         INT16_C(   194),  INT16_C(   201),  INT16_C(   155),  INT16_C(    53),  INT16_C(    42),  INT16_C(   157),  INT16_C(   217),  INT16_C(   225),
         INT16_C(    54),  INT16_C(   101),  INT16_C(    41),  INT16_C(    62),  INT16_C(   123),  INT16_C(   238),  INT16_C(   142),  INT16_C(   235),
         INT16_C(    97),  INT16_C(   216),  INT16_C(    46),  INT16_C(   251),  INT16_C(    17),  INT16_C(    14),  INT16_C(   114),  INT16_C(    93) },
      { -INT16_C( 16216), -INT16_C( 21054),  INT16_C( 17641), -INT16_C( 30485), -INT16_C( 22081),  INT16_C( 19574), -INT16_C( 22985), -INT16_C( 30664),
        -INT16_C(  5113),  INT16_C(  1120),  INT16_C( 27931),  INT16_C( 29440), -INT16_C( 26242),  INT16_C( 26753),  INT16_C( 28683), -INT16_C( 19259),
        -INT16_C( 30671),  INT16_C(  6753),  INT16_C( 19916), -INT16_C( 29790),  INT16_C(  6390),  INT16_C( 11736),  INT16_C(  4286), -INT16_C( 14667),
         INT16_C(  5628),  INT16_C(  6090), -INT16_C( 13694),  INT16_C(   139),  INT16_C(  3171),  INT16_C( 28521),  INT16_C( 11901), -INT16_C( 20957) },
      {      INT8_MAX,      INT8_MAX,      INT8_MAX,  INT8_C(  28),  INT8_C( 117),      INT8_MAX,  INT8_C(  17),  INT8_C(  66),
             INT8_MIN,      INT8_MIN,      INT8_MAX,      INT8_MIN,      INT8_MIN,      INT8_MAX,      INT8_MIN,      INT8_MIN,
             INT8_MAX,      INT8_MAX,      INT8_MAX,  INT8_C(  53),  INT8_C(  42),      INT8_MAX,      INT8_MAX,      INT8_MAX,
             INT8_MIN,      INT8_MAX,      INT8_MAX,      INT8_MAX,      INT8_MIN,      INT8_MAX,      INT8_MAX,      INT8_MIN,
         INT8_C(  54),  INT8_C( 101),  INT8_C(  41),  INT8_C(  62),  INT8_C( 123),      INT8_MAX,      INT8_MAX,      INT8_MAX,
             INT8_MIN,      INT8_MAX,      INT8_MAX,      INT8_MIN,      INT8_MAX,      INT8_MAX,      INT8_MAX,      INT8_MIN,
         INT8_C(  97),      INT8_MAX,  INT8_C(  46),      INT8_MAX,  INT8_C(  17),  INT8_C(  14),  INT8_C( 114),  INT8_C(  93),
             INT8_MAX,      INT8_MAX,      INT8_MIN,      INT8_MAX,      INT8_MAX,      INT8_MAX,      INT8_MAX,      INT8_MIN } },
    { {  INT16_C(   132),  INT16_C(   130),  INT16_C(   107),  INT16_C(   199),  INT16_C(   230),  INT16_C(    66),  INT16_C(   170),  INT16_C(   242),
         INT16_C(   210),  INT16_C(    66),  INT16_C(   149),  INT16_C(     0),  INT16_C(   172),  INT16_C(    30),  INT16_C(   146),  INT16_C(   145),
         INT16_C(   149),  INT16_C(   232),  INT16_C(    33),  INT16_C(   131),  INT16_C(   165),  INT16_C(   253),  INT16_C(   205),  INT16_C(    15),
         INT16_C(   250),  INT16_C(    61),  INT16_C(   149),  INT16_C(    48),  INT16_C(   173),  INT16_C(    27),  INT16_C(    27),  INT16_C(    86) },
      { -INT16_C( 16208), -INT16_C( 20417), -INT16_C(  4127), -INT16_C(  5836), -INT16_C(  1644), -INT16_C(  7194), -INT16_C( 10553),  INT16_C( 26611),
         INT16_C( 17872),  INT16_C( 24484), -INT16_C(  7718),  INT16_C(  7056), -INT16_C(  8306), -INT16_C( 12746), -INT16_C(  7174), -INT16_C( 21724),
         INT16_C( 25507), -INT16_C( 31653), -INT16_C( 28846), -INT16_C(  6547),  INT16_C( 21641),  INT16_C( 20682), -INT16_C( 17110), -INT16_C(  1097),
         INT16_C( 23298), -INT16_C(  9126), -INT16_C(  5572), -INT16_C( 13321),  INT16_C( 11721), -INT16_C( 15207), -INT16_C( 17136), -INT16_C( 19601) },
      {      INT8_MAX,      INT8_MAX,  INT8_C( 107),      INT8_MAX,      INT8_MAX,  INT8_C(  66),      INT8_MAX,      INT8_MAX,
             INT8_MIN,      INT8_MIN,      INT8_MIN,      INT8_MIN,      INT8_MIN,      INT8_MIN,      INT8_MIN,      INT8_MAX,
             INT8_MAX,  INT8_C(  66),      INT8_MAX,  INT8_C(   0),      INT8_MAX,  INT8_C(  30),      INT8_MAX,      INT8_MAX,
             INT8_MAX,      INT8_MAX,      INT8_MIN,      INT8_MAX,      INT8_MIN,      INT8_MIN,      INT8_MIN,      INT8_MIN,
             INT8_MAX,      INT8_MAX,  INT8_C(  33),      INT8_MAX,      INT8_MAX,      INT8_MAX,      INT8_MAX,  INT8_C(  15),
             INT8_MAX,      INT8_MIN,      INT8_MIN,      INT8_MIN,      INT8_MAX,      INT8_MAX,      INT8_MIN,      INT8_MIN,
             INT8_MAX,  INT8_C(  61),      INT8_MAX,  INT8_C(  48),      INT8_MAX,  INT8_C(  27),  INT8_C(  27),  INT8_C(  86),
             INT8_MAX,      INT8_MIN,      INT8_MIN,      INT8_MIN,      INT8_MAX,      INT8_MIN,      INT8_MIN,      INT8_MIN } },
    { {  INT16_C(   202),  INT16_C(   115),  INT16_C(   165),  INT16_C(   227),  INT16_C(    36),  INT16_C(    36),  INT16_C(   234),  INT16_C(   227),
         INT16_C(   121),  INT16_C(   129),  INT16_C(   182),  INT16_C(    45),  INT16_C(   229),  INT16_C(   244),  INT16_C(    96),  INT16_C(   196),
         INT16_C(   223),  INT16_C(   133),  INT16_C(   145),  INT16_C(   126),  INT16_C(   155),  INT16_C(   150),  INT16_C(   193),  INT16_C(   202),
         INT16_C(    56),  INT16_C(   159),  INT16_C(   152),  INT16_C(   210),  INT16_C(   190),  INT16_C(    32),  INT16_C(   109),  INT16_C(    73) },
      {  INT16_C(  7245), -INT16_C( 11570),  INT16_C( 13997),  INT16_C( 25424), -INT16_C(  3119),  INT16_C( 22265),  INT16_C( 29620), -INT16_C(  4320),
         INT16_C( 27819), -INT16_C( 25970),  INT16_C( 23300), -INT16_C( 32404),  INT16_C( 12825),  INT16_C( 14242), -INT16_C( 31073), -INT16_C(  4991),
         INT16_C( 20386),  INT16_C( 20670),  INT16_C(  3974),  INT16_C( 22451), -INT16_C( 21502), -INT16_C( 18770), -INT16_C( 12769), -INT16_C( 13402),
         INT16_C( 13370),  INT16_C( 15973), -INT16_C( 11889), -INT16_C( 22336),  INT16_C( 25091), -INT16_C( 23840),  INT16_C( 25064), -INT16_C( 29809) },
      {      INT8_MAX,  INT8_C( 115),      INT8_MAX,      INT8_MAX,  INT8_C(  36),  INT8_C(  36),      INT8_MAX,      INT8_MAX,
             INT8_MAX,      INT8_MIN,      INT8_MAX,      INT8_MAX,      INT8_MIN,      INT8_MAX,      INT8_MAX,      INT8_MIN,
         INT8_C( 121),      INT8_MAX,      INT8_MAX,  INT8_C(  45),      INT8_MAX,      INT8_MAX,  INT8_C(  96),      INT8_MAX,
             INT8_MAX,      INT8_MIN,      INT8_MAX,      INT8_MIN,      INT8_MAX,      INT8_MAX,      INT8_MIN,      INT8_MIN,
             INT8_MAX,      INT8_MAX,      INT8_MAX,  INT8_C( 126),      INT8_MAX,      INT8_MAX,      INT8_MAX,      INT8_MAX,
             INT8_MAX,      INT8_MAX,      INT8_MAX,      INT8_MAX,      INT8_MIN,      INT8_MIN,      INT8_MIN,      INT8_MIN,
         INT8_C(  56),      INT8_MAX,      INT8_MAX,      INT8_MAX,      INT8_MAX,  INT8_C(  32),  INT8_C( 109),  INT8_C(  73),
             INT8_MAX,      INT8_MAX,      INT8_MIN,      INT8_MIN,      INT8_MAX,      INT8_MIN,      INT8_MAX,      INT8_MIN } },
    { {  INT16_C(    77),  INT16_C(    54),  INT16_C(   142),  INT16_C(    94),  INT16_C(    60),  INT16_C(    90),  INT16_C(   187),  INT16_C(    69),
         INT16_C(   138),  INT16_C(   127),  INT16_C(    67),  INT16_C(    94),  INT16_C(     7),  INT16_C(   142),  INT16_C(   143),  INT16_C(    25),
         INT16_C(   244),  INT16_C(    57),  INT16_C(   221),  INT16_C(   188),  INT16_C(   173),  INT16_C(    36),  INT16_C(    59),  INT16_C(    87),
         INT16_C(   236),  INT16_C(    32),  INT16_C(   254),  INT16_C(   213),  INT16_C(   127),  INT16_C(   110),  INT16_C(   124),  INT16_C(   235) },
      { -INT16_C( 10640), -INT16_C(  3547), -INT16_C( 16972), -INT16_C( 12881), -INT16_C( 14998), -INT16_C( 11535),  INT16_C( 23041), -INT16_C( 14807),
         INT16_C(    71),  INT16_C( 30695),  INT16_C( 26110),  INT16_C(   844), -INT16_C( 20252), -INT16_C(  3215), -INT16_C(  2004), -INT16_C( 25122),
         INT16_C(   975), -INT16_C( 31857),  INT16_C( 16064),  INT16_C( 10832),  INT16_C( 16900),  INT16_C(  1532),  INT16_C(  9884), -INT16_C(  7221),
        -INT16_C( 19930),  INT16_C(  9306), -INT16_C( 22760), -INT16_C(   985), -INT16_C( 26281), -INT16_C( 31761), -INT16_C( 12655),  INT16_C( 24608) },
      {  INT8_C(  77),  INT8_C(  54),      INT8_MAX,  INT8_C(  94),  INT8_C(  60),  INT8_C(  90),      INT8_MAX,  INT8_C(  69),
             INT8_MIN,      INT8_MIN,      INT8_MIN,      INT8_MIN,      INT8_MIN,      INT8_MIN,      INT8_MAX,      INT8_MIN,
             INT8_MAX,      INT8_MAX,  INT8_C(  67),  INT8_C(  94),  INT8_C(   7),      INT8_MAX,      INT8_MAX,  INT8_C(  25),
         INT8_C(  71),      INT8_MAX,      INT8_MAX,      INT8_MAX,      INT8_MIN,      INT8_MIN,      INT8_MIN,      INT8_MIN,
             INT8_MAX,  INT8_C(  57),      INT8_MAX,      INT8_MAX,      INT8_MAX,  INT8_C(  36),  INT8_C(  59),  INT8_C(  87),
             INT8_MAX,      INT8_MIN,      INT8_MAX,      INT8_MAX,      INT8_MAX,      INT8_MAX,      INT8_MAX,      INT8_MIN,
             INT8_MAX,  INT8_C(  32),      INT8_MAX,      INT8_MAX,      INT8_MAX,  INT8_C( 110),  INT8_C( 124),      INT8_MAX,
             INT8_MIN,      INT8_MAX,      INT8_MIN,      INT8_MIN,      INT8_MIN,      INT8_MIN,      INT8_MIN,      INT8_MAX } },
    { {  INT16_C(   176),  INT16_C(   146),  INT16_C(    52),  INT16_C(   242),  INT16_C(   185),  INT16_C(    18),  INT16_C(   195),  INT16_C(     5),
         INT16_C(    80),  INT16_C(   141),  INT16_C(    80),  INT16_C(    78),  INT16_C(   121),  INT16_C(   123),  INT16_C(   242),  INT16_C(    25),
         INT16_C(   191),  INT16_C(   145),  INT16_C(   103),  INT16_C(   105),  INT16_C(   123),  INT16_C(   255),  INT16_C(   113),  INT16_C(   179),
         INT16_C(    45),  INT16_C(   185),  INT16_C(   203),  INT16_C(   103),  INT16_C(   218),  INT16_C(   140),  INT16_C(   190),  INT16_C(   111) },
      {  INT16_C( 20605),  INT16_C( 28672), -INT16_C( 31817), -INT16_C( 10023),  INT16_C( 21758),  INT16_C( 15575), -INT16_C(  9018), -INT16_C( 30480),
         INT16_C( 12553), -INT16_C( 30911),  INT16_C( 18940),  INT16_C( 16623), -INT16_C( 11997), -INT16_C(  3892),  INT16_C( 29071),  INT16_C(  3167),
         INT16_C( 24513),  INT16_C( 31100),  INT16_C( 21986), -INT16_C(  7855),  INT16_C( 10410),  INT16_C( 28701),  INT16_C(  3332),  INT16_C(  3832),
         INT16_C( 14654),  INT16_C( 14997), -INT16_C( 31613), -INT16_C( 22917),  INT16_C( 18262), -INT16_C(  6762), -INT16_C(  2631),  INT16_C( 31474) },
      {      INT8_MAX,      INT8_MAX,  INT8_C(  52),      INT8_MAX,      INT8_MAX,  INT8_C(  18),      INT8_MAX,  INT8_C(   5),
             INT8_MAX,      INT8_MAX,      INT8_MIN,      INT8_MIN,      INT8_MAX,      INT8_MAX,      INT8_MIN,      INT8_MIN,
         INT8_C(  80),      INT8_MAX,  INT8_C(  80),  INT8_C(  78),  INT8_C( 121),  INT8_C( 123),      INT8_MAX,  INT8_C(  25),
             INT8_MAX,      INT8_MIN,      INT8_MAX,      INT8_MAX,      INT8_MIN,      INT8_MIN,      INT8_MAX,      INT8_MAX,
             INT8_MAX,      INT8_MAX,  INT8_C( 103),  INT8_C( 105),  INT8_C( 123),      INT8_MAX,  INT8_C( 113),      INT8_MAX,
             INT8_MAX,      INT8_MAX,      INT8_MAX,      INT8_MIN,      INT8_MAX,      INT8_MAX,      INT8_MAX,      INT8_MAX,
         INT8_C(  45),      INT8_MAX,      INT8_MAX,  INT8_C( 103),      INT8_MAX,      INT8_MAX,      INT8_MAX,  INT8_C( 111),
             INT8_MAX,      INT8_MAX,      INT8_MIN,      INT8_MIN,      INT8_MAX,      INT8_MIN,      INT8_MIN,      INT8_MAX } },
    { {  INT16_C(   110),  INT16_C(    55),  INT16_C(    68),  INT16_C(   110),  INT16_C(    53),  INT16_C(   113),  INT16_C(   214),  INT16_C(   129),
         INT16_C(    21),  INT16_C(   146),  INT16_C(    55),  INT16_C(   239),  INT16_C(   207),  INT16_C(    55),  INT16_C(   199),  INT16_C(    25),
         INT16_C(   165),  INT16_C(   249),  INT16_C(   104),  INT16_C(    87),  INT16_C(    69),  INT16_C(   225),  INT16_C(    72),  INT16_C(    43),
         INT16_C(    30),  INT16_C(   246),  INT16_C(   246),  INT16_C(   212),  INT16_C(   187),  INT16_C(   139),  INT16_C(   189),  INT16_C(   183) },
      { -INT16_C(  2717),  INT16_C( 19889),  INT16_C(  6237), -INT16_C(  1116),  INT16_C( 27742),  INT16_C( 31196),  INT16_C( 16308),  INT16_C(  4516),
         INT16_C( 25181), -INT16_C( 19704), -INT16_C(  4520),  INT16_C(  7815), -INT16_C( 27991),  INT16_C( 11177),  INT16_C( 20048), -INT16_C( 19486),
        -INT16_C( 27837), -INT16_C( 24576), -INT16_C( 23380),  INT16_C(  2716),  INT16_C( 30736), -INT16_C( 14973),  INT16_C( 10423),  INT16_C(  5590),
        -INT16_C(  8566), -INT16_C(  7480),  INT16_C( 20428),  INT16_C( 29953), -INT16_C( 21791),  INT16_C( 12704), -INT16_C( 31752),  INT16_C( 15332) },
      {  INT8_C( 110),  INT8_C(  55),  INT8_C(  68),  INT8_C( 110),  INT8_C(  53),  INT8_C( 113),      INT8_MAX,      INT8_MAX,
             INT8_MIN,      INT8_MAX,      INT8_MAX,      INT8_MIN,      INT8_MAX,      INT8_MAX,      INT8_MAX,      INT8_MAX,
         INT8_C(  21),      INT8_MAX,  INT8_C(  55),      INT8_MAX,      INT8_MAX,  INT8_C(  55),      INT8_MAX,  INT8_C(  25),
             INT8_MAX,      INT8_MIN,      INT8_MIN,      INT8_MAX,      INT8_MIN,      INT8_MAX,      INT8_MAX,      INT8_MIN,
             INT8_MAX,      INT8_MAX,  INT8_C( 104),  INT8_C(  87),  INT8_C(  69),      INT8_MAX,  INT8_C(  72),  INT8_C(  43),
             INT8_MIN,      INT8_MIN,      INT8_MIN,      INT8_MAX,      INT8_MAX,      INT8_MIN,      INT8_MAX,      INT8_MAX,
         INT8_C(  30),      INT8_MAX,      INT8_MAX,      INT8_MAX,      INT8_MAX,      INT8_MAX,      INT8_MAX,      INT8_MAX,
             INT8_MIN,      INT8_MIN,      INT8_MAX,      INT8_MAX,      INT8_MIN,      INT8_MAX,      INT8_MIN,      INT8_MAX } },
    { {  INT16_C(   228),  INT16_C(   194),  INT16_C(   120),  INT16_C(   153),  INT16_C(    80),  INT16_C(   168),  INT16_C(    52),  INT16_C(     2),
         INT16_C(   133),  INT16_C(   223),  INT16_C(   229),  INT16_C(   181),  INT16_C(   245),  INT16_C(   136),  INT16_C(   203),  INT16_C(   143),
         INT16_C(   160),  INT16_C(    56),  INT16_C(    30),  INT16_C(     8),  INT16_C(    47),  INT16_C(   230),  INT16_C(   109),  INT16_C(   119),
         INT16_C(   204),  INT16_C(   198),  INT16_C(   171),  INT16_C(    66),  INT16_C(    99),  INT16_C(    25),  INT16_C(   142),  INT16_C(   222) },
      { -INT16_C(  1490),  INT16_C( 17943), -INT16_C(  6120), -INT16_C( 31153), -INT16_C(   232),  INT16_C( 31852),  INT16_C( 21613),  INT16_C( 24563),
         INT16_C( 18720), -INT16_C( 11738), -INT16_C( 23819), -INT16_C( 27116), -INT16_C(  8443),  INT16_C( 13231),  INT16_C( 22637), -INT16_C( 25582),
         INT16_C( 10578),  INT16_C( 27362),  INT16_C( 12561),  INT16_C( 10736),  INT16_C( 23601), -INT16_C( 24923), -INT16_C( 26448), -INT16_C( 12035),
         INT16_C(  9186), -INT16_C( 10333), -INT16_C( 18491), -INT16_C( 13715),  INT16_C(  7318),  INT16_C(  1278),  INT16_C(  4212), -INT16_C( 14688) },
      {      INT8_MAX,      INT8_MAX,  INT8_C( 120),      INT8_MAX,  INT8_C(  80),      INT8_MAX,  INT8_C(  52),  INT8_C(   2),
             INT8_MIN,      INT8_MAX,      INT8_MIN,      INT8_MIN,      INT8_MIN,      INT8_MAX,      INT8_MAX,      INT8_MAX,
             INT8_MAX,      INT8_MAX,      INT8_MAX,      INT8_MAX,      INT8_MAX,      INT8_MAX,      INT8_MAX,      INT8_MAX,
             INT8_MAX,      INT8_MIN,      INT8_MIN,      INT8_MIN,      INT8_MIN,      INT8_MAX,      INT8_MAX,      INT8_MIN,
             INT8_MAX,  INT8_C(  56),  INT8_C(  30),  INT8_C(   8),  INT8_C(  47),      INT8_MAX,  INT8_C( 109),  INT8_C( 119),
             INT8_MAX,      INT8_MAX,      INT8_MAX,      INT8_MAX,      INT8_MAX,      INT8_MIN,      INT8_MIN,      INT8_MIN,
             INT8_MAX,      INT8_MAX,      INT8_MAX,  INT8_C(  66),  INT8_C(  99),  INT8_C(  25),      INT8_MAX,      INT8_MAX,
             INT8_MAX,      INT8_MIN,      INT8_MIN,      INT8_MIN,      INT8_MAX,      INT8_MAX,      INT8_MAX,      INT8_MIN } }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
    simde__m512i a = simde_mm512_loadu_epi16(test_vec[i].a);
    simde__m512i b = simde_mm512_loadu_epi16(test_vec[i].b);
    simde__m512i r = simde_mm512_packs_epi16(a, b);
    simde_test_x86_assert_equal_i8x64(r, simde_mm512_loadu_epi16(test_vec[i].r));
  }

  return 0;
}

static int
test_simde_mm512_packs_epi32 (SIMDE_MUNIT_TEST_ARGS) {
  static const struct {
    const int32_t a[16];
    const int32_t b[16];
    const int16_t r[32];
  } test_vec[] = {
    { {  INT32_C(  1800617241), -INT32_C(   686819306),  INT32_C(   140214962),  INT32_C(  1970280150), -INT32_C(  1837652367), -INT32_C(   601751898), -INT32_C(   689735000), -INT32_C(   924571217),
         INT32_C(  2083731302), -INT32_C(   497859792), -INT32_C(  1679118651),  INT32_C(   907041733), -INT32_C(  1463253247),  INT32_C(   780462469),  INT32_C(   319055716), -INT32_C(   153359984) },
      {  INT32_C(       20594),  INT32_C(        5683),  INT32_C(       14769),  INT32_C(       31344),  INT32_C(       53026),  INT32_C(       34557),  INT32_C(       40345),  INT32_C(        2963),
         INT32_C(       54363),  INT32_C(       16618),  INT32_C(        9337),  INT32_C(       42910),  INT32_C(       17526),  INT32_C(       29642),  INT32_C(       24336),  INT32_C(       22890) },
      {       INT16_MAX,       INT16_MIN,       INT16_MAX,       INT16_MAX,  INT16_C( 20594),  INT16_C(  5683),  INT16_C( 14769),  INT16_C( 31344),
              INT16_MIN,       INT16_MIN,       INT16_MIN,       INT16_MIN,       INT16_MAX,       INT16_MAX,       INT16_MAX,  INT16_C(  2963),
              INT16_MAX,       INT16_MIN,       INT16_MIN,       INT16_MAX,       INT16_MAX,  INT16_C( 16618),  INT16_C(  9337),       INT16_MAX,
              INT16_MIN,       INT16_MAX,       INT16_MAX,       INT16_MIN,  INT16_C( 17526),  INT16_C( 29642),  INT16_C( 24336),  INT16_C( 22890) } },
    { {  INT32_C(  1949157033),  INT32_C(    11802708),  INT32_C(   304426676),  INT32_C(   968475415), -INT32_C(   360894332),  INT32_C(   408831907), -INT32_C(  2122813782), -INT32_C(  1143217646),
        -INT32_C(    47249240), -INT32_C(   721558496),  INT32_C(   702947858),  INT32_C(  1784914150),  INT32_C(  1934942416), -INT32_C(   762531288),  INT32_C(   861144097), -INT32_C(  1880215578) },
      {  INT32_C(       22668),  INT32_C(        4908),  INT32_C(       37437),  INT32_C(       33788),  INT32_C(       43254),  INT32_C(        9339),  INT32_C(       27991),  INT32_C(       13820),
         INT32_C(       25741),  INT32_C(       48503),  INT32_C(       32847),  INT32_C(       54531),  INT32_C(       40829),  INT32_C(         707),  INT32_C(       50543),  INT32_C(       49659) },
      {       INT16_MAX,       INT16_MAX,       INT16_MAX,       INT16_MAX,  INT16_C( 22668),  INT16_C(  4908),       INT16_MAX,       INT16_MAX,
              INT16_MIN,       INT16_MAX,       INT16_MIN,       INT16_MIN,       INT16_MAX,  INT16_C(  9339),  INT16_C( 27991),  INT16_C( 13820),
              INT16_MIN,       INT16_MIN,       INT16_MAX,       INT16_MAX,  INT16_C( 25741),       INT16_MAX,       INT16_MAX,       INT16_MAX,
              INT16_MAX,       INT16_MIN,       INT16_MAX,       INT16_MIN,       INT16_MAX,  INT16_C(   707),       INT16_MAX,       INT16_MAX } },
    { {  INT32_C(    86345971),  INT32_C(   264412482), -INT32_C(  1500573103), -INT32_C(   109342115),  INT32_C(   144242828), -INT32_C(  1207280655), -INT32_C(   729908619), -INT32_C(   644449819),
         INT32_C(  1155447553), -INT32_C(  1437360040),  INT32_C(   273736626),  INT32_C(    17419125), -INT32_C(  1274436925),  INT32_C(  1936528637),  INT32_C(  1934093198),  INT32_C(  1699536228) },
      {  INT32_C(       61865),  INT32_C(       32155),  INT32_C(       21901),  INT32_C(       31319),  INT32_C(       13870),  INT32_C(         681),  INT32_C(       60022),  INT32_C(       26448),
         INT32_C(       47193),  INT32_C(       54837),  INT32_C(       38444),  INT32_C(       37648),  INT32_C(       22729),  INT32_C(       24922),  INT32_C(       12875),  INT32_C(       32922) },
      {       INT16_MAX,       INT16_MAX,       INT16_MIN,       INT16_MIN,       INT16_MAX,  INT16_C( 32155),  INT16_C( 21901),  INT16_C( 31319),
              INT16_MAX,       INT16_MIN,       INT16_MIN,       INT16_MIN,  INT16_C( 13870),  INT16_C(   681),       INT16_MAX,  INT16_C( 26448),
              INT16_MAX,       INT16_MIN,       INT16_MAX,       INT16_MAX,       INT16_MAX,       INT16_MAX,       INT16_MAX,       INT16_MAX,
              INT16_MIN,       INT16_MAX,       INT16_MAX,       INT16_MAX,  INT16_C( 22729),  INT16_C( 24922),  INT16_C( 12875),       INT16_MAX } },
    { { -INT32_C(  1959201899), -INT32_C(   949850649), -INT32_C(  1973514704), -INT32_C(   199397871), -INT32_C(  2008225875), -INT32_C(  1091983526),  INT32_C(   183514231),  INT32_C(  1703578320),
         INT32_C(  1710277245),  INT32_C(  1613517360), -INT32_C(   236221728), -INT32_C(  1494873863),  INT32_C(  1227764463),  INT32_C(  1359419353),  INT32_C(   475789388),  INT32_C(     8513154) },
      {  INT32_C(       55397),  INT32_C(       42041),  INT32_C(        5526),  INT32_C(        7355),  INT32_C(       34917),  INT32_C(       19929),  INT32_C(       59241),  INT32_C(       50151),
         INT32_C(        8347),  INT32_C(       64196),  INT32_C(        9487),  INT32_C(       34113),  INT32_C(       46605),  INT32_C(       30723),  INT32_C(       13664),  INT32_C(       46072) },
      {       INT16_MIN,       INT16_MIN,       INT16_MIN,       INT16_MIN,       INT16_MAX,       INT16_MAX,  INT16_C(  5526),  INT16_C(  7355),
              INT16_MIN,       INT16_MIN,       INT16_MAX,       INT16_MAX,       INT16_MAX,  INT16_C( 19929),       INT16_MAX,       INT16_MAX,
              INT16_MAX,       INT16_MAX,       INT16_MIN,       INT16_MIN,  INT16_C(  8347),       INT16_MAX,  INT16_C(  9487),       INT16_MAX,
              INT16_MAX,       INT16_MAX,       INT16_MAX,       INT16_MAX,       INT16_MAX,  INT16_C( 30723),  INT16_C( 13664),       INT16_MAX } },
    { {  INT32_C(  1926468500),  INT32_C(  1617729640), -INT32_C(   913998862), -INT32_C(    95500731), -INT32_C(  2135925907),  INT32_C(  1543091009),  INT32_C(  2022725920),  INT32_C(   875268256),
        -INT32_C(  2069430500), -INT32_C(  1981541737), -INT32_C(   749573491), -INT32_C(  1647468496),  INT32_C(  1008631291),  INT32_C(  1368921904),  INT32_C(   281618544), -INT32_C(   851053391) },
      {  INT32_C(       35409),  INT32_C(       35604),  INT32_C(       53342),  INT32_C(         621),  INT32_C(       55615),  INT32_C(        4650),  INT32_C(       45091),  INT32_C(       56189),
         INT32_C(       20837),  INT32_C(       41949),  INT32_C(       59251),  INT32_C(        4073),  INT32_C(        4072),  INT32_C(       65313),  INT32_C(       60847),  INT32_C(         200) },
      {       INT16_MAX,       INT16_MAX,       INT16_MIN,       INT16_MIN,       INT16_MAX,       INT16_MAX,       INT16_MAX,  INT16_C(   621),
              INT16_MIN,       INT16_MAX,       INT16_MAX,       INT16_MAX,       INT16_MAX,  INT16_C(  4650),       INT16_MAX,       INT16_MAX,
              INT16_MIN,       INT16_MIN,       INT16_MIN,       INT16_MIN,  INT16_C( 20837),       INT16_MAX,       INT16_MAX,  INT16_C(  4073),
              INT16_MAX,       INT16_MAX,       INT16_MAX,       INT16_MIN,  INT16_C(  4072),       INT16_MAX,       INT16_MAX,  INT16_C(   200) } },
    { { -INT32_C(    11457029), -INT32_C(  2019348825), -INT32_C(   781314454),  INT32_C(  1692424183),  INT32_C(  2138294656), -INT32_C(   511798053), -INT32_C(  2050085159),  INT32_C(  1451595355),
         INT32_C(  1784076227),  INT32_C(  1878128901),  INT32_C(   121659151),  INT32_C(   929767863), -INT32_C(   977871126),  INT32_C(  1269183858), -INT32_C(  1093569437), -INT32_C(   837528054) },
      {  INT32_C(       13112),  INT32_C(       29602),  INT32_C(       16506),  INT32_C(       61047),  INT32_C(       13747),  INT32_C(       50817),  INT32_C(       55684),  INT32_C(       54951),
         INT32_C(       26121),  INT32_C(       37849),  INT32_C(       37587),  INT32_C(       64384),  INT32_C(       56369),  INT32_C(       23714),  INT32_C(       44085),  INT32_C(       49538) },
      {       INT16_MIN,       INT16_MIN,       INT16_MIN,       INT16_MAX,  INT16_C( 13112),  INT16_C( 29602),  INT16_C( 16506),       INT16_MAX,
              INT16_MAX,       INT16_MIN,       INT16_MIN,       INT16_MAX,  INT16_C( 13747),       INT16_MAX,       INT16_MAX,       INT16_MAX,
              INT16_MAX,       INT16_MAX,       INT16_MAX,       INT16_MAX,  INT16_C( 26121),       INT16_MAX,       INT16_MAX,       INT16_MAX,
              INT16_MIN,       INT16_MAX,       INT16_MIN,       INT16_MIN,       INT16_MAX,  INT16_C( 23714),       INT16_MAX,       INT16_MAX } },
    { { -INT32_C(   987198532), -INT32_C(   984088265), -INT32_C(  1923601323), -INT32_C(   259401609), -INT32_C(  1697859060),  INT32_C(  1895263852),  INT32_C(  1377578132), -INT32_C(   988504311),
         INT32_C(  1636449322), -INT32_C(  1842879683), -INT32_C(  2044690673),  INT32_C(  1685498199), -INT32_C(   805420445),  INT32_C(  1145042352),  INT32_C(   731274018),  INT32_C(   636529402) },
      {  INT32_C(        9350),  INT32_C(       27830),  INT32_C(       34034),  INT32_C(       58088),  INT32_C(       23217),  INT32_C(       65182),  INT32_C(       17961),  INT32_C(       50795),
         INT32_C(       61930),  INT32_C(       52317),  INT32_C(       63056),  INT32_C(       25561),  INT32_C(       64189),  INT32_C(       51192),  INT32_C(       28685),  INT32_C(       52790) },
      {       INT16_MIN,       INT16_MIN,       INT16_MIN,       INT16_MIN,  INT16_C(  9350),  INT16_C( 27830),       INT16_MAX,       INT16_MAX,
              INT16_MIN,       INT16_MAX,       INT16_MAX,       INT16_MIN,  INT16_C( 23217),       INT16_MAX,  INT16_C( 17961),       INT16_MAX,
              INT16_MAX,       INT16_MIN,       INT16_MIN,       INT16_MAX,       INT16_MAX,       INT16_MAX,       INT16_MAX,  INT16_C( 25561),
              INT16_MIN,       INT16_MAX,       INT16_MAX,       INT16_MAX,       INT16_MAX,       INT16_MAX,  INT16_C( 28685),       INT16_MAX } },
    { {  INT32_C(   180297835),  INT32_C(   953556161),  INT32_C(   623781484),  INT32_C(  2106066782),  INT32_C(   225920402),  INT32_C(   852783265), -INT32_C(   861675119), -INT32_C(   979707558),
        -INT32_C(  1143973382), -INT32_C(   487348619),  INT32_C(   721887693), -INT32_C(  1146581207),  INT32_C(  1992827092),  INT32_C(   564698256), -INT32_C(   655537283),  INT32_C(   530417445) },
      {  INT32_C(       22234),  INT32_C(       57656),  INT32_C(        5900),  INT32_C(       41682),  INT32_C(       25880),  INT32_C(       46214),  INT32_C(       12684),  INT32_C(       56400),
         INT32_C(       43826),  INT32_C(       59020),  INT32_C(       30717),  INT32_C(        8729),  INT32_C(       41351),  INT32_C(       65365),  INT32_C(       32049),  INT32_C(       41305) },
      {       INT16_MAX,       INT16_MAX,       INT16_MAX,       INT16_MAX,  INT16_C( 22234),       INT16_MAX,  INT16_C(  5900),       INT16_MAX,
              INT16_MAX,       INT16_MAX,       INT16_MIN,       INT16_MIN,  INT16_C( 25880),       INT16_MAX,  INT16_C( 12684),       INT16_MAX,
              INT16_MIN,       INT16_MIN,       INT16_MAX,       INT16_MIN,       INT16_MAX,       INT16_MAX,  INT16_C( 30717),  INT16_C(  8729),
              INT16_MAX,       INT16_MAX,       INT16_MIN,       INT16_MAX,       INT16_MAX,       INT16_MAX,  INT16_C( 32049),       INT16_MAX } }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
    simde__m512i a = simde_mm512_loadu_epi32(test_vec[i].a);
    simde__m512i b = simde_mm512_loadu_epi32(test_vec[i].b);
    simde__m512i r = simde_mm512_packs_epi32(a, b);
    simde_test_x86_assert_equal_i16x32(r, simde_mm512_loadu_epi32(test_vec[i].r));
  }

  return 0;
}

static int
test_simde_mm512_packus_epi16 (SIMDE_MUNIT_TEST_ARGS) {
  static const struct {
    const int16_t a[32];
    const int16_t b[32];
    const uint8_t r[64];
  } test_vec[] = {
    { { -INT16_C( 11809),  INT16_C(  3301),  INT16_C(  4381), -INT16_C( 29201), -INT16_C( 11622), -INT16_C(  1564),  INT16_C(  3475), -INT16_C(  8537),
         INT16_C(  4169), -INT16_C( 23067),  INT16_C( 13975),  INT16_C( 16305), -INT16_C( 18418),  INT16_C( 12904), -INT16_C( 19774), -INT16_C( 24123),
        -INT16_C( 21629), -INT16_C( 24403), -INT16_C( 25412),  INT16_C( 22062),  INT16_C(  4719),  INT16_C(   591), -INT16_C(  2528),  INT16_C( 27104),
        -INT16_C( 15098), -INT16_C( 25330), -INT16_C( 16389),  INT16_C(  2780),  INT16_C( 17527),  INT16_C( 14652),  INT16_C(   758),  INT16_C( 31195) },
      {  INT16_C(   136),  INT16_C(   105),  INT16_C(    72),  INT16_C(   148),  INT16_C(    14),  INT16_C(   122),  INT16_C(   119),  INT16_C(    10),
         INT16_C(   241),  INT16_C(    56),  INT16_C(   132),  INT16_C(    39),  INT16_C(   126),  INT16_C(   191),  INT16_C(    60),  INT16_C(    45),
         INT16_C(    83),  INT16_C(   233),  INT16_C(    85),  INT16_C(   245),  INT16_C(    20),  INT16_C(   103),  INT16_C(    83),  INT16_C(   199),
         INT16_C(    26),  INT16_C(   245),  INT16_C(    65),  INT16_C(   103),  INT16_C(   126),  INT16_C(    64),  INT16_C(    96),  INT16_C(   126) },
      { UINT8_C(  0),    UINT8_MAX,    UINT8_MAX, UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),    UINT8_MAX, UINT8_C(  0),
        UINT8_C(136), UINT8_C(105), UINT8_C( 72), UINT8_C(148), UINT8_C( 14), UINT8_C(122), UINT8_C(119), UINT8_C( 10),
           UINT8_MAX, UINT8_C(  0),    UINT8_MAX,    UINT8_MAX, UINT8_C(  0),    UINT8_MAX, UINT8_C(  0), UINT8_C(  0),
        UINT8_C(241), UINT8_C( 56), UINT8_C(132), UINT8_C( 39), UINT8_C(126), UINT8_C(191), UINT8_C( 60), UINT8_C( 45),
        UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),    UINT8_MAX,    UINT8_MAX,    UINT8_MAX, UINT8_C(  0),    UINT8_MAX,
        UINT8_C( 83), UINT8_C(233), UINT8_C( 85), UINT8_C(245), UINT8_C( 20), UINT8_C(103), UINT8_C( 83), UINT8_C(199),
        UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),    UINT8_MAX,    UINT8_MAX,    UINT8_MAX,    UINT8_MAX,    UINT8_MAX,
        UINT8_C( 26), UINT8_C(245), UINT8_C( 65), UINT8_C(103), UINT8_C(126), UINT8_C( 64), UINT8_C( 96), UINT8_C(126) } },
    { {  INT16_C(  1203),  INT16_C( 20072), -INT16_C(  6822), -INT16_C( 17085), -INT16_C( 19463), -INT16_C( 31707), -INT16_C( 26873),  INT16_C( 19532),
         INT16_C( 19377),  INT16_C( 20289),  INT16_C( 24205),  INT16_C( 19895), -INT16_C(  8484), -INT16_C( 26995), -INT16_C(  1218), -INT16_C(  3819),
         INT16_C( 32000),  INT16_C( 23103), -INT16_C( 32158),  INT16_C( 23575),  INT16_C( 15414),  INT16_C( 15840),  INT16_C( 11475), -INT16_C( 31607),
        -INT16_C( 13704),  INT16_C(  1492), -INT16_C( 29911),  INT16_C(  1362), -INT16_C(  8343), -INT16_C( 22628), -INT16_C( 20005), -INT16_C(  9320) },
      {  INT16_C(   215),  INT16_C(   144),  INT16_C(    76),  INT16_C(   143),  INT16_C(   205),  INT16_C(    92),  INT16_C(    85),  INT16_C(   113),
         INT16_C(   181),  INT16_C(    73),  INT16_C(   200),  INT16_C(   169),  INT16_C(   234),  INT16_C(   131),  INT16_C(   232),  INT16_C(   201),
         INT16_C(   147),  INT16_C(    24),  INT16_C(    70),  INT16_C(   104),  INT16_C(   116),  INT16_C(    13),  INT16_C(   166),  INT16_C(   234),
         INT16_C(   245),  INT16_C(   155),  INT16_C(   129),  INT16_C(   101),  INT16_C(   148),  INT16_C(     7),  INT16_C(    70),  INT16_C(    59) },
      {    UINT8_MAX,    UINT8_MAX, UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),    UINT8_MAX,
        UINT8_C(215), UINT8_C(144), UINT8_C( 76), UINT8_C(143), UINT8_C(205), UINT8_C( 92), UINT8_C( 85), UINT8_C(113),
           UINT8_MAX,    UINT8_MAX,    UINT8_MAX,    UINT8_MAX, UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
        UINT8_C(181), UINT8_C( 73), UINT8_C(200), UINT8_C(169), UINT8_C(234), UINT8_C(131), UINT8_C(232), UINT8_C(201),
           UINT8_MAX,    UINT8_MAX, UINT8_C(  0),    UINT8_MAX,    UINT8_MAX,    UINT8_MAX,    UINT8_MAX, UINT8_C(  0),
        UINT8_C(147), UINT8_C( 24), UINT8_C( 70), UINT8_C(104), UINT8_C(116), UINT8_C( 13), UINT8_C(166), UINT8_C(234),
        UINT8_C(  0),    UINT8_MAX, UINT8_C(  0),    UINT8_MAX, UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
        UINT8_C(245), UINT8_C(155), UINT8_C(129), UINT8_C(101), UINT8_C(148), UINT8_C(  7), UINT8_C( 70), UINT8_C( 59) } },
    { {  INT16_C( 11225), -INT16_C( 18093), -INT16_C(  1167), -INT16_C( 31455), -INT16_C(  6544),  INT16_C( 14994),  INT16_C(  4236), -INT16_C(  6364),
         INT16_C( 22277), -INT16_C( 15486), -INT16_C( 14632),  INT16_C( 17448),  INT16_C(  4442), -INT16_C( 10676),  INT16_C(  7511),  INT16_C( 12561),
         INT16_C( 25928), -INT16_C( 17942),  INT16_C(  2912), -INT16_C( 12226), -INT16_C( 12046),  INT16_C( 32266),  INT16_C( 12001), -INT16_C(  6554),
        -INT16_C(  6011),  INT16_C( 24233), -INT16_C( 11601),  INT16_C(  2466), -INT16_C(  4381),  INT16_C( 15072), -INT16_C(  3829),  INT16_C( 21355) },
      {  INT16_C(    85),  INT16_C(   183),  INT16_C(    75),  INT16_C(    83),  INT16_C(   146),  INT16_C(   253),  INT16_C(    55),  INT16_C(    70),
         INT16_C(   141),  INT16_C(   207),  INT16_C(    70),  INT16_C(    66),  INT16_C(   184),  INT16_C(    64),  INT16_C(   232),  INT16_C(     0),
         INT16_C(   161),  INT16_C(   158),  INT16_C(    63),  INT16_C(     8),  INT16_C(   195),  INT16_C(   145),  INT16_C(   233),  INT16_C(    26),
         INT16_C(   123),  INT16_C(   213),  INT16_C(   194),  INT16_C(   247),  INT16_C(   147),  INT16_C(    36),  INT16_C(   203),  INT16_C(   185) },
      {    UINT8_MAX, UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),    UINT8_MAX,    UINT8_MAX, UINT8_C(  0),
        UINT8_C( 85), UINT8_C(183), UINT8_C( 75), UINT8_C( 83), UINT8_C(146), UINT8_C(253), UINT8_C( 55), UINT8_C( 70),
           UINT8_MAX, UINT8_C(  0), UINT8_C(  0),    UINT8_MAX,    UINT8_MAX, UINT8_C(  0),    UINT8_MAX,    UINT8_MAX,
        UINT8_C(141), UINT8_C(207), UINT8_C( 70), UINT8_C( 66), UINT8_C(184), UINT8_C( 64), UINT8_C(232), UINT8_C(  0),
           UINT8_MAX, UINT8_C(  0),    UINT8_MAX, UINT8_C(  0), UINT8_C(  0),    UINT8_MAX,    UINT8_MAX, UINT8_C(  0),
        UINT8_C(161), UINT8_C(158), UINT8_C( 63), UINT8_C(  8), UINT8_C(195), UINT8_C(145), UINT8_C(233), UINT8_C( 26),
        UINT8_C(  0),    UINT8_MAX, UINT8_C(  0),    UINT8_MAX, UINT8_C(  0),    UINT8_MAX, UINT8_C(  0),    UINT8_MAX,
        UINT8_C(123), UINT8_C(213), UINT8_C(194), UINT8_C(247), UINT8_C(147), UINT8_C( 36), UINT8_C(203), UINT8_C(185) } },
    { { -INT16_C(  9108),  INT16_C( 22871),  INT16_C( 18715), -INT16_C(  5023),  INT16_C( 26380),  INT16_C(  1662),  INT16_C( 21840), -INT16_C( 14815),
         INT16_C(  2769), -INT16_C( 27749), -INT16_C( 19764),  INT16_C( 18314), -INT16_C( 16059), -INT16_C( 16021), -INT16_C( 28531), -INT16_C(  1670),
        -INT16_C( 11923), -INT16_C( 30638), -INT16_C( 19430),  INT16_C(  9845), -INT16_C(  3301),  INT16_C( 27437),  INT16_C( 20040),  INT16_C(  6449),
        -INT16_C( 13224),  INT16_C(  9644),  INT16_C( 13950), -INT16_C( 15508), -INT16_C( 10248), -INT16_C( 31356), -INT16_C(   408), -INT16_C( 10882) },
      {  INT16_C(   209),  INT16_C(   234),  INT16_C(   210),  INT16_C(   160),  INT16_C(    62),  INT16_C(    14),  INT16_C(    60),  INT16_C(   228),
         INT16_C(   212),  INT16_C(   134),  INT16_C(   117),  INT16_C(     2),  INT16_C(   206),  INT16_C(   181),  INT16_C(     6),  INT16_C(   156),
         INT16_C(   231),  INT16_C(    92),  INT16_C(   152),  INT16_C(   127),  INT16_C(     7),  INT16_C(    98),  INT16_C(   181),  INT16_C(    75),
         INT16_C(    80),  INT16_C(   147),  INT16_C(    26),  INT16_C(    18),  INT16_C(    29),  INT16_C(   181),  INT16_C(    81),  INT16_C(   250) },
      { UINT8_C(  0),    UINT8_MAX,    UINT8_MAX, UINT8_C(  0),    UINT8_MAX,    UINT8_MAX,    UINT8_MAX, UINT8_C(  0),
        UINT8_C(209), UINT8_C(234), UINT8_C(210), UINT8_C(160), UINT8_C( 62), UINT8_C( 14), UINT8_C( 60), UINT8_C(228),
           UINT8_MAX, UINT8_C(  0), UINT8_C(  0),    UINT8_MAX, UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
        UINT8_C(212), UINT8_C(134), UINT8_C(117), UINT8_C(  2), UINT8_C(206), UINT8_C(181), UINT8_C(  6), UINT8_C(156),
        UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),    UINT8_MAX, UINT8_C(  0),    UINT8_MAX,    UINT8_MAX,    UINT8_MAX,
        UINT8_C(231), UINT8_C( 92), UINT8_C(152), UINT8_C(127), UINT8_C(  7), UINT8_C( 98), UINT8_C(181), UINT8_C( 75),
        UINT8_C(  0),    UINT8_MAX,    UINT8_MAX, UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
        UINT8_C( 80), UINT8_C(147), UINT8_C( 26), UINT8_C( 18), UINT8_C( 29), UINT8_C(181), UINT8_C( 81), UINT8_C(250) } },
    { { -INT16_C( 10183), -INT16_C(  3242),  INT16_C( 21104),  INT16_C( 18034),  INT16_C(    89), -INT16_C( 25432), -INT16_C(  4171),  INT16_C( 16103),
        -INT16_C( 18369),  INT16_C(  1233),  INT16_C( 26579), -INT16_C( 17641), -INT16_C(  8571), -INT16_C( 22416), -INT16_C( 15824),  INT16_C( 27043),
        -INT16_C(  1638),  INT16_C(  2908), -INT16_C( 12724), -INT16_C( 23215), -INT16_C(  1330), -INT16_C( 31934),  INT16_C( 10729),  INT16_C( 10433),
        -INT16_C( 27678), -INT16_C( 19156),  INT16_C( 17402),  INT16_C( 32624), -INT16_C(  7902),  INT16_C( 21032), -INT16_C( 13405),  INT16_C( 15803) },
      {  INT16_C(    23),  INT16_C(    16),  INT16_C(   154),  INT16_C(   180),  INT16_C(   248),  INT16_C(   125),  INT16_C(   249),  INT16_C(     3),
         INT16_C(   209),  INT16_C(   134),  INT16_C(    41),  INT16_C(    55),  INT16_C(    46),  INT16_C(   173),  INT16_C(    68),  INT16_C(   189),
         INT16_C(    51),  INT16_C(    64),  INT16_C(   132),  INT16_C(    97),  INT16_C(    44),  INT16_C(   157),  INT16_C(   131),  INT16_C(   177),
         INT16_C(    89),  INT16_C(   105),  INT16_C(    61),  INT16_C(   140),  INT16_C(    41),  INT16_C(   100),  INT16_C(    36),  INT16_C(   200) },
      { UINT8_C(  0), UINT8_C(  0),    UINT8_MAX,    UINT8_MAX, UINT8_C( 89), UINT8_C(  0), UINT8_C(  0),    UINT8_MAX,
        UINT8_C( 23), UINT8_C( 16), UINT8_C(154), UINT8_C(180), UINT8_C(248), UINT8_C(125), UINT8_C(249), UINT8_C(  3),
        UINT8_C(  0),    UINT8_MAX,    UINT8_MAX, UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),    UINT8_MAX,
        UINT8_C(209), UINT8_C(134), UINT8_C( 41), UINT8_C( 55), UINT8_C( 46), UINT8_C(173), UINT8_C( 68), UINT8_C(189),
        UINT8_C(  0),    UINT8_MAX, UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),    UINT8_MAX,    UINT8_MAX,
        UINT8_C( 51), UINT8_C( 64), UINT8_C(132), UINT8_C( 97), UINT8_C( 44), UINT8_C(157), UINT8_C(131), UINT8_C(177),
        UINT8_C(  0), UINT8_C(  0),    UINT8_MAX,    UINT8_MAX, UINT8_C(  0),    UINT8_MAX, UINT8_C(  0),    UINT8_MAX,
        UINT8_C( 89), UINT8_C(105), UINT8_C( 61), UINT8_C(140), UINT8_C( 41), UINT8_C(100), UINT8_C( 36), UINT8_C(200) } },
    { { -INT16_C(  4009),  INT16_C(  9225), -INT16_C(   652), -INT16_C(  3963),  INT16_C( 25385),  INT16_C( 20109),  INT16_C( 12006),  INT16_C( 15103),
         INT16_C( 14216),  INT16_C(  2724),  INT16_C( 17524), -INT16_C(  8041), -INT16_C( 12178), -INT16_C(  9404),  INT16_C( 26356),  INT16_C( 19364),
        -INT16_C( 21162), -INT16_C( 13713), -INT16_C(  2902), -INT16_C( 11078),  INT16_C( 18519),  INT16_C( 15650),  INT16_C(  8822), -INT16_C(   392),
         INT16_C(  7257), -INT16_C( 13047), -INT16_C( 24480), -INT16_C( 12627), -INT16_C(  3472),  INT16_C( 26026),  INT16_C( 20056), -INT16_C( 20560) },
      {  INT16_C(    32),  INT16_C(   165),  INT16_C(    52),  INT16_C(   108),  INT16_C(   156),  INT16_C(   242),  INT16_C(    33),  INT16_C(    23),
         INT16_C(   250),  INT16_C(   158),  INT16_C(   146),  INT16_C(    10),  INT16_C(    22),  INT16_C(   220),  INT16_C(    32),  INT16_C(    95),
         INT16_C(     5),  INT16_C(    84),  INT16_C(   126),  INT16_C(   181),  INT16_C(   106),  INT16_C(   216),  INT16_C(   152),  INT16_C(   201),
         INT16_C(   212),  INT16_C(    44),  INT16_C(   211),  INT16_C(   234),  INT16_C(   166),  INT16_C(    78),  INT16_C(    82),  INT16_C(     6) },
      { UINT8_C(  0),    UINT8_MAX, UINT8_C(  0), UINT8_C(  0),    UINT8_MAX,    UINT8_MAX,    UINT8_MAX,    UINT8_MAX,
        UINT8_C( 32), UINT8_C(165), UINT8_C( 52), UINT8_C(108), UINT8_C(156), UINT8_C(242), UINT8_C( 33), UINT8_C( 23),
           UINT8_MAX,    UINT8_MAX,    UINT8_MAX, UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),    UINT8_MAX,    UINT8_MAX,
        UINT8_C(250), UINT8_C(158), UINT8_C(146), UINT8_C( 10), UINT8_C( 22), UINT8_C(220), UINT8_C( 32), UINT8_C( 95),
        UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),    UINT8_MAX,    UINT8_MAX,    UINT8_MAX, UINT8_C(  0),
        UINT8_C(  5), UINT8_C( 84), UINT8_C(126), UINT8_C(181), UINT8_C(106), UINT8_C(216), UINT8_C(152), UINT8_C(201),
           UINT8_MAX, UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),    UINT8_MAX,    UINT8_MAX, UINT8_C(  0),
        UINT8_C(212), UINT8_C( 44), UINT8_C(211), UINT8_C(234), UINT8_C(166), UINT8_C( 78), UINT8_C( 82), UINT8_C(  6) } },
    { { -INT16_C( 19625), -INT16_C( 28581),  INT16_C(  6961),  INT16_C( 19525), -INT16_C(  4987),  INT16_C(  4388),  INT16_C(  5253),  INT16_C(  6106),
         INT16_C( 16872),  INT16_C( 20036),  INT16_C( 31508), -INT16_C(   456), -INT16_C(   479), -INT16_C(  6067), -INT16_C(  1200), -INT16_C( 22546),
         INT16_C( 18862), -INT16_C(  8393),  INT16_C( 31845), -INT16_C(  5589),  INT16_C( 20585), -INT16_C(  4357), -INT16_C( 10908),  INT16_C( 19461),
         INT16_C( 18710),  INT16_C( 11162), -INT16_C( 11580), -INT16_C(  6615),  INT16_C( 30416),  INT16_C(  8654), -INT16_C( 17295),  INT16_C(  8136) },
      {  INT16_C(     0),  INT16_C(   107),  INT16_C(    42),  INT16_C(   229),  INT16_C(    81),  INT16_C(   222),  INT16_C(   217),  INT16_C(    61),
         INT16_C(   196),  INT16_C(   231),  INT16_C(   145),  INT16_C(   103),  INT16_C(   155),  INT16_C(   121),  INT16_C(    80),  INT16_C(    93),
         INT16_C(   152),  INT16_C(   205),  INT16_C(    30),  INT16_C(    61),  INT16_C(   134),  INT16_C(   149),  INT16_C(    70),  INT16_C(   129),
         INT16_C(    58),  INT16_C(   161),  INT16_C(    53),  INT16_C(   212),  INT16_C(   144),  INT16_C(    40),  INT16_C(   230),  INT16_C(    49) },
      { UINT8_C(  0), UINT8_C(  0),    UINT8_MAX,    UINT8_MAX, UINT8_C(  0),    UINT8_MAX,    UINT8_MAX,    UINT8_MAX,
        UINT8_C(  0), UINT8_C(107), UINT8_C( 42), UINT8_C(229), UINT8_C( 81), UINT8_C(222), UINT8_C(217), UINT8_C( 61),
           UINT8_MAX,    UINT8_MAX,    UINT8_MAX, UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
        UINT8_C(196), UINT8_C(231), UINT8_C(145), UINT8_C(103), UINT8_C(155), UINT8_C(121), UINT8_C( 80), UINT8_C( 93),
           UINT8_MAX, UINT8_C(  0),    UINT8_MAX, UINT8_C(  0),    UINT8_MAX, UINT8_C(  0), UINT8_C(  0),    UINT8_MAX,
        UINT8_C(152), UINT8_C(205), UINT8_C( 30), UINT8_C( 61), UINT8_C(134), UINT8_C(149), UINT8_C( 70), UINT8_C(129),
           UINT8_MAX,    UINT8_MAX, UINT8_C(  0), UINT8_C(  0),    UINT8_MAX,    UINT8_MAX, UINT8_C(  0),    UINT8_MAX,
        UINT8_C( 58), UINT8_C(161), UINT8_C( 53), UINT8_C(212), UINT8_C(144), UINT8_C( 40), UINT8_C(230), UINT8_C( 49) } },
    { {  INT16_C( 20094),  INT16_C( 16894), -INT16_C( 20372), -INT16_C(  9346), -INT16_C( 26314), -INT16_C( 27280),  INT16_C( 17375), -INT16_C(  5609),
         INT16_C( 32637),  INT16_C( 18827), -INT16_C( 27723), -INT16_C( 31459),  INT16_C( 27427),  INT16_C(   941),  INT16_C( 13137), -INT16_C( 12236),
         INT16_C( 12929), -INT16_C(  4847), -INT16_C( 28701),  INT16_C(  6600),  INT16_C( 14376),  INT16_C(  2223), -INT16_C( 14725), -INT16_C(  1550),
         INT16_C( 32069), -INT16_C(  1470),  INT16_C( 24592),  INT16_C( 13184),  INT16_C( 11723),  INT16_C(  7222),  INT16_C( 27488), -INT16_C(  7700) },
      {  INT16_C(   253),  INT16_C(   128),  INT16_C(   150),  INT16_C(   181),  INT16_C(    73),  INT16_C(    74),  INT16_C(   175),  INT16_C(    84),
         INT16_C(   134),  INT16_C(    60),  INT16_C(   207),  INT16_C(   177),  INT16_C(   165),  INT16_C(    93),  INT16_C(   186),  INT16_C(   174),
         INT16_C(    13),  INT16_C(    68),  INT16_C(   200),  INT16_C(   114),  INT16_C(   182),  INT16_C(    32),  INT16_C(     0),  INT16_C(   145),
         INT16_C(   196),  INT16_C(   108),  INT16_C(    60),  INT16_C(   143),  INT16_C(   235),  INT16_C(   242),  INT16_C(    43),  INT16_C(    92) },
      {    UINT8_MAX,    UINT8_MAX, UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),    UINT8_MAX, UINT8_C(  0),
        UINT8_C(253), UINT8_C(128), UINT8_C(150), UINT8_C(181), UINT8_C( 73), UINT8_C( 74), UINT8_C(175), UINT8_C( 84),
           UINT8_MAX,    UINT8_MAX, UINT8_C(  0), UINT8_C(  0),    UINT8_MAX,    UINT8_MAX,    UINT8_MAX, UINT8_C(  0),
        UINT8_C(134), UINT8_C( 60), UINT8_C(207), UINT8_C(177), UINT8_C(165), UINT8_C( 93), UINT8_C(186), UINT8_C(174),
           UINT8_MAX, UINT8_C(  0), UINT8_C(  0),    UINT8_MAX,    UINT8_MAX,    UINT8_MAX, UINT8_C(  0), UINT8_C(  0),
        UINT8_C( 13), UINT8_C( 68), UINT8_C(200), UINT8_C(114), UINT8_C(182), UINT8_C( 32), UINT8_C(  0), UINT8_C(145),
           UINT8_MAX, UINT8_C(  0),    UINT8_MAX,    UINT8_MAX,    UINT8_MAX,    UINT8_MAX,    UINT8_MAX, UINT8_C(  0),
        UINT8_C(196), UINT8_C(108), UINT8_C( 60), UINT8_C(143), UINT8_C(235), UINT8_C(242), UINT8_C( 43), UINT8_C( 92) } }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
    simde__m512i a = simde_mm512_loadu_epi16(test_vec[i].a);
    simde__m512i b = simde_mm512_loadu_epi16(test_vec[i].b);
    simde__m512i r = simde_mm512_packus_epi16(a, b);
    simde_test_x86_assert_equal_u8x64(r, simde_mm512_loadu_epi16(test_vec[i].r));
  }

  return 0;
}

static int
test_simde_mm512_packus_epi32 (SIMDE_MUNIT_TEST_ARGS) {
  static const struct {
    const int32_t a[16];
    const int32_t b[16];
    const uint16_t r[32];
  } test_vec[] = {
    { {  INT32_C(       32838),  INT32_C(         707),  INT32_C(       18249),  INT32_C(       43411),  INT32_C(       33031),  INT32_C(       48266),  INT32_C(       46389),  INT32_C(       30506),
         INT32_C(       19447),  INT32_C(       16717),  INT32_C(        9608),  INT32_C(       32719),  INT32_C(       16128),  INT32_C(         507),  INT32_C(        9398),  INT32_C(       24219) },
      { -INT32_C(   374762927), -INT32_C(   768936372),  INT32_C(  1090040461), -INT32_C(   926955570),  INT32_C(  1560788893), -INT32_C(  1621228982), -INT32_C(  1144842958),  INT32_C(  1192845046),
         INT32_C(  1009828848),  INT32_C(  1175411385), -INT32_C(   611907827),  INT32_C(  1805862606),  INT32_C(  1355393542), -INT32_C(   554752084),  INT32_C(   848933692),  INT32_C(    41595665) },
      { UINT16_C(32838), UINT16_C(  707), UINT16_C(18249), UINT16_C(43411), UINT16_C(    0), UINT16_C(    0),      UINT16_MAX, UINT16_C(    0),
        UINT16_C(33031), UINT16_C(48266), UINT16_C(46389), UINT16_C(30506),      UINT16_MAX, UINT16_C(    0), UINT16_C(    0),      UINT16_MAX,
        UINT16_C(19447), UINT16_C(16717), UINT16_C( 9608), UINT16_C(32719),      UINT16_MAX,      UINT16_MAX, UINT16_C(    0),      UINT16_MAX,
        UINT16_C(16128), UINT16_C(  507), UINT16_C( 9398), UINT16_C(24219),      UINT16_MAX, UINT16_C(    0),      UINT16_MAX,      UINT16_MAX } },
    { {  INT32_C(       12094),  INT32_C(        4726),  INT32_C(        8941),  INT32_C(       18830),  INT32_C(       59545),  INT32_C(       48070),  INT32_C(       19949),  INT32_C(       35151),
         INT32_C(        6072),  INT32_C(       12329),  INT32_C(       28498),  INT32_C(       58296),  INT32_C(       46795),  INT32_C(        6001),  INT32_C(        1124),  INT32_C(       55437) },
      {  INT32_C(   502220354), -INT32_C(  1605560204), -INT32_C(   703619026), -INT32_C(  1195784320), -INT32_C(   194083815),  INT32_C(   118218517),  INT32_C(    51081277),  INT32_C(  1725667620),
         INT32_C(  1401146079),  INT32_C(   301191650), -INT32_C(   236518799), -INT32_C(   475422518),  INT32_C(   970463012),  INT32_C(   876667894),  INT32_C(  2000112723), -INT32_C(   992144411) },
      { UINT16_C(12094), UINT16_C( 4726), UINT16_C( 8941), UINT16_C(18830),      UINT16_MAX, UINT16_C(    0), UINT16_C(    0), UINT16_C(    0),
        UINT16_C(59545), UINT16_C(48070), UINT16_C(19949), UINT16_C(35151), UINT16_C(    0),      UINT16_MAX,      UINT16_MAX,      UINT16_MAX,
        UINT16_C( 6072), UINT16_C(12329), UINT16_C(28498), UINT16_C(58296),      UINT16_MAX,      UINT16_MAX, UINT16_C(    0), UINT16_C(    0),
        UINT16_C(46795), UINT16_C( 6001), UINT16_C( 1124), UINT16_C(55437),      UINT16_MAX,      UINT16_MAX,      UINT16_MAX, UINT16_C(    0) } },
    { {  INT32_C(       49175),  INT32_C(       41937),  INT32_C(       55188),  INT32_C(       31931),  INT32_C(       19637),  INT32_C(       51840),  INT32_C(       10049),  INT32_C(       43243),
         INT32_C(       45672),  INT32_C(        6997),  INT32_C(       18930),  INT32_C(       32197),  INT32_C(       47049),  INT32_C(       45697),  INT32_C(       52185),  INT32_C(       24947) },
      { -INT32_C(   736896057),  INT32_C(    99575828),  INT32_C(  2035212882), -INT32_C(   789179505), -INT32_C(    24658035),  INT32_C(   162531336), -INT32_C(  1395356982),  INT32_C(   353191758),
         INT32_C(   921313570), -INT32_C(   616834679),  INT32_C(  1263897019),  INT32_C(   689654684),  INT32_C(   321364491),  INT32_C(  1948047530), -INT32_C(  1340018590),  INT32_C(  1506160183) },
      { UINT16_C(49175), UINT16_C(41937), UINT16_C(55188), UINT16_C(31931), UINT16_C(    0),      UINT16_MAX,      UINT16_MAX, UINT16_C(    0),
        UINT16_C(19637), UINT16_C(51840), UINT16_C(10049), UINT16_C(43243), UINT16_C(    0),      UINT16_MAX, UINT16_C(    0),      UINT16_MAX,
        UINT16_C(45672), UINT16_C( 6997), UINT16_C(18930), UINT16_C(32197),      UINT16_MAX, UINT16_C(    0),      UINT16_MAX,      UINT16_MAX,
        UINT16_C(47049), UINT16_C(45697), UINT16_C(52185), UINT16_C(24947),      UINT16_MAX,      UINT16_MAX, UINT16_C(    0),      UINT16_MAX } },
    { {  INT32_C(       55439),  INT32_C(       17844),  INT32_C(       61328),  INT32_C(       24345),  INT32_C(       63347),  INT32_C(       31339),  INT32_C(       46891),  INT32_C(        2321),
         INT32_C(       10977),  INT32_C(       48751),  INT32_C(       62382),  INT32_C(       63314),  INT32_C(        8430),  INT32_C(       54682),  INT32_C(       41100),  INT32_C(       22441) },
      { -INT32_C(  1451062722), -INT32_C(  1100484320), -INT32_C(  1682893327), -INT32_C(   460127012),  INT32_C(   503611849), -INT32_C(  1040998693),  INT32_C(   442597476),  INT32_C(  1534200349),
        -INT32_C(  1257966443), -INT32_C(   697078555),  INT32_C(  1584539009), -INT32_C(   230554327),  INT32_C(  1645299334),  INT32_C(  1210254564), -INT32_C(  1570536060),  INT32_C(   620615055) },
      { UINT16_C(55439), UINT16_C(17844), UINT16_C(61328), UINT16_C(24345), UINT16_C(    0), UINT16_C(    0), UINT16_C(    0), UINT16_C(    0),
        UINT16_C(63347), UINT16_C(31339), UINT16_C(46891), UINT16_C( 2321),      UINT16_MAX, UINT16_C(    0),      UINT16_MAX,      UINT16_MAX,
        UINT16_C(10977), UINT16_C(48751), UINT16_C(62382), UINT16_C(63314), UINT16_C(    0), UINT16_C(    0),      UINT16_MAX, UINT16_C(    0),
        UINT16_C( 8430), UINT16_C(54682), UINT16_C(41100), UINT16_C(22441),      UINT16_MAX,      UINT16_MAX, UINT16_C(    0),      UINT16_MAX } },
    { {  INT32_C(       44761),  INT32_C(       61317),  INT32_C(       39757),  INT32_C(       33421),  INT32_C(       47844),  INT32_C(        9986),  INT32_C(        7369),  INT32_C(         833),
         INT32_C(       14258),  INT32_C(       55590),  INT32_C(       10868),  INT32_C(       55724),  INT32_C(       17299),  INT32_C(        9835),  INT32_C(       13634),  INT32_C(       50233) },
      {  INT32_C(   100395934),  INT32_C(  1356800546), -INT32_C(  1720036458), -INT32_C(   160291243),  INT32_C(  1345914295), -INT32_C(  1770609509), -INT32_C(   724846119), -INT32_C(   627506116),
         INT32_C(   299930863),  INT32_C(  1281474486),  INT32_C(  1759959826), -INT32_C(  1184999422), -INT32_C(   116746402),  INT32_C(   361726012),  INT32_C(  1995004473),  INT32_C(  1313899103) },
      { UINT16_C(44761), UINT16_C(61317), UINT16_C(39757), UINT16_C(33421),      UINT16_MAX,      UINT16_MAX, UINT16_C(    0), UINT16_C(    0),
        UINT16_C(47844), UINT16_C( 9986), UINT16_C( 7369), UINT16_C(  833),      UINT16_MAX, UINT16_C(    0), UINT16_C(    0), UINT16_C(    0),
        UINT16_C(14258), UINT16_C(55590), UINT16_C(10868), UINT16_C(55724),      UINT16_MAX,      UINT16_MAX,      UINT16_MAX, UINT16_C(    0),
        UINT16_C(17299), UINT16_C( 9835), UINT16_C(13634), UINT16_C(50233), UINT16_C(    0),      UINT16_MAX,      UINT16_MAX,      UINT16_MAX } },
    { {  INT32_C(       52576),  INT32_C(         538),  INT32_C(       40810),  INT32_C(       46680),  INT32_C(       39855),  INT32_C(        7344),  INT32_C(       63634),  INT32_C(       13126),
         INT32_C(         769),  INT32_C(        1285),  INT32_C(       29604),  INT32_C(       38442),  INT32_C(       16946),  INT32_C(       45406),  INT32_C(       39337),  INT32_C(       59340) },
      { -INT32_C(    18166378),  INT32_C(    50589672), -INT32_C(  1787320482),  INT32_C(    36479395), -INT32_C(  1841013126), -INT32_C(  1119640768),  INT32_C(  1750527124),  INT32_C(  1917788892),
        -INT32_C(   663733520), -INT32_C(  1998818519), -INT32_C(  1122151654),  INT32_C(  1858095604), -INT32_C(   402586457),  INT32_C(  1000686759),  INT32_C(   228850481),  INT32_C(   226489117) },
      { UINT16_C(52576), UINT16_C(  538), UINT16_C(40810), UINT16_C(46680), UINT16_C(    0),      UINT16_MAX, UINT16_C(    0),      UINT16_MAX,
        UINT16_C(39855), UINT16_C( 7344), UINT16_C(63634), UINT16_C(13126), UINT16_C(    0), UINT16_C(    0),      UINT16_MAX,      UINT16_MAX,
        UINT16_C(  769), UINT16_C( 1285), UINT16_C(29604), UINT16_C(38442), UINT16_C(    0), UINT16_C(    0), UINT16_C(    0),      UINT16_MAX,
        UINT16_C(16946), UINT16_C(45406), UINT16_C(39337), UINT16_C(59340), UINT16_C(    0),      UINT16_MAX,      UINT16_MAX,      UINT16_MAX } },
    { {  INT32_C(       22246),  INT32_C(       31966),  INT32_C(        2361),  INT32_C(       60791),  INT32_C(       42453),  INT32_C(       61153),  INT32_C(       37627),  INT32_C(       42144),
         INT32_C(       52219),  INT32_C(       23879),  INT32_C(        7014),  INT32_C(       30728),  INT32_C(        4893),  INT32_C(       52225),  INT32_C(       64094),  INT32_C(       57247) },
      { -INT32_C(   861234556),  INT32_C(  1227485555), -INT32_C(   345731215), -INT32_C(  1016894355), -INT32_C(  1596554935),  INT32_C(    40687487),  INT32_C(  1241369299),  INT32_C(  1294507209),
        -INT32_C(  1457860042),  INT32_C(   888292291),  INT32_C(  1075861203),  INT32_C(   184779714), -INT32_C(  2069112572), -INT32_C(  2088364112), -INT32_C(  1412660254),  INT32_C(  1442378783) },
      { UINT16_C(22246), UINT16_C(31966), UINT16_C( 2361), UINT16_C(60791), UINT16_C(    0),      UINT16_MAX, UINT16_C(    0), UINT16_C(    0),
        UINT16_C(42453), UINT16_C(61153), UINT16_C(37627), UINT16_C(42144), UINT16_C(    0),      UINT16_MAX,      UINT16_MAX,      UINT16_MAX,
        UINT16_C(52219), UINT16_C(23879), UINT16_C( 7014), UINT16_C(30728), UINT16_C(    0),      UINT16_MAX,      UINT16_MAX,      UINT16_MAX,
        UINT16_C( 4893), UINT16_C(52225), UINT16_C(64094), UINT16_C(57247), UINT16_C(    0), UINT16_C(    0), UINT16_C(    0),      UINT16_MAX } },
    { {  INT32_C(       35327),  INT32_C(       10685),  INT32_C(        2665),  INT32_C(       25878),  INT32_C(       62953),  INT32_C(       47992),  INT32_C(        4966),  INT32_C(       65128),
         INT32_C(       51079),  INT32_C(       41456),  INT32_C(       33707),  INT32_C(        2792),  INT32_C(       23807),  INT32_C(       13591),  INT32_C(       62280),  INT32_C(       19697) },
      {  INT32_C(  1897101336), -INT32_C(   569244740),  INT32_C(   560053852),  INT32_C(    36391551),  INT32_C(  1583229468),  INT32_C(  1553167777), -INT32_C(   833626894), -INT32_C(  1525006195),
         INT32_C(  1964453560), -INT32_C(  1907152591),  INT32_C(  1739568615),  INT32_C(   459922431), -INT32_C(  1485191163),  INT32_C(   805506109),  INT32_C(  1979601896),  INT32_C(  1276844179) },
      { UINT16_C(35327), UINT16_C(10685), UINT16_C( 2665), UINT16_C(25878),      UINT16_MAX, UINT16_C(    0),      UINT16_MAX,      UINT16_MAX,
        UINT16_C(62953), UINT16_C(47992), UINT16_C( 4966), UINT16_C(65128),      UINT16_MAX,      UINT16_MAX, UINT16_C(    0), UINT16_C(    0),
        UINT16_C(51079), UINT16_C(41456), UINT16_C(33707), UINT16_C( 2792),      UINT16_MAX, UINT16_C(    0),      UINT16_MAX,      UINT16_MAX,
        UINT16_C(23807), UINT16_C(13591), UINT16_C(62280), UINT16_C(19697), UINT16_C(    0),      UINT16_MAX,      UINT16_MAX,      UINT16_MAX } }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
    simde__m512i a = simde_mm512_loadu_epi32(test_vec[i].a);
    simde__m512i b = simde_mm512_loadu_epi32(test_vec[i].b);
    simde__m512i r = simde_mm512_packus_epi32(a, b);
    simde_test_x86_assert_equal_u16x32(r, simde_mm512_loadu_epi32(test_vec[i].r));
  }

  return 0;
}

static int
test_simde_mm512_sad_epu8 (SIMDE_MUNIT_TEST_ARGS) {
  static const struct {
    const uint8_t a[64];
    const uint8_t b[64];
    const uint64_t r[8];
  } test_vec[] = {
    { { UINT8_C( 88), UINT8_C(111), UINT8_C( 54), UINT8_C( 92), UINT8_C( 49), UINT8_C(210), UINT8_C( 24), UINT8_C(  5),
        UINT8_C( 48), UINT8_C( 13), UINT8_C(211), UINT8_C( 11), UINT8_C(190), UINT8_C( 85), UINT8_C(117), UINT8_C( 12),
        UINT8_C(184), UINT8_C( 19), UINT8_C(180), UINT8_C(185), UINT8_C( 42), UINT8_C( 26), UINT8_C(118), UINT8_C(165),
        UINT8_C(131), UINT8_C( 96), UINT8_C( 71), UINT8_C(113), UINT8_C(208), UINT8_C(125), UINT8_C( 93), UINT8_C( 40),
        UINT8_C(236), UINT8_C(147), UINT8_C(132), UINT8_C( 29), UINT8_C(101), UINT8_C(157), UINT8_C( 34), UINT8_C(149),
        UINT8_C(170), UINT8_C(245), UINT8_C(161), UINT8_C(105), UINT8_C( 75), UINT8_C( 22), UINT8_C(117), UINT8_C(  3),
        UINT8_C( 41), UINT8_C( 42), UINT8_C(188), UINT8_C( 83), UINT8_C( 68), UINT8_C( 51), UINT8_C(249), UINT8_C(200),
        UINT8_C(147), UINT8_C( 64), UINT8_C( 57), UINT8_C( 99), UINT8_C(189), UINT8_C(150), UINT8_C(139), UINT8_C(169) },
      { UINT8_C( 42), UINT8_C( 16), UINT8_C(198), UINT8_C(143), UINT8_C(173), UINT8_C(233), UINT8_C( 37), UINT8_C( 87),
        UINT8_C(222), UINT8_C(198), UINT8_C(192), UINT8_C( 41), UINT8_C(220), UINT8_C( 54), UINT8_C( 44), UINT8_C(  5),
        UINT8_C( 96), UINT8_C(233), UINT8_C( 89), UINT8_C(164), UINT8_C( 28), UINT8_C( 82), UINT8_C(108), UINT8_C(175),
        UINT8_C(146), UINT8_C(165), UINT8_C( 19), UINT8_C( 79), UINT8_C( 60), UINT8_C(158), UINT8_C(248), UINT8_C(102),
        UINT8_C(174), UINT8_C(190), UINT8_C(245), UINT8_C( 91), UINT8_C(167), UINT8_C( 26), UINT8_C(179), UINT8_C(134),
        UINT8_C(224), UINT8_C(115), UINT8_C(175), UINT8_C(188), UINT8_C(169), UINT8_C(220), UINT8_C(194), UINT8_C(  9),
        UINT8_C(197), UINT8_C( 27), UINT8_C(174), UINT8_C(225), UINT8_C(109), UINT8_C( 26), UINT8_C(144),    UINT8_MAX,
        UINT8_C(192), UINT8_C(163), UINT8_C( 78), UINT8_C(252), UINT8_C( 66), UINT8_C( 70), UINT8_C( 98), UINT8_C(240) },
      { UINT64_C(                 578), UINT64_C(                 549), UINT64_C(                 504), UINT64_C(                 568),
        UINT64_C(                 637), UINT64_C(                 656), UINT64_C(                 553), UINT64_C(                 633) } },
    { { UINT8_C(  4), UINT8_C( 87), UINT8_C( 76), UINT8_C(172), UINT8_C(114),    UINT8_MAX, UINT8_C( 50), UINT8_C( 82),
        UINT8_C(114), UINT8_C(225), UINT8_C( 15), UINT8_C( 28), UINT8_C(189), UINT8_C(209), UINT8_C( 37), UINT8_C(130),
        UINT8_C(236), UINT8_C(211), UINT8_C( 99), UINT8_C( 89), UINT8_C(238), UINT8_C(244), UINT8_C( 88), UINT8_C(174),
        UINT8_C(151), UINT8_C(166), UINT8_C(170), UINT8_C(217), UINT8_C(236), UINT8_C( 12), UINT8_C(202), UINT8_C(240),
        UINT8_C( 99), UINT8_C( 22), UINT8_C(156), UINT8_C(213), UINT8_C( 21), UINT8_C(206), UINT8_C( 40), UINT8_C(135),
        UINT8_C(176), UINT8_C( 55), UINT8_C(163), UINT8_C(109), UINT8_C(  8), UINT8_C(201), UINT8_C(240), UINT8_C(244),
        UINT8_C(156), UINT8_C( 83), UINT8_C( 77), UINT8_C(138), UINT8_C( 71), UINT8_C(165), UINT8_C( 56), UINT8_C(223),
        UINT8_C( 75), UINT8_C(226), UINT8_C(184), UINT8_C( 55), UINT8_C(238), UINT8_C(130), UINT8_C( 39), UINT8_C( 82) },
      { UINT8_C(152), UINT8_C(196), UINT8_C( 39), UINT8_C(173), UINT8_C(146), UINT8_C( 79), UINT8_C( 53), UINT8_C( 66),
        UINT8_C(134), UINT8_C(216), UINT8_C(176), UINT8_C(142), UINT8_C(161), UINT8_C(160), UINT8_C(130), UINT8_C( 62),
        UINT8_C(243), UINT8_C(207), UINT8_C(200), UINT8_C( 59), UINT8_C(116), UINT8_C(  1), UINT8_C( 26), UINT8_C(191),
        UINT8_C(227), UINT8_C(210), UINT8_C(246), UINT8_C(210), UINT8_C( 85), UINT8_C( 30), UINT8_C( 36), UINT8_C(237),
        UINT8_C(226), UINT8_C( 75), UINT8_C(155), UINT8_C(116), UINT8_C(155), UINT8_C(208), UINT8_C(183), UINT8_C( 33),
        UINT8_C(168), UINT8_C(103), UINT8_C(176), UINT8_C( 74), UINT8_C(  7), UINT8_C( 50), UINT8_C(136), UINT8_C(250),
        UINT8_C(  2), UINT8_C( 80), UINT8_C( 53), UINT8_C(118), UINT8_C( 81), UINT8_C( 79), UINT8_C( 54), UINT8_C( 53),
        UINT8_C( 34), UINT8_C( 44), UINT8_C(  7), UINT8_C(119), UINT8_C( 74), UINT8_C( 43), UINT8_C(100), UINT8_C( 44) },
      { UINT64_C(                 522), UINT64_C(                 542), UINT64_C(                 586), UINT64_C(                 541),
        UINT64_C(                 659), UINT64_C(                 366), UINT64_C(                 469), UINT64_C(                 814) } },
    { { UINT8_C(118),    UINT8_MAX, UINT8_C(161), UINT8_C( 17), UINT8_C(207), UINT8_C( 88), UINT8_C( 51), UINT8_C(120),
        UINT8_C(191), UINT8_C(227), UINT8_C(194), UINT8_C(198), UINT8_C( 21), UINT8_C( 74), UINT8_C(192), UINT8_C( 23),
        UINT8_C(154), UINT8_C(246), UINT8_C(142), UINT8_C(236), UINT8_C( 69), UINT8_C(196), UINT8_C( 33), UINT8_C(103),
        UINT8_C(240), UINT8_C( 40), UINT8_C(222), UINT8_C( 59), UINT8_C( 83), UINT8_C( 67), UINT8_C(103), UINT8_C(201),
        UINT8_C( 66), UINT8_C(  8), UINT8_C(219), UINT8_C( 18), UINT8_C( 96), UINT8_C( 14), UINT8_C(138), UINT8_C( 31),
        UINT8_C(241), UINT8_C( 76), UINT8_C(229), UINT8_C(  6), UINT8_C(150), UINT8_C(166), UINT8_C( 30), UINT8_C( 48),
        UINT8_C(156), UINT8_C(172), UINT8_C( 28), UINT8_C(225), UINT8_C(112), UINT8_C( 61), UINT8_C( 73), UINT8_C( 96),
        UINT8_C(101), UINT8_C( 39), UINT8_C(155), UINT8_C(184), UINT8_C(106), UINT8_C(  3), UINT8_C(130), UINT8_C(173) },
      { UINT8_C( 11), UINT8_C( 93), UINT8_C(191), UINT8_C(108), UINT8_C(107), UINT8_C( 73), UINT8_C(139), UINT8_C( 92),
        UINT8_C(149), UINT8_C(113), UINT8_C( 98), UINT8_C( 43), UINT8_C( 23), UINT8_C(128), UINT8_C( 91), UINT8_C(179),
        UINT8_C( 44), UINT8_C(120), UINT8_C(148), UINT8_C(156), UINT8_C(181), UINT8_C(221), UINT8_C(253), UINT8_C( 27),
        UINT8_C(  5), UINT8_C(152), UINT8_C(211), UINT8_C(111), UINT8_C(155), UINT8_C( 85), UINT8_C( 28), UINT8_C(167),
        UINT8_C(178), UINT8_C(219), UINT8_C( 19), UINT8_C( 29), UINT8_C( 36), UINT8_C(158), UINT8_C(121), UINT8_C(185),
        UINT8_C( 15), UINT8_C(220), UINT8_C(228), UINT8_C( 38), UINT8_C( 92), UINT8_C( 64), UINT8_C(217), UINT8_C(137),
        UINT8_C(184), UINT8_C(110), UINT8_C( 37), UINT8_C(109), UINT8_C( 75), UINT8_C( 34), UINT8_C(136), UINT8_C( 80),
        UINT8_C(187), UINT8_C( 92), UINT8_C(192), UINT8_C( 86), UINT8_C(177), UINT8_C(220), UINT8_C(253), UINT8_C(100) },
      { UINT64_C(                 621), UINT64_C(                 720), UINT64_C(                 755), UINT64_C(                 609),
        UINT64_C(                 909), UINT64_C(                 839), UINT64_C(                 358), UINT64_C(                 758) } },
    { { UINT8_C(184), UINT8_C( 16), UINT8_C(129), UINT8_C(220), UINT8_C(175), UINT8_C(251), UINT8_C(150), UINT8_C(190),
        UINT8_C(215), UINT8_C(122), UINT8_C(229), UINT8_C( 51), UINT8_C(186), UINT8_C(190), UINT8_C(188), UINT8_C(114),
        UINT8_C( 44), UINT8_C(226), UINT8_C(224), UINT8_C(120), UINT8_C(  4), UINT8_C(104), UINT8_C(200), UINT8_C(191),
        UINT8_C(196), UINT8_C(136), UINT8_C( 22), UINT8_C(118), UINT8_C(101), UINT8_C( 19), UINT8_C(218), UINT8_C( 29),
        UINT8_C( 36), UINT8_C( 91), UINT8_C(249), UINT8_C(211), UINT8_C( 86), UINT8_C(143), UINT8_C(145), UINT8_C( 45),
        UINT8_C( 10), UINT8_C(118), UINT8_C( 97), UINT8_C(196), UINT8_C( 53), UINT8_C( 29), UINT8_C( 55), UINT8_C( 97),
           UINT8_MAX, UINT8_C( 23), UINT8_C(217), UINT8_C(  4), UINT8_C(127), UINT8_C(162), UINT8_C(195), UINT8_C( 68),
        UINT8_C( 42), UINT8_C(217), UINT8_C(186), UINT8_C(143), UINT8_C(237), UINT8_C(148), UINT8_C(172), UINT8_C( 17) },
      { UINT8_C(239), UINT8_C(166), UINT8_C(228), UINT8_C( 70), UINT8_C( 53), UINT8_C(117), UINT8_C(115), UINT8_C( 63),
        UINT8_C(236), UINT8_C(212), UINT8_C(  4), UINT8_C( 33), UINT8_C(242), UINT8_C( 59), UINT8_C(130), UINT8_C(241),
        UINT8_C( 82), UINT8_C( 92), UINT8_C(245), UINT8_C(209), UINT8_C(254), UINT8_C(185), UINT8_C( 21), UINT8_C( 40),
        UINT8_C(146), UINT8_C(207), UINT8_C(184), UINT8_C(127), UINT8_C( 99), UINT8_C(100), UINT8_C(144), UINT8_C( 83),
        UINT8_C( 10), UINT8_C(116), UINT8_C(153), UINT8_C( 64), UINT8_C(234), UINT8_C( 12), UINT8_C(127), UINT8_C(214),
        UINT8_C(225), UINT8_C(131), UINT8_C(247), UINT8_C(211), UINT8_C(190), UINT8_C(121), UINT8_C(196), UINT8_C( 16),
        UINT8_C(213), UINT8_C(186), UINT8_C(226), UINT8_C(211), UINT8_C(115), UINT8_C(247), UINT8_C(252), UINT8_C(  5),
        UINT8_C(199), UINT8_C(180), UINT8_C(133), UINT8_C( 42), UINT8_C( 24), UINT8_C( 21), UINT8_C(125), UINT8_C( 35) },
      { UINT64_C(                 872), UINT64_C(                 726), UINT64_C(                 943), UINT64_C(                 503),
        UINT64_C(                 760), UINT64_C(                 844), UINT64_C(                 638), UINT64_C(                 753) } },
    { { UINT8_C(138), UINT8_C( 22), UINT8_C( 99), UINT8_C(116), UINT8_C( 35), UINT8_C(226), UINT8_C( 74), UINT8_C(  4),
        UINT8_C(102), UINT8_C( 65), UINT8_C(215), UINT8_C( 36), UINT8_C(186), UINT8_C(155), UINT8_C( 53), UINT8_C(144),
        UINT8_C( 85), UINT8_C( 23), UINT8_C( 99), UINT8_C(200), UINT8_C( 14), UINT8_C( 95), UINT8_C(206), UINT8_C(213),
        UINT8_C( 19), UINT8_C( 83), UINT8_C(  0), UINT8_C( 44), UINT8_C(104), UINT8_C(125), UINT8_C( 79), UINT8_C(242),
        UINT8_C(148), UINT8_C(178), UINT8_C(102), UINT8_C(183), UINT8_C(148), UINT8_C(176), UINT8_C(187), UINT8_C(250),
        UINT8_C(241), UINT8_C(146), UINT8_C( 31), UINT8_C(172), UINT8_C( 45), UINT8_C( 84), UINT8_C( 60), UINT8_C(131),
        UINT8_C(107), UINT8_C(159), UINT8_C( 75), UINT8_C(121),    UINT8_MAX, UINT8_C( 25), UINT8_C( 79), UINT8_C( 18),
        UINT8_C(108), UINT8_C( 79), UINT8_C( 62), UINT8_C(213), UINT8_C(204), UINT8_C(141), UINT8_C(199), UINT8_C( 96) },
      { UINT8_C( 63), UINT8_C( 46), UINT8_C( 23), UINT8_C(212), UINT8_C(222), UINT8_C(210), UINT8_C(206), UINT8_C(208),
        UINT8_C(100), UINT8_C(237), UINT8_C(124), UINT8_C(146), UINT8_C( 65), UINT8_C(184), UINT8_C( 21), UINT8_C(172),
        UINT8_C( 87), UINT8_C( 96), UINT8_C( 38), UINT8_C( 86), UINT8_C(122), UINT8_C(117), UINT8_C(105), UINT8_C(230),
        UINT8_C(196), UINT8_C(167), UINT8_C(187), UINT8_C(144), UINT8_C( 53), UINT8_C(131), UINT8_C(241), UINT8_C(116),
        UINT8_C(177), UINT8_C(  8), UINT8_C( 72), UINT8_C(143), UINT8_C(219), UINT8_C( 23), UINT8_C( 95), UINT8_C( 63),
        UINT8_C(  4), UINT8_C(219), UINT8_C(209), UINT8_C( 70), UINT8_C(147), UINT8_C(230), UINT8_C(242), UINT8_C(235),
        UINT8_C( 71), UINT8_C( 24), UINT8_C( 65), UINT8_C(193), UINT8_C(141), UINT8_C(170), UINT8_C(167), UINT8_C( 81),
        UINT8_C( 82), UINT8_C( 99), UINT8_C(226), UINT8_C(135), UINT8_C(230), UINT8_C(211), UINT8_C(251), UINT8_C(151) },
      { UINT64_C(                 810), UINT64_C(                 585), UINT64_C(                 498), UINT64_C(                 893),
        UINT64_C(                 772), UINT64_C(                1124), UINT64_C(                 663), UINT64_C(                 491) } },
    { { UINT8_C(219), UINT8_C( 68), UINT8_C( 38), UINT8_C(182), UINT8_C( 91), UINT8_C(134), UINT8_C(246), UINT8_C( 95),
        UINT8_C( 97), UINT8_C(199), UINT8_C(165), UINT8_C(245), UINT8_C(174), UINT8_C(152), UINT8_C(224), UINT8_C(245),
        UINT8_C(176), UINT8_C( 33), UINT8_C(182), UINT8_C( 62), UINT8_C(204), UINT8_C( 93), UINT8_C(143), UINT8_C( 30),
        UINT8_C(192), UINT8_C(113), UINT8_C(165), UINT8_C(166), UINT8_C( 68), UINT8_C(160), UINT8_C( 61), UINT8_C( 32),
        UINT8_C(228), UINT8_C(100), UINT8_C(214), UINT8_C( 63), UINT8_C(234), UINT8_C(204), UINT8_C(159), UINT8_C( 75),
        UINT8_C(148), UINT8_C( 68), UINT8_C( 64), UINT8_C( 66), UINT8_C(220), UINT8_C( 32), UINT8_C( 55), UINT8_C(141),
        UINT8_C( 66), UINT8_C(237), UINT8_C(203), UINT8_C( 14), UINT8_C( 74), UINT8_C( 90), UINT8_C( 44), UINT8_C( 11),
        UINT8_C(204), UINT8_C(209), UINT8_C(177), UINT8_C( 16), UINT8_C(113), UINT8_C(239), UINT8_C( 48), UINT8_C( 86) },
      { UINT8_C( 83), UINT8_C(  7), UINT8_C(149), UINT8_C( 61), UINT8_C(211), UINT8_C( 52), UINT8_C(136), UINT8_C(103),
        UINT8_C(121), UINT8_C(201), UINT8_C(169), UINT8_C( 85), UINT8_C(233), UINT8_C(224), UINT8_C(226), UINT8_C( 43),
        UINT8_C(205), UINT8_C(173), UINT8_C( 57), UINT8_C( 24), UINT8_C(  8), UINT8_C(101), UINT8_C( 35), UINT8_C(212),
        UINT8_C( 54), UINT8_C(212), UINT8_C(228), UINT8_C(168), UINT8_C(195), UINT8_C( 21), UINT8_C(254), UINT8_C( 22),
        UINT8_C( 28), UINT8_C(147), UINT8_C( 83), UINT8_C(239), UINT8_C(200), UINT8_C(220), UINT8_C( 87), UINT8_C( 65),
        UINT8_C(165), UINT8_C(  0), UINT8_C(150), UINT8_C(142), UINT8_C(225), UINT8_C(121), UINT8_C(186), UINT8_C(174),
        UINT8_C( 38), UINT8_C(243), UINT8_C(198), UINT8_C( 46), UINT8_C( 89), UINT8_C(233), UINT8_C(  2), UINT8_C(143),
        UINT8_C(190), UINT8_C(231), UINT8_C( 55), UINT8_C(129), UINT8_C(252), UINT8_C( 53), UINT8_C(152), UINT8_C( 24) },
      { UINT64_C(                 749), UINT64_C(                 525), UINT64_C(                 826), UINT64_C(                 771),
        UINT64_C(                 686), UINT64_C(                 505), UINT64_C(                 403), UINT64_C(                 762) } },
    { { UINT8_C(201), UINT8_C(235), UINT8_C(  7), UINT8_C(145), UINT8_C(199), UINT8_C( 94), UINT8_C(210), UINT8_C(108),
        UINT8_C( 95), UINT8_C(104), UINT8_C(251), UINT8_C( 64), UINT8_C(225), UINT8_C(181), UINT8_C(238), UINT8_C(  8),
        UINT8_C(168), UINT8_C(181), UINT8_C( 54), UINT8_C(  1), UINT8_C(158), UINT8_C( 57), UINT8_C(145), UINT8_C( 92),
        UINT8_C( 32), UINT8_C(200), UINT8_C(222), UINT8_C( 28), UINT8_C(254), UINT8_C(118), UINT8_C( 52), UINT8_C(199),
        UINT8_C( 97), UINT8_C( 59), UINT8_C( 88), UINT8_C( 41), UINT8_C(154), UINT8_C( 42), UINT8_C(149), UINT8_C(249),
        UINT8_C(146), UINT8_C(144), UINT8_C( 57), UINT8_C(116), UINT8_C( 69), UINT8_C( 39), UINT8_C(124), UINT8_C(238),
        UINT8_C(220), UINT8_C(178), UINT8_C(239), UINT8_C(123), UINT8_C(235), UINT8_C(128), UINT8_C(215), UINT8_C( 11),
        UINT8_C( 73), UINT8_C(181), UINT8_C( 39), UINT8_C( 71), UINT8_C( 43), UINT8_C( 91), UINT8_C( 14), UINT8_C(141) },
      { UINT8_C(151), UINT8_C(102), UINT8_C(182), UINT8_C( 49), UINT8_C(144), UINT8_C( 75), UINT8_C( 42), UINT8_C( 34),
        UINT8_C(220), UINT8_C( 99), UINT8_C(150), UINT8_C( 33), UINT8_C(138), UINT8_C( 18), UINT8_C( 15), UINT8_C(103),
        UINT8_C(197),    UINT8_MAX, UINT8_C(226), UINT8_C(176), UINT8_C(127), UINT8_C(185), UINT8_C(188), UINT8_C(200),
        UINT8_C(111), UINT8_C(227), UINT8_C( 15), UINT8_C(154), UINT8_C( 63), UINT8_C( 29), UINT8_C( 39), UINT8_C(214),
        UINT8_C(131), UINT8_C(221), UINT8_C(  7), UINT8_C( 19), UINT8_C( 41), UINT8_C( 49), UINT8_C( 54), UINT8_C(  5),
        UINT8_C(148), UINT8_C(204), UINT8_C( 38), UINT8_C( 30), UINT8_C(223), UINT8_C( 54), UINT8_C(133), UINT8_C(164),
        UINT8_C( 53), UINT8_C(103), UINT8_C( 84), UINT8_C(180), UINT8_C( 33), UINT8_C( 16), UINT8_C(125), UINT8_C(144),
        UINT8_C(244), UINT8_C(140), UINT8_C( 42), UINT8_C( 51), UINT8_C(170), UINT8_C( 82), UINT8_C(  9), UINT8_C( 45) },
      { UINT64_C(                 770), UINT64_C(                 830), UINT64_C(                 760), UINT64_C(                 747),
        UINT64_C(                 758), UINT64_C(                 419), UINT64_C(                 991), UINT64_C(                 472) } },
    { { UINT8_C( 47), UINT8_C( 16), UINT8_C( 65), UINT8_C( 88), UINT8_C( 65), UINT8_C(119), UINT8_C( 93), UINT8_C(213),
        UINT8_C( 67), UINT8_C(132), UINT8_C(243), UINT8_C( 34), UINT8_C(186), UINT8_C(121), UINT8_C(198), UINT8_C(239),
        UINT8_C(224), UINT8_C( 27), UINT8_C(163), UINT8_C(  1), UINT8_C( 43), UINT8_C( 32), UINT8_C(145), UINT8_C( 31),
        UINT8_C(173), UINT8_C(188), UINT8_C( 82), UINT8_C( 87), UINT8_C( 14), UINT8_C( 91), UINT8_C(132), UINT8_C( 61),
        UINT8_C(107), UINT8_C(197), UINT8_C(150), UINT8_C(172), UINT8_C( 60), UINT8_C(243), UINT8_C(129), UINT8_C(128),
        UINT8_C(119), UINT8_C(117), UINT8_C(162), UINT8_C( 49), UINT8_C(238), UINT8_C(105), UINT8_C( 32), UINT8_C(206),
        UINT8_C(132), UINT8_C(196), UINT8_C(208), UINT8_C(175), UINT8_C(228), UINT8_C( 97), UINT8_C(207), UINT8_C(145),
        UINT8_C( 29), UINT8_C( 33), UINT8_C(232), UINT8_C( 43), UINT8_C(125), UINT8_C(109), UINT8_C(105), UINT8_C(232) },
      { UINT8_C( 50),    UINT8_MAX, UINT8_C(149), UINT8_C(111), UINT8_C(242), UINT8_C( 22), UINT8_C(239), UINT8_C(106),
        UINT8_C(139), UINT8_C(145), UINT8_C(155), UINT8_C(121), UINT8_C(250), UINT8_C(188), UINT8_C( 72), UINT8_C(126),
        UINT8_C(128), UINT8_C( 24), UINT8_C( 46), UINT8_C(100), UINT8_C(121), UINT8_C(253), UINT8_C(246), UINT8_C(151),
        UINT8_C( 30), UINT8_C(222), UINT8_C(194), UINT8_C(155), UINT8_C( 75), UINT8_C( 43), UINT8_C(132), UINT8_C(126),
        UINT8_C( 42), UINT8_C( 25), UINT8_C(237), UINT8_C( 29), UINT8_C( 47), UINT8_C(220), UINT8_C(135), UINT8_C(187),
        UINT8_C(109), UINT8_C( 34), UINT8_C( 52), UINT8_C(104), UINT8_C(222), UINT8_C(124), UINT8_C(230), UINT8_C( 94),
        UINT8_C(148), UINT8_C( 20), UINT8_C(195), UINT8_C( 14), UINT8_C( 17), UINT8_C(185), UINT8_C(165), UINT8_C( 48),
        UINT8_C(151), UINT8_C(103), UINT8_C(203), UINT8_C(227), UINT8_C(147), UINT8_C( 79), UINT8_C( 97), UINT8_C(189) },
      { UINT64_C(                 876), UINT64_C(                 630), UINT64_C(                 835), UINT64_C(                 531),
        UINT64_C(                 568), UINT64_C(                 603), UINT64_C(                 804), UINT64_C(                 508) } }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
    simde__m512i a = simde_mm512_loadu_epi8(test_vec[i].a);
    simde__m512i b = simde_mm512_loadu_epi8(test_vec[i].b);
    simde__m512i r = simde_mm512_sad_epu8(a, b);
    simde_test_x86_assert_equal_u64x8(r, simde_mm512_loadu_epi64(test_vec[i].r));
  }

  return 0;
}

static int
test_simde_mm512_sll_epi16 (SIMDE_MUNIT_TEST_ARGS) {
  static const struct {
    const int16_t a[32];
    const int64_t b[2];
    const int16_t r[32];
  } test_vec[] = {
    { { -INT16_C( 11176), -INT16_C( 31146),  INT16_C( 31553),  INT16_C(    68),  INT16_C(   109), -INT16_C(  6231), -INT16_C( 28515),  INT16_C(  4842),
        -INT16_C(  8039), -INT16_C( 26148), -INT16_C( 31237),  INT16_C( 19279), -INT16_C(  2919), -INT16_C( 17167),  INT16_C( 24677), -INT16_C( 16888),
         INT16_C( 24116),  INT16_C( 30020), -INT16_C( 30246),  INT16_C( 18294),  INT16_C(  8073),  INT16_C( 10031),  INT16_C(  6575),  INT16_C( 18489),
         INT16_C(  5625), -INT16_C(  2847),  INT16_C( 12442),  INT16_C( 13375),  INT16_C( 12324), -INT16_C( 29968), -INT16_C(  1903), -INT16_C( 15032) },
      {  INT64_C(                  19),  INT64_C(                  23) },
      {  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0) } },
    { { -INT16_C( 22508), -INT16_C( 20817), -INT16_C(  4391), -INT16_C(   542), -INT16_C( 11489), -INT16_C( 20345), -INT16_C( 12341),  INT16_C(  8821),
        -INT16_C( 20388),  INT16_C( 29011), -INT16_C( 13215),  INT16_C( 12560), -INT16_C( 10637),  INT16_C( 13488),  INT16_C( 30677), -INT16_C(  5649),
        -INT16_C( 25056), -INT16_C(  1640),  INT16_C( 31372), -INT16_C( 21514),  INT16_C( 32333),  INT16_C(  6491), -INT16_C( 11955), -INT16_C( 22213),
        -INT16_C( 28799), -INT16_C(  7397),  INT16_C( 11099), -INT16_C( 12780), -INT16_C( 15102), -INT16_C( 10493), -INT16_C(  3524),  INT16_C( 23745) },
      {  INT64_C(                   4),  INT64_C(                  14) },
      { -INT16_C( 32448), -INT16_C(  5392), -INT16_C(  4720), -INT16_C(  8672),  INT16_C( 12784),  INT16_C(  2160), -INT16_C(   848),  INT16_C( 10064),
         INT16_C(  1472),  INT16_C(  5424), -INT16_C( 14832),  INT16_C(  4352),  INT16_C( 26416),  INT16_C( 19200),  INT16_C( 32080), -INT16_C( 24848),
        -INT16_C(  7680), -INT16_C( 26240), -INT16_C( 22336), -INT16_C( 16544), -INT16_C(  6960), -INT16_C( 27216),  INT16_C(  5328), -INT16_C( 27728),
        -INT16_C(  2032),  INT16_C( 12720), -INT16_C( 19024), -INT16_C(  7872),  INT16_C( 20512),  INT16_C( 28720),  INT16_C(  9152), -INT16_C( 13296) } },
    { { -INT16_C(  9212),  INT16_C( 24409),  INT16_C( 27911),  INT16_C(  2350),  INT16_C( 12594),  INT16_C( 28641), -INT16_C( 24029), -INT16_C( 19509),
         INT16_C(  8699), -INT16_C( 12593), -INT16_C( 26771),  INT16_C( 14319),  INT16_C( 10683), -INT16_C( 20658),  INT16_C(  3999), -INT16_C( 23771),
         INT16_C( 32491), -INT16_C(  3325),  INT16_C( 12780),  INT16_C(  7932), -INT16_C(  8862), -INT16_C( 31347),  INT16_C( 22911),  INT16_C( 31288),
         INT16_C(  1914), -INT16_C(  6327),  INT16_C( 14495),  INT16_C( 23070),  INT16_C( 27746),  INT16_C(   265),  INT16_C( 12156),  INT16_C( 26532) },
      {  INT64_C(                   7),  INT64_C(                   3) },
      {  INT16_C(   512), -INT16_C( 21376), -INT16_C( 31872), -INT16_C( 26880), -INT16_C( 26368), -INT16_C(  3968),  INT16_C(  4480), -INT16_C(  6784),
        -INT16_C(   640),  INT16_C( 26496), -INT16_C( 18816), -INT16_C(  2176), -INT16_C(  8832), -INT16_C( 22784), -INT16_C( 12416), -INT16_C( 28032),
         INT16_C( 30080), -INT16_C( 32384), -INT16_C(  2560),  INT16_C( 32256), -INT16_C( 20224), -INT16_C( 14720), -INT16_C( 16512),  INT16_C(  7168),
        -INT16_C( 17152), -INT16_C( 23424),  INT16_C( 20352),  INT16_C(  3840),  INT16_C( 12544), -INT16_C( 31616), -INT16_C( 16896), -INT16_C( 11776) } },
    { {  INT16_C( 30719), -INT16_C( 24833),  INT16_C(  7600),  INT16_C(  4856),  INT16_C(   394),  INT16_C(  1555), -INT16_C( 18640), -INT16_C(  8595),
        -INT16_C( 14241),  INT16_C( 14199),  INT16_C( 12063),  INT16_C( 21362),  INT16_C( 12661),  INT16_C(  4871),  INT16_C( 13865),  INT16_C( 10284),
         INT16_C( 11181),  INT16_C( 24006), -INT16_C( 16823), -INT16_C( 11409), -INT16_C( 32065), -INT16_C(  3879),  INT16_C( 17978), -INT16_C( 26162),
         INT16_C( 17678),  INT16_C( 11728),  INT16_C( 17013), -INT16_C(  5503), -INT16_C( 30604), -INT16_C( 25091),  INT16_C( 10686),  INT16_C( 27845) },
      {  INT64_C(                   1),  INT64_C(                  19) },
      { -INT16_C(  4098),  INT16_C( 15870),  INT16_C( 15200),  INT16_C(  9712),  INT16_C(   788),  INT16_C(  3110),  INT16_C( 28256), -INT16_C( 17190),
        -INT16_C( 28482),  INT16_C( 28398),  INT16_C( 24126), -INT16_C( 22812),  INT16_C( 25322),  INT16_C(  9742),  INT16_C( 27730),  INT16_C( 20568),
         INT16_C( 22362), -INT16_C( 17524),  INT16_C( 31890), -INT16_C( 22818),  INT16_C(  1406), -INT16_C(  7758), -INT16_C( 29580),  INT16_C( 13212),
        -INT16_C( 30180),  INT16_C( 23456), -INT16_C( 31510), -INT16_C( 11006),  INT16_C(  4328),  INT16_C( 15354),  INT16_C( 21372), -INT16_C(  9846) } },
    { {  INT16_C( 24332), -INT16_C( 32308),  INT16_C( 19873),  INT16_C(  5483),  INT16_C( 26838), -INT16_C( 27470),  INT16_C( 30610), -INT16_C(  6400),
        -INT16_C( 13822),  INT16_C( 19333), -INT16_C(  2557), -INT16_C( 16812),  INT16_C( 19520), -INT16_C( 12108),  INT16_C( 16915),  INT16_C(  8047),
         INT16_C( 15521),  INT16_C( 17312),  INT16_C(  2953),  INT16_C( 24408),  INT16_C(  2931),  INT16_C(  1524), -INT16_C(  2942), -INT16_C( 31252),
         INT16_C( 29118), -INT16_C( 15920),  INT16_C(  9319), -INT16_C( 22656),  INT16_C( 13425), -INT16_C( 31624), -INT16_C(  6282),  INT16_C(  6307) },
      {  INT64_C(                  24),  INT64_C(                  22) },
      {  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0) } },
    { { -INT16_C( 27099), -INT16_C( 29579), -INT16_C(  2629),  INT16_C( 11316), -INT16_C( 21463), -INT16_C( 24656),  INT16_C( 21395), -INT16_C( 18505),
         INT16_C(  4758), -INT16_C(  7068),  INT16_C( 28870), -INT16_C( 31579),  INT16_C( 27761),  INT16_C( 26309), -INT16_C( 29920),  INT16_C( 17689),
        -INT16_C( 29150), -INT16_C(  8751),  INT16_C(  1411), -INT16_C( 21495), -INT16_C( 17999),  INT16_C( 17740),  INT16_C(   780), -INT16_C( 23812),
         INT16_C( 24598), -INT16_C(  9082),  INT16_C( 11216),  INT16_C( 16736),  INT16_C(  9880), -INT16_C( 18265), -INT16_C( 15951), -INT16_C( 11267) },
      {  INT64_C(                  16),  INT64_C(                  28) },
      {  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0) } },
    { { -INT16_C( 23002), -INT16_C(  2111),  INT16_C(  8658),  INT16_C( 27192), -INT16_C(  8121), -INT16_C(  1758),  INT16_C(  8097), -INT16_C(  3892),
         INT16_C( 32237), -INT16_C( 15933),  INT16_C( 17206), -INT16_C( 22201),  INT16_C(  4366), -INT16_C(  8921),  INT16_C( 18648), -INT16_C(   318),
        -INT16_C( 31762), -INT16_C( 16139),  INT16_C( 11941), -INT16_C(  5078),  INT16_C( 19470), -INT16_C( 20507), -INT16_C( 19861),  INT16_C( 22943),
         INT16_C( 25391),  INT16_C( 25882),  INT16_C( 24998), -INT16_C( 19442),  INT16_C( 13939),  INT16_C( 19346),  INT16_C( 21630),  INT16_C( 27721) },
      {  INT64_C(                  15),  INT64_C(                   6) },
      {  INT16_C(     0),       INT16_MIN,  INT16_C(     0),  INT16_C(     0),       INT16_MIN,  INT16_C(     0),       INT16_MIN,  INT16_C(     0),
              INT16_MIN,       INT16_MIN,  INT16_C(     0),       INT16_MIN,  INT16_C(     0),       INT16_MIN,  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),       INT16_MIN,       INT16_MIN,  INT16_C(     0),  INT16_C(     0),       INT16_MIN,       INT16_MIN,       INT16_MIN,
              INT16_MIN,  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),       INT16_MIN,  INT16_C(     0),  INT16_C(     0),       INT16_MIN } },
    { { -INT16_C( 31956), -INT16_C( 11627), -INT16_C( 23324),  INT16_C( 22407),  INT16_C(  6618),  INT16_C( 22690), -INT16_C(  5011),  INT16_C( 17860),
        -INT16_C(  3797), -INT16_C( 26430),  INT16_C( 11337), -INT16_C(  4845),  INT16_C( 15739),  INT16_C( 31996),  INT16_C( 25862),  INT16_C( 13228),
         INT16_C( 16872), -INT16_C( 13307), -INT16_C( 29467), -INT16_C( 16604), -INT16_C( 14683),  INT16_C(  4887), -INT16_C(  9038), -INT16_C(  8872),
         INT16_C(  7117),  INT16_C(  5749), -INT16_C( 30649), -INT16_C( 15869),  INT16_C(   197), -INT16_C( 13250), -INT16_C(  5531),  INT16_C( 19967) },
      {  INT64_C(                   6),  INT64_C(                  18) },
      { -INT16_C( 13568), -INT16_C( 23232),  INT16_C( 14592), -INT16_C(  7744),  INT16_C( 30336),  INT16_C( 10368),  INT16_C(  6976),  INT16_C( 28928),
         INT16_C( 19136),  INT16_C( 12416),  INT16_C(  4672),  INT16_C( 17600),  INT16_C( 24256),  INT16_C( 16128),  INT16_C( 16768), -INT16_C(  5376),
         INT16_C( 31232),  INT16_C(   320),  INT16_C( 14656), -INT16_C( 14080), -INT16_C( 22208), -INT16_C( 14912),  INT16_C( 11392),  INT16_C( 22016),
        -INT16_C(  3264), -INT16_C( 25280),  INT16_C(  4544), -INT16_C( 32576),  INT16_C( 12608),  INT16_C(  3968), -INT16_C( 26304),  INT16_C( 32704) } }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
    simde__m512i a = simde_mm512_loadu_epi16(test_vec[i].a);
    simde__m128i b = simde_x_mm_loadu_epi64(test_vec[i].b);
    simde__m512i r = simde_mm512_sll_epi16(a, b);
    simde_test_x86_assert_equal_i16x32(r, simde_mm512_loadu_epi16(test_vec[i].r));
  }

  return 0;
}

static int
test_simde_mm512_slli_epi16 (SIMDE_MUNIT_TEST_ARGS) {
  static const struct {
    const int16_t a[32];
    const int16_t r0[32];
    const int16_t r3[32];
    const int16_t r7[32];
    const int16_t r13[32];
    const int16_t r24[32];
  } test_vec[] = {
    { { -INT16_C(  4513), -INT16_C( 32064), -INT16_C( 20539),  INT16_C( 16953), -INT16_C( 19443),  INT16_C(  8904),  INT16_C( 17111), -INT16_C( 18058),
         INT16_C(  9034), -INT16_C( 18739), -INT16_C( 25271),  INT16_C(  4847), -INT16_C( 27918), -INT16_C(  9400), -INT16_C(  4204), -INT16_C(  3107),
        -INT16_C( 24867), -INT16_C( 23691), -INT16_C( 20915),  INT16_C( 23269), -INT16_C( 21149),  INT16_C( 14973), -INT16_C(  3088),  INT16_C( 15091),
        -INT16_C( 16362),  INT16_C( 24561), -INT16_C(  8099),  INT16_C( 20594), -INT16_C( 17806),  INT16_C(  1579),  INT16_C(  2218), -INT16_C( 30727) },
      { -INT16_C(  4513), -INT16_C( 32064), -INT16_C( 20539),  INT16_C( 16953), -INT16_C( 19443),  INT16_C(  8904),  INT16_C( 17111), -INT16_C( 18058),
         INT16_C(  9034), -INT16_C( 18739), -INT16_C( 25271),  INT16_C(  4847), -INT16_C( 27918), -INT16_C(  9400), -INT16_C(  4204), -INT16_C(  3107),
        -INT16_C( 24867), -INT16_C( 23691), -INT16_C( 20915),  INT16_C( 23269), -INT16_C( 21149),  INT16_C( 14973), -INT16_C(  3088),  INT16_C( 15091),
        -INT16_C( 16362),  INT16_C( 24561), -INT16_C(  8099),  INT16_C( 20594), -INT16_C( 17806),  INT16_C(  1579),  INT16_C(  2218), -INT16_C( 30727) },
      {  INT16_C( 29432),  INT16_C(  5632),  INT16_C( 32296),  INT16_C(  4552), -INT16_C( 24472),  INT16_C(  5696),  INT16_C(  5816), -INT16_C( 13392),
         INT16_C(  6736), -INT16_C( 18840), -INT16_C(  5560), -INT16_C( 26760), -INT16_C( 26736), -INT16_C(  9664),  INT16_C( 31904), -INT16_C( 24856),
        -INT16_C(  2328),  INT16_C(  7080),  INT16_C( 29288), -INT16_C( 10456),  INT16_C( 27416), -INT16_C( 11288), -INT16_C( 24704), -INT16_C( 10344),
         INT16_C(   176), -INT16_C(   120),  INT16_C(   744), -INT16_C( 31856), -INT16_C( 11376),  INT16_C( 12632),  INT16_C( 17744),  INT16_C( 16328) },
      {  INT16_C( 12160),  INT16_C( 24576), -INT16_C(  7552),  INT16_C(  7296),  INT16_C(  1664),  INT16_C( 25600),  INT16_C( 27520), -INT16_C( 17664),
        -INT16_C( 23296),  INT16_C( 26240), -INT16_C( 23424),  INT16_C( 30592),  INT16_C( 30976), -INT16_C( 23552), -INT16_C( 13824), -INT16_C(  4480),
         INT16_C( 28288), -INT16_C( 17792),  INT16_C(  9856),  INT16_C( 29312), -INT16_C( 20096),  INT16_C( 16000), -INT16_C(  2048),  INT16_C( 31104),
         INT16_C(  2816), -INT16_C(  1920),  INT16_C( 11904),  INT16_C( 14592),  INT16_C( 14592),  INT16_C(  5504),  INT16_C( 21760), -INT16_C(   896) },
      { -INT16_C(  8192),  INT16_C(     0), -INT16_C( 24576),  INT16_C(  8192), -INT16_C( 24576),  INT16_C(     0), -INT16_C(  8192), -INT16_C( 16384),
         INT16_C( 16384), -INT16_C( 24576),  INT16_C(  8192), -INT16_C(  8192),  INT16_C( 16384),  INT16_C(     0),       INT16_MIN, -INT16_C( 24576),
        -INT16_C( 24576), -INT16_C( 24576), -INT16_C( 24576), -INT16_C( 24576),  INT16_C( 24576), -INT16_C( 24576),  INT16_C(     0),  INT16_C( 24576),
        -INT16_C( 16384),  INT16_C(  8192), -INT16_C( 24576),  INT16_C( 16384),  INT16_C( 16384),  INT16_C( 24576),  INT16_C( 16384),  INT16_C(  8192) },
      {  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0) } },
    { {  INT16_C( 28582), -INT16_C(  3030),  INT16_C(  3869), -INT16_C( 32690), -INT16_C( 13379), -INT16_C( 21062), -INT16_C( 20801), -INT16_C( 10777),
        -INT16_C( 10130), -INT16_C( 13259), -INT16_C( 22600),  INT16_C( 11036),  INT16_C( 18273),  INT16_C(  2865),  INT16_C( 11087), -INT16_C(  2413),
        -INT16_C( 16998), -INT16_C( 18454),  INT16_C( 14541), -INT16_C( 30152), -INT16_C(  3580), -INT16_C( 15561),  INT16_C(  7840),  INT16_C(  3992),
        -INT16_C( 12809), -INT16_C( 20517), -INT16_C(  2188), -INT16_C( 10534),  INT16_C(  3134), -INT16_C( 29215),  INT16_C( 29751), -INT16_C( 11901) },
      {  INT16_C( 28582), -INT16_C(  3030),  INT16_C(  3869), -INT16_C( 32690), -INT16_C( 13379), -INT16_C( 21062), -INT16_C( 20801), -INT16_C( 10777),
        -INT16_C( 10130), -INT16_C( 13259), -INT16_C( 22600),  INT16_C( 11036),  INT16_C( 18273),  INT16_C(  2865),  INT16_C( 11087), -INT16_C(  2413),
        -INT16_C( 16998), -INT16_C( 18454),  INT16_C( 14541), -INT16_C( 30152), -INT16_C(  3580), -INT16_C( 15561),  INT16_C(  7840),  INT16_C(  3992),
        -INT16_C( 12809), -INT16_C( 20517), -INT16_C(  2188), -INT16_C( 10534),  INT16_C(  3134), -INT16_C( 29215),  INT16_C( 29751), -INT16_C( 11901) },
      {  INT16_C( 32048), -INT16_C( 24240),  INT16_C( 30952),  INT16_C(   624),  INT16_C( 24040),  INT16_C( 28112),  INT16_C( 30200), -INT16_C( 20680),
        -INT16_C( 15504),  INT16_C( 25000),  INT16_C( 15808),  INT16_C( 22752),  INT16_C( 15112),  INT16_C( 22920),  INT16_C( 23160), -INT16_C( 19304),
        -INT16_C(  4912), -INT16_C( 16560), -INT16_C( 14744),  INT16_C( 20928), -INT16_C( 28640),  INT16_C(  6584), -INT16_C(  2816),  INT16_C( 31936),
         INT16_C( 28600),  INT16_C( 32472), -INT16_C( 17504), -INT16_C( 18736),  INT16_C( 25072),  INT16_C( 28424), -INT16_C( 24136), -INT16_C( 29672) },
      { -INT16_C( 11520),  INT16_C(  5376), -INT16_C( 29056),  INT16_C(  9984), -INT16_C(  8576), -INT16_C(  8960),  INT16_C( 24448), -INT16_C(  3200),
         INT16_C( 14080),  INT16_C(  6784), -INT16_C(  9216), -INT16_C( 29184), -INT16_C( 20352), -INT16_C( 26496), -INT16_C( 22656),  INT16_C( 18816),
        -INT16_C( 13056), -INT16_C(  2816),  INT16_C( 26240),  INT16_C(  7168),  INT16_C(   512), -INT16_C( 25728),  INT16_C( 20480), -INT16_C( 13312),
        -INT16_C(  1152), -INT16_C(  4736), -INT16_C( 17920),  INT16_C( 27904),  INT16_C(  7936), -INT16_C(  3968),  INT16_C(  7040), -INT16_C( 16000) },
      { -INT16_C( 16384),  INT16_C( 16384), -INT16_C( 24576), -INT16_C( 16384), -INT16_C( 24576),  INT16_C( 16384), -INT16_C(  8192), -INT16_C(  8192),
        -INT16_C( 16384), -INT16_C( 24576),  INT16_C(     0),       INT16_MIN,  INT16_C(  8192),  INT16_C(  8192), -INT16_C(  8192),  INT16_C( 24576),
         INT16_C( 16384),  INT16_C( 16384), -INT16_C( 24576),  INT16_C(     0),       INT16_MIN, -INT16_C(  8192),  INT16_C(     0),  INT16_C(     0),
        -INT16_C(  8192),  INT16_C( 24576),       INT16_MIN,  INT16_C( 16384), -INT16_C( 16384),  INT16_C(  8192), -INT16_C(  8192),  INT16_C( 24576) },
      {  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0) } },
    { {  INT16_C( 27954), -INT16_C(   120), -INT16_C( 16218), -INT16_C( 21879), -INT16_C( 16205),  INT16_C( 21357),  INT16_C(  1502), -INT16_C( 10910),
         INT16_C( 15827),  INT16_C( 18309),  INT16_C( 24372),  INT16_C( 29213), -INT16_C(   149), -INT16_C( 24064), -INT16_C( 31885), -INT16_C( 23181),
        -INT16_C(   783), -INT16_C( 26716),  INT16_C( 11708),  INT16_C( 28481), -INT16_C( 20755), -INT16_C( 13117),  INT16_C(  9651), -INT16_C( 31071),
         INT16_C(  9827), -INT16_C( 26674), -INT16_C(  5242), -INT16_C(  3830),  INT16_C(  2794),  INT16_C( 24212),  INT16_C(  1933),  INT16_C( 32259) },
      {  INT16_C( 27954), -INT16_C(   120), -INT16_C( 16218), -INT16_C( 21879), -INT16_C( 16205),  INT16_C( 21357),  INT16_C(  1502), -INT16_C( 10910),
         INT16_C( 15827),  INT16_C( 18309),  INT16_C( 24372),  INT16_C( 29213), -INT16_C(   149), -INT16_C( 24064), -INT16_C( 31885), -INT16_C( 23181),
        -INT16_C(   783), -INT16_C( 26716),  INT16_C( 11708),  INT16_C( 28481), -INT16_C( 20755), -INT16_C( 13117),  INT16_C(  9651), -INT16_C( 31071),
         INT16_C(  9827), -INT16_C( 26674), -INT16_C(  5242), -INT16_C(  3830),  INT16_C(  2794),  INT16_C( 24212),  INT16_C(  1933),  INT16_C( 32259) },
      {  INT16_C( 27024), -INT16_C(   960),  INT16_C(  1328),  INT16_C( 21576),  INT16_C(  1432), -INT16_C( 25752),  INT16_C( 12016), -INT16_C( 21744),
        -INT16_C(  4456),  INT16_C( 15400), -INT16_C(  1632), -INT16_C( 28440), -INT16_C(  1192),  INT16_C(  4096),  INT16_C(  7064),  INT16_C( 11160),
        -INT16_C(  6264), -INT16_C( 17120),  INT16_C( 28128),  INT16_C( 31240),  INT16_C( 30568),  INT16_C( 26136),  INT16_C( 11672),  INT16_C( 13576),
         INT16_C( 13080), -INT16_C( 16784),  INT16_C( 23600), -INT16_C( 30640),  INT16_C( 22352), -INT16_C(  2912),  INT16_C( 15464), -INT16_C(  4072) },
      { -INT16_C( 26368), -INT16_C( 15360),  INT16_C( 21248),  INT16_C( 17536),  INT16_C( 22912), -INT16_C( 18816), -INT16_C(  4352), -INT16_C( 20224),
        -INT16_C(  5760), -INT16_C( 15744), -INT16_C( 26112),  INT16_C(  3712), -INT16_C( 19072),  INT16_C(     0), -INT16_C( 18048), -INT16_C( 18048),
         INT16_C( 30848), -INT16_C( 11776), -INT16_C(  8704), -INT16_C( 24448),  INT16_C( 30336),  INT16_C( 24960), -INT16_C(  9856),  INT16_C( 20608),
         INT16_C( 12672), -INT16_C(  6400), -INT16_C( 15616), -INT16_C( 31488),  INT16_C( 29952),  INT16_C( 18944), -INT16_C( 14720),  INT16_C(   384) },
      {  INT16_C( 16384),  INT16_C(     0), -INT16_C( 16384),  INT16_C(  8192),  INT16_C( 24576), -INT16_C( 24576), -INT16_C( 16384),  INT16_C( 16384),
         INT16_C( 24576), -INT16_C( 24576),       INT16_MIN, -INT16_C( 24576),  INT16_C( 24576),  INT16_C(     0),  INT16_C( 24576),  INT16_C( 24576),
         INT16_C(  8192),       INT16_MIN,       INT16_MIN,  INT16_C(  8192), -INT16_C( 24576),  INT16_C( 24576),  INT16_C( 24576),  INT16_C(  8192),
         INT16_C( 24576), -INT16_C( 16384), -INT16_C( 16384),  INT16_C( 16384),  INT16_C( 16384),       INT16_MIN, -INT16_C( 24576),  INT16_C( 24576) },
      {  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0) } },
    { { -INT16_C( 22525), -INT16_C( 16363),  INT16_C( 22229), -INT16_C( 15569), -INT16_C(  3580), -INT16_C( 18289),  INT16_C( 12312),  INT16_C( 31550),
         INT16_C(  3159), -INT16_C(  8942),  INT16_C(  7416), -INT16_C(  7474),  INT16_C( 25126), -INT16_C( 19392),  INT16_C( 17514),  INT16_C( 27954),
         INT16_C( 18668), -INT16_C( 16083),  INT16_C( 23966), -INT16_C( 23676),  INT16_C(  4943),  INT16_C( 26459), -INT16_C( 26300), -INT16_C( 25630),
        -INT16_C(  2650), -INT16_C( 24968),  INT16_C( 17937),  INT16_C( 14464), -INT16_C( 15959),  INT16_C(  5100),  INT16_C(  7685), -INT16_C(  3712) },
      { -INT16_C( 22525), -INT16_C( 16363),  INT16_C( 22229), -INT16_C( 15569), -INT16_C(  3580), -INT16_C( 18289),  INT16_C( 12312),  INT16_C( 31550),
         INT16_C(  3159), -INT16_C(  8942),  INT16_C(  7416), -INT16_C(  7474),  INT16_C( 25126), -INT16_C( 19392),  INT16_C( 17514),  INT16_C( 27954),
         INT16_C( 18668), -INT16_C( 16083),  INT16_C( 23966), -INT16_C( 23676),  INT16_C(  4943),  INT16_C( 26459), -INT16_C( 26300), -INT16_C( 25630),
        -INT16_C(  2650), -INT16_C( 24968),  INT16_C( 17937),  INT16_C( 14464), -INT16_C( 15959),  INT16_C(  5100),  INT16_C(  7685), -INT16_C(  3712) },
      {  INT16_C( 16408),  INT16_C(   168), -INT16_C( 18776),  INT16_C(  6520), -INT16_C( 28640), -INT16_C( 15240), -INT16_C( 32576), -INT16_C(  9744),
         INT16_C( 25272), -INT16_C(  6000), -INT16_C(  6208),  INT16_C(  5744),  INT16_C(  4400), -INT16_C( 24064),  INT16_C(  9040),  INT16_C( 27024),
         INT16_C( 18272),  INT16_C(  2408), -INT16_C(  4880),  INT16_C(  7200), -INT16_C( 25992),  INT16_C( 15064), -INT16_C( 13792), -INT16_C(  8432),
        -INT16_C( 21200), -INT16_C(  3136),  INT16_C( 12424), -INT16_C( 15360),  INT16_C(  3400), -INT16_C( 24736), -INT16_C(  4056), -INT16_C( 29696) },
      {  INT16_C(   384),  INT16_C(  2688),  INT16_C( 27264), -INT16_C( 26752),  INT16_C(   512),  INT16_C( 18304),  INT16_C(  3072), -INT16_C( 24832),
         INT16_C( 11136), -INT16_C( 30464),  INT16_C( 31744),  INT16_C( 26368),  INT16_C(  4864),  INT16_C(  8192),  INT16_C( 13568), -INT16_C( 26368),
         INT16_C( 30208), -INT16_C( 27008), -INT16_C( 12544), -INT16_C( 15872), -INT16_C( 22656), -INT16_C( 21120), -INT16_C( 24064), -INT16_C(  3840),
        -INT16_C( 11520),  INT16_C( 15360),  INT16_C(  2176),  INT16_C( 16384), -INT16_C( 11136), -INT16_C(  2560),  INT16_C(   640), -INT16_C( 16384) },
      {  INT16_C( 24576), -INT16_C( 24576), -INT16_C( 24576), -INT16_C(  8192),       INT16_MIN, -INT16_C(  8192),  INT16_C(     0), -INT16_C( 16384),
        -INT16_C(  8192),  INT16_C( 16384),  INT16_C(     0), -INT16_C( 16384), -INT16_C( 16384),  INT16_C(     0),  INT16_C( 16384),  INT16_C( 16384),
              INT16_MIN, -INT16_C( 24576), -INT16_C( 16384),       INT16_MIN, -INT16_C(  8192),  INT16_C( 24576),       INT16_MIN,  INT16_C( 16384),
        -INT16_C( 16384),  INT16_C(     0),  INT16_C(  8192),  INT16_C(     0),  INT16_C(  8192),       INT16_MIN, -INT16_C( 24576),  INT16_C(     0) },
      {  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0) } },
    { { -INT16_C( 20890),  INT16_C(  1458),  INT16_C( 14091),  INT16_C( 23208),  INT16_C(   842), -INT16_C( 28990), -INT16_C( 23396),  INT16_C( 16937),
        -INT16_C( 24167), -INT16_C( 21536),  INT16_C( 25064), -INT16_C( 28189), -INT16_C( 12510),  INT16_C( 10148),  INT16_C(  9453),  INT16_C( 21528),
        -INT16_C( 13614), -INT16_C(  8871),  INT16_C(   257),  INT16_C( 19512), -INT16_C(  1532), -INT16_C( 24358),  INT16_C(  1182),  INT16_C( 14563),
        -INT16_C( 15451), -INT16_C( 29213), -INT16_C( 14812),  INT16_C( 17950), -INT16_C( 15723), -INT16_C( 32147), -INT16_C( 31257), -INT16_C( 17962) },
      { -INT16_C( 20890),  INT16_C(  1458),  INT16_C( 14091),  INT16_C( 23208),  INT16_C(   842), -INT16_C( 28990), -INT16_C( 23396),  INT16_C( 16937),
        -INT16_C( 24167), -INT16_C( 21536),  INT16_C( 25064), -INT16_C( 28189), -INT16_C( 12510),  INT16_C( 10148),  INT16_C(  9453),  INT16_C( 21528),
        -INT16_C( 13614), -INT16_C(  8871),  INT16_C(   257),  INT16_C( 19512), -INT16_C(  1532), -INT16_C( 24358),  INT16_C(  1182),  INT16_C( 14563),
        -INT16_C( 15451), -INT16_C( 29213), -INT16_C( 14812),  INT16_C( 17950), -INT16_C( 15723), -INT16_C( 32147), -INT16_C( 31257), -INT16_C( 17962) },
      {  INT16_C( 29488),  INT16_C( 11664), -INT16_C( 18344), -INT16_C( 10944),  INT16_C(  6736),  INT16_C( 30224),  INT16_C(  9440),  INT16_C(  4424),
         INT16_C(  3272),  INT16_C( 24320),  INT16_C(  3904), -INT16_C( 28904),  INT16_C( 30992),  INT16_C( 15648),  INT16_C( 10088), -INT16_C( 24384),
         INT16_C( 22160), -INT16_C(  5432),  INT16_C(  2056),  INT16_C( 25024), -INT16_C( 12256),  INT16_C(  1744),  INT16_C(  9456), -INT16_C( 14568),
         INT16_C(  7464),  INT16_C( 28440),  INT16_C( 12576),  INT16_C( 12528),  INT16_C(  5288),  INT16_C(  4968),  INT16_C( 12088), -INT16_C( 12624) },
      {  INT16_C( 13056), -INT16_C(  9984), -INT16_C( 31360),  INT16_C( 21504), -INT16_C( 23296),  INT16_C( 24832),  INT16_C( 19968),  INT16_C(  5248),
        -INT16_C( 13184), -INT16_C(  4096), -INT16_C(  3072), -INT16_C(  3712), -INT16_C( 28416), -INT16_C( 11776),  INT16_C( 30336),  INT16_C(  3072),
         INT16_C( 26880), -INT16_C( 21376), -INT16_C( 32640),  INT16_C(  7168),  INT16_C(   512),  INT16_C( 27904),  INT16_C( 20224),  INT16_C( 29056),
        -INT16_C( 11648), -INT16_C(  3712),  INT16_C(  4608),  INT16_C(  3840),  INT16_C( 19072),  INT16_C( 13952), -INT16_C(  3200), -INT16_C(  5376) },
      { -INT16_C( 16384),  INT16_C( 16384),  INT16_C( 24576),  INT16_C(     0),  INT16_C( 16384),  INT16_C( 16384),       INT16_MIN,  INT16_C(  8192),
         INT16_C(  8192),  INT16_C(     0),  INT16_C(     0),  INT16_C( 24576),  INT16_C( 16384),       INT16_MIN, -INT16_C( 24576),  INT16_C(     0),
         INT16_C( 16384),  INT16_C(  8192),  INT16_C(  8192),  INT16_C(     0),       INT16_MIN,  INT16_C( 16384), -INT16_C( 16384),  INT16_C( 24576),
        -INT16_C( 24576),  INT16_C( 24576),       INT16_MIN, -INT16_C( 16384), -INT16_C( 24576), -INT16_C( 24576), -INT16_C(  8192), -INT16_C( 16384) },
      {  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0) } },
    { {  INT16_C( 12112),  INT16_C( 20887), -INT16_C( 12496),  INT16_C( 13469),  INT16_C( 30921),  INT16_C( 26581), -INT16_C( 18308),  INT16_C(  8607),
        -INT16_C( 32133), -INT16_C( 24401), -INT16_C( 12984), -INT16_C(  8730),  INT16_C( 21648),  INT16_C( 30560),  INT16_C( 14041),  INT16_C( 10544),
        -INT16_C( 14490), -INT16_C( 27013),  INT16_C(  6294),  INT16_C( 24523), -INT16_C( 24432),  INT16_C(  3271),  INT16_C( 26200), -INT16_C( 11474),
        -INT16_C(  8727),  INT16_C( 12659),  INT16_C( 23210),  INT16_C( 14863),  INT16_C( 28590), -INT16_C( 30799), -INT16_C(  7515),  INT16_C(  2993) },
      {  INT16_C( 12112),  INT16_C( 20887), -INT16_C( 12496),  INT16_C( 13469),  INT16_C( 30921),  INT16_C( 26581), -INT16_C( 18308),  INT16_C(  8607),
        -INT16_C( 32133), -INT16_C( 24401), -INT16_C( 12984), -INT16_C(  8730),  INT16_C( 21648),  INT16_C( 30560),  INT16_C( 14041),  INT16_C( 10544),
        -INT16_C( 14490), -INT16_C( 27013),  INT16_C(  6294),  INT16_C( 24523), -INT16_C( 24432),  INT16_C(  3271),  INT16_C( 26200), -INT16_C( 11474),
        -INT16_C(  8727),  INT16_C( 12659),  INT16_C( 23210),  INT16_C( 14863),  INT16_C( 28590), -INT16_C( 30799), -INT16_C(  7515),  INT16_C(  2993) },
      {  INT16_C( 31360), -INT16_C( 29512),  INT16_C( 31104), -INT16_C( 23320), -INT16_C( 14776),  INT16_C( 16040), -INT16_C( 15392),  INT16_C(  3320),
         INT16_C(  5080),  INT16_C(  1400),  INT16_C( 27200), -INT16_C(  4304), -INT16_C( 23424), -INT16_C( 17664), -INT16_C( 18744),  INT16_C( 18816),
         INT16_C( 15152), -INT16_C( 19496), -INT16_C( 15184), -INT16_C(   424),  INT16_C(  1152),  INT16_C( 26168),  INT16_C( 12992), -INT16_C( 26256),
        -INT16_C(  4280), -INT16_C( 29800), -INT16_C( 10928), -INT16_C( 12168),  INT16_C( 32112),  INT16_C( 15752),  INT16_C(  5416),  INT16_C( 23944) },
      { -INT16_C( 22528), -INT16_C( 13440), -INT16_C( 26624),  INT16_C( 20096),  INT16_C( 25728), -INT16_C(  5504),  INT16_C( 15872), -INT16_C( 12416),
         INT16_C( 15744),  INT16_C( 22400), -INT16_C( 23552), -INT16_C(  3328),  INT16_C( 18432), -INT16_C( 20480),  INT16_C( 27776), -INT16_C( 26624),
        -INT16_C( 19712),  INT16_C( 15744),  INT16_C( 19200), -INT16_C(  6784),  INT16_C( 18432),  INT16_C( 25472),  INT16_C( 11264), -INT16_C( 26880),
        -INT16_C(  2944), -INT16_C( 18048),  INT16_C( 21760),  INT16_C(  1920), -INT16_C( 10496), -INT16_C( 10112),  INT16_C( 21120), -INT16_C( 10112) },
      {  INT16_C(     0), -INT16_C(  8192),  INT16_C(     0), -INT16_C( 24576),  INT16_C(  8192), -INT16_C( 24576),       INT16_MIN, -INT16_C(  8192),
         INT16_C( 24576), -INT16_C(  8192),  INT16_C(     0), -INT16_C( 16384),  INT16_C(     0),  INT16_C(     0),  INT16_C(  8192),  INT16_C(     0),
        -INT16_C( 16384),  INT16_C( 24576), -INT16_C( 16384),  INT16_C( 24576),  INT16_C(     0), -INT16_C(  8192),  INT16_C(     0), -INT16_C( 16384),
         INT16_C(  8192),  INT16_C( 24576),  INT16_C( 16384), -INT16_C(  8192), -INT16_C( 16384),  INT16_C(  8192), -INT16_C( 24576),  INT16_C(  8192) },
      {  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0) } },
    { {  INT16_C( 11433),  INT16_C( 16546),  INT16_C( 27972), -INT16_C( 10849),  INT16_C( 26125),  INT16_C( 26081),  INT16_C(  4045), -INT16_C( 18888),
        -INT16_C( 21268), -INT16_C( 26649), -INT16_C(  2554), -INT16_C( 19247), -INT16_C( 31899),  INT16_C(  2875), -INT16_C(  5019),  INT16_C(  3606),
        -INT16_C( 18408),  INT16_C( 23886), -INT16_C(  4571),  INT16_C( 12850),  INT16_C(  4948),  INT16_C(  8599), -INT16_C( 12253),  INT16_C(  4055),
        -INT16_C( 16516), -INT16_C( 32090),  INT16_C( 30901),  INT16_C(  6966),  INT16_C( 29179),  INT16_C( 24614),  INT16_C( 15454),  INT16_C( 30318) },
      {  INT16_C( 11433),  INT16_C( 16546),  INT16_C( 27972), -INT16_C( 10849),  INT16_C( 26125),  INT16_C( 26081),  INT16_C(  4045), -INT16_C( 18888),
        -INT16_C( 21268), -INT16_C( 26649), -INT16_C(  2554), -INT16_C( 19247), -INT16_C( 31899),  INT16_C(  2875), -INT16_C(  5019),  INT16_C(  3606),
        -INT16_C( 18408),  INT16_C( 23886), -INT16_C(  4571),  INT16_C( 12850),  INT16_C(  4948),  INT16_C(  8599), -INT16_C( 12253),  INT16_C(  4055),
        -INT16_C( 16516), -INT16_C( 32090),  INT16_C( 30901),  INT16_C(  6966),  INT16_C( 29179),  INT16_C( 24614),  INT16_C( 15454),  INT16_C( 30318) },
      {  INT16_C( 25928),  INT16_C(  1296),  INT16_C( 27168), -INT16_C( 21256),  INT16_C( 12392),  INT16_C( 12040),  INT16_C( 32360), -INT16_C( 20032),
         INT16_C( 26464), -INT16_C( 16584), -INT16_C( 20432), -INT16_C( 22904),  INT16_C(  6952),  INT16_C( 23000),  INT16_C( 25384),  INT16_C( 28848),
        -INT16_C( 16192), -INT16_C(  5520),  INT16_C( 28968), -INT16_C( 28272), -INT16_C( 25952),  INT16_C(  3256), -INT16_C( 32488),  INT16_C( 32440),
        -INT16_C(  1056),  INT16_C(  5424), -INT16_C( 14936), -INT16_C(  9808), -INT16_C( 28712),  INT16_C(   304), -INT16_C(  7440), -INT16_C( 19600) },
      {  INT16_C( 21632),  INT16_C( 20736), -INT16_C( 24064), -INT16_C( 12416),  INT16_C(  1664), -INT16_C(  3968), -INT16_C(  6528),  INT16_C(  7168),
         INT16_C( 30208), -INT16_C(  3200),  INT16_C(   768),  INT16_C( 26752), -INT16_C( 19840), -INT16_C( 25216),  INT16_C( 12928),  INT16_C(  2816),
         INT16_C(  3072), -INT16_C( 22784),  INT16_C(  4736),  INT16_C(  6400), -INT16_C( 22016), -INT16_C( 13440),  INT16_C(  4480), -INT16_C(  5248),
        -INT16_C( 16896),  INT16_C( 21248),  INT16_C( 23168), -INT16_C( 25856), -INT16_C(   640),  INT16_C(  4864),  INT16_C( 12032),  INT16_C( 14080) },
      {  INT16_C(  8192),  INT16_C( 16384),       INT16_MIN, -INT16_C(  8192), -INT16_C( 24576),  INT16_C(  8192), -INT16_C( 24576),  INT16_C(     0),
              INT16_MIN, -INT16_C(  8192), -INT16_C( 16384),  INT16_C(  8192), -INT16_C( 24576),  INT16_C( 24576), -INT16_C( 24576), -INT16_C( 16384),
         INT16_C(     0), -INT16_C( 16384), -INT16_C( 24576),  INT16_C( 16384),       INT16_MIN, -INT16_C(  8192),  INT16_C( 24576), -INT16_C(  8192),
              INT16_MIN, -INT16_C( 16384), -INT16_C( 24576), -INT16_C( 16384),  INT16_C( 24576), -INT16_C( 16384), -INT16_C( 16384), -INT16_C( 16384) },
      {  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0) } },
    { { -INT16_C( 16907),  INT16_C(  6867),  INT16_C(  1451), -INT16_C(   179), -INT16_C(  7143),  INT16_C( 15393), -INT16_C(  1868),  INT16_C( 12363),
        -INT16_C(  3401),  INT16_C( 28082), -INT16_C(  6038),  INT16_C( 25992), -INT16_C( 20902), -INT16_C( 18235),  INT16_C( 13290), -INT16_C(  8402),
         INT16_C(   752), -INT16_C( 25606),  INT16_C( 18183),  INT16_C(  8347), -INT16_C( 17365), -INT16_C(  8100), -INT16_C( 22348),  INT16_C( 27664),
        -INT16_C( 15462),  INT16_C(  1241),  INT16_C( 25003),  INT16_C(  1385),  INT16_C( 11791), -INT16_C(  1603), -INT16_C(  5023),  INT16_C( 21209) },
      { -INT16_C( 16907),  INT16_C(  6867),  INT16_C(  1451), -INT16_C(   179), -INT16_C(  7143),  INT16_C( 15393), -INT16_C(  1868),  INT16_C( 12363),
        -INT16_C(  3401),  INT16_C( 28082), -INT16_C(  6038),  INT16_C( 25992), -INT16_C( 20902), -INT16_C( 18235),  INT16_C( 13290), -INT16_C(  8402),
         INT16_C(   752), -INT16_C( 25606),  INT16_C( 18183),  INT16_C(  8347), -INT16_C( 17365), -INT16_C(  8100), -INT16_C( 22348),  INT16_C( 27664),
        -INT16_C( 15462),  INT16_C(  1241),  INT16_C( 25003),  INT16_C(  1385),  INT16_C( 11791), -INT16_C(  1603), -INT16_C(  5023),  INT16_C( 21209) },
      { -INT16_C(  4184), -INT16_C( 10600),  INT16_C( 11608), -INT16_C(  1432),  INT16_C(  8392), -INT16_C(  7928), -INT16_C( 14944), -INT16_C( 32168),
        -INT16_C( 27208),  INT16_C( 28048),  INT16_C( 17232),  INT16_C( 11328),  INT16_C( 29392), -INT16_C( 14808), -INT16_C( 24752), -INT16_C(  1680),
         INT16_C(  6016), -INT16_C(  8240),  INT16_C( 14392),  INT16_C(  1240), -INT16_C(  7848),  INT16_C(   736),  INT16_C( 17824),  INT16_C( 24704),
         INT16_C(  7376),  INT16_C(  9928),  INT16_C(  3416),  INT16_C( 11080),  INT16_C( 28792), -INT16_C( 12824),  INT16_C( 25352), -INT16_C( 26936) },
      { -INT16_C(  1408),  INT16_C( 27008), -INT16_C( 10880), -INT16_C( 22912),  INT16_C(  3200),  INT16_C(  4224),  INT16_C( 23040),  INT16_C(  9600),
         INT16_C( 23424), -INT16_C(  9984),  INT16_C( 13568), -INT16_C( 15360),  INT16_C( 11520),  INT16_C( 25216), -INT16_C(  2816), -INT16_C( 26880),
         INT16_C( 30720), -INT16_C(   768), -INT16_C( 31872),  INT16_C( 19840),  INT16_C(  5504),  INT16_C( 11776),  INT16_C( 23040),  INT16_C(  2048),
        -INT16_C( 13056),  INT16_C( 27776), -INT16_C( 10880), -INT16_C( 19328),  INT16_C(  1920), -INT16_C(  8576),  INT16_C( 12416),  INT16_C( 27776) },
      { -INT16_C( 24576),  INT16_C( 24576),  INT16_C( 24576), -INT16_C( 24576),  INT16_C(  8192),  INT16_C(  8192),       INT16_MIN,  INT16_C( 24576),
        -INT16_C(  8192),  INT16_C( 16384),  INT16_C( 16384),  INT16_C(     0),  INT16_C( 16384), -INT16_C( 24576),  INT16_C( 16384), -INT16_C( 16384),
         INT16_C(     0),  INT16_C( 16384), -INT16_C(  8192),  INT16_C( 24576),  INT16_C( 24576),       INT16_MIN,       INT16_MIN,  INT16_C(     0),
         INT16_C( 16384),  INT16_C(  8192),  INT16_C( 24576),  INT16_C(  8192), -INT16_C(  8192), -INT16_C( 24576),  INT16_C(  8192),  INT16_C(  8192) },
      {  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0) } }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
    simde__m512i a = simde_mm512_loadu_epi16(test_vec[i].a);
    simde__m512i r0 = simde_mm512_slli_epi16(a, 0);
    simde_test_x86_assert_equal_i16x32(r0, simde_mm512_loadu_epi16(test_vec[i].r0));
    simde__m512i r3 = simde_mm512_slli_epi16(a, 3);
    simde_test_x86_assert_equal_i16x32(r3, simde_mm512_loadu_epi16(test_vec[i].r3));
    simde__m512i r7 = simde_mm512_slli_epi16(a, 7);
    simde_test_x86_assert_equal_i16x32(r7, simde_mm512_loadu_epi16(test_vec[i].r7));
    simde__m512i r13 = simde_mm512_slli_epi16(a, 13);
    simde_test_x86_assert_equal_i16x32(r13, simde_mm512_loadu_epi16(test_vec[i].r13));
    simde__m512i r24 = simde_mm512_slli_epi16(a, 24);
    simde_test_x86_assert_equal_i16x32(r24, simde_mm512_loadu_epi16(test_vec[i].r24));
  }

  return 0;
}

static int
test_simde_mm512_sllv_epi16 (SIMDE_MUNIT_TEST_ARGS) {
  static const struct {
    const int16_t a[32];
    const int16_t b[32];
    const int16_t r[32];
  } test_vec[] = {
    { {  INT16_C( 22565),  INT16_C(  7765), -INT16_C(  5967),  INT16_C(  8467),  INT16_C( 20064),  INT16_C( 22451),  INT16_C(  4892), -INT16_C( 11833),
        -INT16_C( 29997),  INT16_C( 21077), -INT16_C( 20080),  INT16_C( 23507),  INT16_C( 27770), -INT16_C( 29233), -INT16_C(  7519), -INT16_C( 14708),
        -INT16_C(  7621), -INT16_C(  4892), -INT16_C(  2102),  INT16_C( 10765), -INT16_C( 16059),  INT16_C( 24961),  INT16_C( 18644), -INT16_C( 22733),
        -INT16_C( 30510),  INT16_C( 25594), -INT16_C( 12999), -INT16_C( 19522), -INT16_C( 29383), -INT16_C(  9663), -INT16_C( 12944), -INT16_C( 21600) },
      {  INT16_C(    16),  INT16_C(    15),  INT16_C(    20),  INT16_C(    24),  INT16_C(     4),  INT16_C(     7),  INT16_C(    10),  INT16_C(     8),
         INT16_C(    27),  INT16_C(     2),  INT16_C(    12),  INT16_C(    28),  INT16_C(     1),  INT16_C(    11),  INT16_C(    11),  INT16_C(    16),
         INT16_C(    20),  INT16_C(    11),  INT16_C(    20),  INT16_C(    21),  INT16_C(     7),  INT16_C(     7),  INT16_C(    24),  INT16_C(    13),
         INT16_C(     3),  INT16_C(     9),  INT16_C(     9),  INT16_C(    14),  INT16_C(    28),  INT16_C(     6),  INT16_C(    27),  INT16_C(     3) },
      {  INT16_C(     0),       INT16_MIN,  INT16_C(     0),  INT16_C(     0), -INT16_C(  6656), -INT16_C(  9856),  INT16_C( 28672), -INT16_C( 14592),
         INT16_C(     0),  INT16_C( 18772),  INT16_C(     0),  INT16_C(     0), -INT16_C(  9996),  INT16_C( 30720),  INT16_C(  2048),  INT16_C(     0),
         INT16_C(     0),  INT16_C(  8192),  INT16_C(     0),  INT16_C(     0), -INT16_C( 23936), -INT16_C( 16256),  INT16_C(     0),  INT16_C( 24576),
         INT16_C( 18064), -INT16_C(  3072),  INT16_C( 29184),       INT16_MIN,  INT16_C(     0), -INT16_C( 28608),  INT16_C(     0),  INT16_C( 23808) } },
    { { -INT16_C( 18052), -INT16_C( 15751), -INT16_C( 27809),  INT16_C( 11118),  INT16_C( 21456),  INT16_C( 24934), -INT16_C(  7911), -INT16_C( 17712),
         INT16_C( 21505), -INT16_C( 32253),  INT16_C( 11682), -INT16_C(  1037), -INT16_C( 15342),  INT16_C( 21035), -INT16_C(  7265),  INT16_C(  7025),
        -INT16_C(  5475), -INT16_C(   802),  INT16_C( 19581),  INT16_C( 19752), -INT16_C( 29025), -INT16_C( 18257),  INT16_C( 32623),  INT16_C( 28786),
         INT16_C( 30163),  INT16_C( 30451), -INT16_C(  6494), -INT16_C( 19343), -INT16_C( 25430),  INT16_C( 18694),  INT16_C( 30592),  INT16_C(  7525) },
      {  INT16_C(     8),  INT16_C(    27),  INT16_C(     8),  INT16_C(     5),  INT16_C(    27),  INT16_C(     7),  INT16_C(    11),  INT16_C(     5),
         INT16_C(    20),  INT16_C(    13),  INT16_C(     2),  INT16_C(     6),  INT16_C(     5),  INT16_C(     6),  INT16_C(    28),  INT16_C(     0),
         INT16_C(    12),  INT16_C(    22),  INT16_C(     1),  INT16_C(    15),  INT16_C(    25),  INT16_C(     8),  INT16_C(    12),  INT16_C(    29),
         INT16_C(     2),  INT16_C(    18),  INT16_C(    15),  INT16_C(    26),  INT16_C(     8),  INT16_C(     9),  INT16_C(    10),  INT16_C(     9) },
      {  INT16_C( 31744),  INT16_C(     0),  INT16_C( 24320),  INT16_C( 28096),  INT16_C(     0), -INT16_C( 19712), -INT16_C( 14336),  INT16_C( 23040),
         INT16_C(     0),  INT16_C( 24576), -INT16_C( 18808), -INT16_C(   832), -INT16_C( 32192), -INT16_C( 30016),  INT16_C(     0),  INT16_C(  7025),
        -INT16_C( 12288),  INT16_C(     0), -INT16_C( 26374),  INT16_C(     0),  INT16_C(     0), -INT16_C( 20736), -INT16_C(  4096),  INT16_C(     0),
        -INT16_C( 10420),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0), -INT16_C( 22016),  INT16_C(  3072),  INT16_C(     0), -INT16_C( 13824) } },
    { {  INT16_C( 10429),  INT16_C( 26366), -INT16_C(  8140),  INT16_C(  6879), -INT16_C( 26968), -INT16_C( 14245), -INT16_C( 13827),  INT16_C(  1973),
         INT16_C(  4570),  INT16_C(   153),  INT16_C( 24464),  INT16_C( 14551), -INT16_C(  8286), -INT16_C( 14464), -INT16_C( 14027), -INT16_C(  3311),
         INT16_C(  4081),  INT16_C(  9561),  INT16_C( 14575), -INT16_C( 26816), -INT16_C( 25649), -INT16_C( 13217),  INT16_C(  5220),  INT16_C( 16083),
         INT16_C( 27941), -INT16_C( 19137),  INT16_C(  5836),  INT16_C( 28653),  INT16_C( 28150),  INT16_C( 11062),  INT16_C( 18486),  INT16_C( 10270) },
      {  INT16_C(    15),  INT16_C(     8),  INT16_C(    17),  INT16_C(    15),  INT16_C(     7),  INT16_C(    17),  INT16_C(     3),  INT16_C(    15),
         INT16_C(     1),  INT16_C(    11),  INT16_C(     3),  INT16_C(     2),  INT16_C(    31),  INT16_C(    23),  INT16_C(    12),  INT16_C(    19),
         INT16_C(     6),  INT16_C(    17),  INT16_C(    24),  INT16_C(    29),  INT16_C(    10),  INT16_C(    10),  INT16_C(     8),  INT16_C(     0),
         INT16_C(    31),  INT16_C(    13),  INT16_C(     4),  INT16_C(    19),  INT16_C(    24),  INT16_C(    12),  INT16_C(     8),  INT16_C(    31) },
      {       INT16_MIN, -INT16_C(   512),  INT16_C(     0),       INT16_MIN,  INT16_C( 21504),  INT16_C(     0),  INT16_C( 20456),       INT16_MIN,
         INT16_C(  9140), -INT16_C( 14336), -INT16_C(   896), -INT16_C(  7332),  INT16_C(     0),  INT16_C(     0),  INT16_C( 20480),  INT16_C(     0),
        -INT16_C(   960),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C( 15360),  INT16_C( 31744),  INT16_C( 25600),  INT16_C( 16083),
         INT16_C(     0), -INT16_C(  8192),  INT16_C( 27840),  INT16_C(     0),  INT16_C(     0),  INT16_C( 24576),  INT16_C( 13824),  INT16_C(     0) } },
    { { -INT16_C(  5769),  INT16_C( 14727), -INT16_C( 28755), -INT16_C( 20956), -INT16_C( 25628),  INT16_C( 22530), -INT16_C( 12579),  INT16_C( 10584),
        -INT16_C( 19768), -INT16_C(  9067),  INT16_C(  6355), -INT16_C(  3207), -INT16_C( 10787),  INT16_C(   858),  INT16_C( 24088), -INT16_C( 28671),
        -INT16_C( 30648), -INT16_C(  2615), -INT16_C(  4841), -INT16_C(  1117), -INT16_C( 22904),  INT16_C( 25939), -INT16_C( 21388),  INT16_C( 15502),
         INT16_C(  9310),  INT16_C( 12569), -INT16_C( 28100),  INT16_C(  6693),  INT16_C( 32616), -INT16_C( 32739),  INT16_C(  7901),  INT16_C(  9488) },
      {  INT16_C(    27),  INT16_C(    23),  INT16_C(    23),  INT16_C(    10),  INT16_C(     1),  INT16_C(    27),  INT16_C(     8),  INT16_C(     2),
         INT16_C(     5),  INT16_C(    20),  INT16_C(    13),  INT16_C(     5),  INT16_C(    27),  INT16_C(    25),  INT16_C(    23),  INT16_C(    19),
         INT16_C(     1),  INT16_C(    11),  INT16_C(     2),  INT16_C(     5),  INT16_C(    12),  INT16_C(    27),  INT16_C(     3),  INT16_C(     1),
         INT16_C(     7),  INT16_C(     0),  INT16_C(    13),  INT16_C(    18),  INT16_C(    27),  INT16_C(     8),  INT16_C(     9),  INT16_C(     4) },
      {  INT16_C(     0),  INT16_C(     0),  INT16_C(     0), -INT16_C( 28672),  INT16_C( 14280),  INT16_C(     0), -INT16_C(  8960), -INT16_C( 23200),
         INT16_C( 22784),  INT16_C(     0),  INT16_C( 24576),  INT16_C( 28448),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C(  4240),  INT16_C( 18432), -INT16_C( 19364),  INT16_C( 29792),       INT16_MIN,  INT16_C(     0),  INT16_C( 25504),  INT16_C( 31004),
         INT16_C( 12032),  INT16_C( 12569),       INT16_MIN,  INT16_C(     0),  INT16_C(     0),  INT16_C(  7424), -INT16_C( 17920),  INT16_C( 20736) } },
    { {  INT16_C( 16724),  INT16_C(  7297),  INT16_C( 11351),  INT16_C( 31047),  INT16_C( 19340),  INT16_C( 12628),  INT16_C( 18020), -INT16_C( 21699),
        -INT16_C(  4481),  INT16_C(  9907), -INT16_C(  7330), -INT16_C( 22088),  INT16_C(  5308),  INT16_C( 20205), -INT16_C( 11937), -INT16_C( 19340),
        -INT16_C(  2798),  INT16_C( 27088),  INT16_C(  5921), -INT16_C( 20765),  INT16_C( 14179), -INT16_C( 14369),  INT16_C(  7293), -INT16_C(   653),
         INT16_C(  9739),  INT16_C( 26915), -INT16_C(  9463), -INT16_C( 15086), -INT16_C(    16),  INT16_C( 20243), -INT16_C( 30511), -INT16_C(  7421) },
      {  INT16_C(    26),  INT16_C(    19),  INT16_C(     6),  INT16_C(     9),  INT16_C(     5),  INT16_C(    28),  INT16_C(    17),  INT16_C(    10),
         INT16_C(     0),  INT16_C(    22),  INT16_C(    25),  INT16_C(    26),  INT16_C(    18),  INT16_C(    19),  INT16_C(     4),  INT16_C(    18),
         INT16_C(    25),  INT16_C(    28),  INT16_C(    16),  INT16_C(    12),  INT16_C(     8),  INT16_C(    30),  INT16_C(     5),  INT16_C(    15),
         INT16_C(     0),  INT16_C(     2),  INT16_C(    22),  INT16_C(    20),  INT16_C(     0),  INT16_C(    11),  INT16_C(    24),  INT16_C(     3) },
      {  INT16_C(     0),  INT16_C(     0),  INT16_C(  5568), -INT16_C( 29184),  INT16_C( 29056),  INT16_C(     0),  INT16_C(     0), -INT16_C(  3072),
        -INT16_C(  4481),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(  5616),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C( 12288),  INT16_C( 25344),  INT16_C(     0), -INT16_C( 28768),       INT16_MIN,
         INT16_C(  9739), -INT16_C( 23412),  INT16_C(     0),  INT16_C(     0), -INT16_C(    16), -INT16_C( 26624),  INT16_C(     0),  INT16_C(  6168) } },
    { {  INT16_C(  8851), -INT16_C( 27904),  INT16_C( 12452),  INT16_C( 20986),  INT16_C( 18038),  INT16_C( 17479), -INT16_C( 28300), -INT16_C( 22592),
        -INT16_C(  2921),  INT16_C( 27578), -INT16_C( 24923), -INT16_C(  6898),  INT16_C( 20386), -INT16_C( 13762),  INT16_C( 11283), -INT16_C( 22552),
        -INT16_C(  5810), -INT16_C(  3526),  INT16_C( 13337), -INT16_C( 28860), -INT16_C( 29830), -INT16_C(  4397), -INT16_C( 27620), -INT16_C( 19563),
         INT16_C( 20360),  INT16_C( 11551),  INT16_C( 11758), -INT16_C( 28653),  INT16_C( 20860), -INT16_C( 28582),  INT16_C( 17277), -INT16_C( 13513) },
      {  INT16_C(    14),  INT16_C(     8),  INT16_C(     0),  INT16_C(     3),  INT16_C(    21),  INT16_C(    21),  INT16_C(    20),  INT16_C(    24),
         INT16_C(    15),  INT16_C(    27),  INT16_C(     0),  INT16_C(     4),  INT16_C(    25),  INT16_C(    26),  INT16_C(    29),  INT16_C(     7),
         INT16_C(    11),  INT16_C(     0),  INT16_C(    10),  INT16_C(    29),  INT16_C(     5),  INT16_C(     7),  INT16_C(    30),  INT16_C(    24),
         INT16_C(    30),  INT16_C(     3),  INT16_C(     2),  INT16_C(     9),  INT16_C(    30),  INT16_C(    29),  INT16_C(    23),  INT16_C(     8) },
      { -INT16_C( 16384),  INT16_C(     0),  INT16_C( 12452), -INT16_C( 28720),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
              INT16_MIN,  INT16_C(     0), -INT16_C( 24923),  INT16_C( 20704),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0), -INT16_C(  3072),
         INT16_C( 28672), -INT16_C(  3526),  INT16_C( 25600),  INT16_C(     0),  INT16_C( 28480),  INT16_C( 27008),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C( 26872), -INT16_C( 18504),  INT16_C(  9728),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C( 14080) } },
    { { -INT16_C( 24036),  INT16_C( 31556),  INT16_C( 26358), -INT16_C(  3225), -INT16_C(   363),  INT16_C( 26156),  INT16_C( 10994),  INT16_C( 25128),
        -INT16_C( 13798),  INT16_C(  4220), -INT16_C( 17188), -INT16_C( 18083),  INT16_C( 32178), -INT16_C( 27229), -INT16_C( 14788),  INT16_C( 22742),
         INT16_C(  6761),  INT16_C( 24531),  INT16_C( 14976),  INT16_C(  5458),  INT16_C( 32312),  INT16_C( 10875), -INT16_C( 23384), -INT16_C( 15475),
         INT16_C(  2414),  INT16_C( 19411),  INT16_C( 12486),  INT16_C( 30724), -INT16_C( 22611), -INT16_C(  5874), -INT16_C(  7059), -INT16_C( 10687) },
      {  INT16_C(     2),  INT16_C(    15),  INT16_C(    17),  INT16_C(    16),  INT16_C(     2),  INT16_C(    21),  INT16_C(     7),  INT16_C(     4),
         INT16_C(     8),  INT16_C(     1),  INT16_C(    14),  INT16_C(     4),  INT16_C(    18),  INT16_C(    16),  INT16_C(     9),  INT16_C(    15),
         INT16_C(    18),  INT16_C(    22),  INT16_C(    17),  INT16_C(     4),  INT16_C(    29),  INT16_C(    10),  INT16_C(     8),  INT16_C(    14),
         INT16_C(    28),  INT16_C(     0),  INT16_C(     1),  INT16_C(    13),  INT16_C(     6),  INT16_C(     2),  INT16_C(    10),  INT16_C(    28) },
      { -INT16_C( 30608),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0), -INT16_C(  1452),  INT16_C(     0),  INT16_C( 30976),  INT16_C(  8832),
         INT16_C(  6656),  INT16_C(  8440),  INT16_C(     0), -INT16_C( 27184),  INT16_C(     0),  INT16_C(     0),  INT16_C( 30720),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C( 21792),  INT16_C(     0), -INT16_C(  5120), -INT16_C( 22528),  INT16_C( 16384),
         INT16_C(     0),  INT16_C( 19411),  INT16_C( 24972),       INT16_MIN, -INT16_C(  5312), -INT16_C( 23496), -INT16_C( 19456),  INT16_C(     0) } },
    { { -INT16_C( 30492),  INT16_C(   151), -INT16_C( 12011), -INT16_C( 19934), -INT16_C(  2883), -INT16_C(  6140),  INT16_C( 31033), -INT16_C( 15524),
        -INT16_C(  8612), -INT16_C( 20028), -INT16_C(  5657), -INT16_C( 31457),  INT16_C(  5148), -INT16_C( 25188),  INT16_C( 11365),  INT16_C( 19074),
         INT16_C(  6836), -INT16_C( 14006),  INT16_C( 27883), -INT16_C( 22148), -INT16_C( 32671), -INT16_C( 25967), -INT16_C(  4614),  INT16_C( 22109),
         INT16_C(  8907), -INT16_C( 19960),  INT16_C(  9995),  INT16_C( 10039), -INT16_C( 11205), -INT16_C( 24123),  INT16_C( 18176), -INT16_C( 18965) },
      {  INT16_C(     6),  INT16_C(     9),  INT16_C(    31),  INT16_C(     0),  INT16_C(    16),  INT16_C(    14),  INT16_C(    31),  INT16_C(     8),
         INT16_C(    26),  INT16_C(     4),  INT16_C(     5),  INT16_C(     6),  INT16_C(     2),  INT16_C(    31),  INT16_C(    24),  INT16_C(    23),
         INT16_C(     6),  INT16_C(    19),  INT16_C(     0),  INT16_C(    21),  INT16_C(     7),  INT16_C(    31),  INT16_C(    29),  INT16_C(     9),
         INT16_C(     6),  INT16_C(    22),  INT16_C(    24),  INT16_C(    11),  INT16_C(    24),  INT16_C(     6),  INT16_C(     1),  INT16_C(    15) },
      {  INT16_C( 14592),  INT16_C( 11776),  INT16_C(     0), -INT16_C( 19934),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C( 23552),
         INT16_C(     0),  INT16_C(  7232),  INT16_C( 15584),  INT16_C( 18368),  INT16_C( 20592),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
        -INT16_C( 21248),  INT16_C(     0),  INT16_C( 27883),  INT16_C(     0),  INT16_C( 12416),  INT16_C(     0),  INT16_C(     0), -INT16_C( 17920),
        -INT16_C( 19776),  INT16_C(     0),  INT16_C(     0), -INT16_C( 18432),  INT16_C(     0),  INT16_C( 28992), -INT16_C( 29184),       INT16_MIN } }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
    simde__m512i a = simde_mm512_loadu_epi16(test_vec[i].a);
    simde__m512i b = simde_mm512_loadu_epi16(test_vec[i].b);
    simde__m512i r = simde_mm512_sllv_epi16(a, b);
    simde_test_x86_assert_equal_i16x32(r, simde_mm512_loadu_epi16(test_vec[i].r));
  }

  return 0;
}

static int
test_simde_mm512_srl_epi16 (SIMDE_MUNIT_TEST_ARGS) {
  static const struct {
    const int16_t a[32];
    const int64_t b[2];
    const int16_t r[32];
  } test_vec[] = {
    { { -INT16_C( 21752), -INT16_C( 22194), -INT16_C( 18737),  INT16_C(  8433),  INT16_C( 23052),  INT16_C( 22961), -INT16_C(  7722), -INT16_C( 29326),
         INT16_C(  6474),  INT16_C( 15054),  INT16_C(  9100), -INT16_C( 16434), -INT16_C( 23329),  INT16_C( 14938), -INT16_C( 23326), -INT16_C(  5412),
         INT16_C( 10831),  INT16_C(  8083), -INT16_C( 31264), -INT16_C(  4801), -INT16_C(  3873), -INT16_C( 18874), -INT16_C( 18223),  INT16_C(  7235),
         INT16_C(  4562),  INT16_C( 24150),  INT16_C(  9268),  INT16_C(  4893),  INT16_C( 30920), -INT16_C( 21939),  INT16_C( 10524),  INT16_C( 27541) },
      {  INT64_C(                  17),  INT64_C(                  30) },
      {  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0) } },
    { { -INT16_C(   616), -INT16_C( 13232),  INT16_C( 28193), -INT16_C(  5664),  INT16_C( 11750),  INT16_C(   660),  INT16_C( 10583), -INT16_C( 21907),
        -INT16_C(  1967), -INT16_C(    34), -INT16_C(    63),  INT16_C( 31628), -INT16_C( 12441), -INT16_C( 30970), -INT16_C( 21163), -INT16_C(  4743),
        -INT16_C( 13910), -INT16_C( 13382), -INT16_C( 26057),  INT16_C(  7604),  INT16_C( 18631),  INT16_C(  7711), -INT16_C( 29327), -INT16_C( 15415),
        -INT16_C( 22651),  INT16_C( 18114),  INT16_C( 20135),  INT16_C(  3777), -INT16_C( 14563),  INT16_C( 29333),  INT16_C(  3700),  INT16_C(  7776) },
      {  INT64_C(                  15),  INT64_C(                  11) },
      {  INT16_C(     1),  INT16_C(     1),  INT16_C(     0),  INT16_C(     1),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     1),
         INT16_C(     1),  INT16_C(     1),  INT16_C(     1),  INT16_C(     0),  INT16_C(     1),  INT16_C(     1),  INT16_C(     1),  INT16_C(     1),
         INT16_C(     1),  INT16_C(     1),  INT16_C(     1),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     1),  INT16_C(     1),
         INT16_C(     1),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     1),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0) } },
    { { -INT16_C(  8950), -INT16_C( 20060),  INT16_C( 26155),  INT16_C( 18623),  INT16_C( 21549), -INT16_C( 23878),  INT16_C(  6754),  INT16_C( 15040),
        -INT16_C( 21964), -INT16_C(  6071),  INT16_C( 30024),  INT16_C( 11876), -INT16_C(   319), -INT16_C( 25978), -INT16_C( 24223),  INT16_C( 27640),
        -INT16_C( 25218), -INT16_C( 22243), -INT16_C(  9213),  INT16_C( 12529), -INT16_C( 21455), -INT16_C( 27694), -INT16_C( 27706), -INT16_C(  1075),
         INT16_C(  5693), -INT16_C( 31261),  INT16_C( 18316),  INT16_C( 19891),  INT16_C( 14917), -INT16_C( 22808), -INT16_C(  7973),  INT16_C( 23058) },
      {  INT64_C(                   7),  INT64_C(                  10) },
      {  INT16_C(   442),  INT16_C(   355),  INT16_C(   204),  INT16_C(   145),  INT16_C(   168),  INT16_C(   325),  INT16_C(    52),  INT16_C(   117),
         INT16_C(   340),  INT16_C(   464),  INT16_C(   234),  INT16_C(    92),  INT16_C(   509),  INT16_C(   309),  INT16_C(   322),  INT16_C(   215),
         INT16_C(   314),  INT16_C(   338),  INT16_C(   440),  INT16_C(    97),  INT16_C(   344),  INT16_C(   295),  INT16_C(   295),  INT16_C(   503),
         INT16_C(    44),  INT16_C(   267),  INT16_C(   143),  INT16_C(   155),  INT16_C(   116),  INT16_C(   333),  INT16_C(   449),  INT16_C(   180) } },
    { {  INT16_C( 18100),  INT16_C( 16600), -INT16_C( 29555), -INT16_C( 11379),  INT16_C( 30150), -INT16_C( 24199), -INT16_C( 29866), -INT16_C( 11269),
        -INT16_C(    70), -INT16_C( 14764),  INT16_C(  1524), -INT16_C( 27390), -INT16_C( 11640), -INT16_C( 24580),  INT16_C( 24432),  INT16_C(  9458),
        -INT16_C( 13403),  INT16_C( 12900), -INT16_C(  3753),  INT16_C(  7429),  INT16_C( 32615), -INT16_C( 16962), -INT16_C( 17910), -INT16_C( 14960),
        -INT16_C(  6983), -INT16_C( 21109), -INT16_C( 29207),  INT16_C( 29250),  INT16_C( 15968), -INT16_C( 12271),  INT16_C(   925),  INT16_C( 17140) },
      {  INT64_C(                  22),  INT64_C(                  14) },
      {  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0) } },
    { {  INT16_C( 21730), -INT16_C( 13279),  INT16_C( 25569),  INT16_C( 16702),  INT16_C( 20385),  INT16_C( 16145),  INT16_C(  1362),  INT16_C(  8577),
        -INT16_C(  2467), -INT16_C( 22714), -INT16_C( 30351),  INT16_C( 27223), -INT16_C( 14966),  INT16_C( 17774),  INT16_C( 14275), -INT16_C( 23111),
        -INT16_C(  9589),  INT16_C( 28017), -INT16_C( 20675), -INT16_C(  8530), -INT16_C( 16130),  INT16_C( 20765), -INT16_C( 24635),  INT16_C(  9074),
        -INT16_C( 18283),  INT16_C(  1738),  INT16_C(  8513), -INT16_C( 13455), -INT16_C(  8218), -INT16_C( 22256), -INT16_C( 14057), -INT16_C( 23985) },
      {  INT64_C(                  13),  INT64_C(                   2) },
      {  INT16_C(     2),  INT16_C(     6),  INT16_C(     3),  INT16_C(     2),  INT16_C(     2),  INT16_C(     1),  INT16_C(     0),  INT16_C(     1),
         INT16_C(     7),  INT16_C(     5),  INT16_C(     4),  INT16_C(     3),  INT16_C(     6),  INT16_C(     2),  INT16_C(     1),  INT16_C(     5),
         INT16_C(     6),  INT16_C(     3),  INT16_C(     5),  INT16_C(     6),  INT16_C(     6),  INT16_C(     2),  INT16_C(     4),  INT16_C(     1),
         INT16_C(     5),  INT16_C(     0),  INT16_C(     1),  INT16_C(     6),  INT16_C(     6),  INT16_C(     5),  INT16_C(     6),  INT16_C(     5) } },
    { {  INT16_C( 12522),  INT16_C( 11031), -INT16_C( 30638),  INT16_C( 14583),  INT16_C(  1896),  INT16_C( 32738),  INT16_C( 12753),  INT16_C( 29729),
         INT16_C( 12785),  INT16_C( 24917),  INT16_C(  5359),  INT16_C( 28112), -INT16_C( 28688),  INT16_C( 27824),  INT16_C(  6081), -INT16_C( 21635),
        -INT16_C( 27577), -INT16_C( 26154), -INT16_C( 13027), -INT16_C( 31278), -INT16_C( 19243), -INT16_C( 23036),  INT16_C(  9701), -INT16_C( 10726),
         INT16_C( 28502),  INT16_C( 17720),  INT16_C(  2179),  INT16_C( 29874),  INT16_C( 25495),  INT16_C( 22752),  INT16_C( 23930), -INT16_C( 16125) },
      {  INT64_C(                  15),  INT64_C(                   2) },
      {  INT16_C(     0),  INT16_C(     0),  INT16_C(     1),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     1),  INT16_C(     0),  INT16_C(     0),  INT16_C(     1),
         INT16_C(     1),  INT16_C(     1),  INT16_C(     1),  INT16_C(     1),  INT16_C(     1),  INT16_C(     1),  INT16_C(     0),  INT16_C(     1),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     1) } },
    { { -INT16_C( 11092),  INT16_C( 12377),  INT16_C(  3036),  INT16_C( 29860), -INT16_C( 31634), -INT16_C(  5940), -INT16_C( 12063), -INT16_C( 11606),
         INT16_C(  1450),  INT16_C( 20961),  INT16_C( 29746),  INT16_C(  5070), -INT16_C(  4084), -INT16_C( 13863),  INT16_C( 29997), -INT16_C(  9508),
         INT16_C( 13642),  INT16_C(  9738), -INT16_C( 20927), -INT16_C( 20582),  INT16_C( 26418),  INT16_C(  5016),  INT16_C( 16951), -INT16_C(  7707),
        -INT16_C( 14777),  INT16_C( 31026),  INT16_C(    59),  INT16_C( 18316),  INT16_C( 26097),  INT16_C(  7696), -INT16_C(  4902),  INT16_C(  9464) },
      {  INT64_C(                  28),  INT64_C(                   6) },
      {  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0) } },
    { { -INT16_C( 26719), -INT16_C(  9044),  INT16_C( 14487), -INT16_C( 30685),  INT16_C( 13213),  INT16_C( 30887), -INT16_C( 24800),  INT16_C( 17052),
        -INT16_C(  6238),  INT16_C( 21157), -INT16_C( 18483),  INT16_C(  6453),  INT16_C( 10850),  INT16_C( 20125),  INT16_C(   261), -INT16_C( 22654),
         INT16_C( 11928),  INT16_C( 12419), -INT16_C( 22681),  INT16_C(  1208),  INT16_C( 24538), -INT16_C(  1412),  INT16_C(  6655), -INT16_C( 24260),
        -INT16_C(  7936), -INT16_C( 12813),  INT16_C( 10393), -INT16_C(  1049), -INT16_C( 31661),  INT16_C( 22601), -INT16_C( 13435),  INT16_C(  7935) },
      {  INT64_C(                   0),  INT64_C(                  31) },
      { -INT16_C( 26719), -INT16_C(  9044),  INT16_C( 14487), -INT16_C( 30685),  INT16_C( 13213),  INT16_C( 30887), -INT16_C( 24800),  INT16_C( 17052),
        -INT16_C(  6238),  INT16_C( 21157), -INT16_C( 18483),  INT16_C(  6453),  INT16_C( 10850),  INT16_C( 20125),  INT16_C(   261), -INT16_C( 22654),
         INT16_C( 11928),  INT16_C( 12419), -INT16_C( 22681),  INT16_C(  1208),  INT16_C( 24538), -INT16_C(  1412),  INT16_C(  6655), -INT16_C( 24260),
        -INT16_C(  7936), -INT16_C( 12813),  INT16_C( 10393), -INT16_C(  1049), -INT16_C( 31661),  INT16_C( 22601), -INT16_C( 13435),  INT16_C(  7935) } }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
    simde__m512i a = simde_mm512_loadu_epi16(test_vec[i].a);
    simde__m128i b = simde_x_mm_loadu_epi64(test_vec[i].b);
    simde__m512i r = simde_mm512_srl_epi16(a, b);
    simde_test_x86_assert_equal_i16x32(r, simde_mm512_loadu_epi16(test_vec[i].r));
  }

  return 0;
}

static int
test_simde_mm512_sra_epi16 (SIMDE_MUNIT_TEST_ARGS) {
  static const struct {
    const int16_t a[32];
    const int64_t b[2];
    const int16_t r[32];
  } test_vec[] = {
    { {  INT16_C( 11061),  INT16_C(  2909),  INT16_C(  7771), -INT16_C( 15451),  INT16_C( 10536),  INT16_C( 16880),  INT16_C(  9564),  INT16_C(  7363),
         INT16_C( 22530), -INT16_C(  8028),  INT16_C(  1724), -INT16_C( 32593), -INT16_C( 10410),  INT16_C(  1671),  INT16_C( 28692),  INT16_C( 18993),
        -INT16_C( 29029), -INT16_C(  2475), -INT16_C(  1107), -INT16_C( 10822), -INT16_C( 21980), -INT16_C( 32490), -INT16_C(  9777), -INT16_C( 11619),
         INT16_C( 16689), -INT16_C(  4686),  INT16_C( 25159), -INT16_C( 25235), -INT16_C(  2759),  INT16_C( 19876), -INT16_C( 10907),  INT16_C(   407) },
      {  INT64_C(                   0),  INT64_C(                   0) },
      {  INT16_C( 11061),  INT16_C(  2909),  INT16_C(  7771), -INT16_C( 15451),  INT16_C( 10536),  INT16_C( 16880),  INT16_C(  9564),  INT16_C(  7363),
         INT16_C( 22530), -INT16_C(  8028),  INT16_C(  1724), -INT16_C( 32593), -INT16_C( 10410),  INT16_C(  1671),  INT16_C( 28692),  INT16_C( 18993),
        -INT16_C( 29029), -INT16_C(  2475), -INT16_C(  1107), -INT16_C( 10822), -INT16_C( 21980), -INT16_C( 32490), -INT16_C(  9777), -INT16_C( 11619),
         INT16_C( 16689), -INT16_C(  4686),  INT16_C( 25159), -INT16_C( 25235), -INT16_C(  2759),  INT16_C( 19876), -INT16_C( 10907),  INT16_C(   407) } },
    { { -INT16_C( 20629), -INT16_C( 19467),  INT16_C( 25361),  INT16_C( 19024), -INT16_C(  2984), -INT16_C( 17000),  INT16_C( 12234),  INT16_C( 11966),
        -INT16_C( 18916),  INT16_C(  1087),  INT16_C(  9575), -INT16_C( 15599), -INT16_C( 25054), -INT16_C(  1554), -INT16_C(  5175),  INT16_C( 13313),
        -INT16_C(  2406), -INT16_C( 21273),  INT16_C( 14425), -INT16_C( 19978), -INT16_C( 29140), -INT16_C(  2449),  INT16_C( 11710), -INT16_C(  9692),
         INT16_C( 25571),  INT16_C( 19423), -INT16_C(  3959), -INT16_C( 21746), -INT16_C(   882),  INT16_C( 22436), -INT16_C( 23065), -INT16_C( 32372) },
      {  INT64_C(                  13),  INT64_C(                   2) },
      { -INT16_C(     3), -INT16_C(     3),  INT16_C(     3),  INT16_C(     2), -INT16_C(     1), -INT16_C(     3),  INT16_C(     1),  INT16_C(     1),
        -INT16_C(     3),  INT16_C(     0),  INT16_C(     1), -INT16_C(     2), -INT16_C(     4), -INT16_C(     1), -INT16_C(     1),  INT16_C(     1),
        -INT16_C(     1), -INT16_C(     3),  INT16_C(     1), -INT16_C(     3), -INT16_C(     4), -INT16_C(     1),  INT16_C(     1), -INT16_C(     2),
         INT16_C(     3),  INT16_C(     2), -INT16_C(     1), -INT16_C(     3), -INT16_C(     1),  INT16_C(     2), -INT16_C(     3), -INT16_C(     4) } },
    { {  INT16_C( 10838), -INT16_C(  8334), -INT16_C( 32742), -INT16_C( 22389),  INT16_C( 12156),  INT16_C( 25344), -INT16_C( 29483),  INT16_C( 29156),
         INT16_C(  4863), -INT16_C( 21658),  INT16_C(  3382), -INT16_C(  6013),  INT16_C( 20771),  INT16_C( 26457), -INT16_C( 23484), -INT16_C( 25714),
         INT16_C(   206), -INT16_C(  6022),  INT16_C(  1408), -INT16_C(   880), -INT16_C( 28619),  INT16_C(  2655),  INT16_C( 17180),  INT16_C(  7291),
        -INT16_C(  7851), -INT16_C( 29753),  INT16_C( 19183),  INT16_C(  4724), -INT16_C( 12901), -INT16_C(  8071),  INT16_C(  1905),  INT16_C( 16251) },
      {  INT64_C(                   3),  INT64_C(                   7) },
      {  INT16_C(  1354), -INT16_C(  1042), -INT16_C(  4093), -INT16_C(  2799),  INT16_C(  1519),  INT16_C(  3168), -INT16_C(  3686),  INT16_C(  3644),
         INT16_C(   607), -INT16_C(  2708),  INT16_C(   422), -INT16_C(   752),  INT16_C(  2596),  INT16_C(  3307), -INT16_C(  2936), -INT16_C(  3215),
         INT16_C(    25), -INT16_C(   753),  INT16_C(   176), -INT16_C(   110), -INT16_C(  3578),  INT16_C(   331),  INT16_C(  2147),  INT16_C(   911),
        -INT16_C(   982), -INT16_C(  3720),  INT16_C(  2397),  INT16_C(   590), -INT16_C(  1613), -INT16_C(  1009),  INT16_C(   238),  INT16_C(  2031) } },
    { {  INT16_C( 18326), -INT16_C( 31481),  INT16_C( 31633),  INT16_C( 11672),  INT16_C(  4424), -INT16_C( 18163), -INT16_C( 30695),  INT16_C(  8440),
         INT16_C(  8061),  INT16_C( 30888),  INT16_C( 11222),  INT16_C(  7848), -INT16_C(  7666),  INT16_C( 13443),  INT16_C(   919),  INT16_C( 11951),
        -INT16_C( 18869), -INT16_C(  9037),  INT16_C( 19249),  INT16_C( 30985),  INT16_C(  5725),  INT16_C( 30258),  INT16_C( 10910),  INT16_C(  7318),
         INT16_C( 15945),  INT16_C(  8340),  INT16_C( 15722),  INT16_C( 30782), -INT16_C( 16097), -INT16_C( 18516),  INT16_C( 23493),  INT16_C(  4325) },
      {  INT64_C(                   4),  INT64_C(                   6) },
      {  INT16_C(  1145), -INT16_C(  1968),  INT16_C(  1977),  INT16_C(   729),  INT16_C(   276), -INT16_C(  1136), -INT16_C(  1919),  INT16_C(   527),
         INT16_C(   503),  INT16_C(  1930),  INT16_C(   701),  INT16_C(   490), -INT16_C(   480),  INT16_C(   840),  INT16_C(    57),  INT16_C(   746),
        -INT16_C(  1180), -INT16_C(   565),  INT16_C(  1203),  INT16_C(  1936),  INT16_C(   357),  INT16_C(  1891),  INT16_C(   681),  INT16_C(   457),
         INT16_C(   996),  INT16_C(   521),  INT16_C(   982),  INT16_C(  1923), -INT16_C(  1007), -INT16_C(  1158),  INT16_C(  1468),  INT16_C(   270) } },
    { {  INT16_C( 23436), -INT16_C(  2429), -INT16_C( 15720), -INT16_C( 18322),  INT16_C(  6787),  INT16_C( 18543),  INT16_C( 21621), -INT16_C( 30888),
         INT16_C( 17900), -INT16_C( 12085), -INT16_C( 30661),  INT16_C( 18193), -INT16_C( 14217), -INT16_C( 28174), -INT16_C( 18154), -INT16_C( 23819),
         INT16_C( 30741), -INT16_C( 21096),  INT16_C(  1594), -INT16_C( 16795), -INT16_C( 11232), -INT16_C( 27386),  INT16_C( 24360),  INT16_C(  5405),
        -INT16_C(  5980), -INT16_C(  8219), -INT16_C(  2192), -INT16_C(  6362),  INT16_C(  6591), -INT16_C( 10887),  INT16_C( 28370), -INT16_C(  6281) },
      {  INT64_C(                   3),  INT64_C(                  14) },
      {  INT16_C(  2929), -INT16_C(   304), -INT16_C(  1965), -INT16_C(  2291),  INT16_C(   848),  INT16_C(  2317),  INT16_C(  2702), -INT16_C(  3861),
         INT16_C(  2237), -INT16_C(  1511), -INT16_C(  3833),  INT16_C(  2274), -INT16_C(  1778), -INT16_C(  3522), -INT16_C(  2270), -INT16_C(  2978),
         INT16_C(  3842), -INT16_C(  2637),  INT16_C(   199), -INT16_C(  2100), -INT16_C(  1404), -INT16_C(  3424),  INT16_C(  3045),  INT16_C(   675),
        -INT16_C(   748), -INT16_C(  1028), -INT16_C(   274), -INT16_C(   796),  INT16_C(   823), -INT16_C(  1361),  INT16_C(  3546), -INT16_C(   786) } },
    { { -INT16_C(  3376),  INT16_C( 16583), -INT16_C(  4375), -INT16_C( 22489), -INT16_C( 24569), -INT16_C(  9858), -INT16_C(  2802), -INT16_C(  2623),
         INT16_C( 22021),  INT16_C(  6678), -INT16_C(  2736),  INT16_C(  8016),  INT16_C(  7130),  INT16_C(  7959),  INT16_C(  8963), -INT16_C( 11513),
        -INT16_C( 12523), -INT16_C(   493),  INT16_C( 15037), -INT16_C( 15193),  INT16_C(  9691), -INT16_C(  5731),  INT16_C( 24090),  INT16_C(  8158),
        -INT16_C(  2892),  INT16_C(  1338), -INT16_C( 29975), -INT16_C( 15324),  INT16_C( 15269), -INT16_C( 22301), -INT16_C(  5537),  INT16_C( 29819) },
      {  INT64_C(                  10),  INT64_C(                  14) },
      { -INT16_C(     4),  INT16_C(    16), -INT16_C(     5), -INT16_C(    22), -INT16_C(    24), -INT16_C(    10), -INT16_C(     3), -INT16_C(     3),
         INT16_C(    21),  INT16_C(     6), -INT16_C(     3),  INT16_C(     7),  INT16_C(     6),  INT16_C(     7),  INT16_C(     8), -INT16_C(    12),
        -INT16_C(    13), -INT16_C(     1),  INT16_C(    14), -INT16_C(    15),  INT16_C(     9), -INT16_C(     6),  INT16_C(    23),  INT16_C(     7),
        -INT16_C(     3),  INT16_C(     1), -INT16_C(    30), -INT16_C(    15),  INT16_C(    14), -INT16_C(    22), -INT16_C(     6),  INT16_C(    29) } },
    { { -INT16_C( 19616),  INT16_C( 18928),  INT16_C(  5181), -INT16_C(  7667), -INT16_C(  4016), -INT16_C( 20598),  INT16_C(  1499), -INT16_C( 27613),
        -INT16_C( 26989),  INT16_C( 23307),  INT16_C( 17840), -INT16_C(  4097), -INT16_C( 29667),  INT16_C( 21577), -INT16_C( 15625),  INT16_C( 22335),
         INT16_C( 12149), -INT16_C( 19807), -INT16_C( 20925), -INT16_C( 27756),  INT16_C(  7839),  INT16_C( 31298),  INT16_C( 26147), -INT16_C( 18930),
         INT16_C(  6652), -INT16_C( 21231),  INT16_C(  4191),  INT16_C( 31900), -INT16_C(  6756), -INT16_C( 27440),  INT16_C(  4007),  INT16_C(  7403) },
      {  INT64_C(                  13),  INT64_C(                  11) },
      { -INT16_C(     3),  INT16_C(     2),  INT16_C(     0), -INT16_C(     1), -INT16_C(     1), -INT16_C(     3),  INT16_C(     0), -INT16_C(     4),
        -INT16_C(     4),  INT16_C(     2),  INT16_C(     2), -INT16_C(     1), -INT16_C(     4),  INT16_C(     2), -INT16_C(     2),  INT16_C(     2),
         INT16_C(     1), -INT16_C(     3), -INT16_C(     3), -INT16_C(     4),  INT16_C(     0),  INT16_C(     3),  INT16_C(     3), -INT16_C(     3),
         INT16_C(     0), -INT16_C(     3),  INT16_C(     0),  INT16_C(     3), -INT16_C(     1), -INT16_C(     4),  INT16_C(     0),  INT16_C(     0) } },
    { {  INT16_C( 27516), -INT16_C(  9369),  INT16_C(  1147),  INT16_C(  6231),  INT16_C( 10473), -INT16_C( 28244), -INT16_C( 26825),  INT16_C( 30381),
         INT16_C( 31780),  INT16_C( 24568),  INT16_C(  3550),  INT16_C( 24377), -INT16_C( 29339),  INT16_C(  8962),  INT16_C( 23791),  INT16_C( 27614),
         INT16_C( 17863),  INT16_C( 16966), -INT16_C( 25015),  INT16_C( 13146),  INT16_C(  1734), -INT16_C(   572),  INT16_C( 29086), -INT16_C( 15757),
         INT16_C( 27629), -INT16_C( 13279),  INT16_C( 23161), -INT16_C(  8661),  INT16_C( 11751), -INT16_C( 10750), -INT16_C(  8055),  INT16_C( 20546) },
      {  INT64_C(                  14),  INT64_C(                  12) },
      {  INT16_C(     1), -INT16_C(     1),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0), -INT16_C(     2), -INT16_C(     2),  INT16_C(     1),
         INT16_C(     1),  INT16_C(     1),  INT16_C(     0),  INT16_C(     1), -INT16_C(     2),  INT16_C(     0),  INT16_C(     1),  INT16_C(     1),
         INT16_C(     1),  INT16_C(     1), -INT16_C(     2),  INT16_C(     0),  INT16_C(     0), -INT16_C(     1),  INT16_C(     1), -INT16_C(     1),
         INT16_C(     1), -INT16_C(     1),  INT16_C(     1), -INT16_C(     1),  INT16_C(     0), -INT16_C(     1), -INT16_C(     1),  INT16_C(     1) } }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
    simde__m512i a = simde_mm512_loadu_epi16(test_vec[i].a);
    simde__m128i b = simde_x_mm_loadu_epi64(test_vec[i].b);
    simde__m512i r = simde_mm512_sra_epi16(a, b);
    simde_test_x86_assert_equal_i16x32(r, simde_mm512_loadu_epi16(test_vec[i].r));
  }

  return 0;
}

static int
test_simde_mm512_srai_epi16 (SIMDE_MUNIT_TEST_ARGS) {
  static const struct {
    const int16_t a[32];
    const int16_t r0[32];
    const int16_t r3[32];
    const int16_t r7[32];
    const int16_t r13[32];
    const int16_t r24[32];
  } test_vec[] = {
    { { -INT16_C(  2725),  INT16_C(  6711),  INT16_C(  7327),  INT16_C( 11963),  INT16_C( 28148),  INT16_C(  5058),  INT16_C( 21695), -INT16_C( 19668),
        -INT16_C( 11147),  INT16_C( 27930), -INT16_C(  5129), -INT16_C( 26938), -INT16_C( 23608),  INT16_C( 22277),  INT16_C( 10373), -INT16_C(  8091),
        -INT16_C( 25571), -INT16_C( 17158), -INT16_C( 19015), -INT16_C( 21013), -INT16_C( 21214), -INT16_C(  7488), -INT16_C(  5119),  INT16_C( 30357),
        -INT16_C( 20543), -INT16_C( 18205), -INT16_C( 21861),  INT16_C( 25422),  INT16_C( 21325), -INT16_C( 11590),  INT16_C(  8315), -INT16_C( 26446) },
      { -INT16_C(  2725),  INT16_C(  6711),  INT16_C(  7327),  INT16_C( 11963),  INT16_C( 28148),  INT16_C(  5058),  INT16_C( 21695), -INT16_C( 19668),
        -INT16_C( 11147),  INT16_C( 27930), -INT16_C(  5129), -INT16_C( 26938), -INT16_C( 23608),  INT16_C( 22277),  INT16_C( 10373), -INT16_C(  8091),
        -INT16_C( 25571), -INT16_C( 17158), -INT16_C( 19015), -INT16_C( 21013), -INT16_C( 21214), -INT16_C(  7488), -INT16_C(  5119),  INT16_C( 30357),
        -INT16_C( 20543), -INT16_C( 18205), -INT16_C( 21861),  INT16_C( 25422),  INT16_C( 21325), -INT16_C( 11590),  INT16_C(  8315), -INT16_C( 26446) },
      { -INT16_C(   341),  INT16_C(   838),  INT16_C(   915),  INT16_C(  1495),  INT16_C(  3518),  INT16_C(   632),  INT16_C(  2711), -INT16_C(  2459),
        -INT16_C(  1394),  INT16_C(  3491), -INT16_C(   642), -INT16_C(  3368), -INT16_C(  2951),  INT16_C(  2784),  INT16_C(  1296), -INT16_C(  1012),
        -INT16_C(  3197), -INT16_C(  2145), -INT16_C(  2377), -INT16_C(  2627), -INT16_C(  2652), -INT16_C(   936), -INT16_C(   640),  INT16_C(  3794),
        -INT16_C(  2568), -INT16_C(  2276), -INT16_C(  2733),  INT16_C(  3177),  INT16_C(  2665), -INT16_C(  1449),  INT16_C(  1039), -INT16_C(  3306) },
      { -INT16_C(    22),  INT16_C(    52),  INT16_C(    57),  INT16_C(    93),  INT16_C(   219),  INT16_C(    39),  INT16_C(   169), -INT16_C(   154),
        -INT16_C(    88),  INT16_C(   218), -INT16_C(    41), -INT16_C(   211), -INT16_C(   185),  INT16_C(   174),  INT16_C(    81), -INT16_C(    64),
        -INT16_C(   200), -INT16_C(   135), -INT16_C(   149), -INT16_C(   165), -INT16_C(   166), -INT16_C(    59), -INT16_C(    40),  INT16_C(   237),
        -INT16_C(   161), -INT16_C(   143), -INT16_C(   171),  INT16_C(   198),  INT16_C(   166), -INT16_C(    91),  INT16_C(    64), -INT16_C(   207) },
      { -INT16_C(     1),  INT16_C(     0),  INT16_C(     0),  INT16_C(     1),  INT16_C(     3),  INT16_C(     0),  INT16_C(     2), -INT16_C(     3),
        -INT16_C(     2),  INT16_C(     3), -INT16_C(     1), -INT16_C(     4), -INT16_C(     3),  INT16_C(     2),  INT16_C(     1), -INT16_C(     1),
        -INT16_C(     4), -INT16_C(     3), -INT16_C(     3), -INT16_C(     3), -INT16_C(     3), -INT16_C(     1), -INT16_C(     1),  INT16_C(     3),
        -INT16_C(     3), -INT16_C(     3), -INT16_C(     3),  INT16_C(     3),  INT16_C(     2), -INT16_C(     2),  INT16_C(     1), -INT16_C(     4) },
      { -INT16_C(     1),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0), -INT16_C(     1),
        -INT16_C(     1),  INT16_C(     0), -INT16_C(     1), -INT16_C(     1), -INT16_C(     1),  INT16_C(     0),  INT16_C(     0), -INT16_C(     1),
        -INT16_C(     1), -INT16_C(     1), -INT16_C(     1), -INT16_C(     1), -INT16_C(     1), -INT16_C(     1), -INT16_C(     1),  INT16_C(     0),
        -INT16_C(     1), -INT16_C(     1), -INT16_C(     1),  INT16_C(     0),  INT16_C(     0), -INT16_C(     1),  INT16_C(     0), -INT16_C(     1) } },
    { { -INT16_C( 21316),  INT16_C( 30036),  INT16_C( 16225), -INT16_C( 31710), -INT16_C(  7444), -INT16_C(  4762), -INT16_C(  1073), -INT16_C( 28572),
         INT16_C( 18347),  INT16_C( 17992), -INT16_C( 26895),  INT16_C( 16041),  INT16_C( 25833),  INT16_C( 25616), -INT16_C( 15740),  INT16_C( 16636),
         INT16_C( 20590), -INT16_C( 12106), -INT16_C( 10096),  INT16_C( 31828), -INT16_C( 17733), -INT16_C( 30102), -INT16_C( 12619),  INT16_C( 24602),
         INT16_C( 25109),  INT16_C(  1958),  INT16_C( 20728), -INT16_C(  7867),  INT16_C( 22196),  INT16_C( 14405),  INT16_C( 16664), -INT16_C( 30856) },
      { -INT16_C( 21316),  INT16_C( 30036),  INT16_C( 16225), -INT16_C( 31710), -INT16_C(  7444), -INT16_C(  4762), -INT16_C(  1073), -INT16_C( 28572),
         INT16_C( 18347),  INT16_C( 17992), -INT16_C( 26895),  INT16_C( 16041),  INT16_C( 25833),  INT16_C( 25616), -INT16_C( 15740),  INT16_C( 16636),
         INT16_C( 20590), -INT16_C( 12106), -INT16_C( 10096),  INT16_C( 31828), -INT16_C( 17733), -INT16_C( 30102), -INT16_C( 12619),  INT16_C( 24602),
         INT16_C( 25109),  INT16_C(  1958),  INT16_C( 20728), -INT16_C(  7867),  INT16_C( 22196),  INT16_C( 14405),  INT16_C( 16664), -INT16_C( 30856) },
      { -INT16_C(  2665),  INT16_C(  3754),  INT16_C(  2028), -INT16_C(  3964), -INT16_C(   931), -INT16_C(   596), -INT16_C(   135), -INT16_C(  3572),
         INT16_C(  2293),  INT16_C(  2249), -INT16_C(  3362),  INT16_C(  2005),  INT16_C(  3229),  INT16_C(  3202), -INT16_C(  1968),  INT16_C(  2079),
         INT16_C(  2573), -INT16_C(  1514), -INT16_C(  1262),  INT16_C(  3978), -INT16_C(  2217), -INT16_C(  3763), -INT16_C(  1578),  INT16_C(  3075),
         INT16_C(  3138),  INT16_C(   244),  INT16_C(  2591), -INT16_C(   984),  INT16_C(  2774),  INT16_C(  1800),  INT16_C(  2083), -INT16_C(  3857) },
      { -INT16_C(   167),  INT16_C(   234),  INT16_C(   126), -INT16_C(   248), -INT16_C(    59), -INT16_C(    38), -INT16_C(     9), -INT16_C(   224),
         INT16_C(   143),  INT16_C(   140), -INT16_C(   211),  INT16_C(   125),  INT16_C(   201),  INT16_C(   200), -INT16_C(   123),  INT16_C(   129),
         INT16_C(   160), -INT16_C(    95), -INT16_C(    79),  INT16_C(   248), -INT16_C(   139), -INT16_C(   236), -INT16_C(    99),  INT16_C(   192),
         INT16_C(   196),  INT16_C(    15),  INT16_C(   161), -INT16_C(    62),  INT16_C(   173),  INT16_C(   112),  INT16_C(   130), -INT16_C(   242) },
      { -INT16_C(     3),  INT16_C(     3),  INT16_C(     1), -INT16_C(     4), -INT16_C(     1), -INT16_C(     1), -INT16_C(     1), -INT16_C(     4),
         INT16_C(     2),  INT16_C(     2), -INT16_C(     4),  INT16_C(     1),  INT16_C(     3),  INT16_C(     3), -INT16_C(     2),  INT16_C(     2),
         INT16_C(     2), -INT16_C(     2), -INT16_C(     2),  INT16_C(     3), -INT16_C(     3), -INT16_C(     4), -INT16_C(     2),  INT16_C(     3),
         INT16_C(     3),  INT16_C(     0),  INT16_C(     2), -INT16_C(     1),  INT16_C(     2),  INT16_C(     1),  INT16_C(     2), -INT16_C(     4) },
      { -INT16_C(     1),  INT16_C(     0),  INT16_C(     0), -INT16_C(     1), -INT16_C(     1), -INT16_C(     1), -INT16_C(     1), -INT16_C(     1),
         INT16_C(     0),  INT16_C(     0), -INT16_C(     1),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0), -INT16_C(     1),  INT16_C(     0),
         INT16_C(     0), -INT16_C(     1), -INT16_C(     1),  INT16_C(     0), -INT16_C(     1), -INT16_C(     1), -INT16_C(     1),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0), -INT16_C(     1),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0), -INT16_C(     1) } },
    { {  INT16_C( 11921),  INT16_C(  8535), -INT16_C( 21753), -INT16_C( 15714),  INT16_C(  2149),  INT16_C(  6732),  INT16_C( 26326), -INT16_C(  5253),
         INT16_C(  8648), -INT16_C( 16142),  INT16_C( 14449),  INT16_C(  9633), -INT16_C(  6514), -INT16_C( 22947), -INT16_C( 10713), -INT16_C( 18387),
        -INT16_C( 31740),  INT16_C(  3034),  INT16_C( 30767), -INT16_C( 27443),  INT16_C(  6528),  INT16_C( 22191),  INT16_C( 10879),  INT16_C( 18241),
         INT16_C( 13387), -INT16_C( 17145), -INT16_C( 22420), -INT16_C(  1310),  INT16_C( 16526), -INT16_C( 19040), -INT16_C( 12778),  INT16_C(  6766) },
      {  INT16_C( 11921),  INT16_C(  8535), -INT16_C( 21753), -INT16_C( 15714),  INT16_C(  2149),  INT16_C(  6732),  INT16_C( 26326), -INT16_C(  5253),
         INT16_C(  8648), -INT16_C( 16142),  INT16_C( 14449),  INT16_C(  9633), -INT16_C(  6514), -INT16_C( 22947), -INT16_C( 10713), -INT16_C( 18387),
        -INT16_C( 31740),  INT16_C(  3034),  INT16_C( 30767), -INT16_C( 27443),  INT16_C(  6528),  INT16_C( 22191),  INT16_C( 10879),  INT16_C( 18241),
         INT16_C( 13387), -INT16_C( 17145), -INT16_C( 22420), -INT16_C(  1310),  INT16_C( 16526), -INT16_C( 19040), -INT16_C( 12778),  INT16_C(  6766) },
      {  INT16_C(  1490),  INT16_C(  1066), -INT16_C(  2720), -INT16_C(  1965),  INT16_C(   268),  INT16_C(   841),  INT16_C(  3290), -INT16_C(   657),
         INT16_C(  1081), -INT16_C(  2018),  INT16_C(  1806),  INT16_C(  1204), -INT16_C(   815), -INT16_C(  2869), -INT16_C(  1340), -INT16_C(  2299),
        -INT16_C(  3968),  INT16_C(   379),  INT16_C(  3845), -INT16_C(  3431),  INT16_C(   816),  INT16_C(  2773),  INT16_C(  1359),  INT16_C(  2280),
         INT16_C(  1673), -INT16_C(  2144), -INT16_C(  2803), -INT16_C(   164),  INT16_C(  2065), -INT16_C(  2380), -INT16_C(  1598),  INT16_C(   845) },
      {  INT16_C(    93),  INT16_C(    66), -INT16_C(   170), -INT16_C(   123),  INT16_C(    16),  INT16_C(    52),  INT16_C(   205), -INT16_C(    42),
         INT16_C(    67), -INT16_C(   127),  INT16_C(   112),  INT16_C(    75), -INT16_C(    51), -INT16_C(   180), -INT16_C(    84), -INT16_C(   144),
        -INT16_C(   248),  INT16_C(    23),  INT16_C(   240), -INT16_C(   215),  INT16_C(    51),  INT16_C(   173),  INT16_C(    84),  INT16_C(   142),
         INT16_C(   104), -INT16_C(   134), -INT16_C(   176), -INT16_C(    11),  INT16_C(   129), -INT16_C(   149), -INT16_C(   100),  INT16_C(    52) },
      {  INT16_C(     1),  INT16_C(     1), -INT16_C(     3), -INT16_C(     2),  INT16_C(     0),  INT16_C(     0),  INT16_C(     3), -INT16_C(     1),
         INT16_C(     1), -INT16_C(     2),  INT16_C(     1),  INT16_C(     1), -INT16_C(     1), -INT16_C(     3), -INT16_C(     2), -INT16_C(     3),
        -INT16_C(     4),  INT16_C(     0),  INT16_C(     3), -INT16_C(     4),  INT16_C(     0),  INT16_C(     2),  INT16_C(     1),  INT16_C(     2),
         INT16_C(     1), -INT16_C(     3), -INT16_C(     3), -INT16_C(     1),  INT16_C(     2), -INT16_C(     3), -INT16_C(     2),  INT16_C(     0) },
      {  INT16_C(     0),  INT16_C(     0), -INT16_C(     1), -INT16_C(     1),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0), -INT16_C(     1),
         INT16_C(     0), -INT16_C(     1),  INT16_C(     0),  INT16_C(     0), -INT16_C(     1), -INT16_C(     1), -INT16_C(     1), -INT16_C(     1),
        -INT16_C(     1),  INT16_C(     0),  INT16_C(     0), -INT16_C(     1),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0), -INT16_C(     1), -INT16_C(     1), -INT16_C(     1),  INT16_C(     0), -INT16_C(     1), -INT16_C(     1),  INT16_C(     0) } },
    { {  INT16_C( 18514), -INT16_C( 32218), -INT16_C(  3136),  INT16_C( 16406), -INT16_C( 15091), -INT16_C( 29546), -INT16_C( 10257),  INT16_C( 15316),
        -INT16_C(  9461),  INT16_C( 30712), -INT16_C(  9596),  INT16_C(  4721),  INT16_C(  4634),  INT16_C( 12488),  INT16_C( 14048),  INT16_C( 12875),
         INT16_C( 29054),  INT16_C( 16052), -INT16_C( 13468),  INT16_C( 29054),  INT16_C(  5264), -INT16_C( 32514), -INT16_C( 11541), -INT16_C(  2117),
        -INT16_C( 19539),  INT16_C( 12654), -INT16_C(  8051), -INT16_C( 22460),  INT16_C(  3314), -INT16_C( 11560),  INT16_C(  9026), -INT16_C( 16380) },
      {  INT16_C( 18514), -INT16_C( 32218), -INT16_C(  3136),  INT16_C( 16406), -INT16_C( 15091), -INT16_C( 29546), -INT16_C( 10257),  INT16_C( 15316),
        -INT16_C(  9461),  INT16_C( 30712), -INT16_C(  9596),  INT16_C(  4721),  INT16_C(  4634),  INT16_C( 12488),  INT16_C( 14048),  INT16_C( 12875),
         INT16_C( 29054),  INT16_C( 16052), -INT16_C( 13468),  INT16_C( 29054),  INT16_C(  5264), -INT16_C( 32514), -INT16_C( 11541), -INT16_C(  2117),
        -INT16_C( 19539),  INT16_C( 12654), -INT16_C(  8051), -INT16_C( 22460),  INT16_C(  3314), -INT16_C( 11560),  INT16_C(  9026), -INT16_C( 16380) },
      {  INT16_C(  2314), -INT16_C(  4028), -INT16_C(   392),  INT16_C(  2050), -INT16_C(  1887), -INT16_C(  3694), -INT16_C(  1283),  INT16_C(  1914),
        -INT16_C(  1183),  INT16_C(  3839), -INT16_C(  1200),  INT16_C(   590),  INT16_C(   579),  INT16_C(  1561),  INT16_C(  1756),  INT16_C(  1609),
         INT16_C(  3631),  INT16_C(  2006), -INT16_C(  1684),  INT16_C(  3631),  INT16_C(   658), -INT16_C(  4065), -INT16_C(  1443), -INT16_C(   265),
        -INT16_C(  2443),  INT16_C(  1581), -INT16_C(  1007), -INT16_C(  2808),  INT16_C(   414), -INT16_C(  1445),  INT16_C(  1128), -INT16_C(  2048) },
      {  INT16_C(   144), -INT16_C(   252), -INT16_C(    25),  INT16_C(   128), -INT16_C(   118), -INT16_C(   231), -INT16_C(    81),  INT16_C(   119),
        -INT16_C(    74),  INT16_C(   239), -INT16_C(    75),  INT16_C(    36),  INT16_C(    36),  INT16_C(    97),  INT16_C(   109),  INT16_C(   100),
         INT16_C(   226),  INT16_C(   125), -INT16_C(   106),  INT16_C(   226),  INT16_C(    41), -INT16_C(   255), -INT16_C(    91), -INT16_C(    17),
        -INT16_C(   153),  INT16_C(    98), -INT16_C(    63), -INT16_C(   176),  INT16_C(    25), -INT16_C(    91),  INT16_C(    70), -INT16_C(   128) },
      {  INT16_C(     2), -INT16_C(     4), -INT16_C(     1),  INT16_C(     2), -INT16_C(     2), -INT16_C(     4), -INT16_C(     2),  INT16_C(     1),
        -INT16_C(     2),  INT16_C(     3), -INT16_C(     2),  INT16_C(     0),  INT16_C(     0),  INT16_C(     1),  INT16_C(     1),  INT16_C(     1),
         INT16_C(     3),  INT16_C(     1), -INT16_C(     2),  INT16_C(     3),  INT16_C(     0), -INT16_C(     4), -INT16_C(     2), -INT16_C(     1),
        -INT16_C(     3),  INT16_C(     1), -INT16_C(     1), -INT16_C(     3),  INT16_C(     0), -INT16_C(     2),  INT16_C(     1), -INT16_C(     2) },
      {  INT16_C(     0), -INT16_C(     1), -INT16_C(     1),  INT16_C(     0), -INT16_C(     1), -INT16_C(     1), -INT16_C(     1),  INT16_C(     0),
        -INT16_C(     1),  INT16_C(     0), -INT16_C(     1),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0), -INT16_C(     1),  INT16_C(     0),  INT16_C(     0), -INT16_C(     1), -INT16_C(     1), -INT16_C(     1),
        -INT16_C(     1),  INT16_C(     0), -INT16_C(     1), -INT16_C(     1),  INT16_C(     0), -INT16_C(     1),  INT16_C(     0), -INT16_C(     1) } },
    { { -INT16_C( 18028), -INT16_C(  1538),  INT16_C( 31876),  INT16_C(  5226),  INT16_C( 26768),  INT16_C( 31636),  INT16_C( 20282), -INT16_C(  6030),
        -INT16_C(  7934), -INT16_C( 28647),  INT16_C( 24001), -INT16_C( 19656),  INT16_C(  4201), -INT16_C( 21627), -INT16_C( 30412), -INT16_C( 14229),
         INT16_C( 26946), -INT16_C( 14655),  INT16_C( 11493),  INT16_C( 30171),  INT16_C( 28564), -INT16_C( 12303),  INT16_C( 25535), -INT16_C( 15945),
        -INT16_C( 12220),  INT16_C(  1361), -INT16_C( 30418), -INT16_C( 26696),  INT16_C( 15770), -INT16_C( 12733), -INT16_C( 20793),  INT16_C(  2454) },
      { -INT16_C( 18028), -INT16_C(  1538),  INT16_C( 31876),  INT16_C(  5226),  INT16_C( 26768),  INT16_C( 31636),  INT16_C( 20282), -INT16_C(  6030),
        -INT16_C(  7934), -INT16_C( 28647),  INT16_C( 24001), -INT16_C( 19656),  INT16_C(  4201), -INT16_C( 21627), -INT16_C( 30412), -INT16_C( 14229),
         INT16_C( 26946), -INT16_C( 14655),  INT16_C( 11493),  INT16_C( 30171),  INT16_C( 28564), -INT16_C( 12303),  INT16_C( 25535), -INT16_C( 15945),
        -INT16_C( 12220),  INT16_C(  1361), -INT16_C( 30418), -INT16_C( 26696),  INT16_C( 15770), -INT16_C( 12733), -INT16_C( 20793),  INT16_C(  2454) },
      { -INT16_C(  2254), -INT16_C(   193),  INT16_C(  3984),  INT16_C(   653),  INT16_C(  3346),  INT16_C(  3954),  INT16_C(  2535), -INT16_C(   754),
        -INT16_C(   992), -INT16_C(  3581),  INT16_C(  3000), -INT16_C(  2457),  INT16_C(   525), -INT16_C(  2704), -INT16_C(  3802), -INT16_C(  1779),
         INT16_C(  3368), -INT16_C(  1832),  INT16_C(  1436),  INT16_C(  3771),  INT16_C(  3570), -INT16_C(  1538),  INT16_C(  3191), -INT16_C(  1994),
        -INT16_C(  1528),  INT16_C(   170), -INT16_C(  3803), -INT16_C(  3337),  INT16_C(  1971), -INT16_C(  1592), -INT16_C(  2600),  INT16_C(   306) },
      { -INT16_C(   141), -INT16_C(    13),  INT16_C(   249),  INT16_C(    40),  INT16_C(   209),  INT16_C(   247),  INT16_C(   158), -INT16_C(    48),
        -INT16_C(    62), -INT16_C(   224),  INT16_C(   187), -INT16_C(   154),  INT16_C(    32), -INT16_C(   169), -INT16_C(   238), -INT16_C(   112),
         INT16_C(   210), -INT16_C(   115),  INT16_C(    89),  INT16_C(   235),  INT16_C(   223), -INT16_C(    97),  INT16_C(   199), -INT16_C(   125),
        -INT16_C(    96),  INT16_C(    10), -INT16_C(   238), -INT16_C(   209),  INT16_C(   123), -INT16_C(   100), -INT16_C(   163),  INT16_C(    19) },
      { -INT16_C(     3), -INT16_C(     1),  INT16_C(     3),  INT16_C(     0),  INT16_C(     3),  INT16_C(     3),  INT16_C(     2), -INT16_C(     1),
        -INT16_C(     1), -INT16_C(     4),  INT16_C(     2), -INT16_C(     3),  INT16_C(     0), -INT16_C(     3), -INT16_C(     4), -INT16_C(     2),
         INT16_C(     3), -INT16_C(     2),  INT16_C(     1),  INT16_C(     3),  INT16_C(     3), -INT16_C(     2),  INT16_C(     3), -INT16_C(     2),
        -INT16_C(     2),  INT16_C(     0), -INT16_C(     4), -INT16_C(     4),  INT16_C(     1), -INT16_C(     2), -INT16_C(     3),  INT16_C(     0) },
      { -INT16_C(     1), -INT16_C(     1),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0), -INT16_C(     1),
        -INT16_C(     1), -INT16_C(     1),  INT16_C(     0), -INT16_C(     1),  INT16_C(     0), -INT16_C(     1), -INT16_C(     1), -INT16_C(     1),
         INT16_C(     0), -INT16_C(     1),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0), -INT16_C(     1),  INT16_C(     0), -INT16_C(     1),
        -INT16_C(     1),  INT16_C(     0), -INT16_C(     1), -INT16_C(     1),  INT16_C(     0), -INT16_C(     1), -INT16_C(     1),  INT16_C(     0) } },
    { {  INT16_C( 22552), -INT16_C(   560), -INT16_C( 21628),  INT16_C(  6259),  INT16_C( 25626), -INT16_C(  9753), -INT16_C( 24889),  INT16_C(  3227),
        -INT16_C(  5009), -INT16_C( 25327), -INT16_C( 13706),  INT16_C(  4148),  INT16_C( 30471), -INT16_C( 12578),  INT16_C( 29734),  INT16_C( 16088),
        -INT16_C( 22324),  INT16_C( 20539), -INT16_C( 20909),  INT16_C( 28009),  INT16_C( 20498), -INT16_C(  9657), -INT16_C(  7441),  INT16_C( 24294),
        -INT16_C(  2098),  INT16_C( 17659),  INT16_C( 12225), -INT16_C( 13996),  INT16_C( 12967), -INT16_C( 12905),  INT16_C( 28583),  INT16_C( 29451) },
      {  INT16_C( 22552), -INT16_C(   560), -INT16_C( 21628),  INT16_C(  6259),  INT16_C( 25626), -INT16_C(  9753), -INT16_C( 24889),  INT16_C(  3227),
        -INT16_C(  5009), -INT16_C( 25327), -INT16_C( 13706),  INT16_C(  4148),  INT16_C( 30471), -INT16_C( 12578),  INT16_C( 29734),  INT16_C( 16088),
        -INT16_C( 22324),  INT16_C( 20539), -INT16_C( 20909),  INT16_C( 28009),  INT16_C( 20498), -INT16_C(  9657), -INT16_C(  7441),  INT16_C( 24294),
        -INT16_C(  2098),  INT16_C( 17659),  INT16_C( 12225), -INT16_C( 13996),  INT16_C( 12967), -INT16_C( 12905),  INT16_C( 28583),  INT16_C( 29451) },
      {  INT16_C(  2819), -INT16_C(    70), -INT16_C(  2704),  INT16_C(   782),  INT16_C(  3203), -INT16_C(  1220), -INT16_C(  3112),  INT16_C(   403),
        -INT16_C(   627), -INT16_C(  3166), -INT16_C(  1714),  INT16_C(   518),  INT16_C(  3808), -INT16_C(  1573),  INT16_C(  3716),  INT16_C(  2011),
        -INT16_C(  2791),  INT16_C(  2567), -INT16_C(  2614),  INT16_C(  3501),  INT16_C(  2562), -INT16_C(  1208), -INT16_C(   931),  INT16_C(  3036),
        -INT16_C(   263),  INT16_C(  2207),  INT16_C(  1528), -INT16_C(  1750),  INT16_C(  1620), -INT16_C(  1614),  INT16_C(  3572),  INT16_C(  3681) },
      {  INT16_C(   176), -INT16_C(     5), -INT16_C(   169),  INT16_C(    48),  INT16_C(   200), -INT16_C(    77), -INT16_C(   195),  INT16_C(    25),
        -INT16_C(    40), -INT16_C(   198), -INT16_C(   108),  INT16_C(    32),  INT16_C(   238), -INT16_C(    99),  INT16_C(   232),  INT16_C(   125),
        -INT16_C(   175),  INT16_C(   160), -INT16_C(   164),  INT16_C(   218),  INT16_C(   160), -INT16_C(    76), -INT16_C(    59),  INT16_C(   189),
        -INT16_C(    17),  INT16_C(   137),  INT16_C(    95), -INT16_C(   110),  INT16_C(   101), -INT16_C(   101),  INT16_C(   223),  INT16_C(   230) },
      {  INT16_C(     2), -INT16_C(     1), -INT16_C(     3),  INT16_C(     0),  INT16_C(     3), -INT16_C(     2), -INT16_C(     4),  INT16_C(     0),
        -INT16_C(     1), -INT16_C(     4), -INT16_C(     2),  INT16_C(     0),  INT16_C(     3), -INT16_C(     2),  INT16_C(     3),  INT16_C(     1),
        -INT16_C(     3),  INT16_C(     2), -INT16_C(     3),  INT16_C(     3),  INT16_C(     2), -INT16_C(     2), -INT16_C(     1),  INT16_C(     2),
        -INT16_C(     1),  INT16_C(     2),  INT16_C(     1), -INT16_C(     2),  INT16_C(     1), -INT16_C(     2),  INT16_C(     3),  INT16_C(     3) },
      {  INT16_C(     0), -INT16_C(     1), -INT16_C(     1),  INT16_C(     0),  INT16_C(     0), -INT16_C(     1), -INT16_C(     1),  INT16_C(     0),
        -INT16_C(     1), -INT16_C(     1), -INT16_C(     1),  INT16_C(     0),  INT16_C(     0), -INT16_C(     1),  INT16_C(     0),  INT16_C(     0),
        -INT16_C(     1),  INT16_C(     0), -INT16_C(     1),  INT16_C(     0),  INT16_C(     0), -INT16_C(     1), -INT16_C(     1),  INT16_C(     0),
        -INT16_C(     1),  INT16_C(     0),  INT16_C(     0), -INT16_C(     1),  INT16_C(     0), -INT16_C(     1),  INT16_C(     0),  INT16_C(     0) } },
    { {  INT16_C( 17943),  INT16_C( 27332),  INT16_C( 11765),  INT16_C(  2008),  INT16_C(  8061),  INT16_C( 27873), -INT16_C( 14591), -INT16_C( 12342),
        -INT16_C( 14913), -INT16_C( 32748),  INT16_C( 26869), -INT16_C( 25527), -INT16_C(  7781),  INT16_C( 17001),  INT16_C( 29776),  INT16_C( 26805),
         INT16_C( 31162), -INT16_C( 20526), -INT16_C( 21850),  INT16_C(  9399), -INT16_C( 26423), -INT16_C( 13680),  INT16_C( 23392),  INT16_C(  8090),
        -INT16_C( 20960),  INT16_C(  5535), -INT16_C(  5866), -INT16_C( 20047),  INT16_C(  6858),  INT16_C(  6899), -INT16_C( 22130),  INT16_C( 18818) },
      {  INT16_C( 17943),  INT16_C( 27332),  INT16_C( 11765),  INT16_C(  2008),  INT16_C(  8061),  INT16_C( 27873), -INT16_C( 14591), -INT16_C( 12342),
        -INT16_C( 14913), -INT16_C( 32748),  INT16_C( 26869), -INT16_C( 25527), -INT16_C(  7781),  INT16_C( 17001),  INT16_C( 29776),  INT16_C( 26805),
         INT16_C( 31162), -INT16_C( 20526), -INT16_C( 21850),  INT16_C(  9399), -INT16_C( 26423), -INT16_C( 13680),  INT16_C( 23392),  INT16_C(  8090),
        -INT16_C( 20960),  INT16_C(  5535), -INT16_C(  5866), -INT16_C( 20047),  INT16_C(  6858),  INT16_C(  6899), -INT16_C( 22130),  INT16_C( 18818) },
      {  INT16_C(  2242),  INT16_C(  3416),  INT16_C(  1470),  INT16_C(   251),  INT16_C(  1007),  INT16_C(  3484), -INT16_C(  1824), -INT16_C(  1543),
        -INT16_C(  1865), -INT16_C(  4094),  INT16_C(  3358), -INT16_C(  3191), -INT16_C(   973),  INT16_C(  2125),  INT16_C(  3722),  INT16_C(  3350),
         INT16_C(  3895), -INT16_C(  2566), -INT16_C(  2732),  INT16_C(  1174), -INT16_C(  3303), -INT16_C(  1710),  INT16_C(  2924),  INT16_C(  1011),
        -INT16_C(  2620),  INT16_C(   691), -INT16_C(   734), -INT16_C(  2506),  INT16_C(   857),  INT16_C(   862), -INT16_C(  2767),  INT16_C(  2352) },
      {  INT16_C(   140),  INT16_C(   213),  INT16_C(    91),  INT16_C(    15),  INT16_C(    62),  INT16_C(   217), -INT16_C(   114), -INT16_C(    97),
        -INT16_C(   117), -INT16_C(   256),  INT16_C(   209), -INT16_C(   200), -INT16_C(    61),  INT16_C(   132),  INT16_C(   232),  INT16_C(   209),
         INT16_C(   243), -INT16_C(   161), -INT16_C(   171),  INT16_C(    73), -INT16_C(   207), -INT16_C(   107),  INT16_C(   182),  INT16_C(    63),
        -INT16_C(   164),  INT16_C(    43), -INT16_C(    46), -INT16_C(   157),  INT16_C(    53),  INT16_C(    53), -INT16_C(   173),  INT16_C(   147) },
      {  INT16_C(     2),  INT16_C(     3),  INT16_C(     1),  INT16_C(     0),  INT16_C(     0),  INT16_C(     3), -INT16_C(     2), -INT16_C(     2),
        -INT16_C(     2), -INT16_C(     4),  INT16_C(     3), -INT16_C(     4), -INT16_C(     1),  INT16_C(     2),  INT16_C(     3),  INT16_C(     3),
         INT16_C(     3), -INT16_C(     3), -INT16_C(     3),  INT16_C(     1), -INT16_C(     4), -INT16_C(     2),  INT16_C(     2),  INT16_C(     0),
        -INT16_C(     3),  INT16_C(     0), -INT16_C(     1), -INT16_C(     3),  INT16_C(     0),  INT16_C(     0), -INT16_C(     3),  INT16_C(     2) },
      {  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0), -INT16_C(     1), -INT16_C(     1),
        -INT16_C(     1), -INT16_C(     1),  INT16_C(     0), -INT16_C(     1), -INT16_C(     1),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0), -INT16_C(     1), -INT16_C(     1),  INT16_C(     0), -INT16_C(     1), -INT16_C(     1),  INT16_C(     0),  INT16_C(     0),
        -INT16_C(     1),  INT16_C(     0), -INT16_C(     1), -INT16_C(     1),  INT16_C(     0),  INT16_C(     0), -INT16_C(     1),  INT16_C(     0) } },
    { {  INT16_C( 21794), -INT16_C( 13832), -INT16_C( 20481), -INT16_C( 13843),  INT16_C( 32072), -INT16_C( 22381),  INT16_C( 11736), -INT16_C(  1593),
         INT16_C( 26331), -INT16_C(  3570), -INT16_C( 16305),  INT16_C(  6563), -INT16_C( 26662),  INT16_C( 26932), -INT16_C( 18880),  INT16_C( 25266),
        -INT16_C( 22005),  INT16_C(  2859),  INT16_C(  6234), -INT16_C( 23852),  INT16_C( 26518),  INT16_C( 28234),  INT16_C(  4501),  INT16_C( 28775),
         INT16_C( 30327), -INT16_C( 14494),  INT16_C(  1590),  INT16_C(  4320),  INT16_C(  5277), -INT16_C(  8839),  INT16_C( 11211), -INT16_C( 10689) },
      {  INT16_C( 21794), -INT16_C( 13832), -INT16_C( 20481), -INT16_C( 13843),  INT16_C( 32072), -INT16_C( 22381),  INT16_C( 11736), -INT16_C(  1593),
         INT16_C( 26331), -INT16_C(  3570), -INT16_C( 16305),  INT16_C(  6563), -INT16_C( 26662),  INT16_C( 26932), -INT16_C( 18880),  INT16_C( 25266),
        -INT16_C( 22005),  INT16_C(  2859),  INT16_C(  6234), -INT16_C( 23852),  INT16_C( 26518),  INT16_C( 28234),  INT16_C(  4501),  INT16_C( 28775),
         INT16_C( 30327), -INT16_C( 14494),  INT16_C(  1590),  INT16_C(  4320),  INT16_C(  5277), -INT16_C(  8839),  INT16_C( 11211), -INT16_C( 10689) },
      {  INT16_C(  2724), -INT16_C(  1729), -INT16_C(  2561), -INT16_C(  1731),  INT16_C(  4009), -INT16_C(  2798),  INT16_C(  1467), -INT16_C(   200),
         INT16_C(  3291), -INT16_C(   447), -INT16_C(  2039),  INT16_C(   820), -INT16_C(  3333),  INT16_C(  3366), -INT16_C(  2360),  INT16_C(  3158),
        -INT16_C(  2751),  INT16_C(   357),  INT16_C(   779), -INT16_C(  2982),  INT16_C(  3314),  INT16_C(  3529),  INT16_C(   562),  INT16_C(  3596),
         INT16_C(  3790), -INT16_C(  1812),  INT16_C(   198),  INT16_C(   540),  INT16_C(   659), -INT16_C(  1105),  INT16_C(  1401), -INT16_C(  1337) },
      {  INT16_C(   170), -INT16_C(   109), -INT16_C(   161), -INT16_C(   109),  INT16_C(   250), -INT16_C(   175),  INT16_C(    91), -INT16_C(    13),
         INT16_C(   205), -INT16_C(    28), -INT16_C(   128),  INT16_C(    51), -INT16_C(   209),  INT16_C(   210), -INT16_C(   148),  INT16_C(   197),
        -INT16_C(   172),  INT16_C(    22),  INT16_C(    48), -INT16_C(   187),  INT16_C(   207),  INT16_C(   220),  INT16_C(    35),  INT16_C(   224),
         INT16_C(   236), -INT16_C(   114),  INT16_C(    12),  INT16_C(    33),  INT16_C(    41), -INT16_C(    70),  INT16_C(    87), -INT16_C(    84) },
      {  INT16_C(     2), -INT16_C(     2), -INT16_C(     3), -INT16_C(     2),  INT16_C(     3), -INT16_C(     3),  INT16_C(     1), -INT16_C(     1),
         INT16_C(     3), -INT16_C(     1), -INT16_C(     2),  INT16_C(     0), -INT16_C(     4),  INT16_C(     3), -INT16_C(     3),  INT16_C(     3),
        -INT16_C(     3),  INT16_C(     0),  INT16_C(     0), -INT16_C(     3),  INT16_C(     3),  INT16_C(     3),  INT16_C(     0),  INT16_C(     3),
         INT16_C(     3), -INT16_C(     2),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0), -INT16_C(     2),  INT16_C(     1), -INT16_C(     2) },
      {  INT16_C(     0), -INT16_C(     1), -INT16_C(     1), -INT16_C(     1),  INT16_C(     0), -INT16_C(     1),  INT16_C(     0), -INT16_C(     1),
         INT16_C(     0), -INT16_C(     1), -INT16_C(     1),  INT16_C(     0), -INT16_C(     1),  INT16_C(     0), -INT16_C(     1),  INT16_C(     0),
        -INT16_C(     1),  INT16_C(     0),  INT16_C(     0), -INT16_C(     1),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0), -INT16_C(     1),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0), -INT16_C(     1),  INT16_C(     0), -INT16_C(     1) } }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
    simde__m512i a = simde_mm512_loadu_epi16(test_vec[i].a);
    simde__m512i r0 = simde_mm512_srai_epi16(a, 0);
    simde__m512i r3 = simde_mm512_srai_epi16(a, 3);
    simde__m512i r7 = simde_mm512_srai_epi16(a, 7);
    simde__m512i r13 = simde_mm512_srai_epi16(a, 13);
    simde__m512i r24 = simde_mm512_srai_epi16(a, 24);
    simde_test_x86_assert_equal_i16x32(r0, simde_mm512_loadu_epi16(test_vec[i].r0));
    simde_test_x86_assert_equal_i16x32(r3, simde_mm512_loadu_epi16(test_vec[i].r3));
    simde_test_x86_assert_equal_i16x32(r7, simde_mm512_loadu_epi16(test_vec[i].r7));
    simde_test_x86_assert_equal_i16x32(r13, simde_mm512_loadu_epi16(test_vec[i].r13));
    simde_test_x86_assert_equal_i16x32(r24, simde_mm512_loadu_epi16(test_vec[i].r24));
  }

  return 0;
}

static int
test_simde_mm512_srav_epi16 (SIMDE_MUNIT_TEST_ARGS) {
  static const struct {
    const int16_t a[32];
    const int16_t b[32];
    const int16_t r[32];
  } test_vec[] = {
    { { -INT16_C( 26126),  INT16_C(  9315),  INT16_C( 20615), -INT16_C( 25676),  INT16_C( 25129), -INT16_C( 13781), -INT16_C( 22935), -INT16_C( 22311),
        -INT16_C(   968),  INT16_C( 28073), -INT16_C(  1215),  INT16_C(  1561), -INT16_C(  5797),  INT16_C( 15623), -INT16_C( 24120), -INT16_C( 17815),
        -INT16_C( 13254), -INT16_C( 15649), -INT16_C( 27875),  INT16_C( 18013), -INT16_C( 30475),  INT16_C( 24080), -INT16_C(  5841),  INT16_C( 26374),
        -INT16_C( 20250),  INT16_C( 10196), -INT16_C(  4693),  INT16_C(  1581),  INT16_C( 13782), -INT16_C( 24765), -INT16_C( 21290),  INT16_C(  4185) },
      {  INT16_C(     3),  INT16_C(     9),  INT16_C(     2),  INT16_C(    12),  INT16_C(    14),  INT16_C(    14),  INT16_C(     2),  INT16_C(    11),
         INT16_C(     2),  INT16_C(     8),  INT16_C(     0),  INT16_C(    14),  INT16_C(    12),  INT16_C(     1),  INT16_C(    13),  INT16_C(    14),
         INT16_C(    15),  INT16_C(    14),  INT16_C(     5),  INT16_C(    14),  INT16_C(    12),  INT16_C(     2),  INT16_C(     1),  INT16_C(    12),
         INT16_C(    11),  INT16_C(     4),  INT16_C(    12),  INT16_C(     1),  INT16_C(    11),  INT16_C(     0),  INT16_C(     5),  INT16_C(    11) },
      { -INT16_C(  3266),  INT16_C(    18),  INT16_C(  5153), -INT16_C(     7),  INT16_C(     1), -INT16_C(     1), -INT16_C(  5734), -INT16_C(    11),
        -INT16_C(   242),  INT16_C(   109), -INT16_C(  1215),  INT16_C(     0), -INT16_C(     2),  INT16_C(  7811), -INT16_C(     3), -INT16_C(     2),
        -INT16_C(     1), -INT16_C(     1), -INT16_C(   872),  INT16_C(     1), -INT16_C(     8),  INT16_C(  6020), -INT16_C(  2921),  INT16_C(     6),
        -INT16_C(    10),  INT16_C(   637), -INT16_C(     2),  INT16_C(   790),  INT16_C(     6), -INT16_C( 24765), -INT16_C(   666),  INT16_C(     2) } },
    { {  INT16_C( 31316), -INT16_C( 32362),  INT16_C( 15066),  INT16_C(  9574),  INT16_C( 13054), -INT16_C(  6075),  INT16_C(  8268), -INT16_C( 30040),
        -INT16_C(  5667), -INT16_C( 22056),  INT16_C(  3505),  INT16_C( 17338), -INT16_C(  6456),  INT16_C( 25163),  INT16_C( 16956), -INT16_C( 28651),
        -INT16_C( 21572), -INT16_C( 27119),  INT16_C( 30693), -INT16_C(  6981),  INT16_C(   169), -INT16_C(  2356),  INT16_C( 29984), -INT16_C(   640),
         INT16_C( 22622),  INT16_C(  4263),  INT16_C( 24933),  INT16_C( 11603), -INT16_C( 24761), -INT16_C( 31601), -INT16_C( 23327), -INT16_C( 25324) },
      {  INT16_C(     2),  INT16_C(     3),  INT16_C(    14),  INT16_C(     4),  INT16_C(    14),  INT16_C(     1),  INT16_C(    11),  INT16_C(    11),
         INT16_C(    11),  INT16_C(     7),  INT16_C(     1),  INT16_C(     5),  INT16_C(     3),  INT16_C(     9),  INT16_C(    15),  INT16_C(     2),
         INT16_C(     6),  INT16_C(    11),  INT16_C(     7),  INT16_C(     4),  INT16_C(     3),  INT16_C(    11),  INT16_C(     6),  INT16_C(     1),
         INT16_C(     3),  INT16_C(     3),  INT16_C(     3),  INT16_C(     1),  INT16_C(     7),  INT16_C(     4),  INT16_C(    14),  INT16_C(     8) },
      {  INT16_C(  7829), -INT16_C(  4046),  INT16_C(     0),  INT16_C(   598),  INT16_C(     0), -INT16_C(  3038),  INT16_C(     4), -INT16_C(    15),
        -INT16_C(     3), -INT16_C(   173),  INT16_C(  1752),  INT16_C(   541), -INT16_C(   807),  INT16_C(    49),  INT16_C(     0), -INT16_C(  7163),
        -INT16_C(   338), -INT16_C(    14),  INT16_C(   239), -INT16_C(   437),  INT16_C(    21), -INT16_C(     2),  INT16_C(   468), -INT16_C(   320),
         INT16_C(  2827),  INT16_C(   532),  INT16_C(  3116),  INT16_C(  5801), -INT16_C(   194), -INT16_C(  1976), -INT16_C(     2), -INT16_C(    99) } },
    { { -INT16_C( 13225), -INT16_C( 19388),  INT16_C( 17733), -INT16_C( 23806),  INT16_C( 24707),  INT16_C( 32347), -INT16_C( 12852), -INT16_C(  4722),
         INT16_C(  6151),  INT16_C( 24100), -INT16_C( 17847), -INT16_C( 20111),  INT16_C(  8241), -INT16_C( 24589),  INT16_C( 24585),  INT16_C( 24618),
         INT16_C( 28205),  INT16_C( 29204),  INT16_C(  5812),  INT16_C( 14101),  INT16_C( 28790),  INT16_C( 17078),  INT16_C( 17469),  INT16_C( 17711),
         INT16_C( 21597), -INT16_C( 22877),  INT16_C(  5134),  INT16_C( 16215),  INT16_C( 19252),  INT16_C( 15839),  INT16_C(  2475), -INT16_C( 10083) },
      {  INT16_C(    11),  INT16_C(     2),  INT16_C(     5),  INT16_C(     3),  INT16_C(     1),  INT16_C(     0),  INT16_C(    11),  INT16_C(    11),
         INT16_C(    15),  INT16_C(     1),  INT16_C(    11),  INT16_C(     3),  INT16_C(     3),  INT16_C(    10),  INT16_C(     1),  INT16_C(    11),
         INT16_C(    13),  INT16_C(     9),  INT16_C(     4),  INT16_C(     0),  INT16_C(     5),  INT16_C(    11),  INT16_C(     6),  INT16_C(     0),
         INT16_C(    13),  INT16_C(     6),  INT16_C(     7),  INT16_C(     8),  INT16_C(     1),  INT16_C(    13),  INT16_C(    12),  INT16_C(     0) },
      { -INT16_C(     7), -INT16_C(  4847),  INT16_C(   554), -INT16_C(  2976),  INT16_C( 12353),  INT16_C( 32347), -INT16_C(     7), -INT16_C(     3),
         INT16_C(     0),  INT16_C( 12050), -INT16_C(     9), -INT16_C(  2514),  INT16_C(  1030), -INT16_C(    25),  INT16_C( 12292),  INT16_C(    12),
         INT16_C(     3),  INT16_C(    57),  INT16_C(   363),  INT16_C( 14101),  INT16_C(   899),  INT16_C(     8),  INT16_C(   272),  INT16_C( 17711),
         INT16_C(     2), -INT16_C(   358),  INT16_C(    40),  INT16_C(    63),  INT16_C(  9626),  INT16_C(     1),  INT16_C(     0), -INT16_C( 10083) } },
    { {  INT16_C( 27799), -INT16_C( 14184),  INT16_C( 27564),  INT16_C(  1738), -INT16_C(  9792), -INT16_C( 14659),  INT16_C( 11834), -INT16_C( 27951),
        -INT16_C(  4351), -INT16_C( 29452), -INT16_C( 27296),  INT16_C(   538),  INT16_C( 22706), -INT16_C(  5410),  INT16_C( 27933), -INT16_C( 19219),
        -INT16_C( 31271), -INT16_C( 31364),  INT16_C( 18161), -INT16_C( 20085),  INT16_C( 18463),  INT16_C( 23160),  INT16_C( 18807),  INT16_C( 30956),
        -INT16_C(  8135), -INT16_C( 26364),  INT16_C(  7797),  INT16_C( 10139),  INT16_C( 31094), -INT16_C( 27887), -INT16_C(    26), -INT16_C( 16569) },
      {  INT16_C(    12),  INT16_C(     7),  INT16_C(    13),  INT16_C(     2),  INT16_C(     9),  INT16_C(     9),  INT16_C(     7),  INT16_C(     2),
         INT16_C(     0),  INT16_C(    12),  INT16_C(     5),  INT16_C(    10),  INT16_C(    15),  INT16_C(    11),  INT16_C(     7),  INT16_C(     8),
         INT16_C(    11),  INT16_C(     4),  INT16_C(     1),  INT16_C(    10),  INT16_C(    15),  INT16_C(    10),  INT16_C(     3),  INT16_C(    11),
         INT16_C(     8),  INT16_C(     7),  INT16_C(     6),  INT16_C(    10),  INT16_C(     4),  INT16_C(     6),  INT16_C(    13),  INT16_C(     0) },
      {  INT16_C(     6), -INT16_C(   111),  INT16_C(     3),  INT16_C(   434), -INT16_C(    20), -INT16_C(    29),  INT16_C(    92), -INT16_C(  6988),
        -INT16_C(  4351), -INT16_C(     8), -INT16_C(   853),  INT16_C(     0),  INT16_C(     0), -INT16_C(     3),  INT16_C(   218), -INT16_C(    76),
        -INT16_C(    16), -INT16_C(  1961),  INT16_C(  9080), -INT16_C(    20),  INT16_C(     0),  INT16_C(    22),  INT16_C(  2350),  INT16_C(    15),
        -INT16_C(    32), -INT16_C(   206),  INT16_C(   121),  INT16_C(     9),  INT16_C(  1943), -INT16_C(   436), -INT16_C(     1), -INT16_C( 16569) } },
    { { -INT16_C(  8822),  INT16_C(  5454), -INT16_C( 15621), -INT16_C( 18248), -INT16_C(  4933),  INT16_C(  9054),  INT16_C(  9511),  INT16_C( 28636),
         INT16_C( 22950),  INT16_C( 32225), -INT16_C(  2877),  INT16_C( 11043),  INT16_C( 32571), -INT16_C(   112),  INT16_C( 30543), -INT16_C(  9726),
         INT16_C( 20564),  INT16_C( 20719), -INT16_C( 22765), -INT16_C( 12792),  INT16_C( 26259), -INT16_C( 17423), -INT16_C( 12917),  INT16_C( 12842),
         INT16_C(  2855), -INT16_C(  5457), -INT16_C( 11265),  INT16_C( 14870), -INT16_C( 22958), -INT16_C( 24263),  INT16_C( 15389),  INT16_C( 29307) },
      {  INT16_C(     6),  INT16_C(     9),  INT16_C(    12),  INT16_C(    10),  INT16_C(     5),  INT16_C(    11),  INT16_C(     8),  INT16_C(     5),
         INT16_C(     9),  INT16_C(     9),  INT16_C(     5),  INT16_C(    12),  INT16_C(     0),  INT16_C(     1),  INT16_C(    14),  INT16_C(    13),
         INT16_C(     4),  INT16_C(     5),  INT16_C(    13),  INT16_C(     4),  INT16_C(     6),  INT16_C(     6),  INT16_C(    15),  INT16_C(     8),
         INT16_C(    15),  INT16_C(     0),  INT16_C(    14),  INT16_C(     4),  INT16_C(     2),  INT16_C(     3),  INT16_C(    14),  INT16_C(     5) },
      { -INT16_C(   138),  INT16_C(    10), -INT16_C(     4), -INT16_C(    18), -INT16_C(   155),  INT16_C(     4),  INT16_C(    37),  INT16_C(   894),
         INT16_C(    44),  INT16_C(    62), -INT16_C(    90),  INT16_C(     2),  INT16_C( 32571), -INT16_C(    56),  INT16_C(     1), -INT16_C(     2),
         INT16_C(  1285),  INT16_C(   647), -INT16_C(     3), -INT16_C(   800),  INT16_C(   410), -INT16_C(   273), -INT16_C(     1),  INT16_C(    50),
         INT16_C(     0), -INT16_C(  5457), -INT16_C(     1),  INT16_C(   929), -INT16_C(  5740), -INT16_C(  3033),  INT16_C(     0),  INT16_C(   915) } },
    { {  INT16_C( 29751),  INT16_C( 20144), -INT16_C( 19886), -INT16_C( 28779), -INT16_C( 26348),  INT16_C(   505), -INT16_C( 18804),  INT16_C(  7300),
        -INT16_C( 25679),  INT16_C(    30), -INT16_C(  7551),  INT16_C( 28489), -INT16_C( 21749),  INT16_C(  5282), -INT16_C( 22890), -INT16_C( 12696),
         INT16_C(  6171),  INT16_C( 27932), -INT16_C( 20022), -INT16_C(  8451), -INT16_C(  2485), -INT16_C( 10272),  INT16_C( 25772),  INT16_C( 24051),
         INT16_C(  4607), -INT16_C( 32675), -INT16_C( 22796), -INT16_C(    17), -INT16_C( 28079), -INT16_C(  6124),  INT16_C( 31800),  INT16_C( 21430) },
      {  INT16_C(    13),  INT16_C(     5),  INT16_C(    11),  INT16_C(    12),  INT16_C(     1),  INT16_C(     6),  INT16_C(     9),  INT16_C(     7),
         INT16_C(     1),  INT16_C(     9),  INT16_C(    14),  INT16_C(     1),  INT16_C(    11),  INT16_C(    11),  INT16_C(    11),  INT16_C(    12),
         INT16_C(    12),  INT16_C(     0),  INT16_C(     5),  INT16_C(     4),  INT16_C(     7),  INT16_C(    15),  INT16_C(     5),  INT16_C(    11),
         INT16_C(     7),  INT16_C(     3),  INT16_C(    15),  INT16_C(    14),  INT16_C(     4),  INT16_C(    13),  INT16_C(    10),  INT16_C(     7) },
      {  INT16_C(     3),  INT16_C(   629), -INT16_C(    10), -INT16_C(     8), -INT16_C( 13174),  INT16_C(     7), -INT16_C(    37),  INT16_C(    57),
        -INT16_C( 12840),  INT16_C(     0), -INT16_C(     1),  INT16_C( 14244), -INT16_C(    11),  INT16_C(     2), -INT16_C(    12), -INT16_C(     4),
         INT16_C(     1),  INT16_C( 27932), -INT16_C(   626), -INT16_C(   529), -INT16_C(    20), -INT16_C(     1),  INT16_C(   805),  INT16_C(    11),
         INT16_C(    35), -INT16_C(  4085), -INT16_C(     1), -INT16_C(     1), -INT16_C(  1755), -INT16_C(     1),  INT16_C(    31),  INT16_C(   167) } },
    { { -INT16_C( 17539),  INT16_C(  2427),  INT16_C( 20248), -INT16_C( 28343), -INT16_C(  5688), -INT16_C(  9334),  INT16_C(   838), -INT16_C( 17000),
        -INT16_C(  3204), -INT16_C(  7180),  INT16_C( 16109), -INT16_C( 26420),  INT16_C( 28289),  INT16_C( 30066),  INT16_C(  3357), -INT16_C( 25878),
         INT16_C( 26057), -INT16_C(  7773), -INT16_C(  4940),  INT16_C( 32114), -INT16_C(   811),  INT16_C(  7000), -INT16_C(  4096),  INT16_C( 31960),
        -INT16_C( 13085), -INT16_C( 12193),  INT16_C( 11018), -INT16_C( 29591), -INT16_C(  9319), -INT16_C( 18943), -INT16_C(  5144), -INT16_C( 20144) },
      {  INT16_C(    15),  INT16_C(     0),  INT16_C(     0),  INT16_C(    11),  INT16_C(    13),  INT16_C(     0),  INT16_C(    10),  INT16_C(    10),
         INT16_C(    13),  INT16_C(     7),  INT16_C(    14),  INT16_C(    10),  INT16_C(     0),  INT16_C(    10),  INT16_C(    10),  INT16_C(     4),
         INT16_C(    14),  INT16_C(     7),  INT16_C(    13),  INT16_C(    15),  INT16_C(    15),  INT16_C(     7),  INT16_C(     7),  INT16_C(     1),
         INT16_C(    10),  INT16_C(     5),  INT16_C(    10),  INT16_C(     4),  INT16_C(     5),  INT16_C(    10),  INT16_C(     5),  INT16_C(     9) },
      { -INT16_C(     1),  INT16_C(  2427),  INT16_C( 20248), -INT16_C(    14), -INT16_C(     1), -INT16_C(  9334),  INT16_C(     0), -INT16_C(    17),
        -INT16_C(     1), -INT16_C(    57),  INT16_C(     0), -INT16_C(    26),  INT16_C( 28289),  INT16_C(    29),  INT16_C(     3), -INT16_C(  1618),
         INT16_C(     1), -INT16_C(    61), -INT16_C(     1),  INT16_C(     0), -INT16_C(     1),  INT16_C(    54), -INT16_C(    32),  INT16_C( 15980),
        -INT16_C(    13), -INT16_C(   382),  INT16_C(    10), -INT16_C(  1850), -INT16_C(   292), -INT16_C(    19), -INT16_C(   161), -INT16_C(    40) } },
    { {  INT16_C( 15426),  INT16_C( 13584),  INT16_C( 16396), -INT16_C( 18902),  INT16_C(  8000), -INT16_C(  6357),  INT16_C( 20114), -INT16_C(  7934),
        -INT16_C( 25616),  INT16_C( 31032),  INT16_C( 12351), -INT16_C(  4156), -INT16_C( 17535),  INT16_C( 31381), -INT16_C( 31730),  INT16_C( 20495),
         INT16_C(  8128), -INT16_C( 13179), -INT16_C( 20640), -INT16_C( 24446), -INT16_C( 20785),  INT16_C( 24967), -INT16_C( 30212), -INT16_C(  5054),
         INT16_C( 31268),  INT16_C( 25701),  INT16_C( 10922),  INT16_C( 11091), -INT16_C(  5915), -INT16_C(  3163), -INT16_C( 19348),  INT16_C( 11331) },
      {  INT16_C(    12),  INT16_C(     3),  INT16_C(     7),  INT16_C(     4),  INT16_C(     5),  INT16_C(     2),  INT16_C(    14),  INT16_C(     0),
         INT16_C(     7),  INT16_C(     0),  INT16_C(    11),  INT16_C(     8),  INT16_C(    13),  INT16_C(     1),  INT16_C(    11),  INT16_C(     6),
         INT16_C(     3),  INT16_C(    15),  INT16_C(     7),  INT16_C(    13),  INT16_C(    14),  INT16_C(    10),  INT16_C(     1),  INT16_C(     3),
         INT16_C(     2),  INT16_C(     2),  INT16_C(     8),  INT16_C(     8),  INT16_C(     2),  INT16_C(    15),  INT16_C(    14),  INT16_C(     6) },
      {  INT16_C(     3),  INT16_C(  1698),  INT16_C(   128), -INT16_C(  1182),  INT16_C(   250), -INT16_C(  1590),  INT16_C(     1), -INT16_C(  7934),
        -INT16_C(   201),  INT16_C( 31032),  INT16_C(     6), -INT16_C(    17), -INT16_C(     3),  INT16_C( 15690), -INT16_C(    16),  INT16_C(   320),
         INT16_C(  1016), -INT16_C(     1), -INT16_C(   162), -INT16_C(     3), -INT16_C(     2),  INT16_C(    24), -INT16_C( 15106), -INT16_C(   632),
         INT16_C(  7817),  INT16_C(  6425),  INT16_C(    42),  INT16_C(    43), -INT16_C(  1479), -INT16_C(     1), -INT16_C(     2),  INT16_C(   177) } }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
    simde__m512i a = simde_mm512_loadu_epi16(test_vec[i].a);
    simde__m512i b = simde_mm512_loadu_epi16(test_vec[i].b);
    simde__m512i r = simde_mm512_srav_epi16(a, b);
    simde_test_x86_assert_equal_i16x32(r, simde_mm512_loadu_epi16(test_vec[i].r));
  }

  return 0;
}

static int
test_simde_mm512_srli_epi16 (SIMDE_MUNIT_TEST_ARGS) {
  static const struct {
    const int16_t a[32];
    const int16_t r[32];
  } test_vec[] = {
    { {  INT16_C(  5064), -INT16_C( 13372), -INT16_C( 27857), -INT16_C( 22226),  INT16_C( 15192),  INT16_C( 15375), -INT16_C(  9626), -INT16_C( 29567),
        -INT16_C( 11953), -INT16_C(  3869), -INT16_C( 31356),  INT16_C( 27097), -INT16_C( 12959),  INT16_C( 26598), -INT16_C( 26711),  INT16_C( 28952),
        -INT16_C(  8790), -INT16_C(  9924),  INT16_C( 27504), -INT16_C( 14205), -INT16_C( 27994),  INT16_C(  3076), -INT16_C( 31124), -INT16_C( 17511),
         INT16_C( 31831), -INT16_C(  9045), -INT16_C( 31743),  INT16_C( 25157),  INT16_C( 11345), -INT16_C(  1335), -INT16_C(  7485),  INT16_C( 28011) },
      {  INT16_C(    39),  INT16_C(   407),  INT16_C(   294),  INT16_C(   338),  INT16_C(   118),  INT16_C(   120),  INT16_C(   436),  INT16_C(   281),
         INT16_C(   418),  INT16_C(   481),  INT16_C(   267),  INT16_C(   211),  INT16_C(   410),  INT16_C(   207),  INT16_C(   303),  INT16_C(   226),
         INT16_C(   443),  INT16_C(   434),  INT16_C(   214),  INT16_C(   401),  INT16_C(   293),  INT16_C(    24),  INT16_C(   268),  INT16_C(   375),
         INT16_C(   248),  INT16_C(   441),  INT16_C(   264),  INT16_C(   196),  INT16_C(    88),  INT16_C(   501),  INT16_C(   453),  INT16_C(   218) } },
    { { -INT16_C( 22593),  INT16_C( 12102), -INT16_C( 14062), -INT16_C( 17928), -INT16_C(   933), -INT16_C( 14395),  INT16_C( 24194), -INT16_C(  9598),
         INT16_C( 11738), -INT16_C(  9290), -INT16_C(  1103),  INT16_C(   574),  INT16_C(  1831), -INT16_C(  5380),  INT16_C( 26601), -INT16_C( 22441),
        -INT16_C( 25073),  INT16_C(  8664), -INT16_C( 12185), -INT16_C( 15398), -INT16_C( 24372),  INT16_C( 20362),  INT16_C(  3582), -INT16_C(  9943),
        -INT16_C(  8390), -INT16_C(  4940), -INT16_C(  3366),  INT16_C(   750), -INT16_C(  5126), -INT16_C(  7188),  INT16_C( 17490),  INT16_C( 24972) },
      {  INT16_C(   335),  INT16_C(    94),  INT16_C(   402),  INT16_C(   371),  INT16_C(   504),  INT16_C(   399),  INT16_C(   189),  INT16_C(   437),
         INT16_C(    91),  INT16_C(   439),  INT16_C(   503),  INT16_C(     4),  INT16_C(    14),  INT16_C(   469),  INT16_C(   207),  INT16_C(   336),
         INT16_C(   316),  INT16_C(    67),  INT16_C(   416),  INT16_C(   391),  INT16_C(   321),  INT16_C(   159),  INT16_C(    27),  INT16_C(   434),
         INT16_C(   446),  INT16_C(   473),  INT16_C(   485),  INT16_C(     5),  INT16_C(   471),  INT16_C(   455),  INT16_C(   136),  INT16_C(   195) } },
    { {  INT16_C( 25826),  INT16_C( 18819),  INT16_C( 23860),  INT16_C(    12), -INT16_C( 26627), -INT16_C(   945),  INT16_C( 30884), -INT16_C(  8491),
        -INT16_C( 30377),  INT16_C( 13002), -INT16_C( 18052),  INT16_C( 30260),  INT16_C(  8356), -INT16_C(  2471), -INT16_C(  6812),  INT16_C( 18008),
        -INT16_C(  9399),  INT16_C( 32144), -INT16_C( 25544),  INT16_C( 13950), -INT16_C( 13005), -INT16_C( 10446),  INT16_C(  1862), -INT16_C( 25162),
        -INT16_C( 32624),  INT16_C(  3279),  INT16_C(   825), -INT16_C(  8830), -INT16_C(  9180), -INT16_C( 30508),  INT16_C( 11457),  INT16_C(  3023) },
      {  INT16_C(   201),  INT16_C(   147),  INT16_C(   186),  INT16_C(     0),  INT16_C(   303),  INT16_C(   504),  INT16_C(   241),  INT16_C(   445),
         INT16_C(   274),  INT16_C(   101),  INT16_C(   370),  INT16_C(   236),  INT16_C(    65),  INT16_C(   492),  INT16_C(   458),  INT16_C(   140),
         INT16_C(   438),  INT16_C(   251),  INT16_C(   312),  INT16_C(   108),  INT16_C(   410),  INT16_C(   430),  INT16_C(    14),  INT16_C(   315),
         INT16_C(   257),  INT16_C(    25),  INT16_C(     6),  INT16_C(   443),  INT16_C(   440),  INT16_C(   273),  INT16_C(    89),  INT16_C(    23) } },
    { {  INT16_C( 24327),  INT16_C( 16264),  INT16_C(  1787),  INT16_C( 12149), -INT16_C( 22572),  INT16_C(  6662), -INT16_C( 17234),  INT16_C( 16311),
        -INT16_C( 30915),  INT16_C( 30283), -INT16_C( 12662), -INT16_C( 20908),  INT16_C( 10410),  INT16_C( 27447),  INT16_C(  1620),  INT16_C( 23414),
        -INT16_C(   155),  INT16_C( 24730),  INT16_C(  4101), -INT16_C(  9841), -INT16_C( 26953),  INT16_C( 26355), -INT16_C( 21678), -INT16_C( 28763),
        -INT16_C(  4046), -INT16_C( 17402),  INT16_C( 23230),  INT16_C( 26731), -INT16_C( 23934), -INT16_C( 10540),  INT16_C( 19112),  INT16_C(  3377) },
      {  INT16_C(   190),  INT16_C(   127),  INT16_C(    13),  INT16_C(    94),  INT16_C(   335),  INT16_C(    52),  INT16_C(   377),  INT16_C(   127),
         INT16_C(   270),  INT16_C(   236),  INT16_C(   413),  INT16_C(   348),  INT16_C(    81),  INT16_C(   214),  INT16_C(    12),  INT16_C(   182),
         INT16_C(   510),  INT16_C(   193),  INT16_C(    32),  INT16_C(   435),  INT16_C(   301),  INT16_C(   205),  INT16_C(   342),  INT16_C(   287),
         INT16_C(   480),  INT16_C(   376),  INT16_C(   181),  INT16_C(   208),  INT16_C(   325),  INT16_C(   429),  INT16_C(   149),  INT16_C(    26) } },
    { { -INT16_C( 13495),  INT16_C( 20333), -INT16_C(   549), -INT16_C( 27864),  INT16_C(  7315), -INT16_C(  6663), -INT16_C( 24889), -INT16_C(  1675),
         INT16_C( 31630),  INT16_C( 19893),  INT16_C(  8405),  INT16_C( 22453), -INT16_C( 30270),  INT16_C( 27181),  INT16_C( 24276),  INT16_C(  7543),
        -INT16_C(  6871),  INT16_C(  1388), -INT16_C( 27166),  INT16_C( 30104), -INT16_C( 28239),  INT16_C( 30810), -INT16_C( 12497), -INT16_C( 17039),
         INT16_C(  9802),  INT16_C(  7946), -INT16_C( 16313),  INT16_C(  2422), -INT16_C( 23735),  INT16_C(  7540), -INT16_C(  5375),  INT16_C( 11067) },
      {  INT16_C(   406),  INT16_C(   158),  INT16_C(   507),  INT16_C(   294),  INT16_C(    57),  INT16_C(   459),  INT16_C(   317),  INT16_C(   498),
         INT16_C(   247),  INT16_C(   155),  INT16_C(    65),  INT16_C(   175),  INT16_C(   275),  INT16_C(   212),  INT16_C(   189),  INT16_C(    58),
         INT16_C(   458),  INT16_C(    10),  INT16_C(   299),  INT16_C(   235),  INT16_C(   291),  INT16_C(   240),  INT16_C(   414),  INT16_C(   378),
         INT16_C(    76),  INT16_C(    62),  INT16_C(   384),  INT16_C(    18),  INT16_C(   326),  INT16_C(    58),  INT16_C(   470),  INT16_C(    86) } },
    { { -INT16_C( 22576), -INT16_C( 19920), -INT16_C( 14276), -INT16_C(  4825), -INT16_C( 32167), -INT16_C( 30619), -INT16_C( 10671), -INT16_C( 25531),
         INT16_C( 20733),  INT16_C( 17595),  INT16_C( 12816),  INT16_C( 22861), -INT16_C( 15915), -INT16_C( 10377), -INT16_C( 19795),  INT16_C( 32002),
         INT16_C( 12889), -INT16_C( 27088),  INT16_C( 22522),  INT16_C( 21379), -INT16_C(  5671),  INT16_C( 11227),  INT16_C(  8383), -INT16_C( 17209),
        -INT16_C( 32144),       INT16_MIN,  INT16_C( 20148), -INT16_C( 29990),  INT16_C( 20751), -INT16_C( 17311),  INT16_C( 25347),  INT16_C( 23610) },
      {  INT16_C(   335),  INT16_C(   356),  INT16_C(   400),  INT16_C(   474),  INT16_C(   260),  INT16_C(   272),  INT16_C(   428),  INT16_C(   312),
         INT16_C(   161),  INT16_C(   137),  INT16_C(   100),  INT16_C(   178),  INT16_C(   387),  INT16_C(   430),  INT16_C(   357),  INT16_C(   250),
         INT16_C(   100),  INT16_C(   300),  INT16_C(   175),  INT16_C(   167),  INT16_C(   467),  INT16_C(    87),  INT16_C(    65),  INT16_C(   377),
         INT16_C(   260),  INT16_C(   256),  INT16_C(   157),  INT16_C(   277),  INT16_C(   162),  INT16_C(   376),  INT16_C(   198),  INT16_C(   184) } },
    { {  INT16_C( 27285), -INT16_C( 28686),  INT16_C( 30401), -INT16_C( 25630), -INT16_C( 17057),  INT16_C(  7878), -INT16_C( 29219),  INT16_C( 20187),
        -INT16_C(  9457), -INT16_C( 15154), -INT16_C( 22487),  INT16_C( 14670), -INT16_C( 20487), -INT16_C(   779),  INT16_C( 12050), -INT16_C( 22695),
         INT16_C( 19353),  INT16_C( 23350),  INT16_C(  6337),  INT16_C(  8438), -INT16_C( 17195), -INT16_C( 19905),  INT16_C(  6729),  INT16_C( 22528),
        -INT16_C( 12299),  INT16_C(  7964),  INT16_C( 27255),  INT16_C( 29016),  INT16_C( 19737),  INT16_C( 11117), -INT16_C( 14723),  INT16_C(  5842) },
      {  INT16_C(   213),  INT16_C(   287),  INT16_C(   237),  INT16_C(   311),  INT16_C(   378),  INT16_C(    61),  INT16_C(   283),  INT16_C(   157),
         INT16_C(   438),  INT16_C(   393),  INT16_C(   336),  INT16_C(   114),  INT16_C(   351),  INT16_C(   505),  INT16_C(    94),  INT16_C(   334),
         INT16_C(   151),  INT16_C(   182),  INT16_C(    49),  INT16_C(    65),  INT16_C(   377),  INT16_C(   356),  INT16_C(    52),  INT16_C(   176),
         INT16_C(   415),  INT16_C(    62),  INT16_C(   212),  INT16_C(   226),  INT16_C(   154),  INT16_C(    86),  INT16_C(   396),  INT16_C(    45) } },
    { {  INT16_C(  2066), -INT16_C( 11407),  INT16_C( 26400), -INT16_C(  2572),  INT16_C( 13091),  INT16_C( 27816), -INT16_C( 22451),  INT16_C( 17093),
        -INT16_C(  7817), -INT16_C(  4255), -INT16_C( 18100),  INT16_C( 25952), -INT16_C( 13049), -INT16_C( 31599),  INT16_C( 25492), -INT16_C( 22886),
         INT16_C(  3180), -INT16_C( 29575),  INT16_C( 28019), -INT16_C( 26750),  INT16_C( 10912), -INT16_C(  4861), -INT16_C( 14126),  INT16_C( 18992),
        -INT16_C( 28246), -INT16_C(  2503), -INT16_C( 26293),  INT16_C( 21083), -INT16_C(  5018), -INT16_C(  1322),  INT16_C( 28752), -INT16_C( 17248) },
      {  INT16_C(    16),  INT16_C(   422),  INT16_C(   206),  INT16_C(   491),  INT16_C(   102),  INT16_C(   217),  INT16_C(   336),  INT16_C(   133),
         INT16_C(   450),  INT16_C(   478),  INT16_C(   370),  INT16_C(   202),  INT16_C(   410),  INT16_C(   265),  INT16_C(   199),  INT16_C(   333),
         INT16_C(    24),  INT16_C(   280),  INT16_C(   218),  INT16_C(   303),  INT16_C(    85),  INT16_C(   474),  INT16_C(   401),  INT16_C(   148),
         INT16_C(   291),  INT16_C(   492),  INT16_C(   306),  INT16_C(   164),  INT16_C(   472),  INT16_C(   501),  INT16_C(   224),  INT16_C(   377) } }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
    simde__m512i a = simde_mm512_loadu_epi16(test_vec[i].a);
    simde__m512i r = simde_mm512_srli_epi16(a, 7);
    simde_test_x86_assert_equal_i16x32(r, simde_mm512_loadu_epi16(test_vec[i].r));
  }

  return 0;
}

static int
test_simde_mm512_srlv_epi16 (SIMDE_MUNIT_TEST_ARGS) {
  static const struct {
    const int16_t a[32];
    const int16_t b[32];
    const int16_t r[32];
  } test_vec[] = {
    { {  INT16_C( 11245),  INT16_C( 15388), -INT16_C(  9450),  INT16_C( 14785),  INT16_C( 29263),  INT16_C( 32422), -INT16_C( 27968), -INT16_C(  5555),
        -INT16_C( 13850),  INT16_C(  7512), -INT16_C( 15858),  INT16_C( 20804),  INT16_C( 10819),  INT16_C(  5799),  INT16_C( 23710), -INT16_C( 29883),
         INT16_C( 25224), -INT16_C( 24889), -INT16_C( 30659), -INT16_C( 29481),  INT16_C( 32251), -INT16_C( 17653),  INT16_C( 22543), -INT16_C(  2651),
        -INT16_C(   735),  INT16_C( 12051),  INT16_C( 22463),  INT16_C(   641),  INT16_C( 10369),  INT16_C(  7960),  INT16_C( 24196),  INT16_C(  3242) },
      {  INT16_C(    14),  INT16_C(    31),  INT16_C(    16),  INT16_C(    30),  INT16_C(    18),  INT16_C(     1),  INT16_C(    10),  INT16_C(     1),
         INT16_C(     2),  INT16_C(     2),  INT16_C(    23),  INT16_C(    30),  INT16_C(     5),  INT16_C(    13),  INT16_C(    23),  INT16_C(     9),
         INT16_C(     4),  INT16_C(     4),  INT16_C(    26),  INT16_C(    20),  INT16_C(    25),  INT16_C(    10),  INT16_C(    22),  INT16_C(    14),
         INT16_C(    19),  INT16_C(     7),  INT16_C(    19),  INT16_C(     8),  INT16_C(     7),  INT16_C(    10),  INT16_C(     5),  INT16_C(     4) },
      {  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C( 16211),  INT16_C(    36),  INT16_C( 29990),
         INT16_C( 12921),  INT16_C(  1878),  INT16_C(     0),  INT16_C(     0),  INT16_C(   338),  INT16_C(     0),  INT16_C(     0),  INT16_C(    69),
         INT16_C(  1576),  INT16_C(  2540),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(    46),  INT16_C(     0),  INT16_C(     3),
         INT16_C(     0),  INT16_C(    94),  INT16_C(     0),  INT16_C(     2),  INT16_C(    81),  INT16_C(     7),  INT16_C(   756),  INT16_C(   202) } },
    { { -INT16_C(  7349), -INT16_C(  4281),  INT16_C( 25524),  INT16_C(  6546),  INT16_C( 17199),  INT16_C( 20844), -INT16_C( 12807), -INT16_C( 14906),
         INT16_C( 19564), -INT16_C( 13824),  INT16_C( 11238), -INT16_C( 21489), -INT16_C( 16538),  INT16_C( 23293), -INT16_C( 26136),  INT16_C( 13179),
        -INT16_C( 15748),  INT16_C( 12322), -INT16_C( 19419),  INT16_C( 21577), -INT16_C( 18953), -INT16_C(  3930),  INT16_C( 27778), -INT16_C(  4426),
        -INT16_C( 18760), -INT16_C( 24904), -INT16_C( 14366),  INT16_C( 18506),  INT16_C( 18567),  INT16_C( 28578),  INT16_C(  7649),  INT16_C( 23970) },
      {  INT16_C(    24),  INT16_C(     0),  INT16_C(    26),  INT16_C(    13),  INT16_C(    31),  INT16_C(     1),  INT16_C(     2),  INT16_C(     4),
         INT16_C(    22),  INT16_C(    21),  INT16_C(     1),  INT16_C(     0),  INT16_C(    19),  INT16_C(     6),  INT16_C(     2),  INT16_C(    18),
         INT16_C(     3),  INT16_C(    10),  INT16_C(    30),  INT16_C(    16),  INT16_C(     4),  INT16_C(    11),  INT16_C(    17),  INT16_C(     0),
         INT16_C(     8),  INT16_C(    23),  INT16_C(    21),  INT16_C(    20),  INT16_C(     6),  INT16_C(    30),  INT16_C(    12),  INT16_C(     4) },
      {  INT16_C(     0), -INT16_C(  4281),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C( 10422),  INT16_C( 13182),  INT16_C(  3164),
         INT16_C(     0),  INT16_C(     0),  INT16_C(  5619), -INT16_C( 21489),  INT16_C(     0),  INT16_C(   363),  INT16_C(  9850),  INT16_C(     0),
         INT16_C(  6223),  INT16_C(    12),  INT16_C(     0),  INT16_C(     0),  INT16_C(  2911),  INT16_C(    30),  INT16_C(     0), -INT16_C(  4426),
         INT16_C(   182),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(   290),  INT16_C(     0),  INT16_C(     1),  INT16_C(  1498) } },
    { {  INT16_C( 10373),  INT16_C( 31349),  INT16_C( 13595),  INT16_C(  3835), -INT16_C( 30122), -INT16_C( 29589), -INT16_C(  5097),  INT16_C( 22927),
         INT16_C( 16685),  INT16_C( 31256), -INT16_C(  9239),  INT16_C( 10779), -INT16_C(  4079),  INT16_C( 23585), -INT16_C( 20650), -INT16_C(  9344),
        -INT16_C(  2601), -INT16_C(  3499),  INT16_C( 20522),       INT16_MIN,  INT16_C( 27867), -INT16_C(  3571), -INT16_C( 25512), -INT16_C( 31413),
         INT16_C( 25565), -INT16_C( 14848),  INT16_C(  6974),  INT16_C( 20464),  INT16_C(  4619),  INT16_C( 25003),  INT16_C( 11201), -INT16_C( 26563) },
      {  INT16_C(    18),  INT16_C(     9),  INT16_C(    17),  INT16_C(    23),  INT16_C(    27),  INT16_C(     9),  INT16_C(    31),  INT16_C(    10),
         INT16_C(    26),  INT16_C(    19),  INT16_C(     1),  INT16_C(    31),  INT16_C(    18),  INT16_C(    27),  INT16_C(    19),  INT16_C(    28),
         INT16_C(    31),  INT16_C(     1),  INT16_C(    30),  INT16_C(    16),  INT16_C(    15),  INT16_C(     8),  INT16_C(    20),  INT16_C(    26),
         INT16_C(    21),  INT16_C(    13),  INT16_C(    11),  INT16_C(    26),  INT16_C(    23),  INT16_C(    22),  INT16_C(     4),  INT16_C(    16) },
      {  INT16_C(     0),  INT16_C(    61),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(    70),  INT16_C(     0),  INT16_C(    22),
         INT16_C(     0),  INT16_C(     0),  INT16_C( 28148),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C( 31018),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(   242),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     6),  INT16_C(     3),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(   700),  INT16_C(     0) } },
    { { -INT16_C( 16352), -INT16_C( 22127),  INT16_C( 24246), -INT16_C( 31446), -INT16_C(  1574),  INT16_C( 21192),  INT16_C( 23965),  INT16_C(  5671),
        -INT16_C( 26358), -INT16_C( 16002), -INT16_C(  7947), -INT16_C(  5998),  INT16_C( 16543), -INT16_C(  2405),  INT16_C( 12385), -INT16_C( 32391),
         INT16_C(  3056), -INT16_C( 22997),  INT16_C( 21865),  INT16_C( 17195), -INT16_C(  3250), -INT16_C(  4971), -INT16_C( 17072),  INT16_C( 23298),
        -INT16_C( 32682),  INT16_C( 19228), -INT16_C( 20896), -INT16_C(   205), -INT16_C( 12306),  INT16_C( 20726),  INT16_C( 28671), -INT16_C(  4143) },
      {  INT16_C(    31),  INT16_C(    28),  INT16_C(    24),  INT16_C(    20),  INT16_C(    23),  INT16_C(     0),  INT16_C(    17),  INT16_C(    25),
         INT16_C(    15),  INT16_C(    13),  INT16_C(     9),  INT16_C(     3),  INT16_C(    12),  INT16_C(     3),  INT16_C(     7),  INT16_C(     9),
         INT16_C(    20),  INT16_C(    17),  INT16_C(    11),  INT16_C(     2),  INT16_C(    22),  INT16_C(    17),  INT16_C(    15),  INT16_C(    10),
         INT16_C(    15),  INT16_C(     4),  INT16_C(     5),  INT16_C(    28),  INT16_C(    20),  INT16_C(    12),  INT16_C(     1),  INT16_C(     2) },
      {  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C( 21192),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     1),  INT16_C(     6),  INT16_C(   112),  INT16_C(  7442),  INT16_C(     4),  INT16_C(  7891),  INT16_C(    96),  INT16_C(    64),
         INT16_C(     0),  INT16_C(     0),  INT16_C(    10),  INT16_C(  4298),  INT16_C(     0),  INT16_C(     0),  INT16_C(     1),  INT16_C(    22),
         INT16_C(     1),  INT16_C(  1201),  INT16_C(  1395),  INT16_C(     0),  INT16_C(     0),  INT16_C(     5),  INT16_C( 14335),  INT16_C( 15348) } },
    { { -INT16_C(  6994),  INT16_C(  4254), -INT16_C( 14788),  INT16_C( 20774),  INT16_C( 17019), -INT16_C( 16928),  INT16_C( 16061), -INT16_C( 19186),
        -INT16_C( 12873),  INT16_C( 32471),  INT16_C(  4858), -INT16_C( 29853),  INT16_C( 26038), -INT16_C( 27409), -INT16_C( 23950),  INT16_C(  8362),
         INT16_C( 18566), -INT16_C( 15824),  INT16_C( 22030), -INT16_C( 30444), -INT16_C(  2920),  INT16_C( 22087),  INT16_C( 21810), -INT16_C(  5877),
        -INT16_C(  7646),  INT16_C(  7271), -INT16_C( 13324), -INT16_C( 21849), -INT16_C( 27088), -INT16_C( 24002), -INT16_C(  6088), -INT16_C( 16702) },
      {  INT16_C(    30),  INT16_C(     7),  INT16_C(    18),  INT16_C(    28),  INT16_C(     1),  INT16_C(    23),  INT16_C(     8),  INT16_C(    16),
         INT16_C(     1),  INT16_C(     3),  INT16_C(     9),  INT16_C(     0),  INT16_C(     0),  INT16_C(     3),  INT16_C(    13),  INT16_C(     3),
         INT16_C(    11),  INT16_C(    20),  INT16_C(     4),  INT16_C(    14),  INT16_C(    23),  INT16_C(    18),  INT16_C(    26),  INT16_C(     4),
         INT16_C(    23),  INT16_C(    22),  INT16_C(    31),  INT16_C(    28),  INT16_C(    12),  INT16_C(    28),  INT16_C(    26),  INT16_C(     5) },
      {  INT16_C(     0),  INT16_C(    33),  INT16_C(     0),  INT16_C(     0),  INT16_C(  8509),  INT16_C(     0),  INT16_C(    62),  INT16_C(     0),
         INT16_C( 26331),  INT16_C(  4058),  INT16_C(     9), -INT16_C( 29853),  INT16_C( 26038),  INT16_C(  4765),  INT16_C(     5),  INT16_C(  1045),
         INT16_C(     9),  INT16_C(     0),  INT16_C(  1376),  INT16_C(     2),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(  3728),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     9),  INT16_C(     0),  INT16_C(     0),  INT16_C(  1526) } },
    { {  INT16_C( 22575),  INT16_C(  7378),  INT16_C( 22649), -INT16_C( 21870), -INT16_C( 15595),  INT16_C(  5183),  INT16_C( 23192),  INT16_C( 30775),
         INT16_C( 29208),  INT16_C(  8239), -INT16_C(  4753),  INT16_C( 27655),  INT16_C(  1875),  INT16_C(  9043),  INT16_C( 21470),  INT16_C(  3408),
         INT16_C(  8875),  INT16_C(  9513), -INT16_C( 17542), -INT16_C( 28721),  INT16_C(  3710),  INT16_C(  5795), -INT16_C(  9624), -INT16_C( 32369),
        -INT16_C( 16820), -INT16_C( 17503), -INT16_C( 22357), -INT16_C(   472),  INT16_C( 31664), -INT16_C( 29150),  INT16_C( 29390),  INT16_C( 31132) },
      {  INT16_C(    24),  INT16_C(     1),  INT16_C(    13),  INT16_C(    31),  INT16_C(     8),  INT16_C(    28),  INT16_C(    20),  INT16_C(    13),
         INT16_C(     0),  INT16_C(     1),  INT16_C(     9),  INT16_C(    11),  INT16_C(     5),  INT16_C(    18),  INT16_C(    17),  INT16_C(     6),
         INT16_C(    21),  INT16_C(    25),  INT16_C(    28),  INT16_C(    18),  INT16_C(    28),  INT16_C(     8),  INT16_C(    28),  INT16_C(    29),
         INT16_C(    26),  INT16_C(    18),  INT16_C(     1),  INT16_C(    29),  INT16_C(    28),  INT16_C(    27),  INT16_C(    17),  INT16_C(    22) },
      {  INT16_C(     0),  INT16_C(  3689),  INT16_C(     2),  INT16_C(     0),  INT16_C(   195),  INT16_C(     0),  INT16_C(     0),  INT16_C(     3),
         INT16_C( 29208),  INT16_C(  4119),  INT16_C(   118),  INT16_C(    13),  INT16_C(    58),  INT16_C(     0),  INT16_C(     0),  INT16_C(    53),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(    22),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0),  INT16_C( 21589),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0) } },
    { {  INT16_C( 22844),  INT16_C( 22407),  INT16_C( 22078),  INT16_C( 26350),  INT16_C( 26939), -INT16_C( 14933),  INT16_C( 23113),  INT16_C( 12210),
        -INT16_C( 20691),  INT16_C( 20164), -INT16_C( 18503), -INT16_C(  3530), -INT16_C( 19049),  INT16_C(   206), -INT16_C(  8125),  INT16_C( 32695),
         INT16_C( 15929),  INT16_C( 30934), -INT16_C( 14956), -INT16_C( 12322), -INT16_C( 30162),  INT16_C( 30868),  INT16_C( 18404),  INT16_C(  4519),
         INT16_C( 27638), -INT16_C( 20641), -INT16_C( 27102), -INT16_C( 18015),  INT16_C( 28491), -INT16_C( 28999),  INT16_C( 29008), -INT16_C( 30451) },
      {  INT16_C(    28),  INT16_C(     8),  INT16_C(    28),  INT16_C(    26),  INT16_C(    21),  INT16_C(     9),  INT16_C(    30),  INT16_C(    28),
         INT16_C(    23),  INT16_C(    16),  INT16_C(     6),  INT16_C(    20),  INT16_C(    30),  INT16_C(    30),  INT16_C(     7),  INT16_C(     3),
         INT16_C(    16),  INT16_C(    24),  INT16_C(    13),  INT16_C(    25),  INT16_C(    29),  INT16_C(     0),  INT16_C(    14),  INT16_C(     8),
         INT16_C(    15),  INT16_C(    17),  INT16_C(     1),  INT16_C(    11),  INT16_C(    11),  INT16_C(    13),  INT16_C(    25),  INT16_C(    22) },
      {  INT16_C(     0),  INT16_C(    87),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(    98),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0),  INT16_C(   734),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(   448),  INT16_C(  4086),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     6),  INT16_C(     0),  INT16_C(     0),  INT16_C( 30868),  INT16_C(     1),  INT16_C(    17),
         INT16_C(     0),  INT16_C(     0),  INT16_C( 19217),  INT16_C(    23),  INT16_C(    13),  INT16_C(     4),  INT16_C(     0),  INT16_C(     0) } },
    { { -INT16_C(  9139), -INT16_C( 21126),  INT16_C(  6219),  INT16_C( 25463), -INT16_C( 28923), -INT16_C(  6039),  INT16_C( 21767),  INT16_C( 15662),
        -INT16_C(  1836), -INT16_C( 30263), -INT16_C(  3072), -INT16_C(    29),  INT16_C( 12878), -INT16_C(  7577), -INT16_C(  6400),  INT16_C( 19861),
         INT16_C(  4035),  INT16_C(  4091),  INT16_C( 29223),  INT16_C( 11378), -INT16_C(  9470),  INT16_C(  2325),  INT16_C( 17200),  INT16_C(  1350),
         INT16_C(  3899),  INT16_C( 15246),  INT16_C( 29188),  INT16_C( 21050), -INT16_C( 23900), -INT16_C( 23500), -INT16_C( 13687),  INT16_C( 19954) },
      {  INT16_C(    29),  INT16_C(     0),  INT16_C(    25),  INT16_C(    12),  INT16_C(     8),  INT16_C(    27),  INT16_C(    22),  INT16_C(    24),
         INT16_C(    13),  INT16_C(    24),  INT16_C(     6),  INT16_C(    16),  INT16_C(     9),  INT16_C(    12),  INT16_C(     3),  INT16_C(    29),
         INT16_C(     1),  INT16_C(    12),  INT16_C(     3),  INT16_C(    16),  INT16_C(     6),  INT16_C(    28),  INT16_C(     7),  INT16_C(    20),
         INT16_C(    20),  INT16_C(    17),  INT16_C(    15),  INT16_C(    21),  INT16_C(     6),  INT16_C(    27),  INT16_C(    23),  INT16_C(    10) },
      {  INT16_C(     0), -INT16_C( 21126),  INT16_C(     0),  INT16_C(     6),  INT16_C(   143),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),
         INT16_C(     7),  INT16_C(     0),  INT16_C(   976),  INT16_C(     0),  INT16_C(    25),  INT16_C(    14),  INT16_C(  7392),  INT16_C(     0),
         INT16_C(  2017),  INT16_C(     0),  INT16_C(  3652),  INT16_C(     0),  INT16_C(   876),  INT16_C(     0),  INT16_C(   134),  INT16_C(     0),
         INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(     0),  INT16_C(   650),  INT16_C(     0),  INT16_C(     0),  INT16_C(    19) } }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
    simde__m512i a = simde_mm512_loadu_epi16(test_vec[i].a);
    simde__m512i b = simde_mm512_loadu_epi16(test_vec[i].b);
    simde__m512i r = simde_mm512_srlv_epi16(a, b);
    simde_test_x86_assert_equal_i16x32(r, simde_mm512_loadu_epi16(test_vec[i].r));
  }

  return 0;
}

static int
test_simde_mm512_sub_epi8(SIMDE_MUNIT_TEST_ARGS) {
  const struct {
    simde__m512i a;
    simde__m512i b;
    simde__m512i r;
  } test_vec[8] = {
    { simde_mm512_set_epi8(INT8_C(  82), INT8_C(  83), INT8_C( 117), INT8_C(  65),
                           INT8_C( -47), INT8_C(-122), INT8_C( 116), INT8_C(  14),
                           INT8_C(  76), INT8_C(   1), INT8_C( -50), INT8_C(   4),
                           INT8_C(  83), INT8_C( -77), INT8_C( 112), INT8_C(-102),
                           INT8_C(  99), INT8_C(-118), INT8_C( -47), INT8_C( -67),
                           INT8_C(  60), INT8_C( -34), INT8_C(  78), INT8_C(-110),
                           INT8_C( -58), INT8_C(  87), INT8_C( -61), INT8_C(  26),
                           INT8_C( -17), INT8_C( -46), INT8_C( 116), INT8_C( -20),
                           INT8_C(-120), INT8_C(  48), INT8_C(  24), INT8_C(  46),
                           INT8_C( 103), INT8_C( -34), INT8_C(  42), INT8_C(  51),
                           INT8_C( -65), INT8_C(  86), INT8_C(  61), INT8_C( -56),
                           INT8_C(  58), INT8_C( 119), INT8_C(  93), INT8_C(  -1),
                           INT8_C( -58), INT8_C(-121), INT8_C( -32), INT8_C(  98),
                           INT8_C( -66), INT8_C(  79), INT8_C(  99), INT8_C( -93),
                           INT8_C(  77), INT8_C( -56), INT8_C( -78), INT8_C(  39),
                           INT8_C( -50), INT8_C( -60), INT8_C( -68), INT8_C(  -4)),
      simde_mm512_set_epi8(INT8_C( 106), INT8_C(  39), INT8_C(-106), INT8_C(  14),
                           INT8_C( -28), INT8_C(  -2), INT8_C(  39), INT8_C( -28),
                           INT8_C(  54), INT8_C(  70), INT8_C( -19), INT8_C( -12),
                           INT8_C( -42), INT8_C(  28), INT8_C( -13), INT8_C(  -6),
                           INT8_C( 116), INT8_C(   2), INT8_C(  23), INT8_C( 121),
                           INT8_C( 112), INT8_C( -35), INT8_C(-124), INT8_C(  10),
                           INT8_C( -16), INT8_C(-117), INT8_C(  26), INT8_C(-125),
                           INT8_C(  36), INT8_C( 109), INT8_C(  29), INT8_C( -35),
                           INT8_C(  -9), INT8_C( -85), INT8_C( -38), INT8_C(  95),
                           INT8_C( -88), INT8_C(   3), INT8_C(   4), INT8_C( 100),
                           INT8_C(  85), INT8_C(  21), INT8_C(  66), INT8_C( -33),
                           INT8_C( -77), INT8_C(  -5), INT8_C(-126), INT8_C( 122),
                           INT8_C( -30), INT8_C( -83), INT8_C(  74), INT8_C(-108),
                           INT8_C(  83), INT8_C( -96), INT8_C( -57), INT8_C(-108),
                           INT8_C(  89), INT8_C(  59), INT8_C( 111), INT8_C( -47),
                           INT8_C( -10), INT8_C( -18), INT8_C(  20), INT8_C(-125)),
      simde_mm512_set_epi8(INT8_C( -24), INT8_C(  44), INT8_C( -33), INT8_C(  51),
                           INT8_C( -19), INT8_C(-120), INT8_C(  77), INT8_C(  42),
                           INT8_C(  22), INT8_C( -69), INT8_C( -31), INT8_C(  16),
                           INT8_C( 125), INT8_C(-105), INT8_C( 125), INT8_C( -96),
                           INT8_C( -17), INT8_C(-120), INT8_C( -70), INT8_C(  68),
                           INT8_C( -52), INT8_C(   1), INT8_C( -54), INT8_C(-120),
                           INT8_C( -42), INT8_C( -52), INT8_C( -87), INT8_C(-105),
                           INT8_C( -53), INT8_C( 101), INT8_C(  87), INT8_C(  15),
                           INT8_C(-111), INT8_C(-123), INT8_C(  62), INT8_C( -49),
                           INT8_C( -65), INT8_C( -37), INT8_C(  38), INT8_C( -49),
                           INT8_C( 106), INT8_C(  65), INT8_C(  -5), INT8_C( -23),
                           INT8_C(-121), INT8_C( 124), INT8_C( -37), INT8_C(-123),
                           INT8_C( -28), INT8_C( -38), INT8_C(-106), INT8_C( -50),
                           INT8_C( 107), INT8_C( -81), INT8_C(-100), INT8_C(  15),
                           INT8_C( -12), INT8_C(-115), INT8_C(  67), INT8_C(  86),
                           INT8_C( -40), INT8_C( -42), INT8_C( -88), INT8_C( 121)) },
    { simde_mm512_set_epi8(INT8_C(-108), INT8_C(-116), INT8_C(  21), INT8_C(-123),
                           INT8_C( -53), INT8_C(  42), INT8_C(  66), INT8_C(  13),
                           INT8_C(   9), INT8_C( 115), INT8_C(  86), INT8_C( 126),
                           INT8_C( -24), INT8_C(  35), INT8_C(  -5), INT8_C( 103),
                           INT8_C(  38), INT8_C( 111), INT8_C(  24), INT8_C( -71),
                           INT8_C(  -1), INT8_C(  17), INT8_C( -63), INT8_C( -13),
                           INT8_C(  14), INT8_C(  82), INT8_C(  78), INT8_C(-102),
                           INT8_C(  -7), INT8_C(  93), INT8_C(  25), INT8_C( 103),
                           INT8_C( 113), INT8_C( -15), INT8_C( -19), INT8_C( -73),
                           INT8_C( -11), INT8_C( 103), INT8_C( -97), INT8_C( 123),
                           INT8_C(  28), INT8_C(  53), INT8_C( -15), INT8_C( 122),
                           INT8_C(   3), INT8_C( -54), INT8_C( -61), INT8_C(  58),
                           INT8_C( -44), INT8_C(  -3), INT8_C( -43), INT8_C( -35),
                           INT8_C(-118), INT8_C( -18), INT8_C(  15), INT8_C(  54),
                           INT8_C(-102), INT8_C( -58), INT8_C( -74), INT8_C( -70),
                           INT8_C(  46), INT8_C(  48), INT8_C( -35), INT8_C(  92)),
      simde_mm512_set_epi8(INT8_C(   6), INT8_C(  68), INT8_C(  77), INT8_C( -94),
                           INT8_C( -48), INT8_C(-101), INT8_C(  -8), INT8_C(  82),
                           INT8_C(  50), INT8_C( -15), INT8_C(   6), INT8_C(  30),
                           INT8_C( -47), INT8_C( -15), INT8_C( -14), INT8_C( -97),
                           INT8_C(  28), INT8_C( -47), INT8_C( -92), INT8_C( -84),
                           INT8_C( -37), INT8_C( -33), INT8_C(-123), INT8_C( -19),
                           INT8_C(  58), INT8_C(  29), INT8_C(  93), INT8_C( -55),
                           INT8_C(-127), INT8_C( -60), INT8_C(  32), INT8_C( 116),
                           INT8_C( -46), INT8_C(  51), INT8_C( -40), INT8_C(  10),
                           INT8_C(   4), INT8_C(  50), INT8_C(  48), INT8_C(  53),
                           INT8_C(  78), INT8_C(  21), INT8_C(  64), INT8_C( 107),
                           INT8_C(  16), INT8_C(  48), INT8_C( -46), INT8_C(  62),
                           INT8_C(  75), INT8_C(  85), INT8_C(-115), INT8_C( -14),
                           INT8_C( -99), INT8_C(  86), INT8_C(-116), INT8_C( -74),
                           INT8_C(  38), INT8_C(  27), INT8_C(-115), INT8_C(  55),
                           INT8_C( -91), INT8_C( -71), INT8_C( -14), INT8_C( -84)),
      simde_mm512_set_epi8(INT8_C(-114), INT8_C(  72), INT8_C( -56), INT8_C( -29),
                           INT8_C(  -5), INT8_C(-113), INT8_C(  74), INT8_C( -69),
                           INT8_C( -41), INT8_C(-126), INT8_C(  80), INT8_C(  96),
                           INT8_C(  23), INT8_C(  50), INT8_C(   9), INT8_C( -56),
                           INT8_C(  10), INT8_C( -98), INT8_C( 116), INT8_C(  13),
                           INT8_C(  36), INT8_C(  50), INT8_C(  60), INT8_C(   6),
                           INT8_C( -44), INT8_C(  53), INT8_C( -15), INT8_C( -47),
                           INT8_C( 120), INT8_C(-103), INT8_C(  -7), INT8_C( -13),
                           INT8_C( -97), INT8_C( -66), INT8_C(  21), INT8_C( -83),
                           INT8_C( -15), INT8_C(  53), INT8_C( 111), INT8_C(  70),
                           INT8_C( -50), INT8_C(  32), INT8_C( -79), INT8_C(  15),
                           INT8_C( -13), INT8_C(-102), INT8_C( -15), INT8_C(  -4),
                           INT8_C(-119), INT8_C( -88), INT8_C(  72), INT8_C( -21),
                           INT8_C( -19), INT8_C(-104), INT8_C(-125), INT8_C(-128),
                           INT8_C( 116), INT8_C( -85), INT8_C(  41), INT8_C(-125),
                           INT8_C(-119), INT8_C( 119), INT8_C( -21), INT8_C( -80)) },
    { simde_mm512_set_epi8(INT8_C(   2), INT8_C( -77), INT8_C( -19), INT8_C(  41),
                           INT8_C( -13), INT8_C(  75), INT8_C(-123), INT8_C(  96),
                           INT8_C( -86), INT8_C( -24), INT8_C( -27), INT8_C( -84),
                           INT8_C(  35), INT8_C( -86), INT8_C( -72), INT8_C( -97),
                           INT8_C(  44), INT8_C(  11), INT8_C(-106), INT8_C(  44),
                           INT8_C(   0), INT8_C(  90), INT8_C( -79), INT8_C(  91),
                           INT8_C( 119), INT8_C(  59), INT8_C( 105), INT8_C(-128),
                           INT8_C( 110), INT8_C( -29), INT8_C(  67), INT8_C( 114),
                           INT8_C( -39), INT8_C( -49), INT8_C( 105), INT8_C( -40),
                           INT8_C( -33), INT8_C( 120), INT8_C( -27), INT8_C( 100),
                           INT8_C( -90), INT8_C(  86), INT8_C( -18), INT8_C( -57),
                           INT8_C(  84), INT8_C( -26), INT8_C( -77), INT8_C(  17),
                           INT8_C( -47), INT8_C(  51), INT8_C( -83), INT8_C(  53),
                           INT8_C(  71), INT8_C(  96), INT8_C( 110), INT8_C( -89),
                           INT8_C(  27), INT8_C( -45), INT8_C(-126), INT8_C(  40),
                           INT8_C(  95), INT8_C( -87), INT8_C( -62), INT8_C( -52)),
      simde_mm512_set_epi8(INT8_C( -84), INT8_C( 127), INT8_C(  61), INT8_C( -16),
                           INT8_C(  30), INT8_C(   6), INT8_C(-112), INT8_C( 104),
                           INT8_C( -60), INT8_C( -88), INT8_C( -39), INT8_C( -19),
                           INT8_C(  44), INT8_C(  36), INT8_C( 105), INT8_C( 120),
                           INT8_C( -26), INT8_C(  21), INT8_C(  14), INT8_C(  42),
                           INT8_C(  49), INT8_C( -84), INT8_C(-120), INT8_C(-107),
                           INT8_C( 123), INT8_C( -47), INT8_C(  21), INT8_C( -10),
                           INT8_C(  95), INT8_C( 124), INT8_C( -33), INT8_C( -34),
                           INT8_C( -33), INT8_C( -71), INT8_C(  11), INT8_C(  74),
                           INT8_C( 104), INT8_C( 108), INT8_C( -35), INT8_C( -59),
                           INT8_C( -55), INT8_C(-126), INT8_C( 107), INT8_C(  23),
                           INT8_C(  29), INT8_C( -27), INT8_C( 123), INT8_C(  23),
                           INT8_C( -83), INT8_C( -90), INT8_C(   9), INT8_C(  94),
                           INT8_C(  91), INT8_C(  69), INT8_C( -51), INT8_C(-103),
                           INT8_C( -72), INT8_C( -45), INT8_C(  16), INT8_C( 108),
                           INT8_C( -80), INT8_C(  27), INT8_C(  58), INT8_C( -83)),
      simde_mm512_set_epi8(INT8_C(  86), INT8_C(  52), INT8_C( -80), INT8_C(  57),
                           INT8_C( -43), INT8_C(  69), INT8_C( -11), INT8_C(  -8),
                           INT8_C( -26), INT8_C(  64), INT8_C(  12), INT8_C( -65),
                           INT8_C(  -9), INT8_C(-122), INT8_C(  79), INT8_C(  39),
                           INT8_C(  70), INT8_C( -10), INT8_C(-120), INT8_C(   2),
                           INT8_C( -49), INT8_C( -82), INT8_C(  41), INT8_C( -58),
                           INT8_C(  -4), INT8_C( 106), INT8_C(  84), INT8_C(-118),
                           INT8_C(  15), INT8_C( 103), INT8_C( 100), INT8_C(-108),
                           INT8_C(  -6), INT8_C(  22), INT8_C(  94), INT8_C(-114),
                           INT8_C( 119), INT8_C(  12), INT8_C(   8), INT8_C( -97),
                           INT8_C( -35), INT8_C( -44), INT8_C(-125), INT8_C( -80),
                           INT8_C(  55), INT8_C(   1), INT8_C(  56), INT8_C(  -6),
                           INT8_C(  36), INT8_C(-115), INT8_C( -92), INT8_C( -41),
                           INT8_C( -20), INT8_C(  27), INT8_C( -95), INT8_C(  14),
                           INT8_C(  99), INT8_C(   0), INT8_C( 114), INT8_C( -68),
                           INT8_C( -81), INT8_C(-114), INT8_C(-120), INT8_C(  31)) },
    { simde_mm512_set_epi8(INT8_C(  17), INT8_C(  99), INT8_C( -13), INT8_C( -49),
                           INT8_C(  45), INT8_C(-128), INT8_C(  55), INT8_C( 105),
                           INT8_C( -34), INT8_C( -51), INT8_C( -97), INT8_C(-103),
                           INT8_C(-124), INT8_C( 111), INT8_C(  74), INT8_C(  75),
                           INT8_C( 102), INT8_C(  98), INT8_C(-117), INT8_C(   9),
                           INT8_C( -74), INT8_C(  61), INT8_C(  99), INT8_C( 124),
                           INT8_C(  79), INT8_C(-114), INT8_C(  19), INT8_C(  97),
                           INT8_C(-100), INT8_C(-124), INT8_C( -17), INT8_C( -62),
                           INT8_C(  25), INT8_C(  -3), INT8_C(  -7), INT8_C(  72),
                           INT8_C(-117), INT8_C( -27), INT8_C( -56), INT8_C(  92),
                           INT8_C( -20), INT8_C( -53), INT8_C(   2), INT8_C( -38),
                           INT8_C( -81), INT8_C(  59), INT8_C(  66), INT8_C(  90),
                           INT8_C(  36), INT8_C( 100), INT8_C( 112), INT8_C( 123),
                           INT8_C( -72), INT8_C( -97), INT8_C(-115), INT8_C(  17),
                           INT8_C( -93), INT8_C(-122), INT8_C(  31), INT8_C(  27),
                           INT8_C( 109), INT8_C( 115), INT8_C(  53), INT8_C( -96)),
      simde_mm512_set_epi8(INT8_C( -43), INT8_C( -18), INT8_C( 114), INT8_C( -29),
                           INT8_C( 118), INT8_C(  -1), INT8_C( -20), INT8_C( -38),
                           INT8_C( -80), INT8_C(  88), INT8_C(-111), INT8_C( -91),
                           INT8_C(  44), INT8_C( -72), INT8_C( 106), INT8_C(  19),
                           INT8_C( -46), INT8_C( 107), INT8_C(  46), INT8_C(  44),
                           INT8_C( -65), INT8_C(-128), INT8_C(  41), INT8_C(  44),
                           INT8_C(  68), INT8_C(  69), INT8_C( -78), INT8_C( -47),
                           INT8_C( 109), INT8_C( 120), INT8_C( -57), INT8_C( -95),
                           INT8_C(  95), INT8_C(  80), INT8_C( -30), INT8_C(  97),
                           INT8_C( -48), INT8_C( -97), INT8_C( 111), INT8_C( -80),
                           INT8_C(-122), INT8_C( -81), INT8_C( -71), INT8_C(  85),
                           INT8_C(  77), INT8_C( -42), INT8_C(-115), INT8_C( -77),
                           INT8_C(  29), INT8_C(  77), INT8_C(  64), INT8_C( -20),
                           INT8_C(  27), INT8_C(  41), INT8_C(  13), INT8_C( 109),
                           INT8_C(  22), INT8_C( -98), INT8_C(  20), INT8_C( -28),
                           INT8_C(  66), INT8_C(  -7), INT8_C(-113), INT8_C(-119)),
      simde_mm512_set_epi8(INT8_C(  60), INT8_C( 117), INT8_C(-127), INT8_C( -20),
                           INT8_C( -73), INT8_C(-127), INT8_C(  75), INT8_C(-113),
                           INT8_C(  46), INT8_C( 117), INT8_C(  14), INT8_C( -12),
                           INT8_C(  88), INT8_C( -73), INT8_C( -32), INT8_C(  56),
                           INT8_C(-108), INT8_C(  -9), INT8_C(  93), INT8_C( -35),
                           INT8_C(  -9), INT8_C( -67), INT8_C(  58), INT8_C(  80),
                           INT8_C(  11), INT8_C(  73), INT8_C(  97), INT8_C(-112),
                           INT8_C(  47), INT8_C(  12), INT8_C(  40), INT8_C(  33),
                           INT8_C( -70), INT8_C( -83), INT8_C(  23), INT8_C( -25),
                           INT8_C( -69), INT8_C(  70), INT8_C(  89), INT8_C( -84),
                           INT8_C( 102), INT8_C(  28), INT8_C(  73), INT8_C(-123),
                           INT8_C(  98), INT8_C( 101), INT8_C( -75), INT8_C( -89),
                           INT8_C(   7), INT8_C(  23), INT8_C(  48), INT8_C(-113),
                           INT8_C( -99), INT8_C( 118), INT8_C(-128), INT8_C( -92),
                           INT8_C(-115), INT8_C( -24), INT8_C(  11), INT8_C(  55),
                           INT8_C(  43), INT8_C( 122), INT8_C( -90), INT8_C(  23)) },
    { simde_mm512_set_epi8(INT8_C(-124), INT8_C( -73), INT8_C(  74), INT8_C(   5),
                           INT8_C(  -9), INT8_C(  17), INT8_C( -81), INT8_C( -54),
                           INT8_C(  -5), INT8_C( -33), INT8_C( -12), INT8_C(  26),
                           INT8_C(  86), INT8_C( 122), INT8_C( -44), INT8_C( -23),
                           INT8_C(   0), INT8_C(  43), INT8_C( -25), INT8_C(-122),
                           INT8_C( -79), INT8_C(-122), INT8_C( -88), INT8_C(-121),
                           INT8_C(-102), INT8_C(  66), INT8_C( -93), INT8_C( 105),
                           INT8_C( 109), INT8_C( -68), INT8_C(  24), INT8_C( -54),
                           INT8_C(  40), INT8_C(  68), INT8_C(   2), INT8_C(  60),
                           INT8_C(   0), INT8_C(   5), INT8_C(  59), INT8_C( -54),
                           INT8_C( -76), INT8_C(  27), INT8_C( -23), INT8_C(  77),
                           INT8_C(-108), INT8_C( -28), INT8_C(-114), INT8_C(  56),
                           INT8_C( -54), INT8_C(-108), INT8_C( -15), INT8_C( -89),
                           INT8_C(-103), INT8_C( -45), INT8_C(  74), INT8_C(  -3),
                           INT8_C(-108), INT8_C(  55), INT8_C( -79), INT8_C( -62),
                           INT8_C(  14), INT8_C( 106), INT8_C( -16), INT8_C( -10)),
      simde_mm512_set_epi8(INT8_C( -47), INT8_C( 124), INT8_C(  57), INT8_C( -74),
                           INT8_C(  20), INT8_C( 124), INT8_C(  70), INT8_C( -69),
                           INT8_C( -65), INT8_C( -12), INT8_C( 124), INT8_C( -90),
                           INT8_C(-113), INT8_C(  63), INT8_C( -79), INT8_C( -70),
                           INT8_C( -76), INT8_C( -34), INT8_C( -60), INT8_C(  -4),
                           INT8_C( -41), INT8_C(  60), INT8_C(  77), INT8_C( -57),
                           INT8_C(  13), INT8_C(   2), INT8_C( 111), INT8_C( -39),
                           INT8_C(  41), INT8_C(  54), INT8_C( -37), INT8_C( 114),
                           INT8_C(  92), INT8_C(-111), INT8_C(  77), INT8_C(  14),
                           INT8_C(-104), INT8_C( -39), INT8_C( -74), INT8_C(  66),
                           INT8_C(  16), INT8_C( -26), INT8_C( -89), INT8_C(-114),
                           INT8_C( -68), INT8_C(   6), INT8_C(  62), INT8_C( -93),
                           INT8_C(  55), INT8_C(-113), INT8_C( -60), INT8_C( -56),
                           INT8_C( -37), INT8_C(   2), INT8_C( -15), INT8_C(  88),
                           INT8_C(  26), INT8_C(  54), INT8_C(  82), INT8_C( 124),
                           INT8_C( -38), INT8_C(-107), INT8_C(  40), INT8_C(  13)),
      simde_mm512_set_epi8(INT8_C( -77), INT8_C(  59), INT8_C(  17), INT8_C(  79),
                           INT8_C( -29), INT8_C(-107), INT8_C( 105), INT8_C(  15),
                           INT8_C(  60), INT8_C( -21), INT8_C( 120), INT8_C( 116),
                           INT8_C( -57), INT8_C(  59), INT8_C(  35), INT8_C(  47),
                           INT8_C(  76), INT8_C(  77), INT8_C(  35), INT8_C(-118),
                           INT8_C( -38), INT8_C(  74), INT8_C(  91), INT8_C( -64),
                           INT8_C(-115), INT8_C(  64), INT8_C(  52), INT8_C(-112),
                           INT8_C(  68), INT8_C(-122), INT8_C(  61), INT8_C(  88),
                           INT8_C( -52), INT8_C( -77), INT8_C( -75), INT8_C(  46),
                           INT8_C( 104), INT8_C(  44), INT8_C(-123), INT8_C(-120),
                           INT8_C( -92), INT8_C(  53), INT8_C(  66), INT8_C( -65),
                           INT8_C( -40), INT8_C( -34), INT8_C(  80), INT8_C(-107),
                           INT8_C(-109), INT8_C(   5), INT8_C(  45), INT8_C( -33),
                           INT8_C( -66), INT8_C( -47), INT8_C(  89), INT8_C( -91),
                           INT8_C( 122), INT8_C(   1), INT8_C(  95), INT8_C(  70),
                           INT8_C(  52), INT8_C( -43), INT8_C( -56), INT8_C( -23)) },
    { simde_mm512_set_epi8(INT8_C(   5), INT8_C( -68), INT8_C( -18), INT8_C( -37),
                           INT8_C(   5), INT8_C(  16), INT8_C(-109), INT8_C( -67),
                           INT8_C( -62), INT8_C(  -4), INT8_C(  14), INT8_C(-109),
                           INT8_C( -29), INT8_C(-121), INT8_C(-109), INT8_C( -55),
                           INT8_C(   1), INT8_C( -38), INT8_C( 107), INT8_C(  55),
                           INT8_C( -36), INT8_C( -76), INT8_C(  35), INT8_C( -40),
                           INT8_C(  10), INT8_C( -90), INT8_C( -48), INT8_C(-112),
                           INT8_C(  -9), INT8_C( -53), INT8_C( 105), INT8_C(  27),
                           INT8_C( -97), INT8_C(-124), INT8_C(   4), INT8_C( -36),
                           INT8_C( -16), INT8_C( -87), INT8_C( -89), INT8_C(-104),
                           INT8_C( -30), INT8_C(-101), INT8_C(  69), INT8_C(  79),
                           INT8_C(  59), INT8_C( -97), INT8_C( -15), INT8_C(  17),
                           INT8_C( 106), INT8_C( -85), INT8_C( 126), INT8_C(-121),
                           INT8_C( -91), INT8_C(  26), INT8_C(-115), INT8_C(-117),
                           INT8_C(  91), INT8_C(  73), INT8_C( -60), INT8_C(  69),
                           INT8_C( -23), INT8_C(  48), INT8_C(  70), INT8_C(  -8)),
      simde_mm512_set_epi8(INT8_C(  91), INT8_C(-103), INT8_C(  69), INT8_C(  61),
                           INT8_C( -82), INT8_C(  73), INT8_C( 122), INT8_C( -22),
                           INT8_C( 122), INT8_C(  76), INT8_C(  -9), INT8_C( 121),
                           INT8_C(-123), INT8_C(-119), INT8_C(-127), INT8_C( 126),
                           INT8_C( 105), INT8_C(  10), INT8_C(-120), INT8_C(-127),
                           INT8_C( -50), INT8_C(  15), INT8_C( -93), INT8_C( -86),
                           INT8_C(-125), INT8_C(  45), INT8_C( -39), INT8_C(-119),
                           INT8_C(  74), INT8_C( -92), INT8_C( -78), INT8_C(  53),
                           INT8_C(  17), INT8_C( -21), INT8_C( 105), INT8_C(-102),
                           INT8_C(  -1), INT8_C( -19), INT8_C( 110), INT8_C( -84),
                           INT8_C( -93), INT8_C(  19), INT8_C( -98), INT8_C(-128),
                           INT8_C( -23), INT8_C(  49), INT8_C( 100), INT8_C( 122),
                           INT8_C( -96), INT8_C(-103), INT8_C(  60), INT8_C( -24),
                           INT8_C(  23), INT8_C( -52), INT8_C( -37), INT8_C( -56),
                           INT8_C( -50), INT8_C(   4), INT8_C( -69), INT8_C(   1),
                           INT8_C( -25), INT8_C( -10), INT8_C(  93), INT8_C(  51)),
      simde_mm512_set_epi8(INT8_C( -86), INT8_C(  35), INT8_C( -87), INT8_C( -98),
                           INT8_C(  87), INT8_C( -57), INT8_C(  25), INT8_C( -45),
                           INT8_C(  72), INT8_C( -80), INT8_C(  23), INT8_C(  26),
                           INT8_C(  94), INT8_C(  -2), INT8_C(  18), INT8_C(  75),
                           INT8_C(-104), INT8_C( -48), INT8_C( -29), INT8_C( -74),
                           INT8_C(  14), INT8_C( -91), INT8_C(-128), INT8_C(  46),
                           INT8_C(-121), INT8_C( 121), INT8_C(  -9), INT8_C(   7),
                           INT8_C( -83), INT8_C(  39), INT8_C( -73), INT8_C( -26),
                           INT8_C(-114), INT8_C(-103), INT8_C(-101), INT8_C(  66),
                           INT8_C( -15), INT8_C( -68), INT8_C(  57), INT8_C( -20),
                           INT8_C(  63), INT8_C(-120), INT8_C( -89), INT8_C( -49),
                           INT8_C(  82), INT8_C( 110), INT8_C(-115), INT8_C(-105),
                           INT8_C( -54), INT8_C(  18), INT8_C(  66), INT8_C( -97),
                           INT8_C(-114), INT8_C(  78), INT8_C( -78), INT8_C( -61),
                           INT8_C(-115), INT8_C(  69), INT8_C(   9), INT8_C(  68),
                           INT8_C(   2), INT8_C(  58), INT8_C( -23), INT8_C( -59)) },
    { simde_mm512_set_epi8(INT8_C( -89), INT8_C(  43), INT8_C(  52), INT8_C(  82),
                           INT8_C( -37), INT8_C(  55), INT8_C( 112), INT8_C( -22),
                           INT8_C( -75), INT8_C( -36), INT8_C( -34), INT8_C( -15),
                           INT8_C(  35), INT8_C( -42), INT8_C(-101), INT8_C(  -5),
                           INT8_C(   2), INT8_C(  35), INT8_C(  14), INT8_C( -73),
                           INT8_C( -50), INT8_C( -33), INT8_C( -65), INT8_C(  94),
                           INT8_C(  -6), INT8_C( -21), INT8_C( -28), INT8_C(  21),
                           INT8_C( 102), INT8_C( -87), INT8_C( 114), INT8_C( 125),
                           INT8_C( 113), INT8_C( 124), INT8_C(-121), INT8_C(-122),
                           INT8_C(  23), INT8_C( 107), INT8_C(  24), INT8_C( 126),
                           INT8_C(  80), INT8_C(  59), INT8_C(  39), INT8_C( -61),
                           INT8_C(-105), INT8_C(  32), INT8_C(  55), INT8_C(  -9),
                           INT8_C(  60), INT8_C(-125), INT8_C(  72), INT8_C( -36),
                           INT8_C(  77), INT8_C( -65), INT8_C( 117), INT8_C( -85),
                           INT8_C(  98), INT8_C( -83), INT8_C( -69), INT8_C( -52),
                           INT8_C(  41), INT8_C( -10), INT8_C( -18), INT8_C(  56)),
      simde_mm512_set_epi8(INT8_C(  22), INT8_C( 122), INT8_C( -90), INT8_C(   2),
                           INT8_C( -65), INT8_C(  51), INT8_C( -94), INT8_C( -50),
                           INT8_C( -15), INT8_C(  19), INT8_C( -19), INT8_C(  66),
                           INT8_C( 119), INT8_C(-118), INT8_C(-112), INT8_C(-116),
                           INT8_C(  44), INT8_C( -12), INT8_C(  31), INT8_C(  43),
                           INT8_C( -16), INT8_C( -37), INT8_C( -24), INT8_C( -32),
                           INT8_C( -95), INT8_C( -86), INT8_C( -96), INT8_C(  80),
                           INT8_C(  68), INT8_C(  13), INT8_C(  -8), INT8_C(  67),
                           INT8_C( 107), INT8_C(-125), INT8_C( 104), INT8_C( -80),
                           INT8_C(  97), INT8_C( -78), INT8_C( 106), INT8_C( -53),
                           INT8_C( -36), INT8_C( -90), INT8_C(  74), INT8_C( -72),
                           INT8_C(  59), INT8_C( -81), INT8_C(  -8), INT8_C( -25),
                           INT8_C( -55), INT8_C( -99), INT8_C(  20), INT8_C(   9),
                           INT8_C( -89), INT8_C( -90), INT8_C( 108), INT8_C(  56),
                           INT8_C( -19), INT8_C(  81), INT8_C( 122), INT8_C(   6),
                           INT8_C(-119), INT8_C( 122), INT8_C( -35), INT8_C( 106)),
      simde_mm512_set_epi8(INT8_C(-111), INT8_C( -79), INT8_C(-114), INT8_C(  80),
                           INT8_C(  28), INT8_C(   4), INT8_C( -50), INT8_C(  28),
                           INT8_C( -60), INT8_C( -55), INT8_C( -15), INT8_C( -81),
                           INT8_C( -84), INT8_C(  76), INT8_C(  11), INT8_C( 111),
                           INT8_C( -42), INT8_C(  47), INT8_C( -17), INT8_C(-116),
                           INT8_C( -34), INT8_C(   4), INT8_C( -41), INT8_C( 126),
                           INT8_C(  89), INT8_C(  65), INT8_C(  68), INT8_C( -59),
                           INT8_C(  34), INT8_C(-100), INT8_C( 122), INT8_C(  58),
                           INT8_C(   6), INT8_C(  -7), INT8_C(  31), INT8_C( -42),
                           INT8_C( -74), INT8_C( -71), INT8_C( -82), INT8_C( -77),
                           INT8_C( 116), INT8_C(-107), INT8_C( -35), INT8_C(  11),
                           INT8_C(  92), INT8_C( 113), INT8_C(  63), INT8_C(  16),
                           INT8_C( 115), INT8_C( -26), INT8_C(  52), INT8_C( -45),
                           INT8_C( -90), INT8_C(  25), INT8_C(   9), INT8_C( 115),
                           INT8_C( 117), INT8_C(  92), INT8_C(  65), INT8_C( -58),
                           INT8_C( -96), INT8_C( 124), INT8_C(  17), INT8_C( -50)) },
    { simde_mm512_set_epi8(INT8_C( 105), INT8_C(-115), INT8_C( 121), INT8_C(-101),
                           INT8_C(   0), INT8_C(  63), INT8_C( -42), INT8_C( -34),
                           INT8_C(  -5), INT8_C( -47), INT8_C(-123), INT8_C( -52),
                           INT8_C( -86), INT8_C( -28), INT8_C( -63), INT8_C(  20),
                           INT8_C( -60), INT8_C( -63), INT8_C(  99), INT8_C(  78),
                           INT8_C(  56), INT8_C( -72), INT8_C( -55), INT8_C( -72),
                           INT8_C(  79), INT8_C( -81), INT8_C( 124), INT8_C( -85),
                           INT8_C( -65), INT8_C( 122), INT8_C( -25), INT8_C( -58),
                           INT8_C( -64), INT8_C(  52), INT8_C( -12), INT8_C(   1),
                           INT8_C( -62), INT8_C( -28), INT8_C( -28), INT8_C(-104),
                           INT8_C(  54), INT8_C(-103), INT8_C( -55), INT8_C( -22),
                           INT8_C( -91), INT8_C(   6), INT8_C(  -9), INT8_C( -31),
                           INT8_C(  18), INT8_C(-111), INT8_C(  58), INT8_C(  71),
                           INT8_C( -73), INT8_C( -96), INT8_C(  28), INT8_C(  -4),
                           INT8_C(  47), INT8_C(  66), INT8_C( 121), INT8_C(  38),
                           INT8_C(  69), INT8_C(-107), INT8_C( -57), INT8_C(-120)),
      simde_mm512_set_epi8(INT8_C( -49), INT8_C(  15), INT8_C( -15), INT8_C( -59),
                           INT8_C(-113), INT8_C( 102), INT8_C( -48), INT8_C( -78),
                           INT8_C(  31), INT8_C(  94), INT8_C(  79), INT8_C(  92),
                           INT8_C( 106), INT8_C( -68), INT8_C(  96), INT8_C( -97),
                           INT8_C( -27), INT8_C(-118), INT8_C( -11), INT8_C( 112),
                           INT8_C(-125), INT8_C(  70), INT8_C(  26), INT8_C( -38),
                           INT8_C( -16), INT8_C(-112), INT8_C(  10), INT8_C(  98),
                           INT8_C(  -4), INT8_C( 120), INT8_C( -33), INT8_C(-127),
                           INT8_C( -65), INT8_C( -40), INT8_C(  88), INT8_C(  -6),
                           INT8_C(  74), INT8_C(  41), INT8_C(  39), INT8_C(  79),
                           INT8_C(-125), INT8_C(  -7), INT8_C(  62), INT8_C(-112),
                           INT8_C(-119), INT8_C(  -9), INT8_C(  71), INT8_C( -68),
                           INT8_C( -79), INT8_C(  48), INT8_C( -20), INT8_C( -97),
                           INT8_C(-116), INT8_C( 120), INT8_C( -65), INT8_C(   6),
                           INT8_C( -32), INT8_C( -75), INT8_C(-106), INT8_C(  26),
                           INT8_C( -96), INT8_C(  50), INT8_C( -45), INT8_C(  16)),
      simde_mm512_set_epi8(INT8_C(-102), INT8_C( 126), INT8_C(-120), INT8_C( -42),
                           INT8_C( 113), INT8_C( -39), INT8_C(   6), INT8_C(  44),
                           INT8_C( -36), INT8_C( 115), INT8_C(  54), INT8_C( 112),
                           INT8_C(  64), INT8_C(  40), INT8_C(  97), INT8_C( 117),
                           INT8_C( -33), INT8_C(  55), INT8_C( 110), INT8_C( -34),
                           INT8_C( -75), INT8_C( 114), INT8_C( -81), INT8_C( -34),
                           INT8_C(  95), INT8_C(  31), INT8_C( 114), INT8_C(  73),
                           INT8_C( -61), INT8_C(   2), INT8_C(   8), INT8_C(  69),
                           INT8_C(   1), INT8_C(  92), INT8_C(-100), INT8_C(   7),
                           INT8_C( 120), INT8_C( -69), INT8_C( -67), INT8_C(  73),
                           INT8_C( -77), INT8_C( -96), INT8_C(-117), INT8_C(  90),
                           INT8_C(  28), INT8_C(  15), INT8_C( -80), INT8_C(  37),
                           INT8_C(  97), INT8_C(  97), INT8_C(  78), INT8_C( -88),
                           INT8_C(  43), INT8_C(  40), INT8_C(  93), INT8_C( -10),
                           INT8_C(  79), INT8_C(-115), INT8_C( -29), INT8_C(  12),
                           INT8_C( -91), INT8_C(  99), INT8_C( -12), INT8_C( 120)) }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])); i++) {
    simde__m512i r = simde_mm512_sub_epi8(test_vec[i].a, test_vec[i].b);
    simde_assert_m512i_i8(r, ==, test_vec[i].r);
  }

  return 0;
}

static int
test_simde_mm512_mask_sub_epi8(SIMDE_MUNIT_TEST_ARGS) {
  const struct {
    simde__m512i src;
    simde__mmask64 k;
    simde__m512i a;
    simde__m512i b;
    simde__m512i r;
  } test_vec[8] = {
    { simde_mm512_set_epi8(INT8_C( 121), INT8_C(  -8), INT8_C(-121), INT8_C( -19),
                           INT8_C(  19), INT8_C(  -3), INT8_C(  10), INT8_C( -37),
                           INT8_C(  96), INT8_C(  15), INT8_C( -45), INT8_C( -44),
                           INT8_C( -83), INT8_C( -37), INT8_C(   8), INT8_C( 111),
                           INT8_C( -30), INT8_C( -99), INT8_C( 116), INT8_C( 112),
                           INT8_C(  67), INT8_C(-123), INT8_C(  59), INT8_C( -62),
                           INT8_C(  33), INT8_C(  51), INT8_C( -16), INT8_C( -35),
                           INT8_C( -53), INT8_C( 108), INT8_C( -37), INT8_C( -15),
                           INT8_C(  26), INT8_C(  83), INT8_C( -47), INT8_C( -23),
                           INT8_C(   6), INT8_C(  52), INT8_C( -19), INT8_C( 108),
                           INT8_C( -33), INT8_C( 120), INT8_C(  55), INT8_C(-128),
                           INT8_C( -46), INT8_C( 117), INT8_C(  41), INT8_C( -54),
                           INT8_C( -99), INT8_C( -39), INT8_C( 117), INT8_C(  57),
                           INT8_C(  78), INT8_C(-110), INT8_C(  -8), INT8_C(-114),
                           INT8_C( -54), INT8_C(  20), INT8_C( 112), INT8_C(  39),
                           INT8_C( -60), INT8_C(  36), INT8_C( -53), INT8_C(  53)),
      UINT64_C(           567574400),
      simde_mm512_set_epi8(INT8_C( 115), INT8_C(  65), INT8_C(-123), INT8_C( 116),
                           INT8_C( -46), INT8_C( -68), INT8_C(  -8), INT8_C(  96),
                           INT8_C( -90), INT8_C( -14), INT8_C(  27), INT8_C(  33),
                           INT8_C(  21), INT8_C(  58), INT8_C( -12), INT8_C( -76),
                           INT8_C(  70), INT8_C( -70), INT8_C(  -4), INT8_C(  64),
                           INT8_C(  35), INT8_C( -32), INT8_C(-115), INT8_C( 109),
                           INT8_C( -69), INT8_C( -61), INT8_C(-126), INT8_C(  45),
                           INT8_C(  93), INT8_C( 100), INT8_C( -53), INT8_C( 105),
                           INT8_C( -51), INT8_C(  43), INT8_C( -96), INT8_C( -95),
                           INT8_C(  86), INT8_C( -66), INT8_C( -47), INT8_C( 123),
                           INT8_C(  63), INT8_C(  16), INT8_C( -66), INT8_C(  12),
                           INT8_C( 115), INT8_C( -39), INT8_C(  10), INT8_C( 108),
                           INT8_C(-120), INT8_C( 110), INT8_C( -25), INT8_C(   7),
                           INT8_C( 105), INT8_C( -93), INT8_C(  68), INT8_C(   3),
                           INT8_C( 113), INT8_C( -50), INT8_C( -34), INT8_C(  22),
                           INT8_C( -61), INT8_C(  75), INT8_C(  28), INT8_C( 116)),
      simde_mm512_set_epi8(INT8_C(  26), INT8_C(  -6), INT8_C( -92), INT8_C(   7),
                           INT8_C(-105), INT8_C( -92), INT8_C(  38), INT8_C( -63),
                           INT8_C(  77), INT8_C(  86), INT8_C( 113), INT8_C( -48),
                           INT8_C( 108), INT8_C( -92), INT8_C(  69), INT8_C(  74),
                           INT8_C(  67), INT8_C(  96), INT8_C( -34), INT8_C(  78),
                           INT8_C( 124), INT8_C(   9), INT8_C(  -1), INT8_C( -86),
                           INT8_C( -35), INT8_C(  26), INT8_C(  67), INT8_C(  46),
                           INT8_C(  75), INT8_C(-119), INT8_C(  68), INT8_C(  31),
                           INT8_C( -52), INT8_C(-102), INT8_C(  -4), INT8_C( 118),
                           INT8_C(   0), INT8_C( -44), INT8_C( 123), INT8_C( -73),
                           INT8_C(  84), INT8_C(  30), INT8_C(  -8), INT8_C(  64),
                           INT8_C( -20), INT8_C( -79), INT8_C( -85), INT8_C( -23),
                           INT8_C( -34), INT8_C(  -4), INT8_C( -85), INT8_C( 107),
                           INT8_C(  -6), INT8_C(  16), INT8_C( -66), INT8_C(-113),
                           INT8_C(  60), INT8_C( 127), INT8_C( -54), INT8_C( -36),
                           INT8_C(  73), INT8_C( -97), INT8_C( -65), INT8_C(  63)),
      simde_mm512_set_epi8(INT8_C( 121), INT8_C(  -8), INT8_C(-121), INT8_C( -19),
                           INT8_C(  19), INT8_C(  -3), INT8_C(  10), INT8_C( -37),
                           INT8_C(  96), INT8_C(  15), INT8_C( -45), INT8_C( -44),
                           INT8_C( -83), INT8_C( -37), INT8_C(   8), INT8_C( 111),
                           INT8_C( -30), INT8_C( -99), INT8_C( 116), INT8_C( 112),
                           INT8_C(  67), INT8_C(-123), INT8_C(  59), INT8_C( -62),
                           INT8_C(  33), INT8_C(  51), INT8_C( -16), INT8_C( -35),
                           INT8_C( -53), INT8_C( 108), INT8_C( -37), INT8_C( -15),
                           INT8_C(  26), INT8_C(  83), INT8_C( -92), INT8_C( -23),
                           INT8_C(   6), INT8_C(  52), INT8_C( -19), INT8_C( -60),
                           INT8_C( -21), INT8_C( -14), INT8_C(  55), INT8_C( -52),
                           INT8_C( -46), INT8_C(  40), INT8_C(  41), INT8_C( -54),
                           INT8_C( -99), INT8_C( 114), INT8_C(  60), INT8_C(-100),
                           INT8_C( 111), INT8_C(-109), INT8_C(-122), INT8_C( 116),
                           INT8_C(  53), INT8_C(  20), INT8_C( 112), INT8_C(  39),
                           INT8_C( -60), INT8_C(  36), INT8_C( -53), INT8_C(  53)) },
    { simde_mm512_set_epi8(INT8_C(  44), INT8_C(  68), INT8_C(  96), INT8_C(  88),
                           INT8_C(   1), INT8_C(  68), INT8_C(  46), INT8_C(  19),
                           INT8_C(  31), INT8_C(  85), INT8_C(  35), INT8_C(  68),
                           INT8_C( -79), INT8_C(  41), INT8_C(  28), INT8_C(  92),
                           INT8_C( -26), INT8_C(  20), INT8_C( -16), INT8_C(  -7),
                           INT8_C(  41), INT8_C(  71), INT8_C(  88), INT8_C(  39),
                           INT8_C( -42), INT8_C(  76), INT8_C(  40), INT8_C( 108),
                           INT8_C( -87), INT8_C(-126), INT8_C(  42), INT8_C(  58),
                           INT8_C(   2), INT8_C( -23), INT8_C(   5), INT8_C(-116),
                           INT8_C(  34), INT8_C(  66), INT8_C(  28), INT8_C(  86),
                           INT8_C(  50), INT8_C( -67), INT8_C(  20), INT8_C(  73),
                           INT8_C(  27), INT8_C( -29), INT8_C(  84), INT8_C( 112),
                           INT8_C( 104), INT8_C(  53), INT8_C( -89), INT8_C(-113),
                           INT8_C(  -4), INT8_C(  94), INT8_C(  75), INT8_C(  21),
                           INT8_C(-120), INT8_C( -25), INT8_C( 111), INT8_C(-128),
                           INT8_C(  -4), INT8_C(  58), INT8_C(-115), INT8_C(   4)),
      UINT64_C(          2779079274),
      simde_mm512_set_epi8(INT8_C( -70), INT8_C( -58), INT8_C(  69), INT8_C(  -7),
                           INT8_C( 115), INT8_C( -10), INT8_C( -39), INT8_C(  78),
                           INT8_C(  56), INT8_C( 116), INT8_C( 104), INT8_C( -92),
                           INT8_C(   5), INT8_C( -47), INT8_C(  27), INT8_C(  94),
                           INT8_C(-126), INT8_C(  88), INT8_C(  80), INT8_C( 112),
                           INT8_C(  21), INT8_C(  62), INT8_C(  86), INT8_C(-103),
                           INT8_C(  66), INT8_C(  -9), INT8_C( -26), INT8_C(  47),
                           INT8_C( -50), INT8_C(-118), INT8_C( 115), INT8_C(  49),
                           INT8_C(  42), INT8_C(   6), INT8_C(  92), INT8_C(   2),
                           INT8_C(  63), INT8_C(  -6), INT8_C( -32), INT8_C(  15),
                           INT8_C(  66), INT8_C(  82), INT8_C(  -9), INT8_C( -79),
                           INT8_C(-123), INT8_C(  52), INT8_C( -90), INT8_C(-111),
                           INT8_C(  62), INT8_C( -43), INT8_C( -50), INT8_C(  62),
                           INT8_C(   4), INT8_C( -92), INT8_C(  86), INT8_C( -32),
                           INT8_C(  69), INT8_C( -15), INT8_C(  55), INT8_C(-127),
                           INT8_C( -36), INT8_C(  56), INT8_C(  46), INT8_C(-119)),
      simde_mm512_set_epi8(INT8_C(  18), INT8_C(  68), INT8_C(  -9), INT8_C(  64),
                           INT8_C(-111), INT8_C(  37), INT8_C( -82), INT8_C( -95),
                           INT8_C(  54), INT8_C(  75), INT8_C( -77), INT8_C( -34),
                           INT8_C(  52), INT8_C( -80), INT8_C( -94), INT8_C(  90),
                           INT8_C(   0), INT8_C(  -8), INT8_C( 123), INT8_C(-111),
                           INT8_C(  16), INT8_C( 125), INT8_C( -51), INT8_C(  99),
                           INT8_C( -22), INT8_C( 121), INT8_C(  63), INT8_C( -55),
                           INT8_C( 117), INT8_C( 109), INT8_C(-126), INT8_C(-111),
                           INT8_C(  47), INT8_C(-127), INT8_C( 109), INT8_C(  -9),
                           INT8_C( -42), INT8_C(  36), INT8_C( -32), INT8_C( 115),
                           INT8_C( -89), INT8_C(   7), INT8_C(  90), INT8_C(  46),
                           INT8_C( -83), INT8_C( -35), INT8_C(  30), INT8_C( -19),
                           INT8_C( -99), INT8_C( -56), INT8_C( -70), INT8_C(  73),
                           INT8_C( -61), INT8_C(  27), INT8_C( 117), INT8_C(  47),
                           INT8_C(   0), INT8_C( -45), INT8_C(  59), INT8_C(  51),
                           INT8_C( -35), INT8_C(  70), INT8_C(  73), INT8_C(  33)),
      simde_mm512_set_epi8(INT8_C(  44), INT8_C(  68), INT8_C(  96), INT8_C(  88),
                           INT8_C(   1), INT8_C(  68), INT8_C(  46), INT8_C(  19),
                           INT8_C(  31), INT8_C(  85), INT8_C(  35), INT8_C(  68),
                           INT8_C( -79), INT8_C(  41), INT8_C(  28), INT8_C(  92),
                           INT8_C( -26), INT8_C(  20), INT8_C( -16), INT8_C(  -7),
                           INT8_C(  41), INT8_C(  71), INT8_C(  88), INT8_C(  39),
                           INT8_C( -42), INT8_C(  76), INT8_C(  40), INT8_C( 108),
                           INT8_C( -87), INT8_C(-126), INT8_C(  42), INT8_C(  58),
                           INT8_C(  -5), INT8_C( -23), INT8_C( -17), INT8_C(-116),
                           INT8_C(  34), INT8_C( -42), INT8_C(  28), INT8_C(-100),
                           INT8_C(-101), INT8_C( -67), INT8_C( -99), INT8_C(  73),
                           INT8_C(  27), INT8_C(  87), INT8_C(  84), INT8_C( -92),
                           INT8_C( 104), INT8_C(  13), INT8_C(  20), INT8_C(-113),
                           INT8_C(  -4), INT8_C(  94), INT8_C( -31), INT8_C(  21),
                           INT8_C(-120), INT8_C(  30), INT8_C(  -4), INT8_C(-128),
                           INT8_C(  -1), INT8_C(  58), INT8_C( -27), INT8_C(   4)) },
    { simde_mm512_set_epi8(INT8_C( -35), INT8_C(  32), INT8_C( -43), INT8_C( 108),
                           INT8_C(  83), INT8_C( -59), INT8_C(  -4), INT8_C( 125),
                           INT8_C( -31), INT8_C( 118), INT8_C( -25), INT8_C( -91),
                           INT8_C(  50), INT8_C( -74), INT8_C(  78), INT8_C(  95),
                           INT8_C( -84), INT8_C( -63), INT8_C(  87), INT8_C(-108),
                           INT8_C(  28), INT8_C( -70), INT8_C(  77), INT8_C(-113),
                           INT8_C( -20), INT8_C(  50), INT8_C(  95), INT8_C(-108),
                           INT8_C( 105), INT8_C( 114), INT8_C(-109), INT8_C(  19),
                           INT8_C( -79), INT8_C( 106), INT8_C(  61), INT8_C( -12),
                           INT8_C( 126), INT8_C(-117), INT8_C( 126), INT8_C(-125),
                           INT8_C( -93), INT8_C(  69), INT8_C( 104), INT8_C( 119),
                           INT8_C(  63), INT8_C(  95), INT8_C(-106), INT8_C( -66),
                           INT8_C( -47), INT8_C( -45), INT8_C( -60), INT8_C( -54),
                           INT8_C(-109), INT8_C( -45), INT8_C( -86), INT8_C( 121),
                           INT8_C(  23), INT8_C( -12), INT8_C(  67), INT8_C(  -6),
                           INT8_C( -37), INT8_C(  92), INT8_C( -35), INT8_C(  99)),
      UINT64_C(          1100920337),
      simde_mm512_set_epi8(INT8_C(  13), INT8_C( 104), INT8_C(  50), INT8_C(  43),
                           INT8_C(  82), INT8_C(  -5), INT8_C( -23), INT8_C( -47),
                           INT8_C(  99), INT8_C(-116), INT8_C( 118), INT8_C(  73),
                           INT8_C( -10), INT8_C( -88), INT8_C( -42), INT8_C( -58),
                           INT8_C( -49), INT8_C(  65), INT8_C( -18), INT8_C(  54),
                           INT8_C( -68), INT8_C(   1), INT8_C(  -7), INT8_C( -96),
                           INT8_C(   4), INT8_C( 115), INT8_C(  42), INT8_C(-106),
                           INT8_C(  31), INT8_C(  94), INT8_C( -71), INT8_C( -41),
                           INT8_C(  33), INT8_C(-106), INT8_C( -65), INT8_C(-107),
                           INT8_C(  71), INT8_C( -10), INT8_C( -21), INT8_C(-128),
                           INT8_C( -23), INT8_C(  20), INT8_C(   2), INT8_C(  96),
                           INT8_C(-128), INT8_C( -51), INT8_C( -38), INT8_C(  47),
                           INT8_C( -56), INT8_C( 123), INT8_C( -20), INT8_C( -50),
                           INT8_C(  -2), INT8_C(  40), INT8_C(  24), INT8_C( -98),
                           INT8_C(   4), INT8_C( -62), INT8_C( -44), INT8_C(  49),
                           INT8_C(  83), INT8_C( 115), INT8_C(   5), INT8_C(  57)),
      simde_mm512_set_epi8(INT8_C(  76), INT8_C( -52), INT8_C( -96), INT8_C(  -6),
                           INT8_C(-119), INT8_C( -87), INT8_C( 102), INT8_C(   5),
                           INT8_C(  24), INT8_C( -44), INT8_C( 110), INT8_C(-113),
                           INT8_C(-116), INT8_C(  -3), INT8_C(  62), INT8_C( -87),
                           INT8_C(   7), INT8_C( -54), INT8_C( -57), INT8_C( -66),
                           INT8_C(  42), INT8_C( -82), INT8_C(  46), INT8_C( -16),
                           INT8_C(  91), INT8_C( -73), INT8_C( -20), INT8_C( -77),
                           INT8_C( -11), INT8_C(  25), INT8_C(  12), INT8_C(  76),
                           INT8_C( -58), INT8_C(   3), INT8_C(-125), INT8_C( -36),
                           INT8_C(  18), INT8_C( -40), INT8_C( 111), INT8_C( 107),
                           INT8_C(  88), INT8_C(  48), INT8_C( 113), INT8_C( -90),
                           INT8_C(-117), INT8_C( 116), INT8_C(  46), INT8_C( -70),
                           INT8_C(  51), INT8_C( -55), INT8_C( 127), INT8_C(  82),
                           INT8_C( -88), INT8_C(  60), INT8_C( -59), INT8_C(  80),
                           INT8_C( -51), INT8_C(  11), INT8_C( -44), INT8_C(  33),
                           INT8_C(  29), INT8_C(   8), INT8_C(   5), INT8_C(  70)),
      simde_mm512_set_epi8(INT8_C( -35), INT8_C(  32), INT8_C( -43), INT8_C( 108),
                           INT8_C(  83), INT8_C( -59), INT8_C(  -4), INT8_C( 125),
                           INT8_C( -31), INT8_C( 118), INT8_C( -25), INT8_C( -91),
                           INT8_C(  50), INT8_C( -74), INT8_C(  78), INT8_C(  95),
                           INT8_C( -84), INT8_C( -63), INT8_C(  87), INT8_C(-108),
                           INT8_C(  28), INT8_C( -70), INT8_C(  77), INT8_C(-113),
                           INT8_C( -20), INT8_C(  50), INT8_C(  95), INT8_C(-108),
                           INT8_C( 105), INT8_C( 114), INT8_C(-109), INT8_C(  19),
                           INT8_C( -79), INT8_C(-109), INT8_C(  61), INT8_C( -12),
                           INT8_C( 126), INT8_C(-117), INT8_C( 126), INT8_C(  21),
                           INT8_C(-111), INT8_C(  69), INT8_C( 104), INT8_C( -70),
                           INT8_C( -11), INT8_C(  89), INT8_C( -84), INT8_C( -66),
                           INT8_C(-107), INT8_C( -45), INT8_C( 109), INT8_C( 124),
                           INT8_C(-109), INT8_C( -20), INT8_C(  83), INT8_C( 121),
                           INT8_C(  23), INT8_C( -12), INT8_C(  67), INT8_C(  16),
                           INT8_C( -37), INT8_C(  92), INT8_C( -35), INT8_C( -13)) },
    { simde_mm512_set_epi8(INT8_C(  27), INT8_C(  45), INT8_C(  71), INT8_C( -63),
                           INT8_C(  96), INT8_C(-106), INT8_C( -43), INT8_C(  10),
                           INT8_C( 104), INT8_C( -19), INT8_C(-110), INT8_C( 126),
                           INT8_C( -52), INT8_C( -56), INT8_C( -96), INT8_C( -27),
                           INT8_C(-125), INT8_C(-116), INT8_C(  25), INT8_C(  78),
                           INT8_C( -76), INT8_C( -85), INT8_C( -23), INT8_C( -19),
                           INT8_C(-106), INT8_C( 126), INT8_C(  19), INT8_C( -41),
                           INT8_C(  40), INT8_C(  78), INT8_C( -69), INT8_C(  57),
                           INT8_C(  73), INT8_C( -58), INT8_C(   3), INT8_C(  65),
                           INT8_C( -87), INT8_C( -37), INT8_C(   5), INT8_C(-126),
                           INT8_C(  14), INT8_C( -36), INT8_C( -37), INT8_C(  11),
                           INT8_C(  94), INT8_C(  24), INT8_C(   8), INT8_C( -31),
                           INT8_C( -38), INT8_C(  -1), INT8_C(  48), INT8_C(  32),
                           INT8_C(  88), INT8_C( -18), INT8_C( 123), INT8_C(  27),
                           INT8_C( 111), INT8_C(  27), INT8_C(  -3), INT8_C(  52),
                           INT8_C( -31), INT8_C(   2), INT8_C( -47), INT8_C(  64)),
      UINT64_C(           361367503),
      simde_mm512_set_epi8(INT8_C( -20), INT8_C(-104), INT8_C( -27), INT8_C(  38),
                           INT8_C(  31), INT8_C( -21), INT8_C(  79), INT8_C( -62),
                           INT8_C(  36), INT8_C(  95), INT8_C(  42), INT8_C(-102),
                           INT8_C( -80), INT8_C( -69), INT8_C( 107), INT8_C(-114),
                           INT8_C(  76), INT8_C( 123), INT8_C(-126), INT8_C( 108),
                           INT8_C( -55), INT8_C(  89), INT8_C( -46), INT8_C(  18),
                           INT8_C( 117), INT8_C(  25), INT8_C(-120), INT8_C(  27),
                           INT8_C(  34), INT8_C(  64), INT8_C(  71), INT8_C(  64),
                           INT8_C( -13), INT8_C( -73), INT8_C( 112), INT8_C(  25),
                           INT8_C( -18), INT8_C( -63), INT8_C( 109), INT8_C(   9),
                           INT8_C(  14), INT8_C(-125), INT8_C( -89), INT8_C(  70),
                           INT8_C(  10), INT8_C(  15), INT8_C( 120), INT8_C( -59),
                           INT8_C(  55), INT8_C( 108), INT8_C(  41), INT8_C(  -5),
                           INT8_C( -91), INT8_C(-120), INT8_C( -46), INT8_C( 122),
                           INT8_C( 116), INT8_C(-120), INT8_C( -67), INT8_C( -86),
                           INT8_C(  48), INT8_C(   2), INT8_C(  37), INT8_C( -26)),
      simde_mm512_set_epi8(INT8_C( -70), INT8_C(   3), INT8_C( 118), INT8_C(  37),
                           INT8_C( 104), INT8_C( 111), INT8_C( -17), INT8_C( 110),
                           INT8_C( -58), INT8_C(  58), INT8_C( 102), INT8_C(  64),
                           INT8_C( -67), INT8_C( -76), INT8_C( -30), INT8_C( 108),
                           INT8_C(  79), INT8_C(  46), INT8_C( -40), INT8_C( 101),
                           INT8_C( -13), INT8_C( -25), INT8_C(  60), INT8_C(  25),
                           INT8_C(  32), INT8_C( -21), INT8_C( 114), INT8_C( -21),
                           INT8_C(  71), INT8_C( -85), INT8_C(  34), INT8_C(  82),
                           INT8_C(-114), INT8_C( -30), INT8_C( -58), INT8_C( 116),
                           INT8_C(  58), INT8_C(-105), INT8_C( 117), INT8_C(  11),
                           INT8_C( -91), INT8_C( 118), INT8_C( -50), INT8_C(  -8),
                           INT8_C( -22), INT8_C(  59), INT8_C( -29), INT8_C( -88),
                           INT8_C( -82), INT8_C( -24), INT8_C(  18), INT8_C( 115),
                           INT8_C( -15), INT8_C(  55), INT8_C(  78), INT8_C(  60),
                           INT8_C(  -8), INT8_C( -91), INT8_C( 126), INT8_C(  15),
                           INT8_C(  23), INT8_C(   6), INT8_C( -21), INT8_C( 120)),
      simde_mm512_set_epi8(INT8_C(  27), INT8_C(  45), INT8_C(  71), INT8_C( -63),
                           INT8_C(  96), INT8_C(-106), INT8_C( -43), INT8_C(  10),
                           INT8_C( 104), INT8_C( -19), INT8_C(-110), INT8_C( 126),
                           INT8_C( -52), INT8_C( -56), INT8_C( -96), INT8_C( -27),
                           INT8_C(-125), INT8_C(-116), INT8_C(  25), INT8_C(  78),
                           INT8_C( -76), INT8_C( -85), INT8_C( -23), INT8_C( -19),
                           INT8_C(-106), INT8_C( 126), INT8_C(  19), INT8_C( -41),
                           INT8_C(  40), INT8_C(  78), INT8_C( -69), INT8_C(  57),
                           INT8_C(  73), INT8_C( -58), INT8_C(   3), INT8_C( -91),
                           INT8_C( -87), INT8_C(  42), INT8_C(   5), INT8_C(  -2),
                           INT8_C( 105), INT8_C( -36), INT8_C( -37), INT8_C(  11),
                           INT8_C(  32), INT8_C(  24), INT8_C(-107), INT8_C( -31),
                           INT8_C( -38), INT8_C(  -1), INT8_C(  48), INT8_C(  32),
                           INT8_C(  88), INT8_C(  81), INT8_C(-124), INT8_C(  62),
                           INT8_C( 124), INT8_C( -29), INT8_C(  -3), INT8_C(  52),
                           INT8_C(  25), INT8_C(  -4), INT8_C(  58), INT8_C( 110)) },
    { simde_mm512_set_epi8(INT8_C(   4), INT8_C(  97), INT8_C(  53), INT8_C( -46),
                           INT8_C(  92), INT8_C(-100), INT8_C(  47), INT8_C( 107),
                           INT8_C( -52), INT8_C(  68), INT8_C(  11), INT8_C( -16),
                           INT8_C( -66), INT8_C( -79), INT8_C( -14), INT8_C(  27),
                           INT8_C(  14), INT8_C( 125), INT8_C(  22), INT8_C( -82),
                           INT8_C(  44), INT8_C( -12), INT8_C(  94), INT8_C( -30),
                           INT8_C(  98), INT8_C( 125), INT8_C(-107), INT8_C(  37),
                           INT8_C( -66), INT8_C(  90), INT8_C(  68), INT8_C(  10),
                           INT8_C( -72), INT8_C( -10), INT8_C(-119), INT8_C(  -9),
                           INT8_C(  49), INT8_C(-107), INT8_C(  10), INT8_C(  47),
                           INT8_C(  58), INT8_C(-125), INT8_C(   4), INT8_C(  68),
                           INT8_C( -24), INT8_C( -12), INT8_C(  44), INT8_C(-128),
                           INT8_C( -52), INT8_C( -61), INT8_C( -14), INT8_C( -38),
                           INT8_C( -93), INT8_C( -34), INT8_C(  64), INT8_C( -67),
                           INT8_C(-123), INT8_C( 123), INT8_C( -93), INT8_C(  41),
                           INT8_C(  97), INT8_C(  -8), INT8_C( -86), INT8_C( -16)),
      UINT64_C(           944667126),
      simde_mm512_set_epi8(INT8_C( -24), INT8_C( -47), INT8_C(-119), INT8_C(   5),
                           INT8_C(  95), INT8_C(  82), INT8_C(  -3), INT8_C( -62),
                           INT8_C(-116), INT8_C( -98), INT8_C( -29), INT8_C(  77),
                           INT8_C( -38), INT8_C(-118), INT8_C( -85), INT8_C( 121),
                           INT8_C( -72), INT8_C(-111), INT8_C(  28), INT8_C( -18),
                           INT8_C(  64), INT8_C(-126), INT8_C( 122), INT8_C( -54),
                           INT8_C(  87), INT8_C( -22), INT8_C(  17), INT8_C(  50),
                           INT8_C( -83), INT8_C( -39), INT8_C(  77), INT8_C( -13),
                           INT8_C(  17), INT8_C( -66), INT8_C(-128), INT8_C(  77),
                           INT8_C( 107), INT8_C(  47), INT8_C( -68), INT8_C( -44),
                           INT8_C( -30), INT8_C( -22), INT8_C(  14), INT8_C(  26),
                           INT8_C(  59), INT8_C( 103), INT8_C( -54), INT8_C( -39),
                           INT8_C(  16), INT8_C(   5), INT8_C(  18), INT8_C(-104),
                           INT8_C(-119), INT8_C( -46), INT8_C( -92), INT8_C(  37),
                           INT8_C( -84), INT8_C(   2), INT8_C( -49), INT8_C(  99),
                           INT8_C( -79), INT8_C(  48), INT8_C(-103), INT8_C(   3)),
      simde_mm512_set_epi8(INT8_C( -56), INT8_C( -56), INT8_C(  57), INT8_C( -25),
                           INT8_C(  -3), INT8_C(  99), INT8_C(  -6), INT8_C(  31),
                           INT8_C( -96), INT8_C(  49), INT8_C( 110), INT8_C( -10),
                           INT8_C( -82), INT8_C(  32), INT8_C( -27), INT8_C( 112),
                           INT8_C(  84), INT8_C(  37), INT8_C( -62), INT8_C(  38),
                           INT8_C( -53), INT8_C( -97), INT8_C(  76), INT8_C(  13),
                           INT8_C(-124), INT8_C(-120), INT8_C( -86), INT8_C(  98),
                           INT8_C(  96), INT8_C(   4), INT8_C(   4), INT8_C(  94),
                           INT8_C( -41), INT8_C( -81), INT8_C( -40), INT8_C( -28),
                           INT8_C( -23), INT8_C( -59), INT8_C( -15), INT8_C( -40),
                           INT8_C( 113), INT8_C( 116), INT8_C(  41), INT8_C( -96),
                           INT8_C( -83), INT8_C(   4), INT8_C(  93), INT8_C(  28),
                           INT8_C( 114), INT8_C(  29), INT8_C( -56), INT8_C( -61),
                           INT8_C(-124), INT8_C(-107), INT8_C( -23), INT8_C( -89),
                           INT8_C(  38), INT8_C( -97), INT8_C( 109), INT8_C(  53),
                           INT8_C(-117), INT8_C(  76), INT8_C( -82), INT8_C( -65)),
      simde_mm512_set_epi8(INT8_C(   4), INT8_C(  97), INT8_C(  53), INT8_C( -46),
                           INT8_C(  92), INT8_C(-100), INT8_C(  47), INT8_C( 107),
                           INT8_C( -52), INT8_C(  68), INT8_C(  11), INT8_C( -16),
                           INT8_C( -66), INT8_C( -79), INT8_C( -14), INT8_C(  27),
                           INT8_C(  14), INT8_C( 125), INT8_C(  22), INT8_C( -82),
                           INT8_C(  44), INT8_C( -12), INT8_C(  94), INT8_C( -30),
                           INT8_C(  98), INT8_C( 125), INT8_C(-107), INT8_C(  37),
                           INT8_C( -66), INT8_C(  90), INT8_C(  68), INT8_C(  10),
                           INT8_C( -72), INT8_C( -10), INT8_C( -88), INT8_C( 105),
                           INT8_C(-126), INT8_C(-107), INT8_C(  10), INT8_C(  47),
                           INT8_C(  58), INT8_C( 118), INT8_C(   4), INT8_C(  68),
                           INT8_C(-114), INT8_C(  99), INT8_C( 109), INT8_C(-128),
                           INT8_C( -52), INT8_C( -24), INT8_C(  74), INT8_C( -43),
                           INT8_C(   5), INT8_C( -34), INT8_C(  64), INT8_C( 126),
                           INT8_C(-122), INT8_C(  99), INT8_C(  98), INT8_C(  46),
                           INT8_C(  97), INT8_C( -28), INT8_C( -21), INT8_C( -16)) },
    { simde_mm512_set_epi8(INT8_C( -50), INT8_C(   0), INT8_C(  80), INT8_C(-123),
                           INT8_C(  19), INT8_C( 112), INT8_C(  30), INT8_C(  95),
                           INT8_C(  58), INT8_C(  21), INT8_C(  13), INT8_C(  32),
                           INT8_C( 113), INT8_C( 126), INT8_C(  27), INT8_C( 113),
                           INT8_C( 121), INT8_C(  97), INT8_C(  51), INT8_C( -16),
                           INT8_C( -77), INT8_C(  84), INT8_C(  16), INT8_C(-112),
                           INT8_C( -40), INT8_C( -69), INT8_C(-116), INT8_C( -97),
                           INT8_C(-120), INT8_C( 102), INT8_C( -82), INT8_C( -42),
                           INT8_C(  43), INT8_C( -70), INT8_C(  46), INT8_C(  17),
                           INT8_C( 108), INT8_C( -47), INT8_C(  53), INT8_C( -84),
                           INT8_C(  19), INT8_C( -37), INT8_C( -32), INT8_C( -59),
                           INT8_C(  33), INT8_C( 110), INT8_C(  17), INT8_C(  67),
                           INT8_C(  51), INT8_C( -19), INT8_C(  91), INT8_C(  26),
                           INT8_C(  33), INT8_C( -43), INT8_C( -14), INT8_C( -56),
                           INT8_C( 112), INT8_C( -72), INT8_C(  96), INT8_C( -62),
                           INT8_C( -21), INT8_C(  96), INT8_C( -25), INT8_C( 104)),
      UINT64_C(          1662672283),
      simde_mm512_set_epi8(INT8_C(  55), INT8_C(  43), INT8_C(-128), INT8_C(  23),
                           INT8_C( -59), INT8_C( -21), INT8_C( -11), INT8_C( -65),
                           INT8_C(-101), INT8_C( -89), INT8_C( -88), INT8_C( -71),
                           INT8_C( -70), INT8_C(  37), INT8_C( 122), INT8_C(  74),
                           INT8_C( 109), INT8_C( -13), INT8_C( -13), INT8_C(  72),
                           INT8_C(  -1), INT8_C( -35), INT8_C(  80), INT8_C( -20),
                           INT8_C(  14), INT8_C(-104), INT8_C( -76), INT8_C(-122),
                           INT8_C( -35), INT8_C( -33), INT8_C(  63), INT8_C(  74),
                           INT8_C(  98), INT8_C(  54), INT8_C( -12), INT8_C(  -1),
                           INT8_C( -30), INT8_C(  96), INT8_C(  95), INT8_C(  58),
                           INT8_C( -63), INT8_C(  -6), INT8_C(-113), INT8_C(  55),
                           INT8_C(-128), INT8_C( -43), INT8_C( -90), INT8_C( -63),
                           INT8_C(   3), INT8_C(  -6), INT8_C( -45), INT8_C( -75),
                           INT8_C( -83), INT8_C(-118), INT8_C(  74), INT8_C(  35),
                           INT8_C(  38), INT8_C(   4), INT8_C(  35), INT8_C(  15),
                           INT8_C( -42), INT8_C(  71), INT8_C(  -1), INT8_C(  27)),
      simde_mm512_set_epi8(INT8_C(  32), INT8_C( 122), INT8_C(  89), INT8_C(  21),
                           INT8_C( -83), INT8_C( -46), INT8_C( -78), INT8_C(  71),
                           INT8_C( -35), INT8_C(  54), INT8_C( -65), INT8_C(-111),
                           INT8_C(  45), INT8_C(  -5), INT8_C( 102), INT8_C(  32),
                           INT8_C(-110), INT8_C( 116), INT8_C( -61), INT8_C(  36),
                           INT8_C( -25), INT8_C( 106), INT8_C( -63), INT8_C(  23),
                           INT8_C( -59), INT8_C(  25), INT8_C(-108), INT8_C( -84),
                           INT8_C( -23), INT8_C( 118), INT8_C( -35), INT8_C(  92),
                           INT8_C( -29), INT8_C(-121), INT8_C( -87), INT8_C(  93),
                           INT8_C(   6), INT8_C( -12), INT8_C(-123), INT8_C(  42),
                           INT8_C( 121), INT8_C(   3), INT8_C(  69), INT8_C(  75),
                           INT8_C(  68), INT8_C(  -1), INT8_C( -25), INT8_C(  83),
                           INT8_C(  -4), INT8_C( -73), INT8_C( -63), INT8_C(  12),
                           INT8_C( -93), INT8_C( -22), INT8_C(  40), INT8_C( -24),
                           INT8_C( -60), INT8_C(  99), INT8_C( 122), INT8_C(  49),
                           INT8_C( -46), INT8_C( 127), INT8_C(  18), INT8_C( 124)),
      simde_mm512_set_epi8(INT8_C( -50), INT8_C(   0), INT8_C(  80), INT8_C(-123),
                           INT8_C(  19), INT8_C( 112), INT8_C(  30), INT8_C(  95),
                           INT8_C(  58), INT8_C(  21), INT8_C(  13), INT8_C(  32),
                           INT8_C( 113), INT8_C( 126), INT8_C(  27), INT8_C( 113),
                           INT8_C( 121), INT8_C(  97), INT8_C(  51), INT8_C( -16),
                           INT8_C( -77), INT8_C(  84), INT8_C(  16), INT8_C(-112),
                           INT8_C( -40), INT8_C( -69), INT8_C(-116), INT8_C( -97),
                           INT8_C(-120), INT8_C( 102), INT8_C( -82), INT8_C( -42),
                           INT8_C(  43), INT8_C( -81), INT8_C(  75), INT8_C(  17),
                           INT8_C( 108), INT8_C( -47), INT8_C( -38), INT8_C(  16),
                           INT8_C(  19), INT8_C( -37), INT8_C( -32), INT8_C( -20),
                           INT8_C(  60), INT8_C( 110), INT8_C( -65), INT8_C(  67),
                           INT8_C(  51), INT8_C(  67), INT8_C(  91), INT8_C( -87),
                           INT8_C(  10), INT8_C( -96), INT8_C( -14), INT8_C(  59),
                           INT8_C(  98), INT8_C( -72), INT8_C(  96), INT8_C( -34),
                           INT8_C(   4), INT8_C(  96), INT8_C( -19), INT8_C( -97)) },
    { simde_mm512_set_epi8(INT8_C( -82), INT8_C(  17), INT8_C( 105), INT8_C(   8),
                           INT8_C( -41), INT8_C( 122), INT8_C( -11), INT8_C( -52),
                           INT8_C( -81), INT8_C( -30), INT8_C( 109), INT8_C( 119),
                           INT8_C( -78), INT8_C(-123), INT8_C(   5), INT8_C( -23),
                           INT8_C(  44), INT8_C( -23), INT8_C(-122), INT8_C(-101),
                           INT8_C( -30), INT8_C( 103), INT8_C(  30), INT8_C(  -6),
                           INT8_C( 113), INT8_C( -64), INT8_C(  -3), INT8_C(-100),
                           INT8_C(  72), INT8_C( -30), INT8_C(  59), INT8_C(  -7),
                           INT8_C(-101), INT8_C(  48), INT8_C( -62), INT8_C(   5),
                           INT8_C( -52), INT8_C(  72), INT8_C(  56), INT8_C(   6),
                           INT8_C(  86), INT8_C( -78), INT8_C( -43), INT8_C(  91),
                           INT8_C( -63), INT8_C( -91), INT8_C(-105), INT8_C( -98),
                           INT8_C(  39), INT8_C(   5), INT8_C(  77), INT8_C(  91),
                           INT8_C( -82), INT8_C(  20), INT8_C(  41), INT8_C(  62),
                           INT8_C(  27), INT8_C(  82), INT8_C( -39), INT8_C(  57),
                           INT8_C(-116), INT8_C( -85), INT8_C(-107), INT8_C(  31)),
      UINT64_C(           782232724),
      simde_mm512_set_epi8(INT8_C(  11), INT8_C(  49), INT8_C( -30), INT8_C(-117),
                           INT8_C(  85), INT8_C(  19), INT8_C(  44), INT8_C(-110),
                           INT8_C(  61), INT8_C( -27), INT8_C(  26), INT8_C( -12),
                           INT8_C( 110), INT8_C(  11), INT8_C(  45), INT8_C( -32),
                           INT8_C(  -1), INT8_C(  86), INT8_C( 125), INT8_C(  95),
                           INT8_C( -41), INT8_C( -73), INT8_C(  -6), INT8_C( 122),
                           INT8_C(  65), INT8_C( -38), INT8_C(-116), INT8_C(  84),
                           INT8_C(-121), INT8_C( -15), INT8_C(  41), INT8_C(-102),
                           INT8_C( -31), INT8_C( -83), INT8_C( -68), INT8_C(  89),
                           INT8_C(  27), INT8_C(-107), INT8_C( -85), INT8_C(  74),
                           INT8_C(  95), INT8_C( -86), INT8_C(  94), INT8_C( -13),
                           INT8_C( -84), INT8_C(  38), INT8_C( 116), INT8_C(-101),
                           INT8_C(  72), INT8_C(  32), INT8_C( -98), INT8_C(  48),
                           INT8_C( -94), INT8_C( -55), INT8_C( -17), INT8_C(  28),
                           INT8_C(  42), INT8_C(  70), INT8_C(  89), INT8_C(-115),
                           INT8_C( -86), INT8_C( 126), INT8_C( -92), INT8_C(  91)),
      simde_mm512_set_epi8(INT8_C( -46), INT8_C( -24), INT8_C( -24), INT8_C( -26),
                           INT8_C(  89), INT8_C( 108), INT8_C(  49), INT8_C( 123),
                           INT8_C( -86), INT8_C( -61), INT8_C( -22), INT8_C( -47),
                           INT8_C(  21), INT8_C(  76), INT8_C(   6), INT8_C( -21),
                           INT8_C( -19), INT8_C(  38), INT8_C(-116), INT8_C( -22),
                           INT8_C( -75), INT8_C(  54), INT8_C( -81), INT8_C(   9),
                           INT8_C(  94), INT8_C( -15), INT8_C(  26), INT8_C(-110),
                           INT8_C(  18), INT8_C( -49), INT8_C( -21), INT8_C(  70),
                           INT8_C(  50), INT8_C(  20), INT8_C( -59), INT8_C(  63),
                           INT8_C( -20), INT8_C( -92), INT8_C( -44), INT8_C(  37),
                           INT8_C(-125), INT8_C(   4), INT8_C(  53), INT8_C( -49),
                           INT8_C( -10), INT8_C(  11), INT8_C(  91), INT8_C( -86),
                           INT8_C( -34), INT8_C(-108), INT8_C( -80), INT8_C( 122),
                           INT8_C(  31), INT8_C(  31), INT8_C( -29), INT8_C(  70),
                           INT8_C(  28), INT8_C(  33), INT8_C( 109), INT8_C(  55),
                           INT8_C( -79), INT8_C(  95), INT8_C( 100), INT8_C( -33)),
      simde_mm512_set_epi8(INT8_C( -82), INT8_C(  17), INT8_C( 105), INT8_C(   8),
                           INT8_C( -41), INT8_C( 122), INT8_C( -11), INT8_C( -52),
                           INT8_C( -81), INT8_C( -30), INT8_C( 109), INT8_C( 119),
                           INT8_C( -78), INT8_C(-123), INT8_C(   5), INT8_C( -23),
                           INT8_C(  44), INT8_C( -23), INT8_C(-122), INT8_C(-101),
                           INT8_C( -30), INT8_C( 103), INT8_C(  30), INT8_C(  -6),
                           INT8_C( 113), INT8_C( -64), INT8_C(  -3), INT8_C(-100),
                           INT8_C(  72), INT8_C( -30), INT8_C(  59), INT8_C(  -7),
                           INT8_C(-101), INT8_C(  48), INT8_C(  -9), INT8_C(   5),
                           INT8_C(  47), INT8_C( -15), INT8_C( -41), INT8_C(   6),
                           INT8_C( -36), INT8_C( -78), INT8_C( -43), INT8_C(  36),
                           INT8_C( -74), INT8_C(  27), INT8_C(  25), INT8_C( -15),
                           INT8_C( 106), INT8_C(-116), INT8_C( -18), INT8_C(  91),
                           INT8_C(-125), INT8_C( -86), INT8_C(  41), INT8_C(  62),
                           INT8_C(  14), INT8_C(  82), INT8_C( -39), INT8_C(  86),
                           INT8_C(-116), INT8_C(  31), INT8_C(-107), INT8_C(  31)) },
    { simde_mm512_set_epi8(INT8_C(  82), INT8_C( -55), INT8_C(  13), INT8_C(-104),
                           INT8_C(  62), INT8_C(  20), INT8_C( -36), INT8_C(  92),
                           INT8_C( -73), INT8_C( -79), INT8_C(  -7), INT8_C( -22),
                           INT8_C( -50), INT8_C(-119), INT8_C( -83), INT8_C( -71),
                           INT8_C( 125), INT8_C(  29), INT8_C( -61), INT8_C(-111),
                           INT8_C(  -9), INT8_C(  67), INT8_C( -39), INT8_C( -17),
                           INT8_C(  23), INT8_C( -11), INT8_C(-122), INT8_C( -24),
                           INT8_C(  37), INT8_C(-122), INT8_C( -16), INT8_C( -40),
                           INT8_C( -34), INT8_C( -17), INT8_C( 100), INT8_C( 120),
                           INT8_C( -51), INT8_C(   8), INT8_C(  82), INT8_C(  19),
                           INT8_C( -50), INT8_C( -24), INT8_C( -20), INT8_C( -32),
                           INT8_C(  74), INT8_C( -84), INT8_C(   9), INT8_C(  14),
                           INT8_C(-102), INT8_C(  -2), INT8_C( 106), INT8_C(  41),
                           INT8_C(  98), INT8_C( -87), INT8_C(-124), INT8_C(  -3),
                           INT8_C(  80), INT8_C( 110), INT8_C( -32), INT8_C(  20),
                           INT8_C( -15), INT8_C(  65), INT8_C( -54), INT8_C( -49)),
      UINT64_C(          1883474426),
      simde_mm512_set_epi8(INT8_C( -36), INT8_C(-125), INT8_C( -71), INT8_C(-101),
                           INT8_C( -95), INT8_C(  -1), INT8_C(  65), INT8_C(  67),
                           INT8_C(   4), INT8_C( 126), INT8_C(  -9), INT8_C(  50),
                           INT8_C(  46), INT8_C(  17), INT8_C(  12), INT8_C(   7),
                           INT8_C(  31), INT8_C( -83), INT8_C(  63), INT8_C(  21),
                           INT8_C(-105), INT8_C(  56), INT8_C(   6), INT8_C(  88),
                           INT8_C(  -4), INT8_C( -51), INT8_C( -16), INT8_C( -27),
                           INT8_C( -26), INT8_C(  50), INT8_C(   3), INT8_C( -65),
                           INT8_C(  -3), INT8_C( -86), INT8_C(  39), INT8_C(  48),
                           INT8_C(  65), INT8_C(  36), INT8_C( -65), INT8_C( -82),
                           INT8_C(-107), INT8_C(  14), INT8_C( 110), INT8_C(  56),
                           INT8_C( 111), INT8_C( -32), INT8_C( 109), INT8_C( -95),
                           INT8_C(  69), INT8_C(-111), INT8_C(  -7), INT8_C(   9),
                           INT8_C( 116), INT8_C(  77), INT8_C( 122), INT8_C(  26),
                           INT8_C(   9), INT8_C( -79), INT8_C(-127), INT8_C(  -5),
                           INT8_C( 117), INT8_C(   5), INT8_C(  80), INT8_C( -85)),
      simde_mm512_set_epi8(INT8_C(  82), INT8_C(-125), INT8_C( -33), INT8_C(  83),
                           INT8_C( -98), INT8_C(  50), INT8_C( -27), INT8_C( -16),
                           INT8_C( -63), INT8_C(-111), INT8_C( -65), INT8_C(   3),
                           INT8_C( -15), INT8_C(  37), INT8_C(  46), INT8_C(  58),
                           INT8_C( -41), INT8_C(  72), INT8_C( 108), INT8_C(-124),
                           INT8_C(   9), INT8_C(  40), INT8_C( 115), INT8_C(  12),
                           INT8_C(   1), INT8_C(  41), INT8_C( -71), INT8_C(  87),
                           INT8_C( -55), INT8_C(  52), INT8_C( -97), INT8_C(  49),
                           INT8_C(  32), INT8_C(-115), INT8_C(  71), INT8_C(  64),
                           INT8_C( -61), INT8_C(  43), INT8_C( -42), INT8_C(  57),
                           INT8_C( -56), INT8_C( 113), INT8_C(  60), INT8_C(  75),
                           INT8_C(   7), INT8_C( -47), INT8_C(   4), INT8_C( 115),
                           INT8_C(  67), INT8_C(  44), INT8_C(  -1), INT8_C( -85),
                           INT8_C( -95), INT8_C( 108), INT8_C(  37), INT8_C( -99),
                           INT8_C( -88), INT8_C( -11), INT8_C(  47), INT8_C( -69),
                           INT8_C(-123), INT8_C(  17), INT8_C( -30), INT8_C(  36)),
      simde_mm512_set_epi8(INT8_C(  82), INT8_C( -55), INT8_C(  13), INT8_C(-104),
                           INT8_C(  62), INT8_C(  20), INT8_C( -36), INT8_C(  92),
                           INT8_C( -73), INT8_C( -79), INT8_C(  -7), INT8_C( -22),
                           INT8_C( -50), INT8_C(-119), INT8_C( -83), INT8_C( -71),
                           INT8_C( 125), INT8_C(  29), INT8_C( -61), INT8_C(-111),
                           INT8_C(  -9), INT8_C(  67), INT8_C( -39), INT8_C( -17),
                           INT8_C(  23), INT8_C( -11), INT8_C(-122), INT8_C( -24),
                           INT8_C(  37), INT8_C(-122), INT8_C( -16), INT8_C( -40),
                           INT8_C( -34), INT8_C(  29), INT8_C( -32), INT8_C( -16),
                           INT8_C( -51), INT8_C(   8), INT8_C(  82), INT8_C(  19),
                           INT8_C( -50), INT8_C( -99), INT8_C( -20), INT8_C( -32),
                           INT8_C(  74), INT8_C( -84), INT8_C( 105), INT8_C(  46),
                           INT8_C(   2), INT8_C(  -2), INT8_C( 106), INT8_C(  41),
                           INT8_C( -45), INT8_C( -87), INT8_C(-124), INT8_C( 125),
                           INT8_C(  97), INT8_C( -68), INT8_C(  82), INT8_C(  64),
                           INT8_C( -16), INT8_C(  65), INT8_C( 110), INT8_C( -49)) }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])); i++) {
    simde__m512i r = simde_mm512_mask_sub_epi8(test_vec[i].src, test_vec[i].k, test_vec[i].a, test_vec[i].b);
    simde_assert_m512i_i8(r, ==, test_vec[i].r);
  }

  return 0;
}

static int
test_simde_mm512_maskz_sub_epi8(SIMDE_MUNIT_TEST_ARGS) {
  const struct {
    simde__mmask64 k;
    simde__m512i a;
    simde__m512i b;
    simde__m512i r;
  } test_vec[8] = {
    { UINT64_C(          3290745653),
      simde_mm512_set_epi8(INT8_C(  68), INT8_C( -18), INT8_C(-120), INT8_C( -91),
                           INT8_C(  33), INT8_C( -44), INT8_C( 127), INT8_C(-128),
                           INT8_C( 121), INT8_C(  -8), INT8_C(-121), INT8_C( -19),
                           INT8_C(  19), INT8_C(  -3), INT8_C(  10), INT8_C( -37),
                           INT8_C(  96), INT8_C(  15), INT8_C( -45), INT8_C( -44),
                           INT8_C( -83), INT8_C( -37), INT8_C(   8), INT8_C( 111),
                           INT8_C( -30), INT8_C( -99), INT8_C( 116), INT8_C( 112),
                           INT8_C(  67), INT8_C(-123), INT8_C(  59), INT8_C( -62),
                           INT8_C(  33), INT8_C(  51), INT8_C( -16), INT8_C( -35),
                           INT8_C( -53), INT8_C( 108), INT8_C( -37), INT8_C( -15),
                           INT8_C(  26), INT8_C(  83), INT8_C( -47), INT8_C( -23),
                           INT8_C(   6), INT8_C(  52), INT8_C( -19), INT8_C( 108),
                           INT8_C( -33), INT8_C( 120), INT8_C(  55), INT8_C(-128),
                           INT8_C( -46), INT8_C( 117), INT8_C(  41), INT8_C( -54),
                           INT8_C( -99), INT8_C( -39), INT8_C( 117), INT8_C(  57),
                           INT8_C(  78), INT8_C(-110), INT8_C(  -8), INT8_C(-114)),
      simde_mm512_set_epi8(INT8_C( 115), INT8_C(  65), INT8_C(-123), INT8_C( 116),
                           INT8_C( -46), INT8_C( -68), INT8_C(  -8), INT8_C(  96),
                           INT8_C( -90), INT8_C( -14), INT8_C(  27), INT8_C(  33),
                           INT8_C(  21), INT8_C(  58), INT8_C( -12), INT8_C( -76),
                           INT8_C(  70), INT8_C( -70), INT8_C(  -4), INT8_C(  64),
                           INT8_C(  35), INT8_C( -32), INT8_C(-115), INT8_C( 109),
                           INT8_C( -69), INT8_C( -61), INT8_C(-126), INT8_C(  45),
                           INT8_C(  93), INT8_C( 100), INT8_C( -53), INT8_C( 105),
                           INT8_C( -51), INT8_C(  43), INT8_C( -96), INT8_C( -95),
                           INT8_C(  86), INT8_C( -66), INT8_C( -47), INT8_C( 123),
                           INT8_C(  63), INT8_C(  16), INT8_C( -66), INT8_C(  12),
                           INT8_C( 115), INT8_C( -39), INT8_C(  10), INT8_C( 108),
                           INT8_C(-120), INT8_C( 110), INT8_C( -25), INT8_C(   7),
                           INT8_C( 105), INT8_C( -93), INT8_C(  68), INT8_C(   3),
                           INT8_C( 113), INT8_C( -50), INT8_C( -34), INT8_C(  22),
                           INT8_C( -61), INT8_C(  75), INT8_C(  28), INT8_C( 116)),
      simde_mm512_set_epi8(INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(  84), INT8_C(   8), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C( -82), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(  19), INT8_C(   0),
                           INT8_C(   0), INT8_C(  91), INT8_C(   0), INT8_C(   0),
                           INT8_C(  87), INT8_C(  10), INT8_C(   0), INT8_C(   0),
                           INT8_C( 105), INT8_C(   0), INT8_C( -27), INT8_C( -57),
                           INT8_C(   0), INT8_C(   0), INT8_C(-105), INT8_C(  35),
                           INT8_C(   0), INT8_C(  71), INT8_C(   0), INT8_C(  26)) },
    { UINT64_C(          1235205951),
      simde_mm512_set_epi8(INT8_C(-120), INT8_C( -25), INT8_C( 111), INT8_C(-128),
                           INT8_C(  -4), INT8_C(  58), INT8_C(-115), INT8_C(   4),
                           INT8_C(  26), INT8_C(  -6), INT8_C( -92), INT8_C(   7),
                           INT8_C(-105), INT8_C( -92), INT8_C(  38), INT8_C( -63),
                           INT8_C(  77), INT8_C(  86), INT8_C( 113), INT8_C( -48),
                           INT8_C( 108), INT8_C( -92), INT8_C(  69), INT8_C(  74),
                           INT8_C(  67), INT8_C(  96), INT8_C( -34), INT8_C(  78),
                           INT8_C( 124), INT8_C(   9), INT8_C(  -1), INT8_C( -86),
                           INT8_C( -35), INT8_C(  26), INT8_C(  67), INT8_C(  46),
                           INT8_C(  75), INT8_C(-119), INT8_C(  68), INT8_C(  31),
                           INT8_C( -52), INT8_C(-102), INT8_C(  -4), INT8_C( 118),
                           INT8_C(   0), INT8_C( -44), INT8_C( 123), INT8_C( -73),
                           INT8_C(  84), INT8_C(  30), INT8_C(  -8), INT8_C(  64),
                           INT8_C( -20), INT8_C( -79), INT8_C( -85), INT8_C( -23),
                           INT8_C( -34), INT8_C(  -4), INT8_C( -85), INT8_C( 107),
                           INT8_C(  -6), INT8_C(  16), INT8_C( -66), INT8_C(-113)),
      simde_mm512_set_epi8(INT8_C( -19), INT8_C( 117), INT8_C( 121), INT8_C(  67),
                           INT8_C( -91), INT8_C( -91), INT8_C(  98), INT8_C( 106),
                           INT8_C(  44), INT8_C(  68), INT8_C(  96), INT8_C(  88),
                           INT8_C(   1), INT8_C(  68), INT8_C(  46), INT8_C(  19),
                           INT8_C(  31), INT8_C(  85), INT8_C(  35), INT8_C(  68),
                           INT8_C( -79), INT8_C(  41), INT8_C(  28), INT8_C(  92),
                           INT8_C( -26), INT8_C(  20), INT8_C( -16), INT8_C(  -7),
                           INT8_C(  41), INT8_C(  71), INT8_C(  88), INT8_C(  39),
                           INT8_C( -42), INT8_C(  76), INT8_C(  40), INT8_C( 108),
                           INT8_C( -87), INT8_C(-126), INT8_C(  42), INT8_C(  58),
                           INT8_C(   2), INT8_C( -23), INT8_C(   5), INT8_C(-116),
                           INT8_C(  34), INT8_C(  66), INT8_C(  28), INT8_C(  86),
                           INT8_C(  50), INT8_C( -67), INT8_C(  20), INT8_C(  73),
                           INT8_C(  27), INT8_C( -29), INT8_C(  84), INT8_C( 112),
                           INT8_C( 104), INT8_C(  53), INT8_C( -89), INT8_C(-113),
                           INT8_C(  -4), INT8_C(  94), INT8_C(  75), INT8_C(  21)),
      simde_mm512_set_epi8(INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C( -50), INT8_C(   0), INT8_C(   0),
                           INT8_C( -94), INT8_C(   0), INT8_C(   0), INT8_C( -27),
                           INT8_C( -54), INT8_C(   0), INT8_C(   0), INT8_C( -22),
                           INT8_C( -34), INT8_C(-110), INT8_C(  95), INT8_C(  97),
                           INT8_C(  34), INT8_C(   0), INT8_C( -28), INT8_C(  -9),
                           INT8_C( -47), INT8_C( -50), INT8_C(  87), INT8_C( 121),
                           INT8_C(   0), INT8_C(   0), INT8_C(   4), INT8_C( -36),
                           INT8_C(  -2), INT8_C( -78), INT8_C( 115), INT8_C( 122)) },
    { UINT64_C(          3694669449),
      simde_mm512_set_epi8(INT8_C(   0), INT8_C( -45), INT8_C(  59), INT8_C(  51),
                           INT8_C( -35), INT8_C(  70), INT8_C(  73), INT8_C(  33),
                           INT8_C( -70), INT8_C( -58), INT8_C(  69), INT8_C(  -7),
                           INT8_C( 115), INT8_C( -10), INT8_C( -39), INT8_C(  78),
                           INT8_C(  56), INT8_C( 116), INT8_C( 104), INT8_C( -92),
                           INT8_C(   5), INT8_C( -47), INT8_C(  27), INT8_C(  94),
                           INT8_C(-126), INT8_C(  88), INT8_C(  80), INT8_C( 112),
                           INT8_C(  21), INT8_C(  62), INT8_C(  86), INT8_C(-103),
                           INT8_C(  66), INT8_C(  -9), INT8_C( -26), INT8_C(  47),
                           INT8_C( -50), INT8_C(-118), INT8_C( 115), INT8_C(  49),
                           INT8_C(  42), INT8_C(   6), INT8_C(  92), INT8_C(   2),
                           INT8_C(  63), INT8_C(  -6), INT8_C( -32), INT8_C(  15),
                           INT8_C(  66), INT8_C(  82), INT8_C(  -9), INT8_C( -79),
                           INT8_C(-123), INT8_C(  52), INT8_C( -90), INT8_C(-111),
                           INT8_C(  62), INT8_C( -43), INT8_C( -50), INT8_C(  62),
                           INT8_C(   4), INT8_C( -92), INT8_C(  86), INT8_C( -32)),
      simde_mm512_set_epi8(INT8_C(  23), INT8_C( -12), INT8_C(  67), INT8_C(  -6),
                           INT8_C( -37), INT8_C(  92), INT8_C( -35), INT8_C(  99),
                           INT8_C(  18), INT8_C(  68), INT8_C(  -9), INT8_C(  64),
                           INT8_C(-111), INT8_C(  37), INT8_C( -82), INT8_C( -95),
                           INT8_C(  54), INT8_C(  75), INT8_C( -77), INT8_C( -34),
                           INT8_C(  52), INT8_C( -80), INT8_C( -94), INT8_C(  90),
                           INT8_C(   0), INT8_C(  -8), INT8_C( 123), INT8_C(-111),
                           INT8_C(  16), INT8_C( 125), INT8_C( -51), INT8_C(  99),
                           INT8_C( -22), INT8_C( 121), INT8_C(  63), INT8_C( -55),
                           INT8_C( 117), INT8_C( 109), INT8_C(-126), INT8_C(-111),
                           INT8_C(  47), INT8_C(-127), INT8_C( 109), INT8_C(  -9),
                           INT8_C( -42), INT8_C(  36), INT8_C( -32), INT8_C( 115),
                           INT8_C( -89), INT8_C(   7), INT8_C(  90), INT8_C(  46),
                           INT8_C( -83), INT8_C( -35), INT8_C(  30), INT8_C( -19),
                           INT8_C( -99), INT8_C( -56), INT8_C( -70), INT8_C(  73),
                           INT8_C( -61), INT8_C(  27), INT8_C( 117), INT8_C(  47)),
      simde_mm512_set_epi8(INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(  88), INT8_C( 126), INT8_C(   0), INT8_C( 102),
                           INT8_C(  89), INT8_C(  29), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C( -17), INT8_C(  11),
                           INT8_C( 105), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C( -99), INT8_C(   0),
                           INT8_C( -40), INT8_C(  87), INT8_C(-120), INT8_C(   0),
                           INT8_C( -95), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(  65), INT8_C(   0), INT8_C(   0), INT8_C( -79)) },
    { UINT64_C(          2480122489),
      simde_mm512_set_epi8(INT8_C(   4), INT8_C( -62), INT8_C( -44), INT8_C(  49),
                           INT8_C(  83), INT8_C( 115), INT8_C(   5), INT8_C(  57),
                           INT8_C( -76), INT8_C( -80), INT8_C(  40), INT8_C(  60),
                           INT8_C(  65), INT8_C( -98), INT8_C( -74), INT8_C(  17),
                           INT8_C( -35), INT8_C(  32), INT8_C( -43), INT8_C( 108),
                           INT8_C(  83), INT8_C( -59), INT8_C(  -4), INT8_C( 125),
                           INT8_C( -31), INT8_C( 118), INT8_C( -25), INT8_C( -91),
                           INT8_C(  50), INT8_C( -74), INT8_C(  78), INT8_C(  95),
                           INT8_C( -84), INT8_C( -63), INT8_C(  87), INT8_C(-108),
                           INT8_C(  28), INT8_C( -70), INT8_C(  77), INT8_C(-113),
                           INT8_C( -20), INT8_C(  50), INT8_C(  95), INT8_C(-108),
                           INT8_C( 105), INT8_C( 114), INT8_C(-109), INT8_C(  19),
                           INT8_C( -79), INT8_C( 106), INT8_C(  61), INT8_C( -12),
                           INT8_C( 126), INT8_C(-117), INT8_C( 126), INT8_C(-125),
                           INT8_C( -93), INT8_C(  69), INT8_C( 104), INT8_C( 119),
                           INT8_C(  63), INT8_C(  95), INT8_C(-106), INT8_C( -66)),
      simde_mm512_set_epi8(INT8_C( -51), INT8_C(  11), INT8_C( -44), INT8_C(  33),
                           INT8_C(  29), INT8_C(   8), INT8_C(   5), INT8_C(  70),
                           INT8_C(  13), INT8_C( 104), INT8_C(  50), INT8_C(  43),
                           INT8_C(  82), INT8_C(  -5), INT8_C( -23), INT8_C( -47),
                           INT8_C(  99), INT8_C(-116), INT8_C( 118), INT8_C(  73),
                           INT8_C( -10), INT8_C( -88), INT8_C( -42), INT8_C( -58),
                           INT8_C( -49), INT8_C(  65), INT8_C( -18), INT8_C(  54),
                           INT8_C( -68), INT8_C(   1), INT8_C(  -7), INT8_C( -96),
                           INT8_C(   4), INT8_C( 115), INT8_C(  42), INT8_C(-106),
                           INT8_C(  31), INT8_C(  94), INT8_C( -71), INT8_C( -41),
                           INT8_C(  33), INT8_C(-106), INT8_C( -65), INT8_C(-107),
                           INT8_C(  71), INT8_C( -10), INT8_C( -21), INT8_C(-128),
                           INT8_C( -23), INT8_C(  20), INT8_C(   2), INT8_C(  96),
                           INT8_C(-128), INT8_C( -51), INT8_C( -38), INT8_C(  47),
                           INT8_C( -56), INT8_C( 123), INT8_C( -20), INT8_C( -50),
                           INT8_C(  -2), INT8_C(  40), INT8_C(  24), INT8_C( -98)),
      simde_mm512_set_epi8(INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C( -88), INT8_C(   0), INT8_C(   0), INT8_C(  -2),
                           INT8_C(   0), INT8_C(   0), INT8_C(-108), INT8_C( -72),
                           INT8_C( -53), INT8_C(-100), INT8_C(   0), INT8_C(  -1),
                           INT8_C(   0), INT8_C(   0), INT8_C( -88), INT8_C(-109),
                           INT8_C( -56), INT8_C(   0), INT8_C(  59), INT8_C(   0),
                           INT8_C(  -2), INT8_C(   0), INT8_C( -92), INT8_C(   0),
                           INT8_C(   0), INT8_C( -54), INT8_C( 124), INT8_C( -87),
                           INT8_C(  65), INT8_C(   0), INT8_C(   0), INT8_C(  32)) },
    { UINT64_C(          2822554960),
      simde_mm512_set_epi8(INT8_C( -38), INT8_C(  -1), INT8_C(  48), INT8_C(  32),
                           INT8_C(  88), INT8_C( -18), INT8_C( 123), INT8_C(  27),
                           INT8_C( 111), INT8_C(  27), INT8_C(  -3), INT8_C(  52),
                           INT8_C( -31), INT8_C(   2), INT8_C( -47), INT8_C(  64),
                           INT8_C(  76), INT8_C( -52), INT8_C( -96), INT8_C(  -6),
                           INT8_C(-119), INT8_C( -87), INT8_C( 102), INT8_C(   5),
                           INT8_C(  24), INT8_C( -44), INT8_C( 110), INT8_C(-113),
                           INT8_C(-116), INT8_C(  -3), INT8_C(  62), INT8_C( -87),
                           INT8_C(   7), INT8_C( -54), INT8_C( -57), INT8_C( -66),
                           INT8_C(  42), INT8_C( -82), INT8_C(  46), INT8_C( -16),
                           INT8_C(  91), INT8_C( -73), INT8_C( -20), INT8_C( -77),
                           INT8_C( -11), INT8_C(  25), INT8_C(  12), INT8_C(  76),
                           INT8_C( -58), INT8_C(   3), INT8_C(-125), INT8_C( -36),
                           INT8_C(  18), INT8_C( -40), INT8_C( 111), INT8_C( 107),
                           INT8_C(  88), INT8_C(  48), INT8_C( 113), INT8_C( -90),
                           INT8_C(-117), INT8_C( 116), INT8_C(  46), INT8_C( -70)),
      simde_mm512_set_epi8(INT8_C( 116), INT8_C(-120), INT8_C( -67), INT8_C( -86),
                           INT8_C(  48), INT8_C(   2), INT8_C(  37), INT8_C( -26),
                           INT8_C( -55), INT8_C(  66), INT8_C(  80), INT8_C(  -7),
                           INT8_C(  21), INT8_C(-118), INT8_C(   7), INT8_C( -49),
                           INT8_C(  27), INT8_C(  45), INT8_C(  71), INT8_C( -63),
                           INT8_C(  96), INT8_C(-106), INT8_C( -43), INT8_C(  10),
                           INT8_C( 104), INT8_C( -19), INT8_C(-110), INT8_C( 126),
                           INT8_C( -52), INT8_C( -56), INT8_C( -96), INT8_C( -27),
                           INT8_C(-125), INT8_C(-116), INT8_C(  25), INT8_C(  78),
                           INT8_C( -76), INT8_C( -85), INT8_C( -23), INT8_C( -19),
                           INT8_C(-106), INT8_C( 126), INT8_C(  19), INT8_C( -41),
                           INT8_C(  40), INT8_C(  78), INT8_C( -69), INT8_C(  57),
                           INT8_C(  73), INT8_C( -58), INT8_C(   3), INT8_C(  65),
                           INT8_C( -87), INT8_C( -37), INT8_C(   5), INT8_C(-126),
                           INT8_C(  14), INT8_C( -36), INT8_C( -37), INT8_C(  11),
                           INT8_C(  94), INT8_C(  24), INT8_C(   8), INT8_C( -31)),
      simde_mm512_set_epi8(INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(-124), INT8_C(   0), INT8_C( -82), INT8_C(   0),
                           INT8_C( 118), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C( -39), INT8_C( -36),
                           INT8_C( -51), INT8_C( -53), INT8_C(   0), INT8_C(   0),
                           INT8_C( 125), INT8_C(  61), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(  -3), INT8_C(   0), INT8_C( -23),
                           INT8_C(   0), INT8_C(  84), INT8_C(   0), INT8_C(-101),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0)) },
    { UINT64_C(          2777207418),
      simde_mm512_set_epi8(INT8_C( -82), INT8_C( -24), INT8_C(  18), INT8_C( 115),
                           INT8_C( -15), INT8_C(  55), INT8_C(  78), INT8_C(  60),
                           INT8_C(  -8), INT8_C( -91), INT8_C( 126), INT8_C(  15),
                           INT8_C(  23), INT8_C(   6), INT8_C( -21), INT8_C( 120),
                           INT8_C( -20), INT8_C(-104), INT8_C( -27), INT8_C(  38),
                           INT8_C(  31), INT8_C( -21), INT8_C(  79), INT8_C( -62),
                           INT8_C(  36), INT8_C(  95), INT8_C(  42), INT8_C(-102),
                           INT8_C( -80), INT8_C( -69), INT8_C( 107), INT8_C(-114),
                           INT8_C(  76), INT8_C( 123), INT8_C(-126), INT8_C( 108),
                           INT8_C( -55), INT8_C(  89), INT8_C( -46), INT8_C(  18),
                           INT8_C( 117), INT8_C(  25), INT8_C(-120), INT8_C(  27),
                           INT8_C(  34), INT8_C(  64), INT8_C(  71), INT8_C(  64),
                           INT8_C( -13), INT8_C( -73), INT8_C( 112), INT8_C(  25),
                           INT8_C( -18), INT8_C( -63), INT8_C( 109), INT8_C(   9),
                           INT8_C(  14), INT8_C(-125), INT8_C( -89), INT8_C(  70),
                           INT8_C(  10), INT8_C(  15), INT8_C( 120), INT8_C( -59)),
      simde_mm512_set_epi8(INT8_C( -52), INT8_C( -61), INT8_C( -14), INT8_C( -38),
                           INT8_C( -93), INT8_C( -34), INT8_C(  64), INT8_C( -67),
                           INT8_C(-123), INT8_C( 123), INT8_C( -93), INT8_C(  41),
                           INT8_C(  97), INT8_C(  -8), INT8_C( -86), INT8_C( -16),
                           INT8_C( -70), INT8_C(   3), INT8_C( 118), INT8_C(  37),
                           INT8_C( 104), INT8_C( 111), INT8_C( -17), INT8_C( 110),
                           INT8_C( -58), INT8_C(  58), INT8_C( 102), INT8_C(  64),
                           INT8_C( -67), INT8_C( -76), INT8_C( -30), INT8_C( 108),
                           INT8_C(  79), INT8_C(  46), INT8_C( -40), INT8_C( 101),
                           INT8_C( -13), INT8_C( -25), INT8_C(  60), INT8_C(  25),
                           INT8_C(  32), INT8_C( -21), INT8_C( 114), INT8_C( -21),
                           INT8_C(  71), INT8_C( -85), INT8_C(  34), INT8_C(  82),
                           INT8_C(-114), INT8_C( -30), INT8_C( -58), INT8_C( 116),
                           INT8_C(  58), INT8_C(-105), INT8_C( 117), INT8_C(  11),
                           INT8_C( -91), INT8_C( 118), INT8_C( -50), INT8_C(  -8),
                           INT8_C( -22), INT8_C(  59), INT8_C( -29), INT8_C( -88)),
      simde_mm512_set_epi8(INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(  -3), INT8_C(   0), INT8_C( -86), INT8_C(   0),
                           INT8_C(   0), INT8_C( 114), INT8_C(   0), INT8_C(  -7),
                           INT8_C(  85), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C( -37), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C( 101), INT8_C( -43), INT8_C(   0), INT8_C( -91),
                           INT8_C(   0), INT8_C(   0), INT8_C(  -8), INT8_C(   0),
                           INT8_C(   0), INT8_C(  13), INT8_C( -39), INT8_C(  78),
                           INT8_C(  32), INT8_C(   0), INT8_C(-107), INT8_C(   0)) },
    { UINT64_C(          3908316288),
      simde_mm512_set_epi8(INT8_C(  16), INT8_C(   5), INT8_C(  18), INT8_C(-104),
                           INT8_C(-119), INT8_C( -46), INT8_C( -92), INT8_C(  37),
                           INT8_C( -84), INT8_C(   2), INT8_C( -49), INT8_C(  99),
                           INT8_C( -79), INT8_C(  48), INT8_C(-103), INT8_C(   3),
                           INT8_C(  54), INT8_C( 118), INT8_C( -53), INT8_C(  24),
                           INT8_C(  56), INT8_C(  78), INT8_C( 121), INT8_C( -10),
                           INT8_C(   4), INT8_C(  97), INT8_C(  53), INT8_C( -46),
                           INT8_C(  92), INT8_C(-100), INT8_C(  47), INT8_C( 107),
                           INT8_C( -52), INT8_C(  68), INT8_C(  11), INT8_C( -16),
                           INT8_C( -66), INT8_C( -79), INT8_C( -14), INT8_C(  27),
                           INT8_C(  14), INT8_C( 125), INT8_C(  22), INT8_C( -82),
                           INT8_C(  44), INT8_C( -12), INT8_C(  94), INT8_C( -30),
                           INT8_C(  98), INT8_C( 125), INT8_C(-107), INT8_C(  37),
                           INT8_C( -66), INT8_C(  90), INT8_C(  68), INT8_C(  10),
                           INT8_C( -72), INT8_C( -10), INT8_C(-119), INT8_C(  -9),
                           INT8_C(  49), INT8_C(-107), INT8_C(  10), INT8_C(  47)),
      simde_mm512_set_epi8(INT8_C( 114), INT8_C(  29), INT8_C( -56), INT8_C( -61),
                           INT8_C(-124), INT8_C(-107), INT8_C( -23), INT8_C( -89),
                           INT8_C(  38), INT8_C( -97), INT8_C( 109), INT8_C(  53),
                           INT8_C(-117), INT8_C(  76), INT8_C( -82), INT8_C( -65),
                           INT8_C( -24), INT8_C( -47), INT8_C(-119), INT8_C(   5),
                           INT8_C(  95), INT8_C(  82), INT8_C(  -3), INT8_C( -62),
                           INT8_C(-116), INT8_C( -98), INT8_C( -29), INT8_C(  77),
                           INT8_C( -38), INT8_C(-118), INT8_C( -85), INT8_C( 121),
                           INT8_C( -72), INT8_C(-111), INT8_C(  28), INT8_C( -18),
                           INT8_C(  64), INT8_C(-126), INT8_C( 122), INT8_C( -54),
                           INT8_C(  87), INT8_C( -22), INT8_C(  17), INT8_C(  50),
                           INT8_C( -83), INT8_C( -39), INT8_C(  77), INT8_C( -13),
                           INT8_C(  17), INT8_C( -66), INT8_C(-128), INT8_C(  77),
                           INT8_C( 107), INT8_C(  47), INT8_C( -68), INT8_C( -44),
                           INT8_C( -30), INT8_C( -22), INT8_C(  14), INT8_C(  26),
                           INT8_C(  59), INT8_C( 103), INT8_C( -54), INT8_C( -39)),
      simde_mm512_set_epi8(INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(  20), INT8_C( -77), INT8_C( -17), INT8_C(   0),
                           INT8_C( 126), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C( -73), INT8_C(-109), INT8_C(   5), INT8_C( 124),
                           INT8_C(   0), INT8_C(  27), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(  21), INT8_C(   0),
                           INT8_C(  83), INT8_C(  43), INT8_C(   0), INT8_C(   0),
                           INT8_C( -42), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0)) },
    { UINT64_C(          2902744348),
      simde_mm512_set_epi8(INT8_C(  19), INT8_C( -37), INT8_C( -32), INT8_C( -59),
                           INT8_C(  33), INT8_C( 110), INT8_C(  17), INT8_C(  67),
                           INT8_C(  51), INT8_C( -19), INT8_C(  91), INT8_C(  26),
                           INT8_C(  33), INT8_C( -43), INT8_C( -14), INT8_C( -56),
                           INT8_C( 112), INT8_C( -72), INT8_C(  96), INT8_C( -62),
                           INT8_C( -21), INT8_C(  96), INT8_C( -25), INT8_C( 104),
                           INT8_C( -56), INT8_C( -56), INT8_C(  57), INT8_C( -25),
                           INT8_C(  -3), INT8_C(  99), INT8_C(  -6), INT8_C(  31),
                           INT8_C( -96), INT8_C(  49), INT8_C( 110), INT8_C( -10),
                           INT8_C( -82), INT8_C(  32), INT8_C( -27), INT8_C( 112),
                           INT8_C(  84), INT8_C(  37), INT8_C( -62), INT8_C(  38),
                           INT8_C( -53), INT8_C( -97), INT8_C(  76), INT8_C(  13),
                           INT8_C(-124), INT8_C(-120), INT8_C( -86), INT8_C(  98),
                           INT8_C(  96), INT8_C(   4), INT8_C(   4), INT8_C(  94),
                           INT8_C( -41), INT8_C( -81), INT8_C( -40), INT8_C( -28),
                           INT8_C( -23), INT8_C( -59), INT8_C( -15), INT8_C( -40)),
      simde_mm512_set_epi8(INT8_C(   3), INT8_C(  -6), INT8_C( -45), INT8_C( -75),
                           INT8_C( -83), INT8_C(-118), INT8_C(  74), INT8_C(  35),
                           INT8_C(  38), INT8_C(   4), INT8_C(  35), INT8_C(  15),
                           INT8_C( -42), INT8_C(  71), INT8_C(  -1), INT8_C(  27),
                           INT8_C( -48), INT8_C( -77), INT8_C( 116), INT8_C(  52),
                           INT8_C(  99), INT8_C(  26), INT8_C(  93), INT8_C(-101),
                           INT8_C( -50), INT8_C(   0), INT8_C(  80), INT8_C(-123),
                           INT8_C(  19), INT8_C( 112), INT8_C(  30), INT8_C(  95),
                           INT8_C(  58), INT8_C(  21), INT8_C(  13), INT8_C(  32),
                           INT8_C( 113), INT8_C( 126), INT8_C(  27), INT8_C( 113),
                           INT8_C( 121), INT8_C(  97), INT8_C(  51), INT8_C( -16),
                           INT8_C( -77), INT8_C(  84), INT8_C(  16), INT8_C(-112),
                           INT8_C( -40), INT8_C( -69), INT8_C(-116), INT8_C( -97),
                           INT8_C(-120), INT8_C( 102), INT8_C( -82), INT8_C( -42),
                           INT8_C(  43), INT8_C( -70), INT8_C(  46), INT8_C(  17),
                           INT8_C( 108), INT8_C( -47), INT8_C(  53), INT8_C( -84)),
      simde_mm512_set_epi8(INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C( 102), INT8_C(   0), INT8_C(  97), INT8_C(   0),
                           INT8_C(  61), INT8_C( -94), INT8_C(   0), INT8_C(  -1),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(  75), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C( -51), INT8_C(   0), INT8_C( -61),
                           INT8_C( -40), INT8_C( -98), INT8_C(   0), INT8_C(-120),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C( -45),
                           INT8_C( 125), INT8_C( -12), INT8_C(   0), INT8_C(   0)) }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])); i++) {
    simde__m512i r = simde_mm512_maskz_sub_epi8(test_vec[i].k, test_vec[i].a, test_vec[i].b);
    simde_assert_m512i_i8(r, ==, test_vec[i].r);
  }

  return 0;
}

static int
test_simde_mm512_sub_epi16(SIMDE_MUNIT_TEST_ARGS) {
  const struct {
    simde__m512i a;
    simde__m512i b;
    simde__m512i r;
  } test_vec[8] = {
    { simde_mm512_set_epi16(INT16_C( 21075), INT16_C( 30017), INT16_C(-11898), INT16_C( 29710),
                            INT16_C( 19457), INT16_C(-12796), INT16_C( 21427), INT16_C( 28826),
                            INT16_C( 25482), INT16_C(-11843), INT16_C( 15582), INT16_C( 20114),
                            INT16_C(-14761), INT16_C(-15590), INT16_C( -4142), INT16_C( 29932),
                            INT16_C(-30672), INT16_C(  6190), INT16_C( 26590), INT16_C( 10803),
                            INT16_C(-16554), INT16_C( 15816), INT16_C( 14967), INT16_C( 24063),
                            INT16_C(-14713), INT16_C( -8094), INT16_C(-16817), INT16_C( 25507),
                            INT16_C( 19912), INT16_C(-19929), INT16_C(-12604), INT16_C(-17156)),
      simde_mm512_set_epi16(INT16_C( 27175), INT16_C(-27122), INT16_C( -6914), INT16_C( 10212),
                            INT16_C( 13894), INT16_C( -4620), INT16_C(-10724), INT16_C( -3078),
                            INT16_C( 29698), INT16_C(  6009), INT16_C( 28893), INT16_C(-31734),
                            INT16_C( -3957), INT16_C(  6787), INT16_C(  9325), INT16_C(  7645),
                            INT16_C( -2133), INT16_C( -9633), INT16_C(-22525), INT16_C(  1124),
                            INT16_C( 21781), INT16_C( 17119), INT16_C(-19461), INT16_C(-32134),
                            INT16_C( -7507), INT16_C( 19092), INT16_C( 21408), INT16_C(-14444),
                            INT16_C( 22843), INT16_C( 28625), INT16_C( -2322), INT16_C(  5251)),
      simde_mm512_set_epi16(INT16_C( -6100), INT16_C( -8397), INT16_C( -4984), INT16_C( 19498),
                            INT16_C(  5563), INT16_C( -8176), INT16_C( 32151), INT16_C( 31904),
                            INT16_C( -4216), INT16_C(-17852), INT16_C(-13311), INT16_C(-13688),
                            INT16_C(-10804), INT16_C(-22377), INT16_C(-13467), INT16_C( 22287),
                            INT16_C(-28539), INT16_C( 15823), INT16_C(-16421), INT16_C(  9679),
                            INT16_C( 27201), INT16_C( -1303), INT16_C(-31108), INT16_C( -9339),
                            INT16_C( -7206), INT16_C(-27186), INT16_C( 27311), INT16_C(-25585),
                            INT16_C( -2931), INT16_C( 16982), INT16_C(-10282), INT16_C(-22407)) },
    { simde_mm512_set_epi16(INT16_C(-27508), INT16_C(  5509), INT16_C(-13526), INT16_C( 16909),
                            INT16_C(  2419), INT16_C( 22142), INT16_C( -6109), INT16_C( -1177),
                            INT16_C(  9839), INT16_C(  6329), INT16_C(  -239), INT16_C(-15885),
                            INT16_C(  3666), INT16_C( 20122), INT16_C( -1699), INT16_C(  6503),
                            INT16_C( 29169), INT16_C( -4681), INT16_C( -2713), INT16_C(-24709),
                            INT16_C(  7221), INT16_C( -3718), INT16_C(   970), INT16_C(-15558),
                            INT16_C(-11011), INT16_C(-10787), INT16_C(-29970), INT16_C(  3894),
                            INT16_C(-25914), INT16_C(-18758), INT16_C( 11824), INT16_C( -8868)),
      simde_mm512_set_epi16(INT16_C(  1604), INT16_C( 19874), INT16_C(-12133), INT16_C( -1966),
                            INT16_C( 13041), INT16_C(  1566), INT16_C(-11791), INT16_C( -3425),
                            INT16_C(  7377), INT16_C(-23380), INT16_C( -9249), INT16_C(-31251),
                            INT16_C( 14877), INT16_C( 24009), INT16_C(-32316), INT16_C(  8308),
                            INT16_C(-11725), INT16_C(-10230), INT16_C(  1074), INT16_C( 12341),
                            INT16_C( 19989), INT16_C( 16491), INT16_C(  4144), INT16_C(-11714),
                            INT16_C( 19285), INT16_C(-29198), INT16_C(-25258), INT16_C(-29514),
                            INT16_C(  9755), INT16_C(-29385), INT16_C(-23111), INT16_C( -3412)),
      simde_mm512_set_epi16(INT16_C(-29112), INT16_C(-14365), INT16_C( -1393), INT16_C( 18875),
                            INT16_C(-10622), INT16_C( 20576), INT16_C(  5682), INT16_C(  2248),
                            INT16_C(  2462), INT16_C( 29709), INT16_C(  9010), INT16_C( 15366),
                            INT16_C(-11211), INT16_C( -3887), INT16_C( 30617), INT16_C( -1805),
                            INT16_C(-24642), INT16_C(  5549), INT16_C( -3787), INT16_C( 28486),
                            INT16_C(-12768), INT16_C(-20209), INT16_C( -3174), INT16_C( -3844),
                            INT16_C(-30296), INT16_C( 18411), INT16_C( -4712), INT16_C(-32128),
                            INT16_C( 29867), INT16_C( 10627), INT16_C(-30601), INT16_C( -5456)) },
    { simde_mm512_set_epi16(INT16_C(   691), INT16_C( -4823), INT16_C( -3253), INT16_C(-31392),
                            INT16_C(-21784), INT16_C( -6740), INT16_C(  9130), INT16_C(-18273),
                            INT16_C( 11275), INT16_C(-27092), INT16_C(    90), INT16_C(-20133),
                            INT16_C( 30523), INT16_C( 27008), INT16_C( 28387), INT16_C( 17266),
                            INT16_C( -9777), INT16_C( 27096), INT16_C( -8328), INT16_C( -6812),
                            INT16_C(-22954), INT16_C( -4409), INT16_C( 21734), INT16_C(-19695),
                            INT16_C(-11981), INT16_C(-21195), INT16_C( 18272), INT16_C( 28327),
                            INT16_C(  7123), INT16_C(-32216), INT16_C( 24489), INT16_C(-15668)),
      simde_mm512_set_epi16(INT16_C(-21377), INT16_C( 15856), INT16_C(  7686), INT16_C(-28568),
                            INT16_C(-15192), INT16_C( -9747), INT16_C( 11300), INT16_C( 27000),
                            INT16_C( -6635), INT16_C(  3626), INT16_C( 12716), INT16_C(-30571),
                            INT16_C( 31697), INT16_C(  5622), INT16_C( 24444), INT16_C( -8226),
                            INT16_C( -8263), INT16_C(  2890), INT16_C( 26732), INT16_C( -8763),
                            INT16_C(-13950), INT16_C( 27415), INT16_C(  7653), INT16_C( 31511),
                            INT16_C(-21082), INT16_C(  2398), INT16_C( 23365), INT16_C(-12903),
                            INT16_C(-18221), INT16_C(  4204), INT16_C(-20453), INT16_C( 15021)),
      simde_mm512_set_epi16(INT16_C( 22068), INT16_C(-20679), INT16_C(-10939), INT16_C( -2824),
                            INT16_C( -6592), INT16_C(  3007), INT16_C( -2170), INT16_C( 20263),
                            INT16_C( 17910), INT16_C(-30718), INT16_C(-12626), INT16_C( 10438),
                            INT16_C( -1174), INT16_C( 21386), INT16_C(  3943), INT16_C( 25492),
                            INT16_C( -1514), INT16_C( 24206), INT16_C( 30476), INT16_C(  1951),
                            INT16_C( -9004), INT16_C(-31824), INT16_C( 14081), INT16_C( 14330),
                            INT16_C(  9101), INT16_C(-23593), INT16_C( -5093), INT16_C(-24306),
                            INT16_C( 25344), INT16_C( 29116), INT16_C(-20594), INT16_C(-30689)) },
    { simde_mm512_set_epi16(INT16_C(  4451), INT16_C( -3121), INT16_C( 11648), INT16_C( 14185),
                            INT16_C( -8499), INT16_C(-24679), INT16_C(-31633), INT16_C( 19019),
                            INT16_C( 26210), INT16_C(-29943), INT16_C(-18883), INT16_C( 25468),
                            INT16_C( 20366), INT16_C(  4961), INT16_C(-25468), INT16_C( -4158),
                            INT16_C(  6653), INT16_C( -1720), INT16_C(-29723), INT16_C(-14244),
                            INT16_C( -4917), INT16_C(   730), INT16_C(-20677), INT16_C( 16986),
                            INT16_C(  9316), INT16_C( 28795), INT16_C(-18273), INT16_C(-29423),
                            INT16_C(-23674), INT16_C(  7963), INT16_C( 28019), INT16_C( 13728)),
      simde_mm512_set_epi16(INT16_C(-10770), INT16_C( 29411), INT16_C( 30463), INT16_C( -4902),
                            INT16_C(-20392), INT16_C(-28251), INT16_C( 11448), INT16_C( 27155),
                            INT16_C(-11669), INT16_C( 11820), INT16_C(-16512), INT16_C( 10540),
                            INT16_C( 17477), INT16_C(-19759), INT16_C( 28024), INT16_C(-14431),
                            INT16_C( 24400), INT16_C( -7583), INT16_C(-12129), INT16_C( 28592),
                            INT16_C(-31057), INT16_C(-18091), INT16_C( 19926), INT16_C(-29261),
                            INT16_C(  7501), INT16_C( 16620), INT16_C(  6953), INT16_C(  3437),
                            INT16_C(  5790), INT16_C(  5348), INT16_C( 17145), INT16_C(-28791)),
      simde_mm512_set_epi16(INT16_C( 15221), INT16_C(-32532), INT16_C(-18815), INT16_C( 19087),
                            INT16_C( 11893), INT16_C(  3572), INT16_C( 22455), INT16_C( -8136),
                            INT16_C(-27657), INT16_C( 23773), INT16_C( -2371), INT16_C( 14928),
                            INT16_C(  2889), INT16_C( 24720), INT16_C( 12044), INT16_C( 10273),
                            INT16_C(-17747), INT16_C(  5863), INT16_C(-17594), INT16_C( 22700),
                            INT16_C( 26140), INT16_C( 18821), INT16_C( 24933), INT16_C(-19289),
                            INT16_C(  1815), INT16_C( 12175), INT16_C(-25226), INT16_C( 32676),
                            INT16_C(-29464), INT16_C(  2615), INT16_C( 10874), INT16_C(-23017)) },
    { simde_mm512_set_epi16(INT16_C(-31561), INT16_C( 18949), INT16_C( -2287), INT16_C(-20534),
                            INT16_C( -1057), INT16_C( -3046), INT16_C( 22138), INT16_C(-11031),
                            INT16_C(    43), INT16_C( -6266), INT16_C(-20090), INT16_C(-22393),
                            INT16_C(-26046), INT16_C(-23703), INT16_C( 28092), INT16_C(  6346),
                            INT16_C( 10308), INT16_C(   572), INT16_C(     5), INT16_C( 15306),
                            INT16_C(-19429), INT16_C( -5811), INT16_C(-27420), INT16_C(-29128),
                            INT16_C(-13676), INT16_C( -3673), INT16_C(-26157), INT16_C( 19197),
                            INT16_C(-27593), INT16_C(-20030), INT16_C(  3690), INT16_C( -3850)),
      simde_mm512_set_epi16(INT16_C(-11908), INT16_C( 14774), INT16_C(  5244), INT16_C( 18107),
                            INT16_C(-16396), INT16_C( 31910), INT16_C(-28865), INT16_C(-20038),
                            INT16_C(-19234), INT16_C(-15108), INT16_C(-10436), INT16_C( 19911),
                            INT16_C(  3330), INT16_C( 28633), INT16_C( 10550), INT16_C( -9358),
                            INT16_C( 23697), INT16_C( 19726), INT16_C(-26407), INT16_C(-18878),
                            INT16_C(  4326), INT16_C(-22642), INT16_C(-17402), INT16_C( 16035),
                            INT16_C( 14223), INT16_C(-15160), INT16_C( -9470), INT16_C( -3752),
                            INT16_C(  6710), INT16_C( 21116), INT16_C( -9579), INT16_C( 10253)),
      simde_mm512_set_epi16(INT16_C(-19653), INT16_C(  4175), INT16_C( -7531), INT16_C( 26895),
                            INT16_C( 15339), INT16_C( 30580), INT16_C(-14533), INT16_C(  9007),
                            INT16_C( 19277), INT16_C(  8842), INT16_C( -9654), INT16_C( 23232),
                            INT16_C(-29376), INT16_C( 13200), INT16_C( 17542), INT16_C( 15704),
                            INT16_C(-13389), INT16_C(-19154), INT16_C( 26412), INT16_C(-31352),
                            INT16_C(-23755), INT16_C( 16831), INT16_C(-10018), INT16_C( 20373),
                            INT16_C(-27899), INT16_C( 11487), INT16_C(-16687), INT16_C( 22949),
                            INT16_C( 31233), INT16_C( 24390), INT16_C( 13269), INT16_C(-14103)) },
    { simde_mm512_set_epi16(INT16_C(  1468), INT16_C( -4389), INT16_C(  1296), INT16_C(-27715),
                            INT16_C(-15620), INT16_C(  3731), INT16_C( -7289), INT16_C(-27703),
                            INT16_C(   474), INT16_C( 27447), INT16_C( -9036), INT16_C(  9176),
                            INT16_C(  2726), INT16_C(-12144), INT16_C( -2101), INT16_C( 26907),
                            INT16_C(-24700), INT16_C(  1244), INT16_C( -3927), INT16_C(-22632),
                            INT16_C( -7525), INT16_C( 17743), INT16_C( 15263), INT16_C( -3823),
                            INT16_C( 27307), INT16_C( 32391), INT16_C(-23270), INT16_C(-29301),
                            INT16_C( 23369), INT16_C(-15291), INT16_C( -5840), INT16_C( 18168)),
      simde_mm512_set_epi16(INT16_C( 23449), INT16_C( 17725), INT16_C(-20919), INT16_C( 31466),
                            INT16_C( 31308), INT16_C( -2183), INT16_C(-31351), INT16_C(-32386),
                            INT16_C( 26890), INT16_C(-30591), INT16_C(-12785), INT16_C(-23638),
                            INT16_C(-31955), INT16_C( -9847), INT16_C( 19108), INT16_C(-19915),
                            INT16_C(  4587), INT16_C( 27034), INT16_C(   -19), INT16_C( 28332),
                            INT16_C(-23789), INT16_C(-24960), INT16_C( -5839), INT16_C( 25722),
                            INT16_C(-24423), INT16_C( 15592), INT16_C(  6092), INT16_C( -9272),
                            INT16_C(-12796), INT16_C(-17663), INT16_C( -6154), INT16_C( 23859)),
      simde_mm512_set_epi16(INT16_C(-21981), INT16_C(-22114), INT16_C( 22215), INT16_C(  6355),
                            INT16_C( 18608), INT16_C(  5914), INT16_C( 24062), INT16_C(  4683),
                            INT16_C(-26416), INT16_C( -7498), INT16_C(  3749), INT16_C(-32722),
                            INT16_C(-30855), INT16_C( -2297), INT16_C(-21209), INT16_C(-18714),
                            INT16_C(-29287), INT16_C(-25790), INT16_C( -3908), INT16_C( 14572),
                            INT16_C( 16264), INT16_C(-22833), INT16_C( 21102), INT16_C(-29545),
                            INT16_C(-13806), INT16_C( 16799), INT16_C(-29362), INT16_C(-20029),
                            INT16_C(-29371), INT16_C(  2372), INT16_C(   314), INT16_C( -5691)) },
    { simde_mm512_set_epi16(INT16_C(-22741), INT16_C( 13394), INT16_C( -9417), INT16_C( 28906),
                            INT16_C(-18980), INT16_C( -8463), INT16_C(  9174), INT16_C(-25605),
                            INT16_C(   547), INT16_C(  3767), INT16_C(-12577), INT16_C(-16546),
                            INT16_C( -1301), INT16_C( -7147), INT16_C( 26281), INT16_C( 29309),
                            INT16_C( 29052), INT16_C(-30842), INT16_C(  5995), INT16_C(  6270),
                            INT16_C( 20539), INT16_C( 10179), INT16_C(-26848), INT16_C( 14327),
                            INT16_C( 15491), INT16_C( 18652), INT16_C( 19903), INT16_C( 30123),
                            INT16_C( 25261), INT16_C(-17460), INT16_C( 10742), INT16_C( -4552)),
      simde_mm512_set_epi16(INT16_C(  5754), INT16_C(-23038), INT16_C(-16589), INT16_C(-23858),
                            INT16_C( -3821), INT16_C( -4798), INT16_C( 30602), INT16_C(-28532),
                            INT16_C( 11508), INT16_C(  7979), INT16_C( -3877), INT16_C( -5920),
                            INT16_C(-24150), INT16_C(-24496), INT16_C( 17421), INT16_C( -1981),
                            INT16_C( 27523), INT16_C( 26800), INT16_C( 25010), INT16_C( 27339),
                            INT16_C( -9050), INT16_C( 19128), INT16_C( 15279), INT16_C( -1817),
                            INT16_C(-13923), INT16_C(  5129), INT16_C(-22618), INT16_C( 27704),
                            INT16_C( -4783), INT16_C( 31238), INT16_C(-30342), INT16_C( -8854)),
      simde_mm512_set_epi16(INT16_C(-28495), INT16_C(-29104), INT16_C(  7172), INT16_C(-12772),
                            INT16_C(-15159), INT16_C( -3665), INT16_C(-21428), INT16_C(  2927),
                            INT16_C(-10961), INT16_C( -4212), INT16_C( -8700), INT16_C(-10626),
                            INT16_C( 22849), INT16_C( 17349), INT16_C(  8860), INT16_C( 31290),
                            INT16_C(  1529), INT16_C(  7894), INT16_C(-19015), INT16_C(-21069),
                            INT16_C( 29589), INT16_C( -8949), INT16_C( 23409), INT16_C( 16144),
                            INT16_C( 29414), INT16_C( 13523), INT16_C(-23015), INT16_C(  2419),
                            INT16_C( 30044), INT16_C( 16838), INT16_C(-24452), INT16_C(  4302)) },
    { simde_mm512_set_epi16(INT16_C( 27021), INT16_C( 31131), INT16_C(    63), INT16_C(-10530),
                            INT16_C( -1071), INT16_C(-31284), INT16_C(-21788), INT16_C(-16108),
                            INT16_C(-15167), INT16_C( 25422), INT16_C( 14520), INT16_C(-13896),
                            INT16_C( 20399), INT16_C( 31915), INT16_C(-16518), INT16_C( -6202),
                            INT16_C(-16332), INT16_C( -3071), INT16_C(-15644), INT16_C( -7016),
                            INT16_C( 13977), INT16_C(-13846), INT16_C(-23290), INT16_C( -2079),
                            INT16_C(  4753), INT16_C( 14919), INT16_C(-18528), INT16_C(  7420),
                            INT16_C( 12098), INT16_C( 31014), INT16_C( 17813), INT16_C(-14456)),
      simde_mm512_set_epi16(INT16_C(-12529), INT16_C( -3643), INT16_C(-28826), INT16_C(-12110),
                            INT16_C(  8030), INT16_C( 20316), INT16_C( 27324), INT16_C( 24735),
                            INT16_C( -6774), INT16_C( -2704), INT16_C(-31930), INT16_C(  6874),
                            INT16_C( -3952), INT16_C(  2658), INT16_C(  -904), INT16_C( -8319),
                            INT16_C(-16424), INT16_C( 22778), INT16_C( 18985), INT16_C( 10063),
                            INT16_C(-31751), INT16_C( 16016), INT16_C(-30217), INT16_C( 18364),
                            INT16_C(-20176), INT16_C( -4961), INT16_C(-29576), INT16_C(-16634),
                            INT16_C( -8011), INT16_C(-27110), INT16_C(-24526), INT16_C(-11504)),
      simde_mm512_set_epi16(INT16_C(-25986), INT16_C(-30762), INT16_C( 28889), INT16_C(  1580),
                            INT16_C( -9101), INT16_C( 13936), INT16_C( 16424), INT16_C( 24693),
                            INT16_C( -8393), INT16_C( 28126), INT16_C(-19086), INT16_C(-20770),
                            INT16_C( 24351), INT16_C( 29257), INT16_C(-15614), INT16_C(  2117),
                            INT16_C(    92), INT16_C(-25849), INT16_C( 30907), INT16_C(-17079),
                            INT16_C(-19808), INT16_C(-29862), INT16_C(  6927), INT16_C(-20443),
                            INT16_C( 24929), INT16_C( 19880), INT16_C( 11048), INT16_C( 24054),
                            INT16_C( 20109), INT16_C( -7412), INT16_C(-23197), INT16_C( -2952)) }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])); i++) {
    simde__m512i r = simde_mm512_sub_epi16(test_vec[i].a, test_vec[i].b);
    simde_assert_m512i_i16(r, ==, test_vec[i].r);
  }

  return 0;
}

static int
test_simde_mm512_subs_epi8(SIMDE_MUNIT_TEST_ARGS) {
  const struct {
    simde__m512i a;
    simde__m512i b;
    simde__m512i r;
  } test_vec[8] = {
    { simde_mm512_set_epi8(INT8_C(  82), INT8_C(  83), INT8_C( 117), INT8_C(  65),
                           INT8_C( -47), INT8_C(-122), INT8_C( 116), INT8_C(  14),
                           INT8_C(  76), INT8_C(   1), INT8_C( -50), INT8_C(   4),
                           INT8_C(  83), INT8_C( -77), INT8_C( 112), INT8_C(-102),
                           INT8_C(  99), INT8_C(-118), INT8_C( -47), INT8_C( -67),
                           INT8_C(  60), INT8_C( -34), INT8_C(  78), INT8_C(-110),
                           INT8_C( -58), INT8_C(  87), INT8_C( -61), INT8_C(  26),
                           INT8_C( -17), INT8_C( -46), INT8_C( 116), INT8_C( -20),
                           INT8_C(-120), INT8_C(  48), INT8_C(  24), INT8_C(  46),
                           INT8_C( 103), INT8_C( -34), INT8_C(  42), INT8_C(  51),
                           INT8_C( -65), INT8_C(  86), INT8_C(  61), INT8_C( -56),
                           INT8_C(  58), INT8_C( 119), INT8_C(  93), INT8_C(  -1),
                           INT8_C( -58), INT8_C(-121), INT8_C( -32), INT8_C(  98),
                           INT8_C( -66), INT8_C(  79), INT8_C(  99), INT8_C( -93),
                           INT8_C(  77), INT8_C( -56), INT8_C( -78), INT8_C(  39),
                           INT8_C( -50), INT8_C( -60), INT8_C( -68), INT8_C(  -4)),
      simde_mm512_set_epi8(INT8_C( 106), INT8_C(  39), INT8_C(-106), INT8_C(  14),
                           INT8_C( -28), INT8_C(  -2), INT8_C(  39), INT8_C( -28),
                           INT8_C(  54), INT8_C(  70), INT8_C( -19), INT8_C( -12),
                           INT8_C( -42), INT8_C(  28), INT8_C( -13), INT8_C(  -6),
                           INT8_C( 116), INT8_C(   2), INT8_C(  23), INT8_C( 121),
                           INT8_C( 112), INT8_C( -35), INT8_C(-124), INT8_C(  10),
                           INT8_C( -16), INT8_C(-117), INT8_C(  26), INT8_C(-125),
                           INT8_C(  36), INT8_C( 109), INT8_C(  29), INT8_C( -35),
                           INT8_C(  -9), INT8_C( -85), INT8_C( -38), INT8_C(  95),
                           INT8_C( -88), INT8_C(   3), INT8_C(   4), INT8_C( 100),
                           INT8_C(  85), INT8_C(  21), INT8_C(  66), INT8_C( -33),
                           INT8_C( -77), INT8_C(  -5), INT8_C(-126), INT8_C( 122),
                           INT8_C( -30), INT8_C( -83), INT8_C(  74), INT8_C(-108),
                           INT8_C(  83), INT8_C( -96), INT8_C( -57), INT8_C(-108),
                           INT8_C(  89), INT8_C(  59), INT8_C( 111), INT8_C( -47),
                           INT8_C( -10), INT8_C( -18), INT8_C(  20), INT8_C(-125)),
      simde_mm512_set_epi8(INT8_C( -24), INT8_C(  44), INT8_C( 127), INT8_C(  51),
                           INT8_C( -19), INT8_C(-120), INT8_C(  77), INT8_C(  42),
                           INT8_C(  22), INT8_C( -69), INT8_C( -31), INT8_C(  16),
                           INT8_C( 125), INT8_C(-105), INT8_C( 125), INT8_C( -96),
                           INT8_C( -17), INT8_C(-120), INT8_C( -70), INT8_C(-128),
                           INT8_C( -52), INT8_C(   1), INT8_C( 127), INT8_C(-120),
                           INT8_C( -42), INT8_C( 127), INT8_C( -87), INT8_C( 127),
                           INT8_C( -53), INT8_C(-128), INT8_C(  87), INT8_C(  15),
                           INT8_C(-111), INT8_C( 127), INT8_C(  62), INT8_C( -49),
                           INT8_C( 127), INT8_C( -37), INT8_C(  38), INT8_C( -49),
                           INT8_C(-128), INT8_C(  65), INT8_C(  -5), INT8_C( -23),
                           INT8_C( 127), INT8_C( 124), INT8_C( 127), INT8_C(-123),
                           INT8_C( -28), INT8_C( -38), INT8_C(-106), INT8_C( 127),
                           INT8_C(-128), INT8_C( 127), INT8_C( 127), INT8_C(  15),
                           INT8_C( -12), INT8_C(-115), INT8_C(-128), INT8_C(  86),
                           INT8_C( -40), INT8_C( -42), INT8_C( -88), INT8_C( 121)) },
    { simde_mm512_set_epi8(INT8_C(-108), INT8_C(-116), INT8_C(  21), INT8_C(-123),
                           INT8_C( -53), INT8_C(  42), INT8_C(  66), INT8_C(  13),
                           INT8_C(   9), INT8_C( 115), INT8_C(  86), INT8_C( 126),
                           INT8_C( -24), INT8_C(  35), INT8_C(  -5), INT8_C( 103),
                           INT8_C(  38), INT8_C( 111), INT8_C(  24), INT8_C( -71),
                           INT8_C(  -1), INT8_C(  17), INT8_C( -63), INT8_C( -13),
                           INT8_C(  14), INT8_C(  82), INT8_C(  78), INT8_C(-102),
                           INT8_C(  -7), INT8_C(  93), INT8_C(  25), INT8_C( 103),
                           INT8_C( 113), INT8_C( -15), INT8_C( -19), INT8_C( -73),
                           INT8_C( -11), INT8_C( 103), INT8_C( -97), INT8_C( 123),
                           INT8_C(  28), INT8_C(  53), INT8_C( -15), INT8_C( 122),
                           INT8_C(   3), INT8_C( -54), INT8_C( -61), INT8_C(  58),
                           INT8_C( -44), INT8_C(  -3), INT8_C( -43), INT8_C( -35),
                           INT8_C(-118), INT8_C( -18), INT8_C(  15), INT8_C(  54),
                           INT8_C(-102), INT8_C( -58), INT8_C( -74), INT8_C( -70),
                           INT8_C(  46), INT8_C(  48), INT8_C( -35), INT8_C(  92)),
      simde_mm512_set_epi8(INT8_C(   6), INT8_C(  68), INT8_C(  77), INT8_C( -94),
                           INT8_C( -48), INT8_C(-101), INT8_C(  -8), INT8_C(  82),
                           INT8_C(  50), INT8_C( -15), INT8_C(   6), INT8_C(  30),
                           INT8_C( -47), INT8_C( -15), INT8_C( -14), INT8_C( -97),
                           INT8_C(  28), INT8_C( -47), INT8_C( -92), INT8_C( -84),
                           INT8_C( -37), INT8_C( -33), INT8_C(-123), INT8_C( -19),
                           INT8_C(  58), INT8_C(  29), INT8_C(  93), INT8_C( -55),
                           INT8_C(-127), INT8_C( -60), INT8_C(  32), INT8_C( 116),
                           INT8_C( -46), INT8_C(  51), INT8_C( -40), INT8_C(  10),
                           INT8_C(   4), INT8_C(  50), INT8_C(  48), INT8_C(  53),
                           INT8_C(  78), INT8_C(  21), INT8_C(  64), INT8_C( 107),
                           INT8_C(  16), INT8_C(  48), INT8_C( -46), INT8_C(  62),
                           INT8_C(  75), INT8_C(  85), INT8_C(-115), INT8_C( -14),
                           INT8_C( -99), INT8_C(  86), INT8_C(-116), INT8_C( -74),
                           INT8_C(  38), INT8_C(  27), INT8_C(-115), INT8_C(  55),
                           INT8_C( -91), INT8_C( -71), INT8_C( -14), INT8_C( -84)),
      simde_mm512_set_epi8(INT8_C(-114), INT8_C(-128), INT8_C( -56), INT8_C( -29),
                           INT8_C(  -5), INT8_C( 127), INT8_C(  74), INT8_C( -69),
                           INT8_C( -41), INT8_C( 127), INT8_C(  80), INT8_C(  96),
                           INT8_C(  23), INT8_C(  50), INT8_C(   9), INT8_C( 127),
                           INT8_C(  10), INT8_C( 127), INT8_C( 116), INT8_C(  13),
                           INT8_C(  36), INT8_C(  50), INT8_C(  60), INT8_C(   6),
                           INT8_C( -44), INT8_C(  53), INT8_C( -15), INT8_C( -47),
                           INT8_C( 120), INT8_C( 127), INT8_C(  -7), INT8_C( -13),
                           INT8_C( 127), INT8_C( -66), INT8_C(  21), INT8_C( -83),
                           INT8_C( -15), INT8_C(  53), INT8_C(-128), INT8_C(  70),
                           INT8_C( -50), INT8_C(  32), INT8_C( -79), INT8_C(  15),
                           INT8_C( -13), INT8_C(-102), INT8_C( -15), INT8_C(  -4),
                           INT8_C(-119), INT8_C( -88), INT8_C(  72), INT8_C( -21),
                           INT8_C( -19), INT8_C(-104), INT8_C( 127), INT8_C( 127),
                           INT8_C(-128), INT8_C( -85), INT8_C(  41), INT8_C(-125),
                           INT8_C( 127), INT8_C( 119), INT8_C( -21), INT8_C( 127)) },
    { simde_mm512_set_epi8(INT8_C(   2), INT8_C( -77), INT8_C( -19), INT8_C(  41),
                           INT8_C( -13), INT8_C(  75), INT8_C(-123), INT8_C(  96),
                           INT8_C( -86), INT8_C( -24), INT8_C( -27), INT8_C( -84),
                           INT8_C(  35), INT8_C( -86), INT8_C( -72), INT8_C( -97),
                           INT8_C(  44), INT8_C(  11), INT8_C(-106), INT8_C(  44),
                           INT8_C(   0), INT8_C(  90), INT8_C( -79), INT8_C(  91),
                           INT8_C( 119), INT8_C(  59), INT8_C( 105), INT8_C(-128),
                           INT8_C( 110), INT8_C( -29), INT8_C(  67), INT8_C( 114),
                           INT8_C( -39), INT8_C( -49), INT8_C( 105), INT8_C( -40),
                           INT8_C( -33), INT8_C( 120), INT8_C( -27), INT8_C( 100),
                           INT8_C( -90), INT8_C(  86), INT8_C( -18), INT8_C( -57),
                           INT8_C(  84), INT8_C( -26), INT8_C( -77), INT8_C(  17),
                           INT8_C( -47), INT8_C(  51), INT8_C( -83), INT8_C(  53),
                           INT8_C(  71), INT8_C(  96), INT8_C( 110), INT8_C( -89),
                           INT8_C(  27), INT8_C( -45), INT8_C(-126), INT8_C(  40),
                           INT8_C(  95), INT8_C( -87), INT8_C( -62), INT8_C( -52)),
      simde_mm512_set_epi8(INT8_C( -84), INT8_C( 127), INT8_C(  61), INT8_C( -16),
                           INT8_C(  30), INT8_C(   6), INT8_C(-112), INT8_C( 104),
                           INT8_C( -60), INT8_C( -88), INT8_C( -39), INT8_C( -19),
                           INT8_C(  44), INT8_C(  36), INT8_C( 105), INT8_C( 120),
                           INT8_C( -26), INT8_C(  21), INT8_C(  14), INT8_C(  42),
                           INT8_C(  49), INT8_C( -84), INT8_C(-120), INT8_C(-107),
                           INT8_C( 123), INT8_C( -47), INT8_C(  21), INT8_C( -10),
                           INT8_C(  95), INT8_C( 124), INT8_C( -33), INT8_C( -34),
                           INT8_C( -33), INT8_C( -71), INT8_C(  11), INT8_C(  74),
                           INT8_C( 104), INT8_C( 108), INT8_C( -35), INT8_C( -59),
                           INT8_C( -55), INT8_C(-126), INT8_C( 107), INT8_C(  23),
                           INT8_C(  29), INT8_C( -27), INT8_C( 123), INT8_C(  23),
                           INT8_C( -83), INT8_C( -90), INT8_C(   9), INT8_C(  94),
                           INT8_C(  91), INT8_C(  69), INT8_C( -51), INT8_C(-103),
                           INT8_C( -72), INT8_C( -45), INT8_C(  16), INT8_C( 108),
                           INT8_C( -80), INT8_C(  27), INT8_C(  58), INT8_C( -83)),
      simde_mm512_set_epi8(INT8_C(  86), INT8_C(-128), INT8_C( -80), INT8_C(  57),
                           INT8_C( -43), INT8_C(  69), INT8_C( -11), INT8_C(  -8),
                           INT8_C( -26), INT8_C(  64), INT8_C(  12), INT8_C( -65),
                           INT8_C(  -9), INT8_C(-122), INT8_C(-128), INT8_C(-128),
                           INT8_C(  70), INT8_C( -10), INT8_C(-120), INT8_C(   2),
                           INT8_C( -49), INT8_C( 127), INT8_C(  41), INT8_C( 127),
                           INT8_C(  -4), INT8_C( 106), INT8_C(  84), INT8_C(-118),
                           INT8_C(  15), INT8_C(-128), INT8_C( 100), INT8_C( 127),
                           INT8_C(  -6), INT8_C(  22), INT8_C(  94), INT8_C(-114),
                           INT8_C(-128), INT8_C(  12), INT8_C(   8), INT8_C( 127),
                           INT8_C( -35), INT8_C( 127), INT8_C(-125), INT8_C( -80),
                           INT8_C(  55), INT8_C(   1), INT8_C(-128), INT8_C(  -6),
                           INT8_C(  36), INT8_C( 127), INT8_C( -92), INT8_C( -41),
                           INT8_C( -20), INT8_C(  27), INT8_C( 127), INT8_C(  14),
                           INT8_C(  99), INT8_C(   0), INT8_C(-128), INT8_C( -68),
                           INT8_C( 127), INT8_C(-114), INT8_C(-120), INT8_C(  31)) },
    { simde_mm512_set_epi8(INT8_C(  17), INT8_C(  99), INT8_C( -13), INT8_C( -49),
                           INT8_C(  45), INT8_C(-128), INT8_C(  55), INT8_C( 105),
                           INT8_C( -34), INT8_C( -51), INT8_C( -97), INT8_C(-103),
                           INT8_C(-124), INT8_C( 111), INT8_C(  74), INT8_C(  75),
                           INT8_C( 102), INT8_C(  98), INT8_C(-117), INT8_C(   9),
                           INT8_C( -74), INT8_C(  61), INT8_C(  99), INT8_C( 124),
                           INT8_C(  79), INT8_C(-114), INT8_C(  19), INT8_C(  97),
                           INT8_C(-100), INT8_C(-124), INT8_C( -17), INT8_C( -62),
                           INT8_C(  25), INT8_C(  -3), INT8_C(  -7), INT8_C(  72),
                           INT8_C(-117), INT8_C( -27), INT8_C( -56), INT8_C(  92),
                           INT8_C( -20), INT8_C( -53), INT8_C(   2), INT8_C( -38),
                           INT8_C( -81), INT8_C(  59), INT8_C(  66), INT8_C(  90),
                           INT8_C(  36), INT8_C( 100), INT8_C( 112), INT8_C( 123),
                           INT8_C( -72), INT8_C( -97), INT8_C(-115), INT8_C(  17),
                           INT8_C( -93), INT8_C(-122), INT8_C(  31), INT8_C(  27),
                           INT8_C( 109), INT8_C( 115), INT8_C(  53), INT8_C( -96)),
      simde_mm512_set_epi8(INT8_C( -43), INT8_C( -18), INT8_C( 114), INT8_C( -29),
                           INT8_C( 118), INT8_C(  -1), INT8_C( -20), INT8_C( -38),
                           INT8_C( -80), INT8_C(  88), INT8_C(-111), INT8_C( -91),
                           INT8_C(  44), INT8_C( -72), INT8_C( 106), INT8_C(  19),
                           INT8_C( -46), INT8_C( 107), INT8_C(  46), INT8_C(  44),
                           INT8_C( -65), INT8_C(-128), INT8_C(  41), INT8_C(  44),
                           INT8_C(  68), INT8_C(  69), INT8_C( -78), INT8_C( -47),
                           INT8_C( 109), INT8_C( 120), INT8_C( -57), INT8_C( -95),
                           INT8_C(  95), INT8_C(  80), INT8_C( -30), INT8_C(  97),
                           INT8_C( -48), INT8_C( -97), INT8_C( 111), INT8_C( -80),
                           INT8_C(-122), INT8_C( -81), INT8_C( -71), INT8_C(  85),
                           INT8_C(  77), INT8_C( -42), INT8_C(-115), INT8_C( -77),
                           INT8_C(  29), INT8_C(  77), INT8_C(  64), INT8_C( -20),
                           INT8_C(  27), INT8_C(  41), INT8_C(  13), INT8_C( 109),
                           INT8_C(  22), INT8_C( -98), INT8_C(  20), INT8_C( -28),
                           INT8_C(  66), INT8_C(  -7), INT8_C(-113), INT8_C(-119)),
      simde_mm512_set_epi8(INT8_C(  60), INT8_C( 117), INT8_C(-127), INT8_C( -20),
                           INT8_C( -73), INT8_C(-127), INT8_C(  75), INT8_C( 127),
                           INT8_C(  46), INT8_C(-128), INT8_C(  14), INT8_C( -12),
                           INT8_C(-128), INT8_C( 127), INT8_C( -32), INT8_C(  56),
                           INT8_C( 127), INT8_C(  -9), INT8_C(-128), INT8_C( -35),
                           INT8_C(  -9), INT8_C( 127), INT8_C(  58), INT8_C(  80),
                           INT8_C(  11), INT8_C(-128), INT8_C(  97), INT8_C( 127),
                           INT8_C(-128), INT8_C(-128), INT8_C(  40), INT8_C(  33),
                           INT8_C( -70), INT8_C( -83), INT8_C(  23), INT8_C( -25),
                           INT8_C( -69), INT8_C(  70), INT8_C(-128), INT8_C( 127),
                           INT8_C( 102), INT8_C(  28), INT8_C(  73), INT8_C(-123),
                           INT8_C(-128), INT8_C( 101), INT8_C( 127), INT8_C( 127),
                           INT8_C(   7), INT8_C(  23), INT8_C(  48), INT8_C( 127),
                           INT8_C( -99), INT8_C(-128), INT8_C(-128), INT8_C( -92),
                           INT8_C(-115), INT8_C( -24), INT8_C(  11), INT8_C(  55),
                           INT8_C(  43), INT8_C( 122), INT8_C( 127), INT8_C(  23)) },
    { simde_mm512_set_epi8(INT8_C(-124), INT8_C( -73), INT8_C(  74), INT8_C(   5),
                           INT8_C(  -9), INT8_C(  17), INT8_C( -81), INT8_C( -54),
                           INT8_C(  -5), INT8_C( -33), INT8_C( -12), INT8_C(  26),
                           INT8_C(  86), INT8_C( 122), INT8_C( -44), INT8_C( -23),
                           INT8_C(   0), INT8_C(  43), INT8_C( -25), INT8_C(-122),
                           INT8_C( -79), INT8_C(-122), INT8_C( -88), INT8_C(-121),
                           INT8_C(-102), INT8_C(  66), INT8_C( -93), INT8_C( 105),
                           INT8_C( 109), INT8_C( -68), INT8_C(  24), INT8_C( -54),
                           INT8_C(  40), INT8_C(  68), INT8_C(   2), INT8_C(  60),
                           INT8_C(   0), INT8_C(   5), INT8_C(  59), INT8_C( -54),
                           INT8_C( -76), INT8_C(  27), INT8_C( -23), INT8_C(  77),
                           INT8_C(-108), INT8_C( -28), INT8_C(-114), INT8_C(  56),
                           INT8_C( -54), INT8_C(-108), INT8_C( -15), INT8_C( -89),
                           INT8_C(-103), INT8_C( -45), INT8_C(  74), INT8_C(  -3),
                           INT8_C(-108), INT8_C(  55), INT8_C( -79), INT8_C( -62),
                           INT8_C(  14), INT8_C( 106), INT8_C( -16), INT8_C( -10)),
      simde_mm512_set_epi8(INT8_C( -47), INT8_C( 124), INT8_C(  57), INT8_C( -74),
                           INT8_C(  20), INT8_C( 124), INT8_C(  70), INT8_C( -69),
                           INT8_C( -65), INT8_C( -12), INT8_C( 124), INT8_C( -90),
                           INT8_C(-113), INT8_C(  63), INT8_C( -79), INT8_C( -70),
                           INT8_C( -76), INT8_C( -34), INT8_C( -60), INT8_C(  -4),
                           INT8_C( -41), INT8_C(  60), INT8_C(  77), INT8_C( -57),
                           INT8_C(  13), INT8_C(   2), INT8_C( 111), INT8_C( -39),
                           INT8_C(  41), INT8_C(  54), INT8_C( -37), INT8_C( 114),
                           INT8_C(  92), INT8_C(-111), INT8_C(  77), INT8_C(  14),
                           INT8_C(-104), INT8_C( -39), INT8_C( -74), INT8_C(  66),
                           INT8_C(  16), INT8_C( -26), INT8_C( -89), INT8_C(-114),
                           INT8_C( -68), INT8_C(   6), INT8_C(  62), INT8_C( -93),
                           INT8_C(  55), INT8_C(-113), INT8_C( -60), INT8_C( -56),
                           INT8_C( -37), INT8_C(   2), INT8_C( -15), INT8_C(  88),
                           INT8_C(  26), INT8_C(  54), INT8_C(  82), INT8_C( 124),
                           INT8_C( -38), INT8_C(-107), INT8_C(  40), INT8_C(  13)),
      simde_mm512_set_epi8(INT8_C( -77), INT8_C(-128), INT8_C(  17), INT8_C(  79),
                           INT8_C( -29), INT8_C(-107), INT8_C(-128), INT8_C(  15),
                           INT8_C(  60), INT8_C( -21), INT8_C(-128), INT8_C( 116),
                           INT8_C( 127), INT8_C(  59), INT8_C(  35), INT8_C(  47),
                           INT8_C(  76), INT8_C(  77), INT8_C(  35), INT8_C(-118),
                           INT8_C( -38), INT8_C(-128), INT8_C(-128), INT8_C( -64),
                           INT8_C(-115), INT8_C(  64), INT8_C(-128), INT8_C( 127),
                           INT8_C(  68), INT8_C(-122), INT8_C(  61), INT8_C(-128),
                           INT8_C( -52), INT8_C( 127), INT8_C( -75), INT8_C(  46),
                           INT8_C( 104), INT8_C(  44), INT8_C( 127), INT8_C(-120),
                           INT8_C( -92), INT8_C(  53), INT8_C(  66), INT8_C( 127),
                           INT8_C( -40), INT8_C( -34), INT8_C(-128), INT8_C( 127),
                           INT8_C(-109), INT8_C(   5), INT8_C(  45), INT8_C( -33),
                           INT8_C( -66), INT8_C( -47), INT8_C(  89), INT8_C( -91),
                           INT8_C(-128), INT8_C(   1), INT8_C(-128), INT8_C(-128),
                           INT8_C(  52), INT8_C( 127), INT8_C( -56), INT8_C( -23)) },
    { simde_mm512_set_epi8(INT8_C(   5), INT8_C( -68), INT8_C( -18), INT8_C( -37),
                           INT8_C(   5), INT8_C(  16), INT8_C(-109), INT8_C( -67),
                           INT8_C( -62), INT8_C(  -4), INT8_C(  14), INT8_C(-109),
                           INT8_C( -29), INT8_C(-121), INT8_C(-109), INT8_C( -55),
                           INT8_C(   1), INT8_C( -38), INT8_C( 107), INT8_C(  55),
                           INT8_C( -36), INT8_C( -76), INT8_C(  35), INT8_C( -40),
                           INT8_C(  10), INT8_C( -90), INT8_C( -48), INT8_C(-112),
                           INT8_C(  -9), INT8_C( -53), INT8_C( 105), INT8_C(  27),
                           INT8_C( -97), INT8_C(-124), INT8_C(   4), INT8_C( -36),
                           INT8_C( -16), INT8_C( -87), INT8_C( -89), INT8_C(-104),
                           INT8_C( -30), INT8_C(-101), INT8_C(  69), INT8_C(  79),
                           INT8_C(  59), INT8_C( -97), INT8_C( -15), INT8_C(  17),
                           INT8_C( 106), INT8_C( -85), INT8_C( 126), INT8_C(-121),
                           INT8_C( -91), INT8_C(  26), INT8_C(-115), INT8_C(-117),
                           INT8_C(  91), INT8_C(  73), INT8_C( -60), INT8_C(  69),
                           INT8_C( -23), INT8_C(  48), INT8_C(  70), INT8_C(  -8)),
      simde_mm512_set_epi8(INT8_C(  91), INT8_C(-103), INT8_C(  69), INT8_C(  61),
                           INT8_C( -82), INT8_C(  73), INT8_C( 122), INT8_C( -22),
                           INT8_C( 122), INT8_C(  76), INT8_C(  -9), INT8_C( 121),
                           INT8_C(-123), INT8_C(-119), INT8_C(-127), INT8_C( 126),
                           INT8_C( 105), INT8_C(  10), INT8_C(-120), INT8_C(-127),
                           INT8_C( -50), INT8_C(  15), INT8_C( -93), INT8_C( -86),
                           INT8_C(-125), INT8_C(  45), INT8_C( -39), INT8_C(-119),
                           INT8_C(  74), INT8_C( -92), INT8_C( -78), INT8_C(  53),
                           INT8_C(  17), INT8_C( -21), INT8_C( 105), INT8_C(-102),
                           INT8_C(  -1), INT8_C( -19), INT8_C( 110), INT8_C( -84),
                           INT8_C( -93), INT8_C(  19), INT8_C( -98), INT8_C(-128),
                           INT8_C( -23), INT8_C(  49), INT8_C( 100), INT8_C( 122),
                           INT8_C( -96), INT8_C(-103), INT8_C(  60), INT8_C( -24),
                           INT8_C(  23), INT8_C( -52), INT8_C( -37), INT8_C( -56),
                           INT8_C( -50), INT8_C(   4), INT8_C( -69), INT8_C(   1),
                           INT8_C( -25), INT8_C( -10), INT8_C(  93), INT8_C(  51)),
      simde_mm512_set_epi8(INT8_C( -86), INT8_C(  35), INT8_C( -87), INT8_C( -98),
                           INT8_C(  87), INT8_C( -57), INT8_C(-128), INT8_C( -45),
                           INT8_C(-128), INT8_C( -80), INT8_C(  23), INT8_C(-128),
                           INT8_C(  94), INT8_C(  -2), INT8_C(  18), INT8_C(-128),
                           INT8_C(-104), INT8_C( -48), INT8_C( 127), INT8_C( 127),
                           INT8_C(  14), INT8_C( -91), INT8_C( 127), INT8_C(  46),
                           INT8_C( 127), INT8_C(-128), INT8_C(  -9), INT8_C(   7),
                           INT8_C( -83), INT8_C(  39), INT8_C( 127), INT8_C( -26),
                           INT8_C(-114), INT8_C(-103), INT8_C(-101), INT8_C(  66),
                           INT8_C( -15), INT8_C( -68), INT8_C(-128), INT8_C( -20),
                           INT8_C(  63), INT8_C(-120), INT8_C( 127), INT8_C( 127),
                           INT8_C(  82), INT8_C(-128), INT8_C(-115), INT8_C(-105),
                           INT8_C( 127), INT8_C(  18), INT8_C(  66), INT8_C( -97),
                           INT8_C(-114), INT8_C(  78), INT8_C( -78), INT8_C( -61),
                           INT8_C( 127), INT8_C(  69), INT8_C(   9), INT8_C(  68),
                           INT8_C(   2), INT8_C(  58), INT8_C( -23), INT8_C( -59)) },
    { simde_mm512_set_epi8(INT8_C( -89), INT8_C(  43), INT8_C(  52), INT8_C(  82),
                           INT8_C( -37), INT8_C(  55), INT8_C( 112), INT8_C( -22),
                           INT8_C( -75), INT8_C( -36), INT8_C( -34), INT8_C( -15),
                           INT8_C(  35), INT8_C( -42), INT8_C(-101), INT8_C(  -5),
                           INT8_C(   2), INT8_C(  35), INT8_C(  14), INT8_C( -73),
                           INT8_C( -50), INT8_C( -33), INT8_C( -65), INT8_C(  94),
                           INT8_C(  -6), INT8_C( -21), INT8_C( -28), INT8_C(  21),
                           INT8_C( 102), INT8_C( -87), INT8_C( 114), INT8_C( 125),
                           INT8_C( 113), INT8_C( 124), INT8_C(-121), INT8_C(-122),
                           INT8_C(  23), INT8_C( 107), INT8_C(  24), INT8_C( 126),
                           INT8_C(  80), INT8_C(  59), INT8_C(  39), INT8_C( -61),
                           INT8_C(-105), INT8_C(  32), INT8_C(  55), INT8_C(  -9),
                           INT8_C(  60), INT8_C(-125), INT8_C(  72), INT8_C( -36),
                           INT8_C(  77), INT8_C( -65), INT8_C( 117), INT8_C( -85),
                           INT8_C(  98), INT8_C( -83), INT8_C( -69), INT8_C( -52),
                           INT8_C(  41), INT8_C( -10), INT8_C( -18), INT8_C(  56)),
      simde_mm512_set_epi8(INT8_C(  22), INT8_C( 122), INT8_C( -90), INT8_C(   2),
                           INT8_C( -65), INT8_C(  51), INT8_C( -94), INT8_C( -50),
                           INT8_C( -15), INT8_C(  19), INT8_C( -19), INT8_C(  66),
                           INT8_C( 119), INT8_C(-118), INT8_C(-112), INT8_C(-116),
                           INT8_C(  44), INT8_C( -12), INT8_C(  31), INT8_C(  43),
                           INT8_C( -16), INT8_C( -37), INT8_C( -24), INT8_C( -32),
                           INT8_C( -95), INT8_C( -86), INT8_C( -96), INT8_C(  80),
                           INT8_C(  68), INT8_C(  13), INT8_C(  -8), INT8_C(  67),
                           INT8_C( 107), INT8_C(-125), INT8_C( 104), INT8_C( -80),
                           INT8_C(  97), INT8_C( -78), INT8_C( 106), INT8_C( -53),
                           INT8_C( -36), INT8_C( -90), INT8_C(  74), INT8_C( -72),
                           INT8_C(  59), INT8_C( -81), INT8_C(  -8), INT8_C( -25),
                           INT8_C( -55), INT8_C( -99), INT8_C(  20), INT8_C(   9),
                           INT8_C( -89), INT8_C( -90), INT8_C( 108), INT8_C(  56),
                           INT8_C( -19), INT8_C(  81), INT8_C( 122), INT8_C(   6),
                           INT8_C(-119), INT8_C( 122), INT8_C( -35), INT8_C( 106)),
      simde_mm512_set_epi8(INT8_C(-111), INT8_C( -79), INT8_C( 127), INT8_C(  80),
                           INT8_C(  28), INT8_C(   4), INT8_C( 127), INT8_C(  28),
                           INT8_C( -60), INT8_C( -55), INT8_C( -15), INT8_C( -81),
                           INT8_C( -84), INT8_C(  76), INT8_C(  11), INT8_C( 111),
                           INT8_C( -42), INT8_C(  47), INT8_C( -17), INT8_C(-116),
                           INT8_C( -34), INT8_C(   4), INT8_C( -41), INT8_C( 126),
                           INT8_C(  89), INT8_C(  65), INT8_C(  68), INT8_C( -59),
                           INT8_C(  34), INT8_C(-100), INT8_C( 122), INT8_C(  58),
                           INT8_C(   6), INT8_C( 127), INT8_C(-128), INT8_C( -42),
                           INT8_C( -74), INT8_C( 127), INT8_C( -82), INT8_C( 127),
                           INT8_C( 116), INT8_C( 127), INT8_C( -35), INT8_C(  11),
                           INT8_C(-128), INT8_C( 113), INT8_C(  63), INT8_C(  16),
                           INT8_C( 115), INT8_C( -26), INT8_C(  52), INT8_C( -45),
                           INT8_C( 127), INT8_C(  25), INT8_C(   9), INT8_C(-128),
                           INT8_C( 117), INT8_C(-128), INT8_C(-128), INT8_C( -58),
                           INT8_C( 127), INT8_C(-128), INT8_C(  17), INT8_C( -50)) },
    { simde_mm512_set_epi8(INT8_C( 105), INT8_C(-115), INT8_C( 121), INT8_C(-101),
                           INT8_C(   0), INT8_C(  63), INT8_C( -42), INT8_C( -34),
                           INT8_C(  -5), INT8_C( -47), INT8_C(-123), INT8_C( -52),
                           INT8_C( -86), INT8_C( -28), INT8_C( -63), INT8_C(  20),
                           INT8_C( -60), INT8_C( -63), INT8_C(  99), INT8_C(  78),
                           INT8_C(  56), INT8_C( -72), INT8_C( -55), INT8_C( -72),
                           INT8_C(  79), INT8_C( -81), INT8_C( 124), INT8_C( -85),
                           INT8_C( -65), INT8_C( 122), INT8_C( -25), INT8_C( -58),
                           INT8_C( -64), INT8_C(  52), INT8_C( -12), INT8_C(   1),
                           INT8_C( -62), INT8_C( -28), INT8_C( -28), INT8_C(-104),
                           INT8_C(  54), INT8_C(-103), INT8_C( -55), INT8_C( -22),
                           INT8_C( -91), INT8_C(   6), INT8_C(  -9), INT8_C( -31),
                           INT8_C(  18), INT8_C(-111), INT8_C(  58), INT8_C(  71),
                           INT8_C( -73), INT8_C( -96), INT8_C(  28), INT8_C(  -4),
                           INT8_C(  47), INT8_C(  66), INT8_C( 121), INT8_C(  38),
                           INT8_C(  69), INT8_C(-107), INT8_C( -57), INT8_C(-120)),
      simde_mm512_set_epi8(INT8_C( -49), INT8_C(  15), INT8_C( -15), INT8_C( -59),
                           INT8_C(-113), INT8_C( 102), INT8_C( -48), INT8_C( -78),
                           INT8_C(  31), INT8_C(  94), INT8_C(  79), INT8_C(  92),
                           INT8_C( 106), INT8_C( -68), INT8_C(  96), INT8_C( -97),
                           INT8_C( -27), INT8_C(-118), INT8_C( -11), INT8_C( 112),
                           INT8_C(-125), INT8_C(  70), INT8_C(  26), INT8_C( -38),
                           INT8_C( -16), INT8_C(-112), INT8_C(  10), INT8_C(  98),
                           INT8_C(  -4), INT8_C( 120), INT8_C( -33), INT8_C(-127),
                           INT8_C( -65), INT8_C( -40), INT8_C(  88), INT8_C(  -6),
                           INT8_C(  74), INT8_C(  41), INT8_C(  39), INT8_C(  79),
                           INT8_C(-125), INT8_C(  -7), INT8_C(  62), INT8_C(-112),
                           INT8_C(-119), INT8_C(  -9), INT8_C(  71), INT8_C( -68),
                           INT8_C( -79), INT8_C(  48), INT8_C( -20), INT8_C( -97),
                           INT8_C(-116), INT8_C( 120), INT8_C( -65), INT8_C(   6),
                           INT8_C( -32), INT8_C( -75), INT8_C(-106), INT8_C(  26),
                           INT8_C( -96), INT8_C(  50), INT8_C( -45), INT8_C(  16)),
      simde_mm512_set_epi8(INT8_C( 127), INT8_C(-128), INT8_C( 127), INT8_C( -42),
                           INT8_C( 113), INT8_C( -39), INT8_C(   6), INT8_C(  44),
                           INT8_C( -36), INT8_C(-128), INT8_C(-128), INT8_C(-128),
                           INT8_C(-128), INT8_C(  40), INT8_C(-128), INT8_C( 117),
                           INT8_C( -33), INT8_C(  55), INT8_C( 110), INT8_C( -34),
                           INT8_C( 127), INT8_C(-128), INT8_C( -81), INT8_C( -34),
                           INT8_C(  95), INT8_C(  31), INT8_C( 114), INT8_C(-128),
                           INT8_C( -61), INT8_C(   2), INT8_C(   8), INT8_C(  69),
                           INT8_C(   1), INT8_C(  92), INT8_C(-100), INT8_C(   7),
                           INT8_C(-128), INT8_C( -69), INT8_C( -67), INT8_C(-128),
                           INT8_C( 127), INT8_C( -96), INT8_C(-117), INT8_C(  90),
                           INT8_C(  28), INT8_C(  15), INT8_C( -80), INT8_C(  37),
                           INT8_C(  97), INT8_C(-128), INT8_C(  78), INT8_C( 127),
                           INT8_C(  43), INT8_C(-128), INT8_C(  93), INT8_C( -10),
                           INT8_C(  79), INT8_C( 127), INT8_C( 127), INT8_C(  12),
                           INT8_C( 127), INT8_C(-128), INT8_C( -12), INT8_C(-128)) }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])); i++) {
    simde__m512i r = simde_mm512_subs_epi8(test_vec[i].a, test_vec[i].b);
    simde_assert_m512i_i8(r, ==, test_vec[i].r);
  }

  return 0;
}

static int
test_simde_mm512_mask_subs_epi8(SIMDE_MUNIT_TEST_ARGS) {
  const struct {
    simde__m512i src;
    simde__mmask64 k;
    simde__m512i a;
    simde__m512i b;
    simde__m512i r;
  } test_vec[8] = {
    { simde_mm512_set_epi8(INT8_C(  52), INT8_C(-124), INT8_C( -17), INT8_C(  -9),
                           INT8_C(  31), INT8_C(  67), INT8_C( -76), INT8_C(  -4),
                           INT8_C( -52), INT8_C(  99), INT8_C( 106), INT8_C( -35),
                           INT8_C(-115), INT8_C(-127), INT8_C( 121), INT8_C( -60),
                           INT8_C( -27), INT8_C(  73), INT8_C( -21), INT8_C( -51),
                           INT8_C(-127), INT8_C(  68), INT8_C( 109), INT8_C(  35),
                           INT8_C(  96), INT8_C(   3), INT8_C( -62), INT8_C( -43),
                           INT8_C( -75), INT8_C( 102), INT8_C(-105), INT8_C(  63),
                           INT8_C(  64), INT8_C( 114), INT8_C( 112), INT8_C(  10),
                           INT8_C( 108), INT8_C(  71), INT8_C( -40), INT8_C(  20),
                           INT8_C( -40), INT8_C(  26), INT8_C( -94), INT8_C( 107),
                           INT8_C( -89), INT8_C(  22), INT8_C(  55), INT8_C( 105),
                           INT8_C(  23), INT8_C(  52), INT8_C(  82), INT8_C(  50),
                           INT8_C( -48), INT8_C(  77), INT8_C(  73), INT8_C(  98),
                           INT8_C( -85), INT8_C( 123), INT8_C(  15), INT8_C(  36),
                           INT8_C(-103), INT8_C(  18), INT8_C( -81), INT8_C(   9)),
      UINT64_C(          2070647823),
      simde_mm512_set_epi8(INT8_C(  87), INT8_C( 118), INT8_C(  10), INT8_C( -53),
                           INT8_C( -21), INT8_C( -77), INT8_C(  81), INT8_C(  16),
                           INT8_C( 125), INT8_C(  53), INT8_C( -93), INT8_C( -44),
                           INT8_C( -14), INT8_C( -81), INT8_C(  93), INT8_C( -81),
                           INT8_C(  69), INT8_C(  88), INT8_C(  17), INT8_C(-127),
                           INT8_C(  49), INT8_C(  91), INT8_C(  55), INT8_C( -23),
                           INT8_C( -84), INT8_C(  12), INT8_C( -97), INT8_C( -75),
                           INT8_C(  99), INT8_C(  54), INT8_C( -92), INT8_C( -28),
                           INT8_C(  -2), INT8_C(  69), INT8_C(-102), INT8_C(  42),
                           INT8_C(  41), INT8_C(-101), INT8_C( -59), INT8_C( -72),
                           INT8_C( -53), INT8_C( -47), INT8_C( -78), INT8_C(  67),
                           INT8_C(  54), INT8_C(  12), INT8_C( -65), INT8_C( 101),
                           INT8_C(  77), INT8_C( -96), INT8_C( -15), INT8_C(  66),
                           INT8_C(  50), INT8_C(   9), INT8_C( -75), INT8_C( 102),
                           INT8_C(   2), INT8_C( -31), INT8_C(  83), INT8_C( -71),
                           INT8_C( -84), INT8_C( -66), INT8_C(-111), INT8_C(  -2)),
      simde_mm512_set_epi8(INT8_C(  87), INT8_C(-105), INT8_C(  96), INT8_C( -79),
                           INT8_C(  99), INT8_C(  74), INT8_C(  20), INT8_C( 120),
                           INT8_C(  60), INT8_C(  49), INT8_C( 101), INT8_C( -94),
                           INT8_C(  -5), INT8_C( 114), INT8_C(  17), INT8_C(   1),
                           INT8_C(  36), INT8_C( -92), INT8_C(  39), INT8_C(-108),
                           INT8_C( -15), INT8_C(  14), INT8_C( -15), INT8_C(  79),
                           INT8_C( 112), INT8_C( 108), INT8_C( -44), INT8_C( -18),
                           INT8_C( 125), INT8_C(  93), INT8_C( -92), INT8_C( -51),
                           INT8_C(  21), INT8_C( -19), INT8_C( -56), INT8_C( 114),
                           INT8_C( -95), INT8_C(  40), INT8_C( -27), INT8_C( -85),
                           INT8_C(  26), INT8_C(  29), INT8_C( -30), INT8_C(  53),
                           INT8_C( -69), INT8_C( -26), INT8_C(  79), INT8_C(-124),
                           INT8_C( -35), INT8_C( -29), INT8_C( -59), INT8_C( -99),
                           INT8_C(-118), INT8_C(  30), INT8_C( 105), INT8_C(   3),
                           INT8_C(  -2), INT8_C(  26), INT8_C(-121), INT8_C( 115),
                           INT8_C( -78), INT8_C(  10), INT8_C(   6), INT8_C( -16)),
      simde_mm512_set_epi8(INT8_C(  52), INT8_C(-124), INT8_C( -17), INT8_C(  -9),
                           INT8_C(  31), INT8_C(  67), INT8_C( -76), INT8_C(  -4),
                           INT8_C( -52), INT8_C(  99), INT8_C( 106), INT8_C( -35),
                           INT8_C(-115), INT8_C(-127), INT8_C( 121), INT8_C( -60),
                           INT8_C( -27), INT8_C(  73), INT8_C( -21), INT8_C( -51),
                           INT8_C(-127), INT8_C(  68), INT8_C( 109), INT8_C(  35),
                           INT8_C(  96), INT8_C(   3), INT8_C( -62), INT8_C( -43),
                           INT8_C( -75), INT8_C( 102), INT8_C(-105), INT8_C(  63),
                           INT8_C(  64), INT8_C(  88), INT8_C( -46), INT8_C( -72),
                           INT8_C( 127), INT8_C(  71), INT8_C( -32), INT8_C(  13),
                           INT8_C( -40), INT8_C( -76), INT8_C( -48), INT8_C( 107),
                           INT8_C( 123), INT8_C(  22), INT8_C(-128), INT8_C( 127),
                           INT8_C( 112), INT8_C(  52), INT8_C(  82), INT8_C( 127),
                           INT8_C( -48), INT8_C( -21), INT8_C(  73), INT8_C(  98),
                           INT8_C( -85), INT8_C( 123), INT8_C(  15), INT8_C(  36),
                           INT8_C(  -6), INT8_C( -76), INT8_C(-117), INT8_C(  14)) },
    { simde_mm512_set_epi8(INT8_C( -60), INT8_C( -92), INT8_C( -73), INT8_C( -20),
                           INT8_C( -84), INT8_C( -11), INT8_C( -28), INT8_C(-123),
                           INT8_C( -48), INT8_C(-118), INT8_C(-107), INT8_C(  73),
                           INT8_C( -80), INT8_C(  46), INT8_C(-117), INT8_C( -85),
                           INT8_C( -21), INT8_C( -54), INT8_C( -49), INT8_C(  -8),
                           INT8_C(  51), INT8_C( 126), INT8_C(  22), INT8_C(  70),
                           INT8_C( -86), INT8_C( -98), INT8_C( -17), INT8_C( -29),
                           INT8_C(  75), INT8_C( 115), INT8_C(  61), INT8_C(  76),
                           INT8_C( -65), INT8_C(  43), INT8_C( -13), INT8_C(  -2),
                           INT8_C(  81), INT8_C( -26), INT8_C(  -6), INT8_C( -15),
                           INT8_C( -40), INT8_C(  72), INT8_C(  66), INT8_C(  32),
                           INT8_C(  22), INT8_C( -74), INT8_C( -73), INT8_C(  67),
                           INT8_C(  75), INT8_C( -18), INT8_C( -97), INT8_C(  75),
                           INT8_C( -47), INT8_C(  32), INT8_C(  26), INT8_C(-108),
                           INT8_C(  31), INT8_C( 110), INT8_C(-101), INT8_C( -57),
                           INT8_C(  28), INT8_C( -50), INT8_C( -16), INT8_C(  37)),
      UINT64_C(          3026541283),
      simde_mm512_set_epi8(INT8_C( -66), INT8_C( -12), INT8_C( -24), INT8_C(-107),
                           INT8_C(-117), INT8_C(  63), INT8_C(  42), INT8_C(  79),
                           INT8_C( -78), INT8_C( -79), INT8_C( -22), INT8_C( -52),
                           INT8_C( -78), INT8_C(  -8), INT8_C( -61), INT8_C( 101),
                           INT8_C(-111), INT8_C(  35), INT8_C( -89), INT8_C( 127),
                           INT8_C(  50), INT8_C(-115), INT8_C(  91), INT8_C( -72),
                           INT8_C( -97), INT8_C( -34), INT8_C( -80), INT8_C( -31),
                           INT8_C( -60), INT8_C( 119), INT8_C(-106), INT8_C(  66),
                           INT8_C(  75), INT8_C(-108), INT8_C(-113), INT8_C( 120),
                           INT8_C(  36), INT8_C( 112), INT8_C( -45), INT8_C(  41),
                           INT8_C(  90), INT8_C( -32), INT8_C(  22), INT8_C(  86),
                           INT8_C(  72), INT8_C( -20), INT8_C(  -4), INT8_C(-125),
                           INT8_C( -37), INT8_C(  84), INT8_C( -95), INT8_C( -66),
                           INT8_C( 109), INT8_C(  18), INT8_C( 120), INT8_C(-115),
                           INT8_C(  83), INT8_C(  26), INT8_C(-108), INT8_C(-128),
                           INT8_C( 113), INT8_C( -65), INT8_C(  84), INT8_C( -78)),
      simde_mm512_set_epi8(INT8_C(-100), INT8_C(-107), INT8_C( 106), INT8_C( -87),
                           INT8_C(  61), INT8_C( -94), INT8_C(   7), INT8_C(  84),
                           INT8_C(  25), INT8_C(  77), INT8_C(  24), INT8_C(  35),
                           INT8_C(  56), INT8_C( -72), INT8_C(  65), INT8_C( -77),
                           INT8_C(  81), INT8_C( 110), INT8_C( 109), INT8_C(  26),
                           INT8_C( -46), INT8_C(   6), INT8_C(  -4), INT8_C( -76),
                           INT8_C(  49), INT8_C(  67), INT8_C( -22), INT8_C(  12),
                           INT8_C(  66), INT8_C( -76), INT8_C( -71), INT8_C(  20),
                           INT8_C( -11), INT8_C(  97), INT8_C(  20), INT8_C(  -1),
                           INT8_C(  69), INT8_C(  54), INT8_C( -68), INT8_C( 104),
                           INT8_C(  61), INT8_C( -16), INT8_C( -52), INT8_C( -98),
                           INT8_C(-126), INT8_C(-109), INT8_C(  86), INT8_C(  51),
                           INT8_C(  95), INT8_C( -88), INT8_C(   6), INT8_C(-121),
                           INT8_C(  49), INT8_C(  97), INT8_C( -69), INT8_C( 125),
                           INT8_C(  57), INT8_C(  79), INT8_C(   6), INT8_C(   7),
                           INT8_C(  37), INT8_C(-119), INT8_C( -51), INT8_C(  99)),
      simde_mm512_set_epi8(INT8_C( -60), INT8_C( -92), INT8_C( -73), INT8_C( -20),
                           INT8_C( -84), INT8_C( -11), INT8_C( -28), INT8_C(-123),
                           INT8_C( -48), INT8_C(-118), INT8_C(-107), INT8_C(  73),
                           INT8_C( -80), INT8_C(  46), INT8_C(-117), INT8_C( -85),
                           INT8_C( -21), INT8_C( -54), INT8_C( -49), INT8_C(  -8),
                           INT8_C(  51), INT8_C( 126), INT8_C(  22), INT8_C(  70),
                           INT8_C( -86), INT8_C( -98), INT8_C( -17), INT8_C( -29),
                           INT8_C(  75), INT8_C( 115), INT8_C(  61), INT8_C(  76),
                           INT8_C(  86), INT8_C(  43), INT8_C(-128), INT8_C( 121),
                           INT8_C(  81), INT8_C(  58), INT8_C(  -6), INT8_C( -15),
                           INT8_C( -40), INT8_C( -16), INT8_C(  74), INT8_C(  32),
                           INT8_C(  22), INT8_C(  89), INT8_C( -73), INT8_C(-128),
                           INT8_C(  75), INT8_C( 127), INT8_C( -97), INT8_C(  55),
                           INT8_C(  60), INT8_C(  32), INT8_C( 127), INT8_C(-108),
                           INT8_C(  26), INT8_C( -53), INT8_C(-114), INT8_C( -57),
                           INT8_C(  28), INT8_C( -50), INT8_C( 127), INT8_C(-128)) },
    { simde_mm512_set_epi8(INT8_C(  66), INT8_C(  28), INT8_C( -53), INT8_C(  48),
                           INT8_C( -75), INT8_C( -97), INT8_C( -42), INT8_C(  47),
                           INT8_C( -33), INT8_C( -17), INT8_C( 113), INT8_C( 120),
                           INT8_C(-111), INT8_C(  14), INT8_C(  77), INT8_C(-108),
                           INT8_C(  25), INT8_C( -42), INT8_C( 109), INT8_C( -97),
                           INT8_C( -19), INT8_C( -18), INT8_C(  -1), INT8_C( -50),
                           INT8_C( -87), INT8_C( -70), INT8_C(  94), INT8_C( -91),
                           INT8_C(  23), INT8_C(  33), INT8_C( -10), INT8_C(  81),
                           INT8_C(  81), INT8_C( -63), INT8_C(  35), INT8_C(  44),
                           INT8_C(  11), INT8_C(-124), INT8_C( -20), INT8_C(  71),
                           INT8_C( -25), INT8_C(-112), INT8_C(   2), INT8_C(  59),
                           INT8_C(  21), INT8_C(-113), INT8_C(  35), INT8_C( -40),
                           INT8_C( -89), INT8_C( -74), INT8_C( -34), INT8_C( 115),
                           INT8_C( -51), INT8_C(  30), INT8_C(-104), INT8_C( 117),
                           INT8_C( 127), INT8_C(  -8), INT8_C(  57), INT8_C( -73),
                           INT8_C(  40), INT8_C(  -7), INT8_C(  90), INT8_C(-110)),
      UINT64_C(          3345097188),
      simde_mm512_set_epi8(INT8_C(  58), INT8_C(-128), INT8_C(-123), INT8_C(  -3),
                           INT8_C(  74), INT8_C( -78), INT8_C(-124), INT8_C( -30),
                           INT8_C(  21), INT8_C(  86), INT8_C( -53), INT8_C(-116),
                           INT8_C(-126), INT8_C(  10), INT8_C(-123), INT8_C( -78),
                           INT8_C(   2), INT8_C( 100), INT8_C( -90), INT8_C( -79),
                           INT8_C( -46), INT8_C( -83), INT8_C(  11), INT8_C(-120),
                           INT8_C( -56), INT8_C(  -4), INT8_C( -39), INT8_C(-114),
                           INT8_C( -98), INT8_C(-108), INT8_C( -22), INT8_C(  24),
                           INT8_C( 127), INT8_C( -20), INT8_C(   7), INT8_C( -16),
                           INT8_C(  -8), INT8_C(  19), INT8_C( 119), INT8_C( -44),
                           INT8_C(   7), INT8_C( -47), INT8_C(-126), INT8_C(-119),
                           INT8_C(   1), INT8_C( 111), INT8_C( -95), INT8_C( -67),
                           INT8_C(  38), INT8_C( -19), INT8_C(  96), INT8_C( -21),
                           INT8_C( -76), INT8_C(-123), INT8_C(-115), INT8_C( -61),
                           INT8_C(  96), INT8_C(  30), INT8_C( 105), INT8_C(  -4),
                           INT8_C(  44), INT8_C(  54), INT8_C(  89), INT8_C(  40)),
      simde_mm512_set_epi8(INT8_C( -42), INT8_C(  43), INT8_C(   6), INT8_C( -97),
                           INT8_C( -90), INT8_C(  -4), INT8_C( -71), INT8_C(  33),
                           INT8_C(   1), INT8_C(   3), INT8_C( -91), INT8_C( -62),
                           INT8_C(-106), INT8_C(  -6), INT8_C(  35), INT8_C(  67),
                           INT8_C(  97), INT8_C(  46), INT8_C(  89), INT8_C(  56),
                           INT8_C( -84), INT8_C( -39), INT8_C( -70), INT8_C(  78),
                           INT8_C( -49), INT8_C(  94), INT8_C(  -1), INT8_C( -23),
                           INT8_C( -88), INT8_C( -11), INT8_C(-128), INT8_C( -62),
                           INT8_C( 106), INT8_C( 125), INT8_C( -71), INT8_C( -96),
                           INT8_C( -28), INT8_C( -58), INT8_C( -40), INT8_C( -32),
                           INT8_C( -13), INT8_C( -84), INT8_C( -69), INT8_C( -40),
                           INT8_C(-122), INT8_C( 117), INT8_C( 115), INT8_C( -87),
                           INT8_C( 101), INT8_C( -82), INT8_C( -68), INT8_C( -48),
                           INT8_C(  42), INT8_C(  29), INT8_C(  67), INT8_C(   9),
                           INT8_C( -44), INT8_C(  54), INT8_C(-101), INT8_C( -13),
                           INT8_C( 111), INT8_C( 110), INT8_C( 114), INT8_C( -57)),
      simde_mm512_set_epi8(INT8_C(  66), INT8_C(  28), INT8_C( -53), INT8_C(  48),
                           INT8_C( -75), INT8_C( -97), INT8_C( -42), INT8_C(  47),
                           INT8_C( -33), INT8_C( -17), INT8_C( 113), INT8_C( 120),
                           INT8_C(-111), INT8_C(  14), INT8_C(  77), INT8_C(-108),
                           INT8_C(  25), INT8_C( -42), INT8_C( 109), INT8_C( -97),
                           INT8_C( -19), INT8_C( -18), INT8_C(  -1), INT8_C( -50),
                           INT8_C( -87), INT8_C( -70), INT8_C(  94), INT8_C( -91),
                           INT8_C(  23), INT8_C(  33), INT8_C( -10), INT8_C(  81),
                           INT8_C(  21), INT8_C(-128), INT8_C(  35), INT8_C(  44),
                           INT8_C(  11), INT8_C(  77), INT8_C( 127), INT8_C( -12),
                           INT8_C( -25), INT8_C(  37), INT8_C( -57), INT8_C(  59),
                           INT8_C(  21), INT8_C(-113), INT8_C(-128), INT8_C( -40),
                           INT8_C( -89), INT8_C( -74), INT8_C( 127), INT8_C( 115),
                           INT8_C( -51), INT8_C(  30), INT8_C(-104), INT8_C( -70),
                           INT8_C( 127), INT8_C( -24), INT8_C( 127), INT8_C( -73),
                           INT8_C(  40), INT8_C( -56), INT8_C(  90), INT8_C(-110)) },
    { simde_mm512_set_epi8(INT8_C( 127), INT8_C(  66), INT8_C(  63), INT8_C( -46),
                           INT8_C(  90), INT8_C(  39), INT8_C( -89), INT8_C(-105),
                           INT8_C( -51), INT8_C( -46), INT8_C( 111), INT8_C( -45),
                           INT8_C( -76), INT8_C(-112), INT8_C( -37), INT8_C(-120),
                           INT8_C(  50), INT8_C( -97), INT8_C(  -2), INT8_C( 121),
                           INT8_C(  68), INT8_C(-106), INT8_C( 101), INT8_C( 115),
                           INT8_C( -29), INT8_C(  59), INT8_C(  77), INT8_C( -36),
                           INT8_C( 111), INT8_C(  95), INT8_C(  48), INT8_C( 113),
                           INT8_C( -97), INT8_C( 105), INT8_C( -37), INT8_C( -42),
                           INT8_C(  -7), INT8_C(  31), INT8_C(  45), INT8_C(  -5),
                           INT8_C( -29), INT8_C(  44), INT8_C(  78), INT8_C( -25),
                           INT8_C( -47), INT8_C(-119), INT8_C( -90), INT8_C( 115),
                           INT8_C(  44), INT8_C(  94), INT8_C( 127), INT8_C( -12),
                           INT8_C(  90), INT8_C( 111), INT8_C( -20), INT8_C(-110),
                           INT8_C( -82), INT8_C( -19), INT8_C( -79), INT8_C(-128),
                           INT8_C(  -6), INT8_C(-119), INT8_C( 100), INT8_C( 125)),
      UINT64_C(          1390729414),
      simde_mm512_set_epi8(INT8_C(  89), INT8_C(  39), INT8_C( 109), INT8_C( 109),
                           INT8_C( -71), INT8_C( -81), INT8_C(  67), INT8_C(  48),
                           INT8_C( -43), INT8_C(  31), INT8_C( -36), INT8_C( -53),
                           INT8_C(  -7), INT8_C(  84), INT8_C( -92), INT8_C( 124),
                           INT8_C( -22), INT8_C(  31), INT8_C(  42), INT8_C(-103),
                           INT8_C(  29), INT8_C(  75), INT8_C( -91), INT8_C(  75),
                           INT8_C( 107), INT8_C(  62), INT8_C( 126), INT8_C(   7),
                           INT8_C( -89), INT8_C( 119), INT8_C(  79), INT8_C( -38),
                           INT8_C(  18), INT8_C(  57), INT8_C(-102), INT8_C(  66),
                           INT8_C(  -7), INT8_C(  89), INT8_C(  57), INT8_C( -55),
                           INT8_C( -68), INT8_C(  21), INT8_C( -21), INT8_C(  -6),
                           INT8_C( -26), INT8_C( 122), INT8_C( 114), INT8_C(  83),
                           INT8_C(  80), INT8_C( 103), INT8_C( 109), INT8_C( -19),
                           INT8_C( -24), INT8_C( -48), INT8_C(  79), INT8_C(   5),
                           INT8_C(  66), INT8_C( -40), INT8_C( -14), INT8_C( -56),
                           INT8_C( -68), INT8_C( -68), INT8_C(-124), INT8_C( -65)),
      simde_mm512_set_epi8(INT8_C(-102), INT8_C(-123), INT8_C(  20), INT8_C(  36),
                           INT8_C(  70), INT8_C( -95), INT8_C(  63), INT8_C( 110),
                           INT8_C(  98), INT8_C(-128), INT8_C( -74), INT8_C( -50),
                           INT8_C(  17), INT8_C( -37), INT8_C(-104), INT8_C( -74),
                           INT8_C(  -4), INT8_C(  15), INT8_C( -59), INT8_C(  62),
                           INT8_C( -89), INT8_C( 103), INT8_C(  -5), INT8_C(  71),
                           INT8_C( 103), INT8_C(-119), INT8_C( -62), INT8_C( -47),
                           INT8_C( -78), INT8_C(  32), INT8_C( 104), INT8_C(  33),
                           INT8_C( -45), INT8_C( -54), INT8_C(  17), INT8_C(-117),
                           INT8_C(  96), INT8_C(  66), INT8_C( -18), INT8_C( -58),
                           INT8_C(-111), INT8_C(-110), INT8_C( -14), INT8_C(   7),
                           INT8_C(  85), INT8_C(-113), INT8_C(  19), INT8_C( -72),
                           INT8_C(  51), INT8_C( -49), INT8_C(  69), INT8_C( -80),
                           INT8_C(  34), INT8_C(  87), INT8_C(  88), INT8_C( -38),
                           INT8_C( -14), INT8_C( -30), INT8_C(-111), INT8_C( -87),
                           INT8_C(  37), INT8_C(  40), INT8_C( -30), INT8_C( -40)),
      simde_mm512_set_epi8(INT8_C( 127), INT8_C(  66), INT8_C(  63), INT8_C( -46),
                           INT8_C(  90), INT8_C(  39), INT8_C( -89), INT8_C(-105),
                           INT8_C( -51), INT8_C( -46), INT8_C( 111), INT8_C( -45),
                           INT8_C( -76), INT8_C(-112), INT8_C( -37), INT8_C(-120),
                           INT8_C(  50), INT8_C( -97), INT8_C(  -2), INT8_C( 121),
                           INT8_C(  68), INT8_C(-106), INT8_C( 101), INT8_C( 115),
                           INT8_C( -29), INT8_C(  59), INT8_C(  77), INT8_C( -36),
                           INT8_C( 111), INT8_C(  95), INT8_C(  48), INT8_C( 113),
                           INT8_C( -97), INT8_C( 111), INT8_C( -37), INT8_C( 127),
                           INT8_C(  -7), INT8_C(  31), INT8_C(  75), INT8_C(  -5),
                           INT8_C(  43), INT8_C( 127), INT8_C(  -7), INT8_C( -25),
                           INT8_C( -47), INT8_C( 127), INT8_C( -90), INT8_C( 115),
                           INT8_C(  29), INT8_C( 127), INT8_C( 127), INT8_C(  61),
                           INT8_C( -58), INT8_C( 111), INT8_C( -20), INT8_C(-110),
                           INT8_C(  80), INT8_C( -10), INT8_C( -79), INT8_C(-128),
                           INT8_C(  -6), INT8_C(-108), INT8_C( -94), INT8_C( 125)) },
    { simde_mm512_set_epi8(INT8_C(  91), INT8_C(  46), INT8_C( -16), INT8_C(  27),
                           INT8_C( -66), INT8_C( -93), INT8_C( -43), INT8_C(  14),
                           INT8_C( 100), INT8_C(-113), INT8_C(  32), INT8_C(  15),
                           INT8_C( -79), INT8_C(  63), INT8_C( -18), INT8_C( -96),
                           INT8_C(-119), INT8_C( 114), INT8_C( -87), INT8_C( -82),
                           INT8_C(  76), INT8_C( 117), INT8_C(  14), INT8_C( -65),
                           INT8_C( -37), INT8_C( -15), INT8_C(  43), INT8_C(   5),
                           INT8_C(-108), INT8_C(  -5), INT8_C( -84), INT8_C(  13),
                           INT8_C( -66), INT8_C(  80), INT8_C( -20), INT8_C(  34),
                           INT8_C(-122), INT8_C(-101), INT8_C( -91), INT8_C( -35),
                           INT8_C(  57), INT8_C( 117), INT8_C( -26), INT8_C( 112),
                           INT8_C(  59), INT8_C(  54), INT8_C(  91), INT8_C(-111),
                           INT8_C( 111), INT8_C(  34), INT8_C( -76), INT8_C(  65),
                           INT8_C( -31), INT8_C(  25), INT8_C( -63), INT8_C(-128),
                           INT8_C( -28), INT8_C(  80), INT8_C( -75), INT8_C(  83),
                           INT8_C( -23), INT8_C( -65), INT8_C( -75), INT8_C( -10)),
      UINT64_C(          2530018527),
      simde_mm512_set_epi8(INT8_C(  54), INT8_C( 110), INT8_C( -53), INT8_C( 100),
                           INT8_C(  94), INT8_C(  -2), INT8_C(  72), INT8_C(  95),
                           INT8_C( -61), INT8_C( -31), INT8_C(   2), INT8_C(  88),
                           INT8_C(  69), INT8_C(-117), INT8_C(  33), INT8_C( -57),
                           INT8_C( -67), INT8_C(  92), INT8_C( -31), INT8_C( -16),
                           INT8_C(-115), INT8_C( -91), INT8_C(   0), INT8_C( -73),
                           INT8_C(  -3), INT8_C( -71), INT8_C(  55), INT8_C( -82),
                           INT8_C( -28), INT8_C( -34), INT8_C( -40), INT8_C(  60),
                           INT8_C(  31), INT8_C(-113), INT8_C(  90), INT8_C( 114),
                           INT8_C(  73), INT8_C(  77), INT8_C( -29), INT8_C(  80),
                           INT8_C(-106), INT8_C( 121), INT8_C(-122), INT8_C(  -4),
                           INT8_C( 104), INT8_C( -76), INT8_C(  85), INT8_C( -33),
                           INT8_C( -62), INT8_C(  96), INT8_C( -27), INT8_C( -88),
                           INT8_C( -35), INT8_C( -58), INT8_C( -83), INT8_C(  36),
                           INT8_C( -16), INT8_C(  50), INT8_C(-127), INT8_C( -82),
                           INT8_C( 106), INT8_C(  56), INT8_C(  74), INT8_C( -59)),
      simde_mm512_set_epi8(INT8_C( -24), INT8_C( -30), INT8_C(  27), INT8_C( -44),
                           INT8_C( -74), INT8_C( -85), INT8_C( -66), INT8_C(  26),
                           INT8_C( -69), INT8_C( 112), INT8_C( -22), INT8_C(  62),
                           INT8_C(  24), INT8_C(-107), INT8_C( -41), INT8_C( -21),
                           INT8_C(  68), INT8_C( -34), INT8_C( 109), INT8_C(  58),
                           INT8_C(  16), INT8_C( -72), INT8_C( -84), INT8_C(  18),
                           INT8_C( -73), INT8_C( -54), INT8_C(  16), INT8_C( -93),
                           INT8_C( -51), INT8_C( -50), INT8_C(  54), INT8_C( -69),
                           INT8_C( -98), INT8_C(-113), INT8_C( -73), INT8_C(-124),
                           INT8_C( -65), INT8_C( -51), INT8_C(  43), INT8_C(  10),
                           INT8_C( -79), INT8_C(  35), INT8_C( -67), INT8_C(  69),
                           INT8_C(  84), INT8_C( -44), INT8_C( -48), INT8_C(  89),
                           INT8_C(  96), INT8_C(-100), INT8_C( -47), INT8_C( 114),
                           INT8_C(-109), INT8_C(   8), INT8_C(  51), INT8_C( 120),
                           INT8_C( -12), INT8_C(-128), INT8_C(  -4), INT8_C(-105),
                           INT8_C(  83), INT8_C(-123), INT8_C( -98), INT8_C(  -2)),
      simde_mm512_set_epi8(INT8_C(  91), INT8_C(  46), INT8_C( -16), INT8_C(  27),
                           INT8_C( -66), INT8_C( -93), INT8_C( -43), INT8_C(  14),
                           INT8_C( 100), INT8_C(-113), INT8_C(  32), INT8_C(  15),
                           INT8_C( -79), INT8_C(  63), INT8_C( -18), INT8_C( -96),
                           INT8_C(-119), INT8_C( 114), INT8_C( -87), INT8_C( -82),
                           INT8_C(  76), INT8_C( 117), INT8_C(  14), INT8_C( -65),
                           INT8_C( -37), INT8_C( -15), INT8_C(  43), INT8_C(   5),
                           INT8_C(-108), INT8_C(  -5), INT8_C( -84), INT8_C(  13),
                           INT8_C( 127), INT8_C(  80), INT8_C( -20), INT8_C( 127),
                           INT8_C(-122), INT8_C( 127), INT8_C( -72), INT8_C( -35),
                           INT8_C( -27), INT8_C(  86), INT8_C( -26), INT8_C( 112),
                           INT8_C(  20), INT8_C( -32), INT8_C(  91), INT8_C(-122),
                           INT8_C( 111), INT8_C(  34), INT8_C( -76), INT8_C(  65),
                           INT8_C( -31), INT8_C( -66), INT8_C( -63), INT8_C(-128),
                           INT8_C(  -4), INT8_C( 127), INT8_C( -75), INT8_C(  23),
                           INT8_C(  23), INT8_C( 127), INT8_C( 127), INT8_C( -57)) },
    { simde_mm512_set_epi8(INT8_C( 125), INT8_C( -29), INT8_C( 116), INT8_C( -26),
                           INT8_C(  78), INT8_C(  37), INT8_C( -43), INT8_C(  45),
                           INT8_C( -81), INT8_C(-109), INT8_C(  26), INT8_C( -51),
                           INT8_C( -54), INT8_C(  99), INT8_C( 124), INT8_C(   2),
                           INT8_C(  10), INT8_C(   6), INT8_C( -77), INT8_C( -61),
                           INT8_C(  59), INT8_C(  60), INT8_C(  42), INT8_C(  33),
                           INT8_C( 126), INT8_C(  88), INT8_C(  41), INT8_C(  66),
                           INT8_C(  98), INT8_C( 111), INT8_C(  94), INT8_C( -70),
                           INT8_C( 116), INT8_C( -40), INT8_C( -88), INT8_C(  13),
                           INT8_C(  50), INT8_C(  54), INT8_C(  32), INT8_C( -48),
                           INT8_C(  85), INT8_C(  12), INT8_C( -17), INT8_C(  78),
                           INT8_C(   2), INT8_C( -46), INT8_C(  21), INT8_C(  89),
                           INT8_C( -58), INT8_C( -19), INT8_C(  -7), INT8_C( -46),
                           INT8_C(  58), INT8_C( 120), INT8_C( -85), INT8_C(  46),
                           INT8_C(  80), INT8_C( -20), INT8_C(  94), INT8_C(  32),
                           INT8_C( -61), INT8_C(  80), INT8_C( -39), INT8_C( 109)),
      UINT64_C(          1874542844),
      simde_mm512_set_epi8(INT8_C(-100), INT8_C(   8), INT8_C( -30), INT8_C( -66),
                           INT8_C( -36), INT8_C( -55), INT8_C(-115), INT8_C(  64),
                           INT8_C(  70), INT8_C(  -8), INT8_C(-128), INT8_C(  84),
                           INT8_C( 103), INT8_C( -54), INT8_C(  15), INT8_C( -45),
                           INT8_C(-118), INT8_C( -27), INT8_C(  32), INT8_C( -75),
                           INT8_C(  62), INT8_C(  67), INT8_C( -42), INT8_C(   4),
                           INT8_C(  16), INT8_C(  45), INT8_C(  43), INT8_C(  21),
                           INT8_C(  14), INT8_C( -97), INT8_C( -37), INT8_C(  -6),
                           INT8_C(-100), INT8_C( -82), INT8_C(  58), INT8_C(  88),
                           INT8_C(  61), INT8_C(  74), INT8_C(   5), INT8_C(  44),
                           INT8_C(  61), INT8_C( -83), INT8_C(  68), INT8_C(  -3),
                           INT8_C(  41), INT8_C( 117), INT8_C( 116), INT8_C( -16),
                           INT8_C(  48), INT8_C( -35), INT8_C(  -2), INT8_C(  -9),
                           INT8_C( -72), INT8_C(  97), INT8_C(-100), INT8_C( 120),
                           INT8_C( -96), INT8_C(  21), INT8_C(  35), INT8_C(  38),
                           INT8_C( -30), INT8_C(  81), INT8_C(-111), INT8_C(  42)),
      simde_mm512_set_epi8(INT8_C( -63), INT8_C( 101), INT8_C( -21), INT8_C( -29),
                           INT8_C( -58), INT8_C(  75), INT8_C( -46), INT8_C(  -8),
                           INT8_C( -92), INT8_C(  68), INT8_C(  64), INT8_C(  71),
                           INT8_C(  50), INT8_C( -60), INT8_C(  45), INT8_C(  13),
                           INT8_C( 106), INT8_C(  39), INT8_C(  64), INT8_C(  94),
                           INT8_C( -73), INT8_C(  90), INT8_C( -93), INT8_C(-109),
                           INT8_C(-100), INT8_C(  76), INT8_C(  29), INT8_C( -99),
                           INT8_C(  84), INT8_C(  37), INT8_C(  69), INT8_C( 125),
                           INT8_C( -66), INT8_C( 106), INT8_C(  75), INT8_C(-109),
                           INT8_C(  19), INT8_C( 119), INT8_C( 108), INT8_C(  52),
                           INT8_C( -69), INT8_C(  84), INT8_C(   6), INT8_C(  75),
                           INT8_C(   9), INT8_C(-103), INT8_C( -24), INT8_C(   9),
                           INT8_C( -42), INT8_C( 127), INT8_C(  47), INT8_C( -53),
                           INT8_C(  93), INT8_C(  18), INT8_C(  -4), INT8_C( -42),
                           INT8_C( -20), INT8_C(  12), INT8_C( 100), INT8_C( -66),
                           INT8_C( -56), INT8_C( -47), INT8_C( -16), INT8_C( 104)),
      simde_mm512_set_epi8(INT8_C( 125), INT8_C( -29), INT8_C( 116), INT8_C( -26),
                           INT8_C(  78), INT8_C(  37), INT8_C( -43), INT8_C(  45),
                           INT8_C( -81), INT8_C(-109), INT8_C(  26), INT8_C( -51),
                           INT8_C( -54), INT8_C(  99), INT8_C( 124), INT8_C(   2),
                           INT8_C(  10), INT8_C(   6), INT8_C( -77), INT8_C( -61),
                           INT8_C(  59), INT8_C(  60), INT8_C(  42), INT8_C(  33),
                           INT8_C( 126), INT8_C(  88), INT8_C(  41), INT8_C(  66),
                           INT8_C(  98), INT8_C( 111), INT8_C(  94), INT8_C( -70),
                           INT8_C( 116), INT8_C(-128), INT8_C( -17), INT8_C(  13),
                           INT8_C(  42), INT8_C( -45), INT8_C(-103), INT8_C(  -8),
                           INT8_C( 127), INT8_C(  12), INT8_C(  62), INT8_C( -78),
                           INT8_C(  32), INT8_C( -46), INT8_C( 127), INT8_C( -25),
                           INT8_C( -58), INT8_C(-128), INT8_C(  -7), INT8_C( -46),
                           INT8_C(  58), INT8_C( 120), INT8_C( -85), INT8_C(  46),
                           INT8_C( -76), INT8_C(   9), INT8_C( -65), INT8_C( 104),
                           INT8_C(  26), INT8_C( 127), INT8_C( -39), INT8_C( 109)) },
    { simde_mm512_set_epi8(INT8_C(-105), INT8_C( -37), INT8_C(  57), INT8_C( -65),
                           INT8_C( -18), INT8_C( -12), INT8_C( -19), INT8_C( 108),
                           INT8_C(-104), INT8_C( -75), INT8_C(  90), INT8_C(  70),
                           INT8_C( -27), INT8_C(  72), INT8_C(  24), INT8_C( -76),
                           INT8_C( -96), INT8_C(-123), INT8_C(  29), INT8_C(-106),
                           INT8_C(  55), INT8_C( 118), INT8_C(  81), INT8_C(  39),
                           INT8_C( -71), INT8_C( -44), INT8_C( 102), INT8_C( -78),
                           INT8_C( -31), INT8_C( -59), INT8_C(  63), INT8_C(   2),
                           INT8_C(-102), INT8_C(  50), INT8_C(  51), INT8_C(-105),
                           INT8_C( -79), INT8_C(  83), INT8_C(  28), INT8_C( 101),
                           INT8_C(  60), INT8_C( -89), INT8_C(-127), INT8_C(  40),
                           INT8_C(  37), INT8_C( -30), INT8_C( -95), INT8_C( -95),
                           INT8_C( -12), INT8_C( -31), INT8_C(  -9), INT8_C(  29),
                           INT8_C(  10), INT8_C(  43), INT8_C(  -6), INT8_C( -78),
                           INT8_C( -94), INT8_C( 107), INT8_C( 111), INT8_C(   4),
                           INT8_C(  -9), INT8_C(  42), INT8_C( -92), INT8_C(  29)),
      UINT64_C(          3975530942),
      simde_mm512_set_epi8(INT8_C( -43), INT8_C(  17), INT8_C(-121), INT8_C(  17),
                           INT8_C( -38), INT8_C(  95), INT8_C(  94), INT8_C( -34),
                           INT8_C(  26), INT8_C(-107), INT8_C(  37), INT8_C(-105),
                           INT8_C(  52), INT8_C(  37), INT8_C(  92), INT8_C( -72),
                           INT8_C( -33), INT8_C( -75), INT8_C( -94), INT8_C(   1),
                           INT8_C( -71), INT8_C(  17), INT8_C(-112), INT8_C( -35),
                           INT8_C(  16), INT8_C( 122), INT8_C( -73), INT8_C(  18),
                           INT8_C(  88), INT8_C(  56), INT8_C( -10), INT8_C( -55),
                           INT8_C( 123), INT8_C(-125), INT8_C( -53), INT8_C(  -1),
                           INT8_C(   2), INT8_C(  36), INT8_C( 121), INT8_C( -35),
                           INT8_C(  48), INT8_C(  77), INT8_C( 102), INT8_C( -56),
                           INT8_C(  57), INT8_C( -53), INT8_C( -69), INT8_C( -26),
                           INT8_C( -26), INT8_C(  90), INT8_C(  94), INT8_C(  84),
                           INT8_C( -13), INT8_C(  64), INT8_C( 115), INT8_C(-119),
                           INT8_C( 126), INT8_C(  83), INT8_C(  55), INT8_C( -37),
                           INT8_C( -59), INT8_C(  31), INT8_C(  24), INT8_C(  17)),
      simde_mm512_set_epi8(INT8_C(  74), INT8_C(  90), INT8_C(  31), INT8_C(  63),
                           INT8_C( -50), INT8_C(   3), INT8_C(  34), INT8_C( -98),
                           INT8_C( -18), INT8_C(-126), INT8_C(  83), INT8_C(  80),
                           INT8_C(  21), INT8_C( 114), INT8_C( -45), INT8_C( -76),
                           INT8_C( -10), INT8_C( -63), INT8_C( -36), INT8_C(-104),
                           INT8_C( -48), INT8_C( -29), INT8_C( -85), INT8_C(   3),
                           INT8_C(-112), INT8_C( -72), INT8_C(  68), INT8_C(   5),
                           INT8_C( -84), INT8_C( -48), INT8_C(-110), INT8_C(-128),
                           INT8_C(  89), INT8_C( -17), INT8_C(  -2), INT8_C( -14),
                           INT8_C(  61), INT8_C(  40), INT8_C( -41), INT8_C(  78),
                           INT8_C( -65), INT8_C(  82), INT8_C( -97), INT8_C(-107),
                           INT8_C(  36), INT8_C(  59), INT8_C( -78), INT8_C(  61),
                           INT8_C(   9), INT8_C(  86), INT8_C( 122), INT8_C(   2),
                           INT8_C(  27), INT8_C( 124), INT8_C( -38), INT8_C(  23),
                           INT8_C( -78), INT8_C(  48), INT8_C(  17), INT8_C(  54),
                           INT8_C( 116), INT8_C(-115), INT8_C( 105), INT8_C( -48)),
      simde_mm512_set_epi8(INT8_C(-105), INT8_C( -37), INT8_C(  57), INT8_C( -65),
                           INT8_C( -18), INT8_C( -12), INT8_C( -19), INT8_C( 108),
                           INT8_C(-104), INT8_C( -75), INT8_C(  90), INT8_C(  70),
                           INT8_C( -27), INT8_C(  72), INT8_C(  24), INT8_C( -76),
                           INT8_C( -96), INT8_C(-123), INT8_C(  29), INT8_C(-106),
                           INT8_C(  55), INT8_C( 118), INT8_C(  81), INT8_C(  39),
                           INT8_C( -71), INT8_C( -44), INT8_C( 102), INT8_C( -78),
                           INT8_C( -31), INT8_C( -59), INT8_C(  63), INT8_C(   2),
                           INT8_C(  34), INT8_C(-108), INT8_C( -51), INT8_C(-105),
                           INT8_C( -59), INT8_C(  -4), INT8_C(  28), INT8_C( 101),
                           INT8_C( 113), INT8_C(  -5), INT8_C( 127), INT8_C(  51),
                           INT8_C(  37), INT8_C(-112), INT8_C( -95), INT8_C( -87),
                           INT8_C( -35), INT8_C(   4), INT8_C(  -9), INT8_C(  29),
                           INT8_C( -40), INT8_C(  43), INT8_C(  -6), INT8_C(-128),
                           INT8_C( 127), INT8_C( 107), INT8_C(  38), INT8_C( -91),
                           INT8_C(-128), INT8_C( 127), INT8_C( -81), INT8_C(  29)) },
    { simde_mm512_set_epi8(INT8_C( -61), INT8_C( -50), INT8_C( -30), INT8_C( 100),
                           INT8_C( -32), INT8_C(-100), INT8_C(   0), INT8_C( -53),
                           INT8_C( -74), INT8_C(  41), INT8_C(  37), INT8_C(  44),
                           INT8_C(   4), INT8_C( -98), INT8_C(  73), INT8_C( -60),
                           INT8_C(  85), INT8_C(  11), INT8_C(  90), INT8_C(  41),
                           INT8_C(  94), INT8_C( 105), INT8_C(  -3), INT8_C( -61),
                           INT8_C( 118), INT8_C( -95), INT8_C(-121), INT8_C( -38),
                           INT8_C(-104), INT8_C(  36), INT8_C(  86), INT8_C(  49),
                           INT8_C( 118), INT8_C( -55), INT8_C( -12), INT8_C( -47),
                           INT8_C(  98), INT8_C(  69), INT8_C(-107), INT8_C( 120),
                           INT8_C(  49), INT8_C( 116), INT8_C( -55), INT8_C( -29),
                           INT8_C(  93), INT8_C(-120), INT8_C( 116), INT8_C(  -2),
                           INT8_C(-100), INT8_C(-116), INT8_C( -60), INT8_C( -65),
                           INT8_C(  55), INT8_C(  64), INT8_C( -42), INT8_C( -46),
                           INT8_C(-101), INT8_C(  -6), INT8_C( -22), INT8_C(  36),
                           INT8_C( 111), INT8_C( -33), INT8_C(  84), INT8_C(  25)),
      UINT64_C(          2085281943),
      simde_mm512_set_epi8(INT8_C( 125), INT8_C(   0), INT8_C(  14), INT8_C(  82),
                           INT8_C(  68), INT8_C( -35), INT8_C( -43), INT8_C(  -7),
                           INT8_C(  68), INT8_C( 127), INT8_C( -94), INT8_C( -60),
                           INT8_C( -16), INT8_C( -81), INT8_C(-125), INT8_C(  75),
                           INT8_C(  -5), INT8_C( 103), INT8_C(  97), INT8_C( -56),
                           INT8_C(   5), INT8_C(  -6), INT8_C(  40), INT8_C(  58),
                           INT8_C( 106), INT8_C(-112), INT8_C( -85), INT8_C(   2),
                           INT8_C(  42), INT8_C( -58), INT8_C( -70), INT8_C( -97),
                           INT8_C(  95), INT8_C(  14), INT8_C( 116), INT8_C( -67),
                           INT8_C(   1), INT8_C(  68), INT8_C( -54), INT8_C( -13),
                           INT8_C( -11), INT8_C( -60), INT8_C( -44), INT8_C( 102),
                           INT8_C(  -9), INT8_C( -71), INT8_C( -51), INT8_C(  40),
                           INT8_C(   0), INT8_C( -81), INT8_C(  85), INT8_C(-103),
                           INT8_C(  21), INT8_C( 112), INT8_C(  59), INT8_C( -49),
                           INT8_C( -57), INT8_C(  28), INT8_C( -72), INT8_C( -76),
                           INT8_C( -32), INT8_C( -46), INT8_C( -10), INT8_C(  43)),
      simde_mm512_set_epi8(INT8_C(  65), INT8_C(  28), INT8_C( 112), INT8_C(  84),
                           INT8_C( -84), INT8_C(  90), INT8_C(  43), INT8_C( -27),
                           INT8_C(  82), INT8_C( -68), INT8_C( -29), INT8_C(-114),
                           INT8_C(  96), INT8_C(  68), INT8_C(  41), INT8_C(  -5),
                           INT8_C(  60), INT8_C(  55), INT8_C(  65), INT8_C(  51),
                           INT8_C(-116), INT8_C(  90), INT8_C( 113), INT8_C(  72),
                           INT8_C( 119), INT8_C( -14), INT8_C(  52), INT8_C(  73),
                           INT8_C( -28), INT8_C( -61), INT8_C(  83), INT8_C(  94),
                           INT8_C( 116), INT8_C( -75), INT8_C(   6), INT8_C( -97),
                           INT8_C( 114), INT8_C( 125), INT8_C( -13), INT8_C( -39),
                           INT8_C( -76), INT8_C( -78), INT8_C( 126), INT8_C(  42),
                           INT8_C( -31), INT8_C(-119), INT8_C(  44), INT8_C( -13),
                           INT8_C(  39), INT8_C(  26), INT8_C( 103), INT8_C( 126),
                           INT8_C( -63), INT8_C( -48), INT8_C( -12), INT8_C(  54),
                           INT8_C( -42), INT8_C(  31), INT8_C(   1), INT8_C( 119),
                           INT8_C( -34), INT8_C( -59), INT8_C(-107), INT8_C( 102)),
      simde_mm512_set_epi8(INT8_C( -61), INT8_C( -50), INT8_C( -30), INT8_C( 100),
                           INT8_C( -32), INT8_C(-100), INT8_C(   0), INT8_C( -53),
                           INT8_C( -74), INT8_C(  41), INT8_C(  37), INT8_C(  44),
                           INT8_C(   4), INT8_C( -98), INT8_C(  73), INT8_C( -60),
                           INT8_C(  85), INT8_C(  11), INT8_C(  90), INT8_C(  41),
                           INT8_C(  94), INT8_C( 105), INT8_C(  -3), INT8_C( -61),
                           INT8_C( 118), INT8_C( -95), INT8_C(-121), INT8_C( -38),
                           INT8_C(-104), INT8_C(  36), INT8_C(  86), INT8_C(  49),
                           INT8_C( 118), INT8_C(  89), INT8_C( 110), INT8_C(  30),
                           INT8_C(-113), INT8_C( -57), INT8_C(-107), INT8_C( 120),
                           INT8_C(  49), INT8_C(  18), INT8_C( -55), INT8_C( -29),
                           INT8_C(  22), INT8_C(-120), INT8_C( -95), INT8_C(  -2),
                           INT8_C( -39), INT8_C(-107), INT8_C( -18), INT8_C( -65),
                           INT8_C(  55), INT8_C(  64), INT8_C( -42), INT8_C( -46),
                           INT8_C( -15), INT8_C(  -6), INT8_C( -22), INT8_C(-128),
                           INT8_C( 111), INT8_C(  13), INT8_C(  97), INT8_C( -59)) }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])); i++) {
    simde__m512i r = simde_mm512_mask_subs_epi8(test_vec[i].src, test_vec[i].k, test_vec[i].a, test_vec[i].b);
    simde_assert_m512i_i8(r, ==, test_vec[i].r);
  }

  return 0;
}

static int
test_simde_mm512_maskz_subs_epi8(SIMDE_MUNIT_TEST_ARGS) {
  const struct {
    simde__mmask64 k;
    simde__m512i a;
    simde__m512i b;
    simde__m512i r;
  } test_vec[8] = {
    { UINT64_C(          2568138505),
      simde_mm512_set_epi8(INT8_C(  65), INT8_C( -91), INT8_C( -13), INT8_C( 114),
                           INT8_C( 123), INT8_C( 107), INT8_C(-108), INT8_C(  15),
                           INT8_C(  52), INT8_C(-124), INT8_C( -17), INT8_C(  -9),
                           INT8_C(  31), INT8_C(  67), INT8_C( -76), INT8_C(  -4),
                           INT8_C( -52), INT8_C(  99), INT8_C( 106), INT8_C( -35),
                           INT8_C(-115), INT8_C(-127), INT8_C( 121), INT8_C( -60),
                           INT8_C( -27), INT8_C(  73), INT8_C( -21), INT8_C( -51),
                           INT8_C(-127), INT8_C(  68), INT8_C( 109), INT8_C(  35),
                           INT8_C(  96), INT8_C(   3), INT8_C( -62), INT8_C( -43),
                           INT8_C( -75), INT8_C( 102), INT8_C(-105), INT8_C(  63),
                           INT8_C(  64), INT8_C( 114), INT8_C( 112), INT8_C(  10),
                           INT8_C( 108), INT8_C(  71), INT8_C( -40), INT8_C(  20),
                           INT8_C( -40), INT8_C(  26), INT8_C( -94), INT8_C( 107),
                           INT8_C( -89), INT8_C(  22), INT8_C(  55), INT8_C( 105),
                           INT8_C(  23), INT8_C(  52), INT8_C(  82), INT8_C(  50),
                           INT8_C( -48), INT8_C(  77), INT8_C(  73), INT8_C(  98)),
      simde_mm512_set_epi8(INT8_C(  87), INT8_C( 118), INT8_C(  10), INT8_C( -53),
                           INT8_C( -21), INT8_C( -77), INT8_C(  81), INT8_C(  16),
                           INT8_C( 125), INT8_C(  53), INT8_C( -93), INT8_C( -44),
                           INT8_C( -14), INT8_C( -81), INT8_C(  93), INT8_C( -81),
                           INT8_C(  69), INT8_C(  88), INT8_C(  17), INT8_C(-127),
                           INT8_C(  49), INT8_C(  91), INT8_C(  55), INT8_C( -23),
                           INT8_C( -84), INT8_C(  12), INT8_C( -97), INT8_C( -75),
                           INT8_C(  99), INT8_C(  54), INT8_C( -92), INT8_C( -28),
                           INT8_C(  -2), INT8_C(  69), INT8_C(-102), INT8_C(  42),
                           INT8_C(  41), INT8_C(-101), INT8_C( -59), INT8_C( -72),
                           INT8_C( -53), INT8_C( -47), INT8_C( -78), INT8_C(  67),
                           INT8_C(  54), INT8_C(  12), INT8_C( -65), INT8_C( 101),
                           INT8_C(  77), INT8_C( -96), INT8_C( -15), INT8_C(  66),
                           INT8_C(  50), INT8_C(   9), INT8_C( -75), INT8_C( 102),
                           INT8_C(   2), INT8_C( -31), INT8_C(  83), INT8_C( -71),
                           INT8_C( -84), INT8_C( -66), INT8_C(-111), INT8_C(  -2)),
      simde_mm512_set_epi8(INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(  98), INT8_C(   0), INT8_C(   0), INT8_C( -85),
                           INT8_C(-116), INT8_C(   0), INT8_C(   0), INT8_C( 127),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C( -57),
                           INT8_C(   0), INT8_C(   0), INT8_C(  25), INT8_C(   0),
                           INT8_C(-117), INT8_C(   0), INT8_C( -79), INT8_C(   0),
                           INT8_C(-128), INT8_C(  13), INT8_C( 127), INT8_C(   3),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(  36), INT8_C(   0), INT8_C(   0), INT8_C( 100)) },
    { UINT64_C(          2987001584),
      simde_mm512_set_epi8(INT8_C(  31), INT8_C( 110), INT8_C(-101), INT8_C( -57),
                           INT8_C(  28), INT8_C( -50), INT8_C( -16), INT8_C(  37),
                           INT8_C(  87), INT8_C(-105), INT8_C(  96), INT8_C( -79),
                           INT8_C(  99), INT8_C(  74), INT8_C(  20), INT8_C( 120),
                           INT8_C(  60), INT8_C(  49), INT8_C( 101), INT8_C( -94),
                           INT8_C(  -5), INT8_C( 114), INT8_C(  17), INT8_C(   1),
                           INT8_C(  36), INT8_C( -92), INT8_C(  39), INT8_C(-108),
                           INT8_C( -15), INT8_C(  14), INT8_C( -15), INT8_C(  79),
                           INT8_C( 112), INT8_C( 108), INT8_C( -44), INT8_C( -18),
                           INT8_C( 125), INT8_C(  93), INT8_C( -92), INT8_C( -51),
                           INT8_C(  21), INT8_C( -19), INT8_C( -56), INT8_C( 114),
                           INT8_C( -95), INT8_C(  40), INT8_C( -27), INT8_C( -85),
                           INT8_C(  26), INT8_C(  29), INT8_C( -30), INT8_C(  53),
                           INT8_C( -69), INT8_C( -26), INT8_C(  79), INT8_C(-124),
                           INT8_C( -35), INT8_C( -29), INT8_C( -59), INT8_C( -99),
                           INT8_C(-118), INT8_C(  30), INT8_C( 105), INT8_C(   3)),
      simde_mm512_set_epi8(INT8_C( 100), INT8_C(-112), INT8_C( 127), INT8_C(  -1),
                           INT8_C( -76), INT8_C( 101), INT8_C(  90), INT8_C( -29),
                           INT8_C( -60), INT8_C( -92), INT8_C( -73), INT8_C( -20),
                           INT8_C( -84), INT8_C( -11), INT8_C( -28), INT8_C(-123),
                           INT8_C( -48), INT8_C(-118), INT8_C(-107), INT8_C(  73),
                           INT8_C( -80), INT8_C(  46), INT8_C(-117), INT8_C( -85),
                           INT8_C( -21), INT8_C( -54), INT8_C( -49), INT8_C(  -8),
                           INT8_C(  51), INT8_C( 126), INT8_C(  22), INT8_C(  70),
                           INT8_C( -86), INT8_C( -98), INT8_C( -17), INT8_C( -29),
                           INT8_C(  75), INT8_C( 115), INT8_C(  61), INT8_C(  76),
                           INT8_C( -65), INT8_C(  43), INT8_C( -13), INT8_C(  -2),
                           INT8_C(  81), INT8_C( -26), INT8_C(  -6), INT8_C( -15),
                           INT8_C( -40), INT8_C(  72), INT8_C(  66), INT8_C(  32),
                           INT8_C(  22), INT8_C( -74), INT8_C( -73), INT8_C(  67),
                           INT8_C(  75), INT8_C( -18), INT8_C( -97), INT8_C(  75),
                           INT8_C( -47), INT8_C(  32), INT8_C(  26), INT8_C(-108)),
      simde_mm512_set_epi8(INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C( 127), INT8_C(   0), INT8_C( -27), INT8_C(  11),
                           INT8_C(   0), INT8_C(   0), INT8_C(-128), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(-128), INT8_C(   0), INT8_C( -21), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(  48), INT8_C( 127), INT8_C(   0),
                           INT8_C(-110), INT8_C( -11), INT8_C(  38), INT8_C(-128),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0)) },
    { UINT64_C(          1908364466),
      simde_mm512_set_epi8(INT8_C(  57), INT8_C(  79), INT8_C(   6), INT8_C(   7),
                           INT8_C(  37), INT8_C(-119), INT8_C( -51), INT8_C(  99),
                           INT8_C( -66), INT8_C( -12), INT8_C( -24), INT8_C(-107),
                           INT8_C(-117), INT8_C(  63), INT8_C(  42), INT8_C(  79),
                           INT8_C( -78), INT8_C( -79), INT8_C( -22), INT8_C( -52),
                           INT8_C( -78), INT8_C(  -8), INT8_C( -61), INT8_C( 101),
                           INT8_C(-111), INT8_C(  35), INT8_C( -89), INT8_C( 127),
                           INT8_C(  50), INT8_C(-115), INT8_C(  91), INT8_C( -72),
                           INT8_C( -97), INT8_C( -34), INT8_C( -80), INT8_C( -31),
                           INT8_C( -60), INT8_C( 119), INT8_C(-106), INT8_C(  66),
                           INT8_C(  75), INT8_C(-108), INT8_C(-113), INT8_C( 120),
                           INT8_C(  36), INT8_C( 112), INT8_C( -45), INT8_C(  41),
                           INT8_C(  90), INT8_C( -32), INT8_C(  22), INT8_C(  86),
                           INT8_C(  72), INT8_C( -20), INT8_C(  -4), INT8_C(-125),
                           INT8_C( -37), INT8_C(  84), INT8_C( -95), INT8_C( -66),
                           INT8_C( 109), INT8_C(  18), INT8_C( 120), INT8_C(-115)),
      simde_mm512_set_epi8(INT8_C( 127), INT8_C(  -8), INT8_C(  57), INT8_C( -73),
                           INT8_C(  40), INT8_C(  -7), INT8_C(  90), INT8_C(-110),
                           INT8_C(-100), INT8_C(-107), INT8_C( 106), INT8_C( -87),
                           INT8_C(  61), INT8_C( -94), INT8_C(   7), INT8_C(  84),
                           INT8_C(  25), INT8_C(  77), INT8_C(  24), INT8_C(  35),
                           INT8_C(  56), INT8_C( -72), INT8_C(  65), INT8_C( -77),
                           INT8_C(  81), INT8_C( 110), INT8_C( 109), INT8_C(  26),
                           INT8_C( -46), INT8_C(   6), INT8_C(  -4), INT8_C( -76),
                           INT8_C(  49), INT8_C(  67), INT8_C( -22), INT8_C(  12),
                           INT8_C(  66), INT8_C( -76), INT8_C( -71), INT8_C(  20),
                           INT8_C( -11), INT8_C(  97), INT8_C(  20), INT8_C(  -1),
                           INT8_C(  69), INT8_C(  54), INT8_C( -68), INT8_C( 104),
                           INT8_C(  61), INT8_C( -16), INT8_C( -52), INT8_C( -98),
                           INT8_C(-126), INT8_C(-109), INT8_C(  86), INT8_C(  51),
                           INT8_C(  95), INT8_C( -88), INT8_C(   6), INT8_C(-121),
                           INT8_C(  49), INT8_C(  97), INT8_C( -69), INT8_C( 125)),
      simde_mm512_set_epi8(INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(-101), INT8_C( -58), INT8_C( -43),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(  46),
                           INT8_C(  86), INT8_C(   0), INT8_C(-128), INT8_C( 121),
                           INT8_C( -33), INT8_C(  58), INT8_C(  23), INT8_C( -63),
                           INT8_C(   0), INT8_C( -16), INT8_C(   0), INT8_C( 127),
                           INT8_C(   0), INT8_C(  89), INT8_C(   0), INT8_C(   0),
                           INT8_C(-128), INT8_C(   0), INT8_C(-101), INT8_C(  55),
                           INT8_C(   0), INT8_C(   0), INT8_C( 127), INT8_C(   0)) },
    { UINT64_C(          3441334389),
      simde_mm512_set_epi8(INT8_C(  96), INT8_C(  30), INT8_C( 105), INT8_C(  -4),
                           INT8_C(  44), INT8_C(  54), INT8_C(  89), INT8_C(  40),
                           INT8_C(  99), INT8_C(  41), INT8_C(   5), INT8_C(  -2),
                           INT8_C( -57), INT8_C(  98), INT8_C(  33), INT8_C( -28),
                           INT8_C(  66), INT8_C(  28), INT8_C( -53), INT8_C(  48),
                           INT8_C( -75), INT8_C( -97), INT8_C( -42), INT8_C(  47),
                           INT8_C( -33), INT8_C( -17), INT8_C( 113), INT8_C( 120),
                           INT8_C(-111), INT8_C(  14), INT8_C(  77), INT8_C(-108),
                           INT8_C(  25), INT8_C( -42), INT8_C( 109), INT8_C( -97),
                           INT8_C( -19), INT8_C( -18), INT8_C(  -1), INT8_C( -50),
                           INT8_C( -87), INT8_C( -70), INT8_C(  94), INT8_C( -91),
                           INT8_C(  23), INT8_C(  33), INT8_C( -10), INT8_C(  81),
                           INT8_C(  81), INT8_C( -63), INT8_C(  35), INT8_C(  44),
                           INT8_C(  11), INT8_C(-124), INT8_C( -20), INT8_C(  71),
                           INT8_C( -25), INT8_C(-112), INT8_C(   2), INT8_C(  59),
                           INT8_C(  21), INT8_C(-113), INT8_C(  35), INT8_C( -40)),
      simde_mm512_set_epi8(INT8_C( -44), INT8_C(  54), INT8_C(-101), INT8_C( -13),
                           INT8_C( 111), INT8_C( 110), INT8_C( 114), INT8_C( -57),
                           INT8_C(  58), INT8_C(-128), INT8_C(-123), INT8_C(  -3),
                           INT8_C(  74), INT8_C( -78), INT8_C(-124), INT8_C( -30),
                           INT8_C(  21), INT8_C(  86), INT8_C( -53), INT8_C(-116),
                           INT8_C(-126), INT8_C(  10), INT8_C(-123), INT8_C( -78),
                           INT8_C(   2), INT8_C( 100), INT8_C( -90), INT8_C( -79),
                           INT8_C( -46), INT8_C( -83), INT8_C(  11), INT8_C(-120),
                           INT8_C( -56), INT8_C(  -4), INT8_C( -39), INT8_C(-114),
                           INT8_C( -98), INT8_C(-108), INT8_C( -22), INT8_C(  24),
                           INT8_C( 127), INT8_C( -20), INT8_C(   7), INT8_C( -16),
                           INT8_C(  -8), INT8_C(  19), INT8_C( 119), INT8_C( -44),
                           INT8_C(   7), INT8_C( -47), INT8_C(-126), INT8_C(-119),
                           INT8_C(   1), INT8_C( 111), INT8_C( -95), INT8_C( -67),
                           INT8_C(  38), INT8_C( -19), INT8_C(  96), INT8_C( -21),
                           INT8_C( -76), INT8_C(-123), INT8_C(-115), INT8_C( -61)),
      simde_mm512_set_epi8(INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(  81), INT8_C( -38), INT8_C(   0), INT8_C(   0),
                           INT8_C(  79), INT8_C(  90), INT8_C(   0), INT8_C( -74),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C( -75),
                           INT8_C(  31), INT8_C(  14), INT8_C(-128), INT8_C(   0),
                           INT8_C(  74), INT8_C(   0), INT8_C(   0), INT8_C( 127),
                           INT8_C(  10), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C( -93), INT8_C( -94), INT8_C(  80),
                           INT8_C(   0), INT8_C(  10), INT8_C(   0), INT8_C(  21)) },
    { UINT64_C(           706560777),
      simde_mm512_set_epi8(INT8_C(  44), INT8_C(  94), INT8_C( 127), INT8_C( -12),
                           INT8_C(  90), INT8_C( 111), INT8_C( -20), INT8_C(-110),
                           INT8_C( -82), INT8_C( -19), INT8_C( -79), INT8_C(-128),
                           INT8_C(  -6), INT8_C(-119), INT8_C( 100), INT8_C( 125),
                           INT8_C( -42), INT8_C(  43), INT8_C(   6), INT8_C( -97),
                           INT8_C( -90), INT8_C(  -4), INT8_C( -71), INT8_C(  33),
                           INT8_C(   1), INT8_C(   3), INT8_C( -91), INT8_C( -62),
                           INT8_C(-106), INT8_C(  -6), INT8_C(  35), INT8_C(  67),
                           INT8_C(  97), INT8_C(  46), INT8_C(  89), INT8_C(  56),
                           INT8_C( -84), INT8_C( -39), INT8_C( -70), INT8_C(  78),
                           INT8_C( -49), INT8_C(  94), INT8_C(  -1), INT8_C( -23),
                           INT8_C( -88), INT8_C( -11), INT8_C(-128), INT8_C( -62),
                           INT8_C( 106), INT8_C( 125), INT8_C( -71), INT8_C( -96),
                           INT8_C( -28), INT8_C( -58), INT8_C( -40), INT8_C( -32),
                           INT8_C( -13), INT8_C( -84), INT8_C( -69), INT8_C( -40),
                           INT8_C(-122), INT8_C( 117), INT8_C( 115), INT8_C( -87)),
      simde_mm512_set_epi8(INT8_C(  66), INT8_C( -40), INT8_C( -14), INT8_C( -56),
                           INT8_C( -68), INT8_C( -68), INT8_C(-124), INT8_C( -65),
                           INT8_C(  41), INT8_C( -59), INT8_C(-122), INT8_C( 101),
                           INT8_C(  82), INT8_C( -28), INT8_C( -40), INT8_C( -58),
                           INT8_C( 127), INT8_C(  66), INT8_C(  63), INT8_C( -46),
                           INT8_C(  90), INT8_C(  39), INT8_C( -89), INT8_C(-105),
                           INT8_C( -51), INT8_C( -46), INT8_C( 111), INT8_C( -45),
                           INT8_C( -76), INT8_C(-112), INT8_C( -37), INT8_C(-120),
                           INT8_C(  50), INT8_C( -97), INT8_C(  -2), INT8_C( 121),
                           INT8_C(  68), INT8_C(-106), INT8_C( 101), INT8_C( 115),
                           INT8_C( -29), INT8_C(  59), INT8_C(  77), INT8_C( -36),
                           INT8_C( 111), INT8_C(  95), INT8_C(  48), INT8_C( 113),
                           INT8_C( -97), INT8_C( 105), INT8_C( -37), INT8_C( -42),
                           INT8_C(  -7), INT8_C(  31), INT8_C(  45), INT8_C(  -5),
                           INT8_C( -29), INT8_C(  44), INT8_C(  78), INT8_C( -25),
                           INT8_C( -47), INT8_C(-119), INT8_C( -90), INT8_C( 115)),
      simde_mm512_set_epi8(INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(  91), INT8_C(   0),
                           INT8_C(-128), INT8_C(   0), INT8_C(-128), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(  13),
                           INT8_C(-128), INT8_C(-106), INT8_C(   0), INT8_C(-128),
                           INT8_C(   0), INT8_C(  20), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C( -85), INT8_C( -27),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C( -75), INT8_C(   0), INT8_C(   0), INT8_C(-128)) },
    { UINT64_C(          3905965829),
      simde_mm512_set_epi8(INT8_C(  51), INT8_C( -49), INT8_C(  69), INT8_C( -80),
                           INT8_C(  34), INT8_C(  87), INT8_C(  88), INT8_C( -38),
                           INT8_C( -14), INT8_C( -30), INT8_C(-111), INT8_C( -87),
                           INT8_C(  37), INT8_C(  40), INT8_C( -30), INT8_C( -40),
                           INT8_C(  89), INT8_C(  39), INT8_C( 109), INT8_C( 109),
                           INT8_C( -71), INT8_C( -81), INT8_C(  67), INT8_C(  48),
                           INT8_C( -43), INT8_C(  31), INT8_C( -36), INT8_C( -53),
                           INT8_C(  -7), INT8_C(  84), INT8_C( -92), INT8_C( 124),
                           INT8_C( -22), INT8_C(  31), INT8_C(  42), INT8_C(-103),
                           INT8_C(  29), INT8_C(  75), INT8_C( -91), INT8_C(  75),
                           INT8_C( 107), INT8_C(  62), INT8_C( 126), INT8_C(   7),
                           INT8_C( -89), INT8_C( 119), INT8_C(  79), INT8_C( -38),
                           INT8_C(  18), INT8_C(  57), INT8_C(-102), INT8_C(  66),
                           INT8_C(  -7), INT8_C(  89), INT8_C(  57), INT8_C( -55),
                           INT8_C( -68), INT8_C(  21), INT8_C( -21), INT8_C(  -6),
                           INT8_C( -26), INT8_C( 122), INT8_C( 114), INT8_C(  83)),
      simde_mm512_set_epi8(INT8_C( 111), INT8_C(  34), INT8_C( -76), INT8_C(  65),
                           INT8_C( -31), INT8_C(  25), INT8_C( -63), INT8_C(-128),
                           INT8_C( -28), INT8_C(  80), INT8_C( -75), INT8_C(  83),
                           INT8_C( -23), INT8_C( -65), INT8_C( -75), INT8_C( -10),
                           INT8_C(-102), INT8_C(-123), INT8_C(  20), INT8_C(  36),
                           INT8_C(  70), INT8_C( -95), INT8_C(  63), INT8_C( 110),
                           INT8_C(  98), INT8_C(-128), INT8_C( -74), INT8_C( -50),
                           INT8_C(  17), INT8_C( -37), INT8_C(-104), INT8_C( -74),
                           INT8_C(  -4), INT8_C(  15), INT8_C( -59), INT8_C(  62),
                           INT8_C( -89), INT8_C( 103), INT8_C(  -5), INT8_C(  71),
                           INT8_C( 103), INT8_C(-119), INT8_C( -62), INT8_C( -47),
                           INT8_C( -78), INT8_C(  32), INT8_C( 104), INT8_C(  33),
                           INT8_C( -45), INT8_C( -54), INT8_C(  17), INT8_C(-117),
                           INT8_C(  96), INT8_C(  66), INT8_C( -18), INT8_C( -58),
                           INT8_C(-111), INT8_C(-110), INT8_C( -14), INT8_C(   7),
                           INT8_C(  85), INT8_C(-113), INT8_C(  19), INT8_C( -72)),
      simde_mm512_set_epi8(INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C( -18), INT8_C(  16), INT8_C( 101), INT8_C(   0),
                           INT8_C( 118), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   4), INT8_C( 127), INT8_C(   0), INT8_C(  54),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C( 111), INT8_C(   0), INT8_C(   0),
                           INT8_C(-103), INT8_C(  23), INT8_C(  75), INT8_C(   3),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C( 127), INT8_C(   0), INT8_C( 127)) },
    { UINT64_C(           993418129),
      simde_mm512_set_epi8(INT8_C( -62), INT8_C(  96), INT8_C( -27), INT8_C( -88),
                           INT8_C( -35), INT8_C( -58), INT8_C( -83), INT8_C(  36),
                           INT8_C( -16), INT8_C(  50), INT8_C(-127), INT8_C( -82),
                           INT8_C( 106), INT8_C(  56), INT8_C(  74), INT8_C( -59),
                           INT8_C( -80), INT8_C( -22), INT8_C(   6), INT8_C( -65),
                           INT8_C(-106), INT8_C( -51), INT8_C(   4), INT8_C( -33),
                           INT8_C(  91), INT8_C(  46), INT8_C( -16), INT8_C(  27),
                           INT8_C( -66), INT8_C( -93), INT8_C( -43), INT8_C(  14),
                           INT8_C( 100), INT8_C(-113), INT8_C(  32), INT8_C(  15),
                           INT8_C( -79), INT8_C(  63), INT8_C( -18), INT8_C( -96),
                           INT8_C(-119), INT8_C( 114), INT8_C( -87), INT8_C( -82),
                           INT8_C(  76), INT8_C( 117), INT8_C(  14), INT8_C( -65),
                           INT8_C( -37), INT8_C( -15), INT8_C(  43), INT8_C(   5),
                           INT8_C(-108), INT8_C(  -5), INT8_C( -84), INT8_C(  13),
                           INT8_C( -66), INT8_C(  80), INT8_C( -20), INT8_C(  34),
                           INT8_C(-122), INT8_C(-101), INT8_C( -91), INT8_C( -35)),
      simde_mm512_set_epi8(INT8_C(  96), INT8_C(-100), INT8_C( -47), INT8_C( 114),
                           INT8_C(-109), INT8_C(   8), INT8_C(  51), INT8_C( 120),
                           INT8_C( -12), INT8_C(-128), INT8_C(  -4), INT8_C(-105),
                           INT8_C(  83), INT8_C(-123), INT8_C( -98), INT8_C(  -2),
                           INT8_C(  54), INT8_C( 110), INT8_C( -53), INT8_C( 100),
                           INT8_C(  94), INT8_C(  -2), INT8_C(  72), INT8_C(  95),
                           INT8_C( -61), INT8_C( -31), INT8_C(   2), INT8_C(  88),
                           INT8_C(  69), INT8_C(-117), INT8_C(  33), INT8_C( -57),
                           INT8_C( -67), INT8_C(  92), INT8_C( -31), INT8_C( -16),
                           INT8_C(-115), INT8_C( -91), INT8_C(   0), INT8_C( -73),
                           INT8_C(  -3), INT8_C( -71), INT8_C(  55), INT8_C( -82),
                           INT8_C( -28), INT8_C( -34), INT8_C( -40), INT8_C(  60),
                           INT8_C(  31), INT8_C(-113), INT8_C(  90), INT8_C( 114),
                           INT8_C(  73), INT8_C(  77), INT8_C( -29), INT8_C(  80),
                           INT8_C(-106), INT8_C( 121), INT8_C(-122), INT8_C(  -4),
                           INT8_C( 104), INT8_C( -76), INT8_C(  85), INT8_C( -33)),
      simde_mm512_set_epi8(INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(  63), INT8_C(  31),
                           INT8_C(  36), INT8_C(   0), INT8_C( -18), INT8_C( -23),
                           INT8_C(   0), INT8_C(   0), INT8_C(-128), INT8_C(   0),
                           INT8_C(   0), INT8_C( 127), INT8_C(  54), INT8_C(   0),
                           INT8_C(   0), INT8_C(  98), INT8_C(   0), INT8_C(-109),
                           INT8_C(-128), INT8_C(   0), INT8_C( -55), INT8_C( -67),
                           INT8_C(  40), INT8_C(   0), INT8_C(   0), INT8_C(  38),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(  -2)) },
    { UINT64_C(          1423233113),
      simde_mm512_set_epi8(INT8_C(  85), INT8_C(  12), INT8_C( -17), INT8_C(  78),
                           INT8_C(   2), INT8_C( -46), INT8_C(  21), INT8_C(  89),
                           INT8_C( -58), INT8_C( -19), INT8_C(  -7), INT8_C( -46),
                           INT8_C(  58), INT8_C( 120), INT8_C( -85), INT8_C(  46),
                           INT8_C(  80), INT8_C( -20), INT8_C(  94), INT8_C(  32),
                           INT8_C( -61), INT8_C(  80), INT8_C( -39), INT8_C( 109),
                           INT8_C( -24), INT8_C( -30), INT8_C(  27), INT8_C( -44),
                           INT8_C( -74), INT8_C( -85), INT8_C( -66), INT8_C(  26),
                           INT8_C( -69), INT8_C( 112), INT8_C( -22), INT8_C(  62),
                           INT8_C(  24), INT8_C(-107), INT8_C( -41), INT8_C( -21),
                           INT8_C(  68), INT8_C( -34), INT8_C( 109), INT8_C(  58),
                           INT8_C(  16), INT8_C( -72), INT8_C( -84), INT8_C(  18),
                           INT8_C( -73), INT8_C( -54), INT8_C(  16), INT8_C( -93),
                           INT8_C( -51), INT8_C( -50), INT8_C(  54), INT8_C( -69),
                           INT8_C( -98), INT8_C(-113), INT8_C( -73), INT8_C(-124),
                           INT8_C( -65), INT8_C( -51), INT8_C(  43), INT8_C(  10)),
      simde_mm512_set_epi8(INT8_C(  48), INT8_C( -35), INT8_C(  -2), INT8_C(  -9),
                           INT8_C( -72), INT8_C(  97), INT8_C(-100), INT8_C( 120),
                           INT8_C( -96), INT8_C(  21), INT8_C(  35), INT8_C(  38),
                           INT8_C( -30), INT8_C(  81), INT8_C(-111), INT8_C(  42),
                           INT8_C(  39), INT8_C(-112), INT8_C(  20), INT8_C(-116),
                           INT8_C( 111), INT8_C( -69), INT8_C(  64), INT8_C(  -4),
                           INT8_C( 125), INT8_C( -29), INT8_C( 116), INT8_C( -26),
                           INT8_C(  78), INT8_C(  37), INT8_C( -43), INT8_C(  45),
                           INT8_C( -81), INT8_C(-109), INT8_C(  26), INT8_C( -51),
                           INT8_C( -54), INT8_C(  99), INT8_C( 124), INT8_C(   2),
                           INT8_C(  10), INT8_C(   6), INT8_C( -77), INT8_C( -61),
                           INT8_C(  59), INT8_C(  60), INT8_C(  42), INT8_C(  33),
                           INT8_C( 126), INT8_C(  88), INT8_C(  41), INT8_C(  66),
                           INT8_C(  98), INT8_C( 111), INT8_C(  94), INT8_C( -70),
                           INT8_C( 116), INT8_C( -40), INT8_C( -88), INT8_C(  13),
                           INT8_C(  50), INT8_C(  54), INT8_C(  32), INT8_C( -48)),
      simde_mm512_set_epi8(INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C( 127), INT8_C(   0), INT8_C( 113),
                           INT8_C(   0), INT8_C(-128), INT8_C(   0), INT8_C(   0),
                           INT8_C(  58), INT8_C( -40), INT8_C(   0), INT8_C( 119),
                           INT8_C(   0), INT8_C(-128), INT8_C(   0), INT8_C(   0),
                           INT8_C(-128), INT8_C(-128), INT8_C(   0), INT8_C(-128),
                           INT8_C(   0), INT8_C(   0), INT8_C(   0), INT8_C(   0),
                           INT8_C(   0), INT8_C( -73), INT8_C(   0), INT8_C(-128),
                           INT8_C(-115), INT8_C(   0), INT8_C(   0), INT8_C(  58)) }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])); i++) {
    simde__m512i r = simde_mm512_maskz_subs_epi8(test_vec[i].k, test_vec[i].a, test_vec[i].b);
    simde_assert_m512i_i8(r, ==, test_vec[i].r);
  }

  return 0;
}

static int
test_simde_mm512_subs_epi16(SIMDE_MUNIT_TEST_ARGS) {
  const struct {
    simde__m512i a;
    simde__m512i b;
    simde__m512i r;
  } test_vec[8] = {
    { simde_mm512_set_epi16(INT16_C( 21075), INT16_C( 30017), INT16_C(-11898), INT16_C( 29710),
                            INT16_C( 19457), INT16_C(-12796), INT16_C( 21427), INT16_C( 28826),
                            INT16_C( 25482), INT16_C(-11843), INT16_C( 15582), INT16_C( 20114),
                            INT16_C(-14761), INT16_C(-15590), INT16_C( -4142), INT16_C( 29932),
                            INT16_C(-30672), INT16_C(  6190), INT16_C( 26590), INT16_C( 10803),
                            INT16_C(-16554), INT16_C( 15816), INT16_C( 14967), INT16_C( 24063),
                            INT16_C(-14713), INT16_C( -8094), INT16_C(-16817), INT16_C( 25507),
                            INT16_C( 19912), INT16_C(-19929), INT16_C(-12604), INT16_C(-17156)),
      simde_mm512_set_epi16(INT16_C( 27175), INT16_C(-27122), INT16_C( -6914), INT16_C( 10212),
                            INT16_C( 13894), INT16_C( -4620), INT16_C(-10724), INT16_C( -3078),
                            INT16_C( 29698), INT16_C(  6009), INT16_C( 28893), INT16_C(-31734),
                            INT16_C( -3957), INT16_C(  6787), INT16_C(  9325), INT16_C(  7645),
                            INT16_C( -2133), INT16_C( -9633), INT16_C(-22525), INT16_C(  1124),
                            INT16_C( 21781), INT16_C( 17119), INT16_C(-19461), INT16_C(-32134),
                            INT16_C( -7507), INT16_C( 19092), INT16_C( 21408), INT16_C(-14444),
                            INT16_C( 22843), INT16_C( 28625), INT16_C( -2322), INT16_C(  5251)),
      simde_mm512_set_epi16(INT16_C( -6100), INT16_C( 32767), INT16_C( -4984), INT16_C( 19498),
                            INT16_C(  5563), INT16_C( -8176), INT16_C( 32151), INT16_C( 31904),
                            INT16_C( -4216), INT16_C(-17852), INT16_C(-13311), INT16_C( 32767),
                            INT16_C(-10804), INT16_C(-22377), INT16_C(-13467), INT16_C( 22287),
                            INT16_C(-28539), INT16_C( 15823), INT16_C( 32767), INT16_C(  9679),
                            INT16_C(-32768), INT16_C( -1303), INT16_C( 32767), INT16_C( 32767),
                            INT16_C( -7206), INT16_C(-27186), INT16_C(-32768), INT16_C( 32767),
                            INT16_C( -2931), INT16_C(-32768), INT16_C(-10282), INT16_C(-22407)) },
    { simde_mm512_set_epi16(INT16_C(-27508), INT16_C(  5509), INT16_C(-13526), INT16_C( 16909),
                            INT16_C(  2419), INT16_C( 22142), INT16_C( -6109), INT16_C( -1177),
                            INT16_C(  9839), INT16_C(  6329), INT16_C(  -239), INT16_C(-15885),
                            INT16_C(  3666), INT16_C( 20122), INT16_C( -1699), INT16_C(  6503),
                            INT16_C( 29169), INT16_C( -4681), INT16_C( -2713), INT16_C(-24709),
                            INT16_C(  7221), INT16_C( -3718), INT16_C(   970), INT16_C(-15558),
                            INT16_C(-11011), INT16_C(-10787), INT16_C(-29970), INT16_C(  3894),
                            INT16_C(-25914), INT16_C(-18758), INT16_C( 11824), INT16_C( -8868)),
      simde_mm512_set_epi16(INT16_C(  1604), INT16_C( 19874), INT16_C(-12133), INT16_C( -1966),
                            INT16_C( 13041), INT16_C(  1566), INT16_C(-11791), INT16_C( -3425),
                            INT16_C(  7377), INT16_C(-23380), INT16_C( -9249), INT16_C(-31251),
                            INT16_C( 14877), INT16_C( 24009), INT16_C(-32316), INT16_C(  8308),
                            INT16_C(-11725), INT16_C(-10230), INT16_C(  1074), INT16_C( 12341),
                            INT16_C( 19989), INT16_C( 16491), INT16_C(  4144), INT16_C(-11714),
                            INT16_C( 19285), INT16_C(-29198), INT16_C(-25258), INT16_C(-29514),
                            INT16_C(  9755), INT16_C(-29385), INT16_C(-23111), INT16_C( -3412)),
      simde_mm512_set_epi16(INT16_C(-29112), INT16_C(-14365), INT16_C( -1393), INT16_C( 18875),
                            INT16_C(-10622), INT16_C( 20576), INT16_C(  5682), INT16_C(  2248),
                            INT16_C(  2462), INT16_C( 29709), INT16_C(  9010), INT16_C( 15366),
                            INT16_C(-11211), INT16_C( -3887), INT16_C( 30617), INT16_C( -1805),
                            INT16_C( 32767), INT16_C(  5549), INT16_C( -3787), INT16_C(-32768),
                            INT16_C(-12768), INT16_C(-20209), INT16_C( -3174), INT16_C( -3844),
                            INT16_C(-30296), INT16_C( 18411), INT16_C( -4712), INT16_C( 32767),
                            INT16_C(-32768), INT16_C( 10627), INT16_C( 32767), INT16_C( -5456)) },
    { simde_mm512_set_epi16(INT16_C(   691), INT16_C( -4823), INT16_C( -3253), INT16_C(-31392),
                            INT16_C(-21784), INT16_C( -6740), INT16_C(  9130), INT16_C(-18273),
                            INT16_C( 11275), INT16_C(-27092), INT16_C(    90), INT16_C(-20133),
                            INT16_C( 30523), INT16_C( 27008), INT16_C( 28387), INT16_C( 17266),
                            INT16_C( -9777), INT16_C( 27096), INT16_C( -8328), INT16_C( -6812),
                            INT16_C(-22954), INT16_C( -4409), INT16_C( 21734), INT16_C(-19695),
                            INT16_C(-11981), INT16_C(-21195), INT16_C( 18272), INT16_C( 28327),
                            INT16_C(  7123), INT16_C(-32216), INT16_C( 24489), INT16_C(-15668)),
      simde_mm512_set_epi16(INT16_C(-21377), INT16_C( 15856), INT16_C(  7686), INT16_C(-28568),
                            INT16_C(-15192), INT16_C( -9747), INT16_C( 11300), INT16_C( 27000),
                            INT16_C( -6635), INT16_C(  3626), INT16_C( 12716), INT16_C(-30571),
                            INT16_C( 31697), INT16_C(  5622), INT16_C( 24444), INT16_C( -8226),
                            INT16_C( -8263), INT16_C(  2890), INT16_C( 26732), INT16_C( -8763),
                            INT16_C(-13950), INT16_C( 27415), INT16_C(  7653), INT16_C( 31511),
                            INT16_C(-21082), INT16_C(  2398), INT16_C( 23365), INT16_C(-12903),
                            INT16_C(-18221), INT16_C(  4204), INT16_C(-20453), INT16_C( 15021)),
      simde_mm512_set_epi16(INT16_C( 22068), INT16_C(-20679), INT16_C(-10939), INT16_C( -2824),
                            INT16_C( -6592), INT16_C(  3007), INT16_C( -2170), INT16_C(-32768),
                            INT16_C( 17910), INT16_C(-30718), INT16_C(-12626), INT16_C( 10438),
                            INT16_C( -1174), INT16_C( 21386), INT16_C(  3943), INT16_C( 25492),
                            INT16_C( -1514), INT16_C( 24206), INT16_C(-32768), INT16_C(  1951),
                            INT16_C( -9004), INT16_C(-31824), INT16_C( 14081), INT16_C(-32768),
                            INT16_C(  9101), INT16_C(-23593), INT16_C( -5093), INT16_C( 32767),
                            INT16_C( 25344), INT16_C(-32768), INT16_C( 32767), INT16_C(-30689)) },
    { simde_mm512_set_epi16(INT16_C(  4451), INT16_C( -3121), INT16_C( 11648), INT16_C( 14185),
                            INT16_C( -8499), INT16_C(-24679), INT16_C(-31633), INT16_C( 19019),
                            INT16_C( 26210), INT16_C(-29943), INT16_C(-18883), INT16_C( 25468),
                            INT16_C( 20366), INT16_C(  4961), INT16_C(-25468), INT16_C( -4158),
                            INT16_C(  6653), INT16_C( -1720), INT16_C(-29723), INT16_C(-14244),
                            INT16_C( -4917), INT16_C(   730), INT16_C(-20677), INT16_C( 16986),
                            INT16_C(  9316), INT16_C( 28795), INT16_C(-18273), INT16_C(-29423),
                            INT16_C(-23674), INT16_C(  7963), INT16_C( 28019), INT16_C( 13728)),
      simde_mm512_set_epi16(INT16_C(-10770), INT16_C( 29411), INT16_C( 30463), INT16_C( -4902),
                            INT16_C(-20392), INT16_C(-28251), INT16_C( 11448), INT16_C( 27155),
                            INT16_C(-11669), INT16_C( 11820), INT16_C(-16512), INT16_C( 10540),
                            INT16_C( 17477), INT16_C(-19759), INT16_C( 28024), INT16_C(-14431),
                            INT16_C( 24400), INT16_C( -7583), INT16_C(-12129), INT16_C( 28592),
                            INT16_C(-31057), INT16_C(-18091), INT16_C( 19926), INT16_C(-29261),
                            INT16_C(  7501), INT16_C( 16620), INT16_C(  6953), INT16_C(  3437),
                            INT16_C(  5790), INT16_C(  5348), INT16_C( 17145), INT16_C(-28791)),
      simde_mm512_set_epi16(INT16_C( 15221), INT16_C(-32532), INT16_C(-18815), INT16_C( 19087),
                            INT16_C( 11893), INT16_C(  3572), INT16_C(-32768), INT16_C( -8136),
                            INT16_C( 32767), INT16_C(-32768), INT16_C( -2371), INT16_C( 14928),
                            INT16_C(  2889), INT16_C( 24720), INT16_C(-32768), INT16_C( 10273),
                            INT16_C(-17747), INT16_C(  5863), INT16_C(-17594), INT16_C(-32768),
                            INT16_C( 26140), INT16_C( 18821), INT16_C(-32768), INT16_C( 32767),
                            INT16_C(  1815), INT16_C( 12175), INT16_C(-25226), INT16_C(-32768),
                            INT16_C(-29464), INT16_C(  2615), INT16_C( 10874), INT16_C( 32767)) },
    { simde_mm512_set_epi16(INT16_C(-31561), INT16_C( 18949), INT16_C( -2287), INT16_C(-20534),
                            INT16_C( -1057), INT16_C( -3046), INT16_C( 22138), INT16_C(-11031),
                            INT16_C(    43), INT16_C( -6266), INT16_C(-20090), INT16_C(-22393),
                            INT16_C(-26046), INT16_C(-23703), INT16_C( 28092), INT16_C(  6346),
                            INT16_C( 10308), INT16_C(   572), INT16_C(     5), INT16_C( 15306),
                            INT16_C(-19429), INT16_C( -5811), INT16_C(-27420), INT16_C(-29128),
                            INT16_C(-13676), INT16_C( -3673), INT16_C(-26157), INT16_C( 19197),
                            INT16_C(-27593), INT16_C(-20030), INT16_C(  3690), INT16_C( -3850)),
      simde_mm512_set_epi16(INT16_C(-11908), INT16_C( 14774), INT16_C(  5244), INT16_C( 18107),
                            INT16_C(-16396), INT16_C( 31910), INT16_C(-28865), INT16_C(-20038),
                            INT16_C(-19234), INT16_C(-15108), INT16_C(-10436), INT16_C( 19911),
                            INT16_C(  3330), INT16_C( 28633), INT16_C( 10550), INT16_C( -9358),
                            INT16_C( 23697), INT16_C( 19726), INT16_C(-26407), INT16_C(-18878),
                            INT16_C(  4326), INT16_C(-22642), INT16_C(-17402), INT16_C( 16035),
                            INT16_C( 14223), INT16_C(-15160), INT16_C( -9470), INT16_C( -3752),
                            INT16_C(  6710), INT16_C( 21116), INT16_C( -9579), INT16_C( 10253)),
      simde_mm512_set_epi16(INT16_C(-19653), INT16_C(  4175), INT16_C( -7531), INT16_C(-32768),
                            INT16_C( 15339), INT16_C(-32768), INT16_C( 32767), INT16_C(  9007),
                            INT16_C( 19277), INT16_C(  8842), INT16_C( -9654), INT16_C(-32768),
                            INT16_C(-29376), INT16_C(-32768), INT16_C( 17542), INT16_C( 15704),
                            INT16_C(-13389), INT16_C(-19154), INT16_C( 26412), INT16_C( 32767),
                            INT16_C(-23755), INT16_C( 16831), INT16_C(-10018), INT16_C(-32768),
                            INT16_C(-27899), INT16_C( 11487), INT16_C(-16687), INT16_C( 22949),
                            INT16_C(-32768), INT16_C(-32768), INT16_C( 13269), INT16_C(-14103)) },
    { simde_mm512_set_epi16(INT16_C(  1468), INT16_C( -4389), INT16_C(  1296), INT16_C(-27715),
                            INT16_C(-15620), INT16_C(  3731), INT16_C( -7289), INT16_C(-27703),
                            INT16_C(   474), INT16_C( 27447), INT16_C( -9036), INT16_C(  9176),
                            INT16_C(  2726), INT16_C(-12144), INT16_C( -2101), INT16_C( 26907),
                            INT16_C(-24700), INT16_C(  1244), INT16_C( -3927), INT16_C(-22632),
                            INT16_C( -7525), INT16_C( 17743), INT16_C( 15263), INT16_C( -3823),
                            INT16_C( 27307), INT16_C( 32391), INT16_C(-23270), INT16_C(-29301),
                            INT16_C( 23369), INT16_C(-15291), INT16_C( -5840), INT16_C( 18168)),
      simde_mm512_set_epi16(INT16_C( 23449), INT16_C( 17725), INT16_C(-20919), INT16_C( 31466),
                            INT16_C( 31308), INT16_C( -2183), INT16_C(-31351), INT16_C(-32386),
                            INT16_C( 26890), INT16_C(-30591), INT16_C(-12785), INT16_C(-23638),
                            INT16_C(-31955), INT16_C( -9847), INT16_C( 19108), INT16_C(-19915),
                            INT16_C(  4587), INT16_C( 27034), INT16_C(   -19), INT16_C( 28332),
                            INT16_C(-23789), INT16_C(-24960), INT16_C( -5839), INT16_C( 25722),
                            INT16_C(-24423), INT16_C( 15592), INT16_C(  6092), INT16_C( -9272),
                            INT16_C(-12796), INT16_C(-17663), INT16_C( -6154), INT16_C( 23859)),
      simde_mm512_set_epi16(INT16_C(-21981), INT16_C(-22114), INT16_C( 22215), INT16_C(-32768),
                            INT16_C(-32768), INT16_C(  5914), INT16_C( 24062), INT16_C(  4683),
                            INT16_C(-26416), INT16_C( 32767), INT16_C(  3749), INT16_C( 32767),
                            INT16_C( 32767), INT16_C( -2297), INT16_C(-21209), INT16_C( 32767),
                            INT16_C(-29287), INT16_C(-25790), INT16_C( -3908), INT16_C(-32768),
                            INT16_C( 16264), INT16_C( 32767), INT16_C( 21102), INT16_C(-29545),
                            INT16_C( 32767), INT16_C( 16799), INT16_C(-29362), INT16_C(-20029),
                            INT16_C( 32767), INT16_C(  2372), INT16_C(   314), INT16_C( -5691)) },
    { simde_mm512_set_epi16(INT16_C(-22741), INT16_C( 13394), INT16_C( -9417), INT16_C( 28906),
                            INT16_C(-18980), INT16_C( -8463), INT16_C(  9174), INT16_C(-25605),
                            INT16_C(   547), INT16_C(  3767), INT16_C(-12577), INT16_C(-16546),
                            INT16_C( -1301), INT16_C( -7147), INT16_C( 26281), INT16_C( 29309),
                            INT16_C( 29052), INT16_C(-30842), INT16_C(  5995), INT16_C(  6270),
                            INT16_C( 20539), INT16_C( 10179), INT16_C(-26848), INT16_C( 14327),
                            INT16_C( 15491), INT16_C( 18652), INT16_C( 19903), INT16_C( 30123),
                            INT16_C( 25261), INT16_C(-17460), INT16_C( 10742), INT16_C( -4552)),
      simde_mm512_set_epi16(INT16_C(  5754), INT16_C(-23038), INT16_C(-16589), INT16_C(-23858),
                            INT16_C( -3821), INT16_C( -4798), INT16_C( 30602), INT16_C(-28532),
                            INT16_C( 11508), INT16_C(  7979), INT16_C( -3877), INT16_C( -5920),
                            INT16_C(-24150), INT16_C(-24496), INT16_C( 17421), INT16_C( -1981),
                            INT16_C( 27523), INT16_C( 26800), INT16_C( 25010), INT16_C( 27339),
                            INT16_C( -9050), INT16_C( 19128), INT16_C( 15279), INT16_C( -1817),
                            INT16_C(-13923), INT16_C(  5129), INT16_C(-22618), INT16_C( 27704),
                            INT16_C( -4783), INT16_C( 31238), INT16_C(-30342), INT16_C( -8854)),
      simde_mm512_set_epi16(INT16_C(-28495), INT16_C( 32767), INT16_C(  7172), INT16_C( 32767),
                            INT16_C(-15159), INT16_C( -3665), INT16_C(-21428), INT16_C(  2927),
                            INT16_C(-10961), INT16_C( -4212), INT16_C( -8700), INT16_C(-10626),
                            INT16_C( 22849), INT16_C( 17349), INT16_C(  8860), INT16_C( 31290),
                            INT16_C(  1529), INT16_C(-32768), INT16_C(-19015), INT16_C(-21069),
                            INT16_C( 29589), INT16_C( -8949), INT16_C(-32768), INT16_C( 16144),
                            INT16_C( 29414), INT16_C( 13523), INT16_C( 32767), INT16_C(  2419),
                            INT16_C( 30044), INT16_C(-32768), INT16_C( 32767), INT16_C(  4302)) },
    { simde_mm512_set_epi16(INT16_C( 27021), INT16_C( 31131), INT16_C(    63), INT16_C(-10530),
                            INT16_C( -1071), INT16_C(-31284), INT16_C(-21788), INT16_C(-16108),
                            INT16_C(-15167), INT16_C( 25422), INT16_C( 14520), INT16_C(-13896),
                            INT16_C( 20399), INT16_C( 31915), INT16_C(-16518), INT16_C( -6202),
                            INT16_C(-16332), INT16_C( -3071), INT16_C(-15644), INT16_C( -7016),
                            INT16_C( 13977), INT16_C(-13846), INT16_C(-23290), INT16_C( -2079),
                            INT16_C(  4753), INT16_C( 14919), INT16_C(-18528), INT16_C(  7420),
                            INT16_C( 12098), INT16_C( 31014), INT16_C( 17813), INT16_C(-14456)),
      simde_mm512_set_epi16(INT16_C(-12529), INT16_C( -3643), INT16_C(-28826), INT16_C(-12110),
                            INT16_C(  8030), INT16_C( 20316), INT16_C( 27324), INT16_C( 24735),
                            INT16_C( -6774), INT16_C( -2704), INT16_C(-31930), INT16_C(  6874),
                            INT16_C( -3952), INT16_C(  2658), INT16_C(  -904), INT16_C( -8319),
                            INT16_C(-16424), INT16_C( 22778), INT16_C( 18985), INT16_C( 10063),
                            INT16_C(-31751), INT16_C( 16016), INT16_C(-30217), INT16_C( 18364),
                            INT16_C(-20176), INT16_C( -4961), INT16_C(-29576), INT16_C(-16634),
                            INT16_C( -8011), INT16_C(-27110), INT16_C(-24526), INT16_C(-11504)),
      simde_mm512_set_epi16(INT16_C( 32767), INT16_C( 32767), INT16_C( 28889), INT16_C(  1580),
                            INT16_C( -9101), INT16_C(-32768), INT16_C(-32768), INT16_C(-32768),
                            INT16_C( -8393), INT16_C( 28126), INT16_C( 32767), INT16_C(-20770),
                            INT16_C( 24351), INT16_C( 29257), INT16_C(-15614), INT16_C(  2117),
                            INT16_C(    92), INT16_C(-25849), INT16_C(-32768), INT16_C(-17079),
                            INT16_C( 32767), INT16_C(-29862), INT16_C(  6927), INT16_C(-20443),
                            INT16_C( 24929), INT16_C( 19880), INT16_C( 11048), INT16_C( 24054),
                            INT16_C( 20109), INT16_C( 32767), INT16_C( 32767), INT16_C( -2952)) }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])); i++) {
    simde__m512i r = simde_mm512_subs_epi16(test_vec[i].a, test_vec[i].b);
    simde_assert_m512i_i16(r, ==, test_vec[i].r);
  }

  return 0;
}

static int
test_simde_mm512_subs_epu8(SIMDE_MUNIT_TEST_ARGS) {
  const struct {
    simde__m512i a;
    simde__m512i b;
    simde__m512i r;
  } test_vec[8] = {
    { simde_x_mm512_set_epu8(UINT8_C( 82), UINT8_C( 83), UINT8_C(117), UINT8_C( 65),
                             UINT8_C(209), UINT8_C(134), UINT8_C(116), UINT8_C( 14),
                             UINT8_C( 76), UINT8_C(  1), UINT8_C(206), UINT8_C(  4),
                             UINT8_C( 83), UINT8_C(179), UINT8_C(112), UINT8_C(154),
                             UINT8_C( 99), UINT8_C(138), UINT8_C(209), UINT8_C(189),
                             UINT8_C( 60), UINT8_C(222), UINT8_C( 78), UINT8_C(146),
                             UINT8_C(198), UINT8_C( 87), UINT8_C(195), UINT8_C( 26),
                             UINT8_C(239), UINT8_C(210), UINT8_C(116), UINT8_C(236),
                             UINT8_C(136), UINT8_C( 48), UINT8_C( 24), UINT8_C( 46),
                             UINT8_C(103), UINT8_C(222), UINT8_C( 42), UINT8_C( 51),
                             UINT8_C(191), UINT8_C( 86), UINT8_C( 61), UINT8_C(200),
                             UINT8_C( 58), UINT8_C(119), UINT8_C( 93), UINT8_C(255),
                             UINT8_C(198), UINT8_C(135), UINT8_C(224), UINT8_C( 98),
                             UINT8_C(190), UINT8_C( 79), UINT8_C( 99), UINT8_C(163),
                             UINT8_C( 77), UINT8_C(200), UINT8_C(178), UINT8_C( 39),
                             UINT8_C(206), UINT8_C(196), UINT8_C(188), UINT8_C(252)),
      simde_x_mm512_set_epu8(UINT8_C(106), UINT8_C( 39), UINT8_C(150), UINT8_C( 14),
                             UINT8_C(228), UINT8_C(254), UINT8_C( 39), UINT8_C(228),
                             UINT8_C( 54), UINT8_C( 70), UINT8_C(237), UINT8_C(244),
                             UINT8_C(214), UINT8_C( 28), UINT8_C(243), UINT8_C(250),
                             UINT8_C(116), UINT8_C(  2), UINT8_C( 23), UINT8_C(121),
                             UINT8_C(112), UINT8_C(221), UINT8_C(132), UINT8_C( 10),
                             UINT8_C(240), UINT8_C(139), UINT8_C( 26), UINT8_C(131),
                             UINT8_C( 36), UINT8_C(109), UINT8_C( 29), UINT8_C(221),
                             UINT8_C(247), UINT8_C(171), UINT8_C(218), UINT8_C( 95),
                             UINT8_C(168), UINT8_C(  3), UINT8_C(  4), UINT8_C(100),
                             UINT8_C( 85), UINT8_C( 21), UINT8_C( 66), UINT8_C(223),
                             UINT8_C(179), UINT8_C(251), UINT8_C(130), UINT8_C(122),
                             UINT8_C(226), UINT8_C(173), UINT8_C( 74), UINT8_C(148),
                             UINT8_C( 83), UINT8_C(160), UINT8_C(199), UINT8_C(148),
                             UINT8_C( 89), UINT8_C( 59), UINT8_C(111), UINT8_C(209),
                             UINT8_C(246), UINT8_C(238), UINT8_C( 20), UINT8_C(131)),
      simde_x_mm512_set_epu8(UINT8_C(  0), UINT8_C( 44), UINT8_C(  0), UINT8_C( 51),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C( 77), UINT8_C(  0),
                             UINT8_C( 22), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(151), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(136), UINT8_C(186), UINT8_C( 68),
                             UINT8_C(  0), UINT8_C(  1), UINT8_C(  0), UINT8_C(136),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(169), UINT8_C(  0),
                             UINT8_C(203), UINT8_C(101), UINT8_C( 87), UINT8_C( 15),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(219), UINT8_C( 38), UINT8_C(  0),
                             UINT8_C(106), UINT8_C( 65), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(133),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(150), UINT8_C(  0),
                             UINT8_C(107), UINT8_C(  0), UINT8_C(  0), UINT8_C( 15),
                             UINT8_C(  0), UINT8_C(141), UINT8_C( 67), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(168), UINT8_C(121)) },
    { simde_x_mm512_set_epu8(UINT8_C(148), UINT8_C(140), UINT8_C( 21), UINT8_C(133),
                             UINT8_C(203), UINT8_C( 42), UINT8_C( 66), UINT8_C( 13),
                             UINT8_C(  9), UINT8_C(115), UINT8_C( 86), UINT8_C(126),
                             UINT8_C(232), UINT8_C( 35), UINT8_C(251), UINT8_C(103),
                             UINT8_C( 38), UINT8_C(111), UINT8_C( 24), UINT8_C(185),
                             UINT8_C(255), UINT8_C( 17), UINT8_C(193), UINT8_C(243),
                             UINT8_C( 14), UINT8_C( 82), UINT8_C( 78), UINT8_C(154),
                             UINT8_C(249), UINT8_C( 93), UINT8_C( 25), UINT8_C(103),
                             UINT8_C(113), UINT8_C(241), UINT8_C(237), UINT8_C(183),
                             UINT8_C(245), UINT8_C(103), UINT8_C(159), UINT8_C(123),
                             UINT8_C( 28), UINT8_C( 53), UINT8_C(241), UINT8_C(122),
                             UINT8_C(  3), UINT8_C(202), UINT8_C(195), UINT8_C( 58),
                             UINT8_C(212), UINT8_C(253), UINT8_C(213), UINT8_C(221),
                             UINT8_C(138), UINT8_C(238), UINT8_C( 15), UINT8_C( 54),
                             UINT8_C(154), UINT8_C(198), UINT8_C(182), UINT8_C(186),
                             UINT8_C( 46), UINT8_C( 48), UINT8_C(221), UINT8_C( 92)),
      simde_x_mm512_set_epu8(UINT8_C(  6), UINT8_C( 68), UINT8_C( 77), UINT8_C(162),
                             UINT8_C(208), UINT8_C(155), UINT8_C(248), UINT8_C( 82),
                             UINT8_C( 50), UINT8_C(241), UINT8_C(  6), UINT8_C( 30),
                             UINT8_C(209), UINT8_C(241), UINT8_C(242), UINT8_C(159),
                             UINT8_C( 28), UINT8_C(209), UINT8_C(164), UINT8_C(172),
                             UINT8_C(219), UINT8_C(223), UINT8_C(133), UINT8_C(237),
                             UINT8_C( 58), UINT8_C( 29), UINT8_C( 93), UINT8_C(201),
                             UINT8_C(129), UINT8_C(196), UINT8_C( 32), UINT8_C(116),
                             UINT8_C(210), UINT8_C( 51), UINT8_C(216), UINT8_C( 10),
                             UINT8_C(  4), UINT8_C( 50), UINT8_C( 48), UINT8_C( 53),
                             UINT8_C( 78), UINT8_C( 21), UINT8_C( 64), UINT8_C(107),
                             UINT8_C( 16), UINT8_C( 48), UINT8_C(210), UINT8_C( 62),
                             UINT8_C( 75), UINT8_C( 85), UINT8_C(141), UINT8_C(242),
                             UINT8_C(157), UINT8_C( 86), UINT8_C(140), UINT8_C(182),
                             UINT8_C( 38), UINT8_C( 27), UINT8_C(141), UINT8_C( 55),
                             UINT8_C(165), UINT8_C(185), UINT8_C(242), UINT8_C(172)),
      simde_x_mm512_set_epu8(UINT8_C(142), UINT8_C( 72), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C( 80), UINT8_C( 96),
                             UINT8_C( 23), UINT8_C(  0), UINT8_C(  9), UINT8_C(  0),
                             UINT8_C( 10), UINT8_C(  0), UINT8_C(  0), UINT8_C( 13),
                             UINT8_C( 36), UINT8_C(  0), UINT8_C( 60), UINT8_C(  6),
                             UINT8_C(  0), UINT8_C( 53), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(120), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(190), UINT8_C( 21), UINT8_C(173),
                             UINT8_C(241), UINT8_C( 53), UINT8_C(111), UINT8_C( 70),
                             UINT8_C(  0), UINT8_C( 32), UINT8_C(177), UINT8_C( 15),
                             UINT8_C(  0), UINT8_C(154), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(137), UINT8_C(168), UINT8_C( 72), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(152), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(116), UINT8_C(171), UINT8_C( 41), UINT8_C(131),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0)) },
    { simde_x_mm512_set_epu8(UINT8_C(  2), UINT8_C(179), UINT8_C(237), UINT8_C( 41),
                             UINT8_C(243), UINT8_C( 75), UINT8_C(133), UINT8_C( 96),
                             UINT8_C(170), UINT8_C(232), UINT8_C(229), UINT8_C(172),
                             UINT8_C( 35), UINT8_C(170), UINT8_C(184), UINT8_C(159),
                             UINT8_C( 44), UINT8_C( 11), UINT8_C(150), UINT8_C( 44),
                             UINT8_C(  0), UINT8_C( 90), UINT8_C(177), UINT8_C( 91),
                             UINT8_C(119), UINT8_C( 59), UINT8_C(105), UINT8_C(128),
                             UINT8_C(110), UINT8_C(227), UINT8_C( 67), UINT8_C(114),
                             UINT8_C(217), UINT8_C(207), UINT8_C(105), UINT8_C(216),
                             UINT8_C(223), UINT8_C(120), UINT8_C(229), UINT8_C(100),
                             UINT8_C(166), UINT8_C( 86), UINT8_C(238), UINT8_C(199),
                             UINT8_C( 84), UINT8_C(230), UINT8_C(179), UINT8_C( 17),
                             UINT8_C(209), UINT8_C( 51), UINT8_C(173), UINT8_C( 53),
                             UINT8_C( 71), UINT8_C( 96), UINT8_C(110), UINT8_C(167),
                             UINT8_C( 27), UINT8_C(211), UINT8_C(130), UINT8_C( 40),
                             UINT8_C( 95), UINT8_C(169), UINT8_C(194), UINT8_C(204)),
      simde_x_mm512_set_epu8(UINT8_C(172), UINT8_C(127), UINT8_C( 61), UINT8_C(240),
                             UINT8_C( 30), UINT8_C(  6), UINT8_C(144), UINT8_C(104),
                             UINT8_C(196), UINT8_C(168), UINT8_C(217), UINT8_C(237),
                             UINT8_C( 44), UINT8_C( 36), UINT8_C(105), UINT8_C(120),
                             UINT8_C(230), UINT8_C( 21), UINT8_C( 14), UINT8_C( 42),
                             UINT8_C( 49), UINT8_C(172), UINT8_C(136), UINT8_C(149),
                             UINT8_C(123), UINT8_C(209), UINT8_C( 21), UINT8_C(246),
                             UINT8_C( 95), UINT8_C(124), UINT8_C(223), UINT8_C(222),
                             UINT8_C(223), UINT8_C(185), UINT8_C( 11), UINT8_C( 74),
                             UINT8_C(104), UINT8_C(108), UINT8_C(221), UINT8_C(197),
                             UINT8_C(201), UINT8_C(130), UINT8_C(107), UINT8_C( 23),
                             UINT8_C( 29), UINT8_C(229), UINT8_C(123), UINT8_C( 23),
                             UINT8_C(173), UINT8_C(166), UINT8_C(  9), UINT8_C( 94),
                             UINT8_C( 91), UINT8_C( 69), UINT8_C(205), UINT8_C(153),
                             UINT8_C(184), UINT8_C(211), UINT8_C( 16), UINT8_C(108),
                             UINT8_C(176), UINT8_C( 27), UINT8_C( 58), UINT8_C(173)),
      simde_x_mm512_set_epu8(UINT8_C(  0), UINT8_C( 52), UINT8_C(176), UINT8_C(  0),
                             UINT8_C(213), UINT8_C( 69), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C( 64), UINT8_C( 12), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(134), UINT8_C( 79), UINT8_C( 39),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(136), UINT8_C(  2),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C( 41), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C( 84), UINT8_C(  0),
                             UINT8_C( 15), UINT8_C(103), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C( 22), UINT8_C( 94), UINT8_C(142),
                             UINT8_C(119), UINT8_C( 12), UINT8_C(  8), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(131), UINT8_C(176),
                             UINT8_C( 55), UINT8_C(  1), UINT8_C( 56), UINT8_C(  0),
                             UINT8_C( 36), UINT8_C(  0), UINT8_C(164), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C( 27), UINT8_C(  0), UINT8_C( 14),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(114), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(142), UINT8_C(136), UINT8_C( 31)) },
    { simde_x_mm512_set_epu8(UINT8_C( 17), UINT8_C( 99), UINT8_C(243), UINT8_C(207),
                             UINT8_C( 45), UINT8_C(128), UINT8_C( 55), UINT8_C(105),
                             UINT8_C(222), UINT8_C(205), UINT8_C(159), UINT8_C(153),
                             UINT8_C(132), UINT8_C(111), UINT8_C( 74), UINT8_C( 75),
                             UINT8_C(102), UINT8_C( 98), UINT8_C(139), UINT8_C(  9),
                             UINT8_C(182), UINT8_C( 61), UINT8_C( 99), UINT8_C(124),
                             UINT8_C( 79), UINT8_C(142), UINT8_C( 19), UINT8_C( 97),
                             UINT8_C(156), UINT8_C(132), UINT8_C(239), UINT8_C(194),
                             UINT8_C( 25), UINT8_C(253), UINT8_C(249), UINT8_C( 72),
                             UINT8_C(139), UINT8_C(229), UINT8_C(200), UINT8_C( 92),
                             UINT8_C(236), UINT8_C(203), UINT8_C(  2), UINT8_C(218),
                             UINT8_C(175), UINT8_C( 59), UINT8_C( 66), UINT8_C( 90),
                             UINT8_C( 36), UINT8_C(100), UINT8_C(112), UINT8_C(123),
                             UINT8_C(184), UINT8_C(159), UINT8_C(141), UINT8_C( 17),
                             UINT8_C(163), UINT8_C(134), UINT8_C( 31), UINT8_C( 27),
                             UINT8_C(109), UINT8_C(115), UINT8_C( 53), UINT8_C(160)),
      simde_x_mm512_set_epu8(UINT8_C(213), UINT8_C(238), UINT8_C(114), UINT8_C(227),
                             UINT8_C(118), UINT8_C(255), UINT8_C(236), UINT8_C(218),
                             UINT8_C(176), UINT8_C( 88), UINT8_C(145), UINT8_C(165),
                             UINT8_C( 44), UINT8_C(184), UINT8_C(106), UINT8_C( 19),
                             UINT8_C(210), UINT8_C(107), UINT8_C( 46), UINT8_C( 44),
                             UINT8_C(191), UINT8_C(128), UINT8_C( 41), UINT8_C( 44),
                             UINT8_C( 68), UINT8_C( 69), UINT8_C(178), UINT8_C(209),
                             UINT8_C(109), UINT8_C(120), UINT8_C(199), UINT8_C(161),
                             UINT8_C( 95), UINT8_C( 80), UINT8_C(226), UINT8_C( 97),
                             UINT8_C(208), UINT8_C(159), UINT8_C(111), UINT8_C(176),
                             UINT8_C(134), UINT8_C(175), UINT8_C(185), UINT8_C( 85),
                             UINT8_C( 77), UINT8_C(214), UINT8_C(141), UINT8_C(179),
                             UINT8_C( 29), UINT8_C( 77), UINT8_C( 64), UINT8_C(236),
                             UINT8_C( 27), UINT8_C( 41), UINT8_C( 13), UINT8_C(109),
                             UINT8_C( 22), UINT8_C(158), UINT8_C( 20), UINT8_C(228),
                             UINT8_C( 66), UINT8_C(249), UINT8_C(143), UINT8_C(137)),
      simde_x_mm512_set_epu8(UINT8_C(  0), UINT8_C(  0), UINT8_C(129), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C( 46), UINT8_C(117), UINT8_C( 14), UINT8_C(  0),
                             UINT8_C( 88), UINT8_C(  0), UINT8_C(  0), UINT8_C( 56),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C( 93), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C( 58), UINT8_C( 80),
                             UINT8_C( 11), UINT8_C( 73), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C( 47), UINT8_C( 12), UINT8_C( 40), UINT8_C( 33),
                             UINT8_C(  0), UINT8_C(173), UINT8_C( 23), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C( 70), UINT8_C( 89), UINT8_C(  0),
                             UINT8_C(102), UINT8_C( 28), UINT8_C(  0), UINT8_C(133),
                             UINT8_C( 98), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  7), UINT8_C( 23), UINT8_C( 48), UINT8_C(  0),
                             UINT8_C(157), UINT8_C(118), UINT8_C(128), UINT8_C(  0),
                             UINT8_C(141), UINT8_C(  0), UINT8_C( 11), UINT8_C(  0),
                             UINT8_C( 43), UINT8_C(  0), UINT8_C(  0), UINT8_C( 23)) },
    { simde_x_mm512_set_epu8(UINT8_C(132), UINT8_C(183), UINT8_C( 74), UINT8_C(  5),
                             UINT8_C(247), UINT8_C( 17), UINT8_C(175), UINT8_C(202),
                             UINT8_C(251), UINT8_C(223), UINT8_C(244), UINT8_C( 26),
                             UINT8_C( 86), UINT8_C(122), UINT8_C(212), UINT8_C(233),
                             UINT8_C(  0), UINT8_C( 43), UINT8_C(231), UINT8_C(134),
                             UINT8_C(177), UINT8_C(134), UINT8_C(168), UINT8_C(135),
                             UINT8_C(154), UINT8_C( 66), UINT8_C(163), UINT8_C(105),
                             UINT8_C(109), UINT8_C(188), UINT8_C( 24), UINT8_C(202),
                             UINT8_C( 40), UINT8_C( 68), UINT8_C(  2), UINT8_C( 60),
                             UINT8_C(  0), UINT8_C(  5), UINT8_C( 59), UINT8_C(202),
                             UINT8_C(180), UINT8_C( 27), UINT8_C(233), UINT8_C( 77),
                             UINT8_C(148), UINT8_C(228), UINT8_C(142), UINT8_C( 56),
                             UINT8_C(202), UINT8_C(148), UINT8_C(241), UINT8_C(167),
                             UINT8_C(153), UINT8_C(211), UINT8_C( 74), UINT8_C(253),
                             UINT8_C(148), UINT8_C( 55), UINT8_C(177), UINT8_C(194),
                             UINT8_C( 14), UINT8_C(106), UINT8_C(240), UINT8_C(246)),
      simde_x_mm512_set_epu8(UINT8_C(209), UINT8_C(124), UINT8_C( 57), UINT8_C(182),
                             UINT8_C( 20), UINT8_C(124), UINT8_C( 70), UINT8_C(187),
                             UINT8_C(191), UINT8_C(244), UINT8_C(124), UINT8_C(166),
                             UINT8_C(143), UINT8_C( 63), UINT8_C(177), UINT8_C(186),
                             UINT8_C(180), UINT8_C(222), UINT8_C(196), UINT8_C(252),
                             UINT8_C(215), UINT8_C( 60), UINT8_C( 77), UINT8_C(199),
                             UINT8_C( 13), UINT8_C(  2), UINT8_C(111), UINT8_C(217),
                             UINT8_C( 41), UINT8_C( 54), UINT8_C(219), UINT8_C(114),
                             UINT8_C( 92), UINT8_C(145), UINT8_C( 77), UINT8_C( 14),
                             UINT8_C(152), UINT8_C(217), UINT8_C(182), UINT8_C( 66),
                             UINT8_C( 16), UINT8_C(230), UINT8_C(167), UINT8_C(142),
                             UINT8_C(188), UINT8_C(  6), UINT8_C( 62), UINT8_C(163),
                             UINT8_C( 55), UINT8_C(143), UINT8_C(196), UINT8_C(200),
                             UINT8_C(219), UINT8_C(  2), UINT8_C(241), UINT8_C( 88),
                             UINT8_C( 26), UINT8_C( 54), UINT8_C( 82), UINT8_C(124),
                             UINT8_C(218), UINT8_C(149), UINT8_C( 40), UINT8_C( 13)),
      simde_x_mm512_set_epu8(UINT8_C(  0), UINT8_C( 59), UINT8_C( 17), UINT8_C(  0),
                             UINT8_C(227), UINT8_C(  0), UINT8_C(105), UINT8_C( 15),
                             UINT8_C( 60), UINT8_C(  0), UINT8_C(120), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C( 59), UINT8_C( 35), UINT8_C( 47),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C( 35), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C( 74), UINT8_C( 91), UINT8_C(  0),
                             UINT8_C(141), UINT8_C( 64), UINT8_C( 52), UINT8_C(  0),
                             UINT8_C( 68), UINT8_C(134), UINT8_C(  0), UINT8_C( 88),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C( 46),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(136),
                             UINT8_C(164), UINT8_C(  0), UINT8_C( 66), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(222), UINT8_C( 80), UINT8_C(  0),
                             UINT8_C(147), UINT8_C(  5), UINT8_C( 45), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(209), UINT8_C(  0), UINT8_C(165),
                             UINT8_C(122), UINT8_C(  1), UINT8_C( 95), UINT8_C( 70),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(200), UINT8_C(233)) },
    { simde_x_mm512_set_epu8(UINT8_C(  5), UINT8_C(188), UINT8_C(238), UINT8_C(219),
                             UINT8_C(  5), UINT8_C( 16), UINT8_C(147), UINT8_C(189),
                             UINT8_C(194), UINT8_C(252), UINT8_C( 14), UINT8_C(147),
                             UINT8_C(227), UINT8_C(135), UINT8_C(147), UINT8_C(201),
                             UINT8_C(  1), UINT8_C(218), UINT8_C(107), UINT8_C( 55),
                             UINT8_C(220), UINT8_C(180), UINT8_C( 35), UINT8_C(216),
                             UINT8_C( 10), UINT8_C(166), UINT8_C(208), UINT8_C(144),
                             UINT8_C(247), UINT8_C(203), UINT8_C(105), UINT8_C( 27),
                             UINT8_C(159), UINT8_C(132), UINT8_C(  4), UINT8_C(220),
                             UINT8_C(240), UINT8_C(169), UINT8_C(167), UINT8_C(152),
                             UINT8_C(226), UINT8_C(155), UINT8_C( 69), UINT8_C( 79),
                             UINT8_C( 59), UINT8_C(159), UINT8_C(241), UINT8_C( 17),
                             UINT8_C(106), UINT8_C(171), UINT8_C(126), UINT8_C(135),
                             UINT8_C(165), UINT8_C( 26), UINT8_C(141), UINT8_C(139),
                             UINT8_C( 91), UINT8_C( 73), UINT8_C(196), UINT8_C( 69),
                             UINT8_C(233), UINT8_C( 48), UINT8_C( 70), UINT8_C(248)),
      simde_x_mm512_set_epu8(UINT8_C( 91), UINT8_C(153), UINT8_C( 69), UINT8_C( 61),
                             UINT8_C(174), UINT8_C( 73), UINT8_C(122), UINT8_C(234),
                             UINT8_C(122), UINT8_C( 76), UINT8_C(247), UINT8_C(121),
                             UINT8_C(133), UINT8_C(137), UINT8_C(129), UINT8_C(126),
                             UINT8_C(105), UINT8_C( 10), UINT8_C(136), UINT8_C(129),
                             UINT8_C(206), UINT8_C( 15), UINT8_C(163), UINT8_C(170),
                             UINT8_C(131), UINT8_C( 45), UINT8_C(217), UINT8_C(137),
                             UINT8_C( 74), UINT8_C(164), UINT8_C(178), UINT8_C( 53),
                             UINT8_C( 17), UINT8_C(235), UINT8_C(105), UINT8_C(154),
                             UINT8_C(255), UINT8_C(237), UINT8_C(110), UINT8_C(172),
                             UINT8_C(163), UINT8_C( 19), UINT8_C(158), UINT8_C(128),
                             UINT8_C(233), UINT8_C( 49), UINT8_C(100), UINT8_C(122),
                             UINT8_C(160), UINT8_C(153), UINT8_C( 60), UINT8_C(232),
                             UINT8_C( 23), UINT8_C(204), UINT8_C(219), UINT8_C(200),
                             UINT8_C(206), UINT8_C(  4), UINT8_C(187), UINT8_C(  1),
                             UINT8_C(231), UINT8_C(246), UINT8_C( 93), UINT8_C( 51)),
      simde_x_mm512_set_epu8(UINT8_C(  0), UINT8_C( 35), UINT8_C(169), UINT8_C(158),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C( 25), UINT8_C(  0),
                             UINT8_C( 72), UINT8_C(176), UINT8_C(  0), UINT8_C( 26),
                             UINT8_C( 94), UINT8_C(  0), UINT8_C( 18), UINT8_C( 75),
                             UINT8_C(  0), UINT8_C(208), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C( 14), UINT8_C(165), UINT8_C(  0), UINT8_C( 46),
                             UINT8_C(  0), UINT8_C(121), UINT8_C(  0), UINT8_C(  7),
                             UINT8_C(173), UINT8_C( 39), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(142), UINT8_C(  0), UINT8_C(  0), UINT8_C( 66),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C( 57), UINT8_C(  0),
                             UINT8_C( 63), UINT8_C(136), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(110), UINT8_C(141), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C( 18), UINT8_C( 66), UINT8_C(  0),
                             UINT8_C(142), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C( 69), UINT8_C(  9), UINT8_C( 68),
                             UINT8_C(  2), UINT8_C(  0), UINT8_C(  0), UINT8_C(197)) },
    { simde_x_mm512_set_epu8(UINT8_C(167), UINT8_C( 43), UINT8_C( 52), UINT8_C( 82),
                             UINT8_C(219), UINT8_C( 55), UINT8_C(112), UINT8_C(234),
                             UINT8_C(181), UINT8_C(220), UINT8_C(222), UINT8_C(241),
                             UINT8_C( 35), UINT8_C(214), UINT8_C(155), UINT8_C(251),
                             UINT8_C(  2), UINT8_C( 35), UINT8_C( 14), UINT8_C(183),
                             UINT8_C(206), UINT8_C(223), UINT8_C(191), UINT8_C( 94),
                             UINT8_C(250), UINT8_C(235), UINT8_C(228), UINT8_C( 21),
                             UINT8_C(102), UINT8_C(169), UINT8_C(114), UINT8_C(125),
                             UINT8_C(113), UINT8_C(124), UINT8_C(135), UINT8_C(134),
                             UINT8_C( 23), UINT8_C(107), UINT8_C( 24), UINT8_C(126),
                             UINT8_C( 80), UINT8_C( 59), UINT8_C( 39), UINT8_C(195),
                             UINT8_C(151), UINT8_C( 32), UINT8_C( 55), UINT8_C(247),
                             UINT8_C( 60), UINT8_C(131), UINT8_C( 72), UINT8_C(220),
                             UINT8_C( 77), UINT8_C(191), UINT8_C(117), UINT8_C(171),
                             UINT8_C( 98), UINT8_C(173), UINT8_C(187), UINT8_C(204),
                             UINT8_C( 41), UINT8_C(246), UINT8_C(238), UINT8_C( 56)),
      simde_x_mm512_set_epu8(UINT8_C( 22), UINT8_C(122), UINT8_C(166), UINT8_C(  2),
                             UINT8_C(191), UINT8_C( 51), UINT8_C(162), UINT8_C(206),
                             UINT8_C(241), UINT8_C( 19), UINT8_C(237), UINT8_C( 66),
                             UINT8_C(119), UINT8_C(138), UINT8_C(144), UINT8_C(140),
                             UINT8_C( 44), UINT8_C(244), UINT8_C( 31), UINT8_C( 43),
                             UINT8_C(240), UINT8_C(219), UINT8_C(232), UINT8_C(224),
                             UINT8_C(161), UINT8_C(170), UINT8_C(160), UINT8_C( 80),
                             UINT8_C( 68), UINT8_C( 13), UINT8_C(248), UINT8_C( 67),
                             UINT8_C(107), UINT8_C(131), UINT8_C(104), UINT8_C(176),
                             UINT8_C( 97), UINT8_C(178), UINT8_C(106), UINT8_C(203),
                             UINT8_C(220), UINT8_C(166), UINT8_C( 74), UINT8_C(184),
                             UINT8_C( 59), UINT8_C(175), UINT8_C(248), UINT8_C(231),
                             UINT8_C(201), UINT8_C(157), UINT8_C( 20), UINT8_C(  9),
                             UINT8_C(167), UINT8_C(166), UINT8_C(108), UINT8_C( 56),
                             UINT8_C(237), UINT8_C( 81), UINT8_C(122), UINT8_C(  6),
                             UINT8_C(137), UINT8_C(122), UINT8_C(221), UINT8_C(106)),
      simde_x_mm512_set_epu8(UINT8_C(145), UINT8_C(  0), UINT8_C(  0), UINT8_C( 80),
                             UINT8_C( 28), UINT8_C(  4), UINT8_C(  0), UINT8_C( 28),
                             UINT8_C(  0), UINT8_C(201), UINT8_C(  0), UINT8_C(175),
                             UINT8_C(  0), UINT8_C( 76), UINT8_C( 11), UINT8_C(111),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(140),
                             UINT8_C(  0), UINT8_C(  4), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C( 89), UINT8_C( 65), UINT8_C( 68), UINT8_C(  0),
                             UINT8_C( 34), UINT8_C(156), UINT8_C(  0), UINT8_C( 58),
                             UINT8_C(  6), UINT8_C(  0), UINT8_C( 31), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C( 11),
                             UINT8_C( 92), UINT8_C(  0), UINT8_C(  0), UINT8_C( 16),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C( 52), UINT8_C(211),
                             UINT8_C(  0), UINT8_C( 25), UINT8_C(  9), UINT8_C(115),
                             UINT8_C(  0), UINT8_C( 92), UINT8_C( 65), UINT8_C(198),
                             UINT8_C(  0), UINT8_C(124), UINT8_C( 17), UINT8_C(  0)) },
    { simde_x_mm512_set_epu8(UINT8_C(105), UINT8_C(141), UINT8_C(121), UINT8_C(155),
                             UINT8_C(  0), UINT8_C( 63), UINT8_C(214), UINT8_C(222),
                             UINT8_C(251), UINT8_C(209), UINT8_C(133), UINT8_C(204),
                             UINT8_C(170), UINT8_C(228), UINT8_C(193), UINT8_C( 20),
                             UINT8_C(196), UINT8_C(193), UINT8_C( 99), UINT8_C( 78),
                             UINT8_C( 56), UINT8_C(184), UINT8_C(201), UINT8_C(184),
                             UINT8_C( 79), UINT8_C(175), UINT8_C(124), UINT8_C(171),
                             UINT8_C(191), UINT8_C(122), UINT8_C(231), UINT8_C(198),
                             UINT8_C(192), UINT8_C( 52), UINT8_C(244), UINT8_C(  1),
                             UINT8_C(194), UINT8_C(228), UINT8_C(228), UINT8_C(152),
                             UINT8_C( 54), UINT8_C(153), UINT8_C(201), UINT8_C(234),
                             UINT8_C(165), UINT8_C(  6), UINT8_C(247), UINT8_C(225),
                             UINT8_C( 18), UINT8_C(145), UINT8_C( 58), UINT8_C( 71),
                             UINT8_C(183), UINT8_C(160), UINT8_C( 28), UINT8_C(252),
                             UINT8_C( 47), UINT8_C( 66), UINT8_C(121), UINT8_C( 38),
                             UINT8_C( 69), UINT8_C(149), UINT8_C(199), UINT8_C(136)),
      simde_x_mm512_set_epu8(UINT8_C(207), UINT8_C( 15), UINT8_C(241), UINT8_C(197),
                             UINT8_C(143), UINT8_C(102), UINT8_C(208), UINT8_C(178),
                             UINT8_C( 31), UINT8_C( 94), UINT8_C( 79), UINT8_C( 92),
                             UINT8_C(106), UINT8_C(188), UINT8_C( 96), UINT8_C(159),
                             UINT8_C(229), UINT8_C(138), UINT8_C(245), UINT8_C(112),
                             UINT8_C(131), UINT8_C( 70), UINT8_C( 26), UINT8_C(218),
                             UINT8_C(240), UINT8_C(144), UINT8_C( 10), UINT8_C( 98),
                             UINT8_C(252), UINT8_C(120), UINT8_C(223), UINT8_C(129),
                             UINT8_C(191), UINT8_C(216), UINT8_C( 88), UINT8_C(250),
                             UINT8_C( 74), UINT8_C( 41), UINT8_C( 39), UINT8_C( 79),
                             UINT8_C(131), UINT8_C(249), UINT8_C( 62), UINT8_C(144),
                             UINT8_C(137), UINT8_C(247), UINT8_C( 71), UINT8_C(188),
                             UINT8_C(177), UINT8_C( 48), UINT8_C(236), UINT8_C(159),
                             UINT8_C(140), UINT8_C(120), UINT8_C(191), UINT8_C(  6),
                             UINT8_C(224), UINT8_C(181), UINT8_C(150), UINT8_C( 26),
                             UINT8_C(160), UINT8_C( 50), UINT8_C(211), UINT8_C( 16)),
      simde_x_mm512_set_epu8(UINT8_C(  0), UINT8_C(126), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  6), UINT8_C( 44),
                             UINT8_C(220), UINT8_C(115), UINT8_C( 54), UINT8_C(112),
                             UINT8_C( 64), UINT8_C( 40), UINT8_C( 97), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C( 55), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(114), UINT8_C(175), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C( 31), UINT8_C(114), UINT8_C( 73),
                             UINT8_C(  0), UINT8_C(  2), UINT8_C(  8), UINT8_C( 69),
                             UINT8_C(  1), UINT8_C(  0), UINT8_C(156), UINT8_C(  0),
                             UINT8_C(120), UINT8_C(187), UINT8_C(189), UINT8_C( 73),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(139), UINT8_C( 90),
                             UINT8_C( 28), UINT8_C(  0), UINT8_C(176), UINT8_C( 37),
                             UINT8_C(  0), UINT8_C( 97), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C( 43), UINT8_C( 40), UINT8_C(  0), UINT8_C(246),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C( 12),
                             UINT8_C(  0), UINT8_C( 99), UINT8_C(  0), UINT8_C(120)) }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])); i++) {
    simde__m512i r = simde_mm512_subs_epu8(test_vec[i].a, test_vec[i].b);
    simde_assert_m512i_u8(r, ==, test_vec[i].r);
  }

  return 0;
}

static int
test_simde_mm512_mask_subs_epu8(SIMDE_MUNIT_TEST_ARGS) {
  const struct {
    simde__m512i src;
    simde__mmask64 k;
    simde__m512i a;
    simde__m512i b;
    simde__m512i r;
  } test_vec[8] = {
    { simde_x_mm512_set_epu8(UINT8_C(160), UINT8_C(209), UINT8_C( 53), UINT8_C(241),
                             UINT8_C(169), UINT8_C( 74), UINT8_C(195), UINT8_C(156),
                             UINT8_C(226), UINT8_C(114), UINT8_C(119), UINT8_C(203),
                             UINT8_C( 15), UINT8_C( 80), UINT8_C(207), UINT8_C(120),
                             UINT8_C(164), UINT8_C(171), UINT8_C( 95), UINT8_C(130),
                             UINT8_C(161), UINT8_C(  3), UINT8_C( 82), UINT8_C(197),
                             UINT8_C( 78), UINT8_C(216), UINT8_C(176), UINT8_C(131),
                             UINT8_C(213), UINT8_C( 21), UINT8_C( 48), UINT8_C(162),
                             UINT8_C(135), UINT8_C( 81), UINT8_C( 67), UINT8_C(242),
                             UINT8_C( 97), UINT8_C( 89), UINT8_C(174), UINT8_C( 64),
                             UINT8_C(170), UINT8_C(194), UINT8_C(235), UINT8_C(133),
                             UINT8_C( 33), UINT8_C(160), UINT8_C(236), UINT8_C(  7),
                             UINT8_C(224), UINT8_C( 63), UINT8_C(130), UINT8_C( 28),
                             UINT8_C( 83), UINT8_C(152), UINT8_C(149), UINT8_C(111),
                             UINT8_C(188), UINT8_C( 24), UINT8_C( 57), UINT8_C( 80),
                             UINT8_C(100), UINT8_C( 11), UINT8_C(241), UINT8_C(117)),
      UINT64_C(          2661966794),
      simde_x_mm512_set_epu8(UINT8_C(164), UINT8_C( 45), UINT8_C(193), UINT8_C(111),
                             UINT8_C( 96), UINT8_C(220), UINT8_C( 54), UINT8_C(232),
                             UINT8_C(214), UINT8_C(244), UINT8_C(236), UINT8_C( 74),
                             UINT8_C( 47), UINT8_C(180), UINT8_C(143), UINT8_C(214),
                             UINT8_C(  6), UINT8_C(178), UINT8_C( 35), UINT8_C(129),
                             UINT8_C( 21), UINT8_C(157), UINT8_C( 30), UINT8_C( 29),
                             UINT8_C(226), UINT8_C(222), UINT8_C( 14), UINT8_C(170),
                             UINT8_C(223), UINT8_C(200), UINT8_C( 41), UINT8_C(245),
                             UINT8_C(  7), UINT8_C(251), UINT8_C( 30), UINT8_C(217),
                             UINT8_C( 93), UINT8_C(228), UINT8_C(143), UINT8_C(  9),
                             UINT8_C(221), UINT8_C( 49), UINT8_C(207), UINT8_C( 44),
                             UINT8_C( 52), UINT8_C(108), UINT8_C(124), UINT8_C( 14),
                             UINT8_C(144), UINT8_C(229), UINT8_C(102), UINT8_C( 16),
                             UINT8_C( 61), UINT8_C(  2), UINT8_C(169), UINT8_C( 72),
                             UINT8_C(194), UINT8_C(122), UINT8_C(216), UINT8_C(151),
                             UINT8_C(244), UINT8_C(227), UINT8_C(  5), UINT8_C( 98)),
      simde_x_mm512_set_epu8(UINT8_C( 53), UINT8_C( 65), UINT8_C(131), UINT8_C(189),
                             UINT8_C(196), UINT8_C(200), UINT8_C(234), UINT8_C( 92),
                             UINT8_C( 99), UINT8_C(187), UINT8_C(123), UINT8_C(180),
                             UINT8_C(209), UINT8_C(163), UINT8_C( 86), UINT8_C( 26),
                             UINT8_C(192), UINT8_C( 36), UINT8_C(205), UINT8_C(108),
                             UINT8_C(173), UINT8_C( 71), UINT8_C(190), UINT8_C( 46),
                             UINT8_C(173), UINT8_C(156), UINT8_C( 59), UINT8_C(250),
                             UINT8_C( 13), UINT8_C(171), UINT8_C(  1), UINT8_C( 47),
                             UINT8_C(227), UINT8_C( 45), UINT8_C(181), UINT8_C( 45),
                             UINT8_C(116), UINT8_C( 89), UINT8_C(112), UINT8_C(127),
                             UINT8_C( 42), UINT8_C(134), UINT8_C(128), UINT8_C(206),
                             UINT8_C( 87), UINT8_C(206), UINT8_C( 39), UINT8_C(  7),
                             UINT8_C( 48), UINT8_C( 47), UINT8_C( 79), UINT8_C( 32),
                             UINT8_C( 39), UINT8_C(205), UINT8_C(174), UINT8_C(244),
                             UINT8_C(251), UINT8_C( 10), UINT8_C( 13), UINT8_C( 53),
                             UINT8_C(255), UINT8_C(222), UINT8_C( 66), UINT8_C( 52)),
      simde_x_mm512_set_epu8(UINT8_C(160), UINT8_C(209), UINT8_C( 53), UINT8_C(241),
                             UINT8_C(169), UINT8_C( 74), UINT8_C(195), UINT8_C(156),
                             UINT8_C(226), UINT8_C(114), UINT8_C(119), UINT8_C(203),
                             UINT8_C( 15), UINT8_C( 80), UINT8_C(207), UINT8_C(120),
                             UINT8_C(164), UINT8_C(171), UINT8_C( 95), UINT8_C(130),
                             UINT8_C(161), UINT8_C(  3), UINT8_C( 82), UINT8_C(197),
                             UINT8_C( 78), UINT8_C(216), UINT8_C(176), UINT8_C(131),
                             UINT8_C(213), UINT8_C( 21), UINT8_C( 48), UINT8_C(162),
                             UINT8_C(  0), UINT8_C( 81), UINT8_C( 67), UINT8_C(172),
                             UINT8_C(  0), UINT8_C(139), UINT8_C( 31), UINT8_C( 64),
                             UINT8_C(179), UINT8_C(194), UINT8_C( 79), UINT8_C(133),
                             UINT8_C(  0), UINT8_C(160), UINT8_C( 85), UINT8_C(  7),
                             UINT8_C(224), UINT8_C(182), UINT8_C( 23), UINT8_C( 28),
                             UINT8_C( 83), UINT8_C(152), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(112), UINT8_C( 57), UINT8_C( 80),
                             UINT8_C(  0), UINT8_C( 11), UINT8_C(  0), UINT8_C(117)) },
    { simde_x_mm512_set_epu8(UINT8_C(108), UINT8_C( 96), UINT8_C(  9), UINT8_C(145),
                             UINT8_C(131), UINT8_C(204), UINT8_C(151), UINT8_C(200),
                             UINT8_C(172), UINT8_C(193), UINT8_C(248), UINT8_C(227),
                             UINT8_C(159), UINT8_C( 34), UINT8_C( 70), UINT8_C( 14),
                             UINT8_C(229), UINT8_C( 98), UINT8_C( 73), UINT8_C(209),
                             UINT8_C( 59), UINT8_C(209), UINT8_C( 82), UINT8_C( 90),
                             UINT8_C(172), UINT8_C( 10), UINT8_C(185), UINT8_C(194),
                             UINT8_C(184), UINT8_C( 76), UINT8_C(173), UINT8_C( 75),
                             UINT8_C(136), UINT8_C(130), UINT8_C(227), UINT8_C(162),
                             UINT8_C(154), UINT8_C(158), UINT8_C(121), UINT8_C( 19),
                             UINT8_C(211), UINT8_C(197), UINT8_C( 15), UINT8_C( 80),
                             UINT8_C( 75), UINT8_C( 26), UINT8_C( 77), UINT8_C(210),
                             UINT8_C(117), UINT8_C( 85), UINT8_C(204), UINT8_C(  0),
                             UINT8_C(244), UINT8_C( 11), UINT8_C(128), UINT8_C(245),
                             UINT8_C(177), UINT8_C(132), UINT8_C(179), UINT8_C(117),
                             UINT8_C(215), UINT8_C( 43), UINT8_C(143), UINT8_C( 75)),
      UINT64_C(          1314676378),
      simde_x_mm512_set_epu8(UINT8_C(122), UINT8_C(121), UINT8_C( 15), UINT8_C(167),
                             UINT8_C(146), UINT8_C(  1), UINT8_C( 27), UINT8_C( 93),
                             UINT8_C(177), UINT8_C(197), UINT8_C(189), UINT8_C(233),
                             UINT8_C(110), UINT8_C( 47), UINT8_C( 66), UINT8_C( 91),
                             UINT8_C( 52), UINT8_C(  7), UINT8_C(197), UINT8_C( 20),
                             UINT8_C( 34), UINT8_C(208), UINT8_C(127), UINT8_C( 73),
                             UINT8_C(145), UINT8_C(  2), UINT8_C( 27), UINT8_C(235),
                             UINT8_C(109), UINT8_C(152), UINT8_C(220), UINT8_C(143),
                             UINT8_C(189), UINT8_C(222), UINT8_C(102), UINT8_C(126),
                             UINT8_C( 80), UINT8_C( 51), UINT8_C(253), UINT8_C(186),
                             UINT8_C( 51), UINT8_C(206), UINT8_C(118), UINT8_C( 48),
                             UINT8_C( 59), UINT8_C(184), UINT8_C(197), UINT8_C(107),
                             UINT8_C( 52), UINT8_C(  5), UINT8_C(208), UINT8_C(231),
                             UINT8_C(151), UINT8_C(166), UINT8_C(151), UINT8_C( 49),
                             UINT8_C( 74), UINT8_C(239), UINT8_C(157), UINT8_C(112),
                             UINT8_C(217), UINT8_C(111), UINT8_C( 21), UINT8_C(221)),
      simde_x_mm512_set_epu8(UINT8_C( 54), UINT8_C( 10), UINT8_C( 52), UINT8_C(157),
                             UINT8_C( 51), UINT8_C( 63), UINT8_C(190), UINT8_C(105),
                             UINT8_C(159), UINT8_C( 57), UINT8_C(152), UINT8_C(  2),
                             UINT8_C(134), UINT8_C(112), UINT8_C( 29), UINT8_C(  8),
                             UINT8_C(240), UINT8_C( 55), UINT8_C(110), UINT8_C(144),
                             UINT8_C(247), UINT8_C( 78), UINT8_C(254), UINT8_C( 89),
                             UINT8_C(189), UINT8_C(169), UINT8_C(164), UINT8_C(239),
                             UINT8_C(227), UINT8_C(187), UINT8_C( 11), UINT8_C(211),
                             UINT8_C(183), UINT8_C(  9), UINT8_C(204), UINT8_C(138),
                             UINT8_C(223), UINT8_C( 91), UINT8_C(198), UINT8_C( 18),
                             UINT8_C(178), UINT8_C(209), UINT8_C(152), UINT8_C(100),
                             UINT8_C(247), UINT8_C(142), UINT8_C( 53), UINT8_C( 94),
                             UINT8_C(238), UINT8_C(239), UINT8_C(151), UINT8_C(119),
                             UINT8_C(229), UINT8_C( 96), UINT8_C(245), UINT8_C(  0),
                             UINT8_C(141), UINT8_C( 95), UINT8_C(101), UINT8_C(146),
                             UINT8_C(141), UINT8_C( 37), UINT8_C( 41), UINT8_C(148)),
      simde_x_mm512_set_epu8(UINT8_C(108), UINT8_C( 96), UINT8_C(  9), UINT8_C(145),
                             UINT8_C(131), UINT8_C(204), UINT8_C(151), UINT8_C(200),
                             UINT8_C(172), UINT8_C(193), UINT8_C(248), UINT8_C(227),
                             UINT8_C(159), UINT8_C( 34), UINT8_C( 70), UINT8_C( 14),
                             UINT8_C(229), UINT8_C( 98), UINT8_C( 73), UINT8_C(209),
                             UINT8_C( 59), UINT8_C(209), UINT8_C( 82), UINT8_C( 90),
                             UINT8_C(172), UINT8_C( 10), UINT8_C(185), UINT8_C(194),
                             UINT8_C(184), UINT8_C( 76), UINT8_C(173), UINT8_C( 75),
                             UINT8_C(136), UINT8_C(213), UINT8_C(227), UINT8_C(162),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C( 55), UINT8_C( 19),
                             UINT8_C(211), UINT8_C(  0), UINT8_C( 15), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C( 42), UINT8_C( 77), UINT8_C(210),
                             UINT8_C(117), UINT8_C(  0), UINT8_C(204), UINT8_C(112),
                             UINT8_C(  0), UINT8_C( 70), UINT8_C(  0), UINT8_C(245),
                             UINT8_C(  0), UINT8_C(132), UINT8_C(179), UINT8_C(  0),
                             UINT8_C( 76), UINT8_C( 43), UINT8_C(  0), UINT8_C( 75)) },
    { simde_x_mm512_set_epu8(UINT8_C(206), UINT8_C(206), UINT8_C( 30), UINT8_C( 15),
                             UINT8_C(114), UINT8_C(103), UINT8_C( 13), UINT8_C(110),
                             UINT8_C(166), UINT8_C( 46), UINT8_C(130), UINT8_C(151),
                             UINT8_C( 16), UINT8_C( 40), UINT8_C(154), UINT8_C( 67),
                             UINT8_C(184), UINT8_C( 37), UINT8_C(207), UINT8_C( 94),
                             UINT8_C( 79), UINT8_C(202), UINT8_C(122), UINT8_C(203),
                             UINT8_C(179), UINT8_C(164), UINT8_C( 37), UINT8_C(173),
                             UINT8_C( 95), UINT8_C(170), UINT8_C( 47), UINT8_C(161),
                             UINT8_C(255), UINT8_C(185), UINT8_C(163), UINT8_C(181),
                             UINT8_C( 29), UINT8_C(148), UINT8_C(134), UINT8_C( 11),
                             UINT8_C(137), UINT8_C(213), UINT8_C(115), UINT8_C(139),
                             UINT8_C( 77), UINT8_C(129), UINT8_C( 55), UINT8_C(  6),
                             UINT8_C(222), UINT8_C(184), UINT8_C(104), UINT8_C( 68),
                             UINT8_C(167), UINT8_C( 53), UINT8_C( 35), UINT8_C( 81),
                             UINT8_C(255), UINT8_C(129), UINT8_C(219), UINT8_C(221),
                             UINT8_C(186), UINT8_C( 75), UINT8_C(231), UINT8_C(243)),
      UINT64_C(          1370699036),
      simde_x_mm512_set_epu8(UINT8_C(228), UINT8_C( 29), UINT8_C(156), UINT8_C(201),
                             UINT8_C(217), UINT8_C( 60), UINT8_C( 61), UINT8_C( 86),
                             UINT8_C(205), UINT8_C(204), UINT8_C( 26), UINT8_C( 35),
                             UINT8_C(113), UINT8_C( 54), UINT8_C( 44), UINT8_C(150),
                             UINT8_C(  5), UINT8_C(127), UINT8_C(118), UINT8_C(122),
                             UINT8_C(  8), UINT8_C( 76), UINT8_C( 62), UINT8_C( 54),
                             UINT8_C(171), UINT8_C(236), UINT8_C(228), UINT8_C( 23),
                             UINT8_C(167), UINT8_C( 85), UINT8_C(106), UINT8_C(203),
                             UINT8_C( 75), UINT8_C(211), UINT8_C(183), UINT8_C(233),
                             UINT8_C(230), UINT8_C(155), UINT8_C(159), UINT8_C(231),
                             UINT8_C( 53), UINT8_C( 16), UINT8_C(224), UINT8_C(218),
                             UINT8_C(254), UINT8_C(170), UINT8_C(229), UINT8_C(158),
                             UINT8_C(154), UINT8_C(108), UINT8_C(114), UINT8_C(193),
                             UINT8_C(254), UINT8_C( 39), UINT8_C(143), UINT8_C(155),
                             UINT8_C(241), UINT8_C(232), UINT8_C(128), UINT8_C(233),
                             UINT8_C(178), UINT8_C(  6), UINT8_C(154), UINT8_C(184)),
      simde_x_mm512_set_epu8(UINT8_C(165), UINT8_C(173), UINT8_C(234), UINT8_C(165),
                             UINT8_C(146), UINT8_C(243), UINT8_C( 52), UINT8_C( 89),
                             UINT8_C(227), UINT8_C( 93), UINT8_C(108), UINT8_C( 47),
                             UINT8_C(207), UINT8_C(115), UINT8_C(178), UINT8_C(155),
                             UINT8_C(250), UINT8_C(115), UINT8_C(  2), UINT8_C( 73),
                             UINT8_C(254), UINT8_C(119), UINT8_C( 72), UINT8_C(108),
                             UINT8_C( 90), UINT8_C( 96), UINT8_C( 56), UINT8_C(182),
                             UINT8_C( 64), UINT8_C(  8), UINT8_C(172), UINT8_C(169),
                             UINT8_C( 32), UINT8_C( 75), UINT8_C( 92), UINT8_C(114),
                             UINT8_C( 16), UINT8_C( 36), UINT8_C(161), UINT8_C( 46),
                             UINT8_C(214), UINT8_C(247), UINT8_C(176), UINT8_C( 43),
                             UINT8_C(168), UINT8_C(161), UINT8_C(148), UINT8_C( 77),
                             UINT8_C(231), UINT8_C(174), UINT8_C( 75), UINT8_C( 48),
                             UINT8_C(123), UINT8_C(251), UINT8_C(221), UINT8_C(100),
                             UINT8_C( 39), UINT8_C(159), UINT8_C( 61), UINT8_C( 37),
                             UINT8_C(160), UINT8_C(166), UINT8_C( 87), UINT8_C(103)),
      simde_x_mm512_set_epu8(UINT8_C(206), UINT8_C(206), UINT8_C( 30), UINT8_C( 15),
                             UINT8_C(114), UINT8_C(103), UINT8_C( 13), UINT8_C(110),
                             UINT8_C(166), UINT8_C( 46), UINT8_C(130), UINT8_C(151),
                             UINT8_C( 16), UINT8_C( 40), UINT8_C(154), UINT8_C( 67),
                             UINT8_C(184), UINT8_C( 37), UINT8_C(207), UINT8_C( 94),
                             UINT8_C( 79), UINT8_C(202), UINT8_C(122), UINT8_C(203),
                             UINT8_C(179), UINT8_C(164), UINT8_C( 37), UINT8_C(173),
                             UINT8_C( 95), UINT8_C(170), UINT8_C( 47), UINT8_C(161),
                             UINT8_C(255), UINT8_C(136), UINT8_C(163), UINT8_C(119),
                             UINT8_C( 29), UINT8_C(148), UINT8_C(134), UINT8_C(185),
                             UINT8_C(  0), UINT8_C(213), UINT8_C( 48), UINT8_C(175),
                             UINT8_C( 77), UINT8_C(129), UINT8_C( 81), UINT8_C( 81),
                             UINT8_C(222), UINT8_C(184), UINT8_C( 39), UINT8_C(145),
                             UINT8_C(167), UINT8_C(  0), UINT8_C( 35), UINT8_C( 55),
                             UINT8_C(255), UINT8_C(129), UINT8_C(219), UINT8_C(196),
                             UINT8_C( 18), UINT8_C(  0), UINT8_C(231), UINT8_C(243)) },
    { simde_x_mm512_set_epu8(UINT8_C(215), UINT8_C( 43), UINT8_C(249), UINT8_C(194),
                             UINT8_C(157), UINT8_C(199), UINT8_C( 98), UINT8_C(233),
                             UINT8_C( 27), UINT8_C(181), UINT8_C(227), UINT8_C( 75),
                             UINT8_C( 73), UINT8_C( 96), UINT8_C(149), UINT8_C(223),
                             UINT8_C(104), UINT8_C( 32), UINT8_C( 22), UINT8_C(168),
                             UINT8_C( 89), UINT8_C( 99), UINT8_C(164), UINT8_C(153),
                             UINT8_C( 65), UINT8_C(170), UINT8_C( 53), UINT8_C( 47),
                             UINT8_C(191), UINT8_C(169), UINT8_C( 40), UINT8_C( 76),
                             UINT8_C(114), UINT8_C(220), UINT8_C( 85), UINT8_C(210),
                             UINT8_C(141), UINT8_C( 16), UINT8_C( 66), UINT8_C(216),
                             UINT8_C(211), UINT8_C(107), UINT8_C(217), UINT8_C(119),
                             UINT8_C(250), UINT8_C( 64), UINT8_C(254), UINT8_C( 91),
                             UINT8_C( 35), UINT8_C(245), UINT8_C(193), UINT8_C( 56),
                             UINT8_C(248), UINT8_C(186), UINT8_C( 68), UINT8_C(150),
                             UINT8_C(220), UINT8_C(248), UINT8_C(101), UINT8_C(  0),
                             UINT8_C(116), UINT8_C(116), UINT8_C( 64), UINT8_C(175)),
      UINT64_C(          4015290579),
      simde_x_mm512_set_epu8(UINT8_C( 21), UINT8_C(153), UINT8_C(252), UINT8_C(180),
                             UINT8_C(184), UINT8_C( 70), UINT8_C( 16), UINT8_C(164),
                             UINT8_C( 32), UINT8_C(157), UINT8_C(177), UINT8_C(185),
                             UINT8_C( 75), UINT8_C(213), UINT8_C(118), UINT8_C( 48),
                             UINT8_C(250), UINT8_C(247), UINT8_C(144), UINT8_C(182),
                             UINT8_C( 89), UINT8_C(193), UINT8_C(215), UINT8_C(109),
                             UINT8_C( 32), UINT8_C( 44), UINT8_C( 30), UINT8_C(115),
                             UINT8_C(122), UINT8_C(173), UINT8_C( 22), UINT8_C(177),
                             UINT8_C(163), UINT8_C(190), UINT8_C(161), UINT8_C(157),
                             UINT8_C(186), UINT8_C(207), UINT8_C(230), UINT8_C( 94),
                             UINT8_C(188), UINT8_C( 54), UINT8_C(164), UINT8_C(150),
                             UINT8_C( 11), UINT8_C( 80), UINT8_C(167), UINT8_C(171),
                             UINT8_C(  7), UINT8_C(177), UINT8_C(223), UINT8_C(132),
                             UINT8_C(186), UINT8_C( 43), UINT8_C( 15), UINT8_C(205),
                             UINT8_C( 56), UINT8_C(209), UINT8_C( 90), UINT8_C(226),
                             UINT8_C(128), UINT8_C( 65), UINT8_C( 94), UINT8_C(244)),
      simde_x_mm512_set_epu8(UINT8_C( 31), UINT8_C( 58), UINT8_C(132), UINT8_C( 37),
                             UINT8_C(154), UINT8_C(  6), UINT8_C( 75), UINT8_C(156),
                             UINT8_C(149), UINT8_C(144), UINT8_C(181), UINT8_C(171),
                             UINT8_C(160), UINT8_C( 77), UINT8_C(155), UINT8_C(252),
                             UINT8_C(181), UINT8_C(149), UINT8_C( 69), UINT8_C( 75),
                             UINT8_C(202), UINT8_C( 32), UINT8_C( 21), UINT8_C( 82),
                             UINT8_C(184), UINT8_C(152), UINT8_C(217), UINT8_C( 20),
                             UINT8_C( 41), UINT8_C( 41), UINT8_C(  1), UINT8_C( 97),
                             UINT8_C(165), UINT8_C(111), UINT8_C(131), UINT8_C( 21),
                             UINT8_C( 63), UINT8_C( 20), UINT8_C(145), UINT8_C(147),
                             UINT8_C( 66), UINT8_C( 29), UINT8_C(208), UINT8_C( 15),
                             UINT8_C(209), UINT8_C(114), UINT8_C(194), UINT8_C(  3),
                             UINT8_C( 96), UINT8_C(111), UINT8_C( 93), UINT8_C(100),
                             UINT8_C(124), UINT8_C( 70), UINT8_C(116), UINT8_C(210),
                             UINT8_C( 69), UINT8_C(255), UINT8_C(157), UINT8_C(160),
                             UINT8_C( 53), UINT8_C( 12), UINT8_C(237), UINT8_C(134)),
      simde_x_mm512_set_epu8(UINT8_C(215), UINT8_C( 43), UINT8_C(249), UINT8_C(194),
                             UINT8_C(157), UINT8_C(199), UINT8_C( 98), UINT8_C(233),
                             UINT8_C( 27), UINT8_C(181), UINT8_C(227), UINT8_C( 75),
                             UINT8_C( 73), UINT8_C( 96), UINT8_C(149), UINT8_C(223),
                             UINT8_C(104), UINT8_C( 32), UINT8_C( 22), UINT8_C(168),
                             UINT8_C( 89), UINT8_C( 99), UINT8_C(164), UINT8_C(153),
                             UINT8_C( 65), UINT8_C(170), UINT8_C( 53), UINT8_C( 47),
                             UINT8_C(191), UINT8_C(169), UINT8_C( 40), UINT8_C( 76),
                             UINT8_C(  0), UINT8_C( 79), UINT8_C( 30), UINT8_C(210),
                             UINT8_C(123), UINT8_C(187), UINT8_C( 85), UINT8_C(  0),
                             UINT8_C(211), UINT8_C( 25), UINT8_C(217), UINT8_C(135),
                             UINT8_C(250), UINT8_C(  0), UINT8_C(254), UINT8_C( 91),
                             UINT8_C( 35), UINT8_C( 66), UINT8_C(130), UINT8_C( 32),
                             UINT8_C( 62), UINT8_C(186), UINT8_C( 68), UINT8_C(150),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(101), UINT8_C( 66),
                             UINT8_C(116), UINT8_C(116), UINT8_C(  0), UINT8_C(110)) },
    { simde_x_mm512_set_epu8(UINT8_C(181), UINT8_C( 56), UINT8_C(192), UINT8_C(150),
                             UINT8_C( 44), UINT8_C(209), UINT8_C( 13), UINT8_C(238),
                             UINT8_C(199), UINT8_C(135), UINT8_C(144), UINT8_C(  8),
                             UINT8_C( 13), UINT8_C(143), UINT8_C(242), UINT8_C(219),
                             UINT8_C(103), UINT8_C(252), UINT8_C(214), UINT8_C(167),
                             UINT8_C(  3), UINT8_C(136), UINT8_C(222), UINT8_C(241),
                             UINT8_C(  7), UINT8_C( 92), UINT8_C(141), UINT8_C(140),
                             UINT8_C(104), UINT8_C(125), UINT8_C(212), UINT8_C(114),
                             UINT8_C(114), UINT8_C(229), UINT8_C(235), UINT8_C(144),
                             UINT8_C(233), UINT8_C(188), UINT8_C( 95), UINT8_C(193),
                             UINT8_C( 27), UINT8_C(148), UINT8_C( 89), UINT8_C(138),
                             UINT8_C(232), UINT8_C(105), UINT8_C(208), UINT8_C(244),
                             UINT8_C( 62), UINT8_C(166), UINT8_C(227), UINT8_C( 87),
                             UINT8_C(254), UINT8_C( 17), UINT8_C(235), UINT8_C(147),
                             UINT8_C(215), UINT8_C(  8), UINT8_C(107), UINT8_C( 75),
                             UINT8_C(237), UINT8_C(121), UINT8_C( 75), UINT8_C( 80)),
      UINT64_C(          3983161372),
      simde_x_mm512_set_epu8(UINT8_C(105), UINT8_C(165), UINT8_C(196), UINT8_C(175),
                             UINT8_C( 21), UINT8_C( 33), UINT8_C( 59), UINT8_C( 91),
                             UINT8_C(173), UINT8_C( 84), UINT8_C(102), UINT8_C(234),
                             UINT8_C(240), UINT8_C( 97), UINT8_C( 44), UINT8_C(117),
                             UINT8_C(253), UINT8_C( 63), UINT8_C(177), UINT8_C(  7),
                             UINT8_C( 84), UINT8_C(101), UINT8_C( 54), UINT8_C(237),
                             UINT8_C(110), UINT8_C( 66), UINT8_C( 52), UINT8_C(158),
                             UINT8_C(218), UINT8_C(146), UINT8_C(129), UINT8_C(  7),
                             UINT8_C(170), UINT8_C( 34), UINT8_C( 11), UINT8_C( 33),
                             UINT8_C(109), UINT8_C( 75), UINT8_C(249), UINT8_C(174),
                             UINT8_C( 89), UINT8_C(221), UINT8_C(115), UINT8_C(113),
                             UINT8_C(179), UINT8_C( 55), UINT8_C(200), UINT8_C( 84),
                             UINT8_C(219), UINT8_C(209), UINT8_C(106), UINT8_C(223),
                             UINT8_C(220), UINT8_C(150), UINT8_C(243), UINT8_C( 88),
                             UINT8_C( 23), UINT8_C( 59), UINT8_C(210), UINT8_C(197),
                             UINT8_C( 39), UINT8_C(187), UINT8_C( 89), UINT8_C( 99)),
      simde_x_mm512_set_epu8(UINT8_C(202), UINT8_C( 54), UINT8_C( 42), UINT8_C(168),
                             UINT8_C( 22), UINT8_C(221), UINT8_C( 17), UINT8_C(189),
                             UINT8_C( 39), UINT8_C(155), UINT8_C(135), UINT8_C(162),
                             UINT8_C(148), UINT8_C(181), UINT8_C(120), UINT8_C( 52),
                             UINT8_C(206), UINT8_C( 24), UINT8_C(206), UINT8_C(117),
                             UINT8_C(240), UINT8_C( 17), UINT8_C(210), UINT8_C(188),
                             UINT8_C(193), UINT8_C(112), UINT8_C( 80), UINT8_C(199),
                             UINT8_C(136), UINT8_C( 33), UINT8_C( 97), UINT8_C(247),
                             UINT8_C(161), UINT8_C( 97), UINT8_C( 42), UINT8_C(181),
                             UINT8_C( 25), UINT8_C( 62), UINT8_C( 47), UINT8_C( 32),
                             UINT8_C( 10), UINT8_C(145), UINT8_C( 81), UINT8_C( 51),
                             UINT8_C(106), UINT8_C( 74), UINT8_C(253), UINT8_C( 27),
                             UINT8_C(198), UINT8_C( 49), UINT8_C(205), UINT8_C(189),
                             UINT8_C( 32), UINT8_C(168), UINT8_C(102), UINT8_C( 88),
                             UINT8_C( 86), UINT8_C(170), UINT8_C(185), UINT8_C( 98),
                             UINT8_C(232), UINT8_C( 43), UINT8_C( 26), UINT8_C(165)),
      simde_x_mm512_set_epu8(UINT8_C(181), UINT8_C( 56), UINT8_C(192), UINT8_C(150),
                             UINT8_C( 44), UINT8_C(209), UINT8_C( 13), UINT8_C(238),
                             UINT8_C(199), UINT8_C(135), UINT8_C(144), UINT8_C(  8),
                             UINT8_C( 13), UINT8_C(143), UINT8_C(242), UINT8_C(219),
                             UINT8_C(103), UINT8_C(252), UINT8_C(214), UINT8_C(167),
                             UINT8_C(  3), UINT8_C(136), UINT8_C(222), UINT8_C(241),
                             UINT8_C(  7), UINT8_C( 92), UINT8_C(141), UINT8_C(140),
                             UINT8_C(104), UINT8_C(125), UINT8_C(212), UINT8_C(114),
                             UINT8_C(  9), UINT8_C(  0), UINT8_C(  0), UINT8_C(144),
                             UINT8_C( 84), UINT8_C( 13), UINT8_C( 95), UINT8_C(142),
                             UINT8_C( 27), UINT8_C( 76), UINT8_C( 34), UINT8_C(138),
                             UINT8_C( 73), UINT8_C(105), UINT8_C(  0), UINT8_C(244),
                             UINT8_C( 62), UINT8_C(166), UINT8_C(  0), UINT8_C( 34),
                             UINT8_C(188), UINT8_C( 17), UINT8_C(235), UINT8_C(147),
                             UINT8_C(215), UINT8_C(  8), UINT8_C(107), UINT8_C( 99),
                             UINT8_C(  0), UINT8_C(144), UINT8_C( 75), UINT8_C( 80)) },
    { simde_x_mm512_set_epu8(UINT8_C( 98), UINT8_C( 81), UINT8_C(150), UINT8_C(221),
                             UINT8_C( 96), UINT8_C( 40), UINT8_C(142), UINT8_C( 23),
                             UINT8_C( 87), UINT8_C(207), UINT8_C(191), UINT8_C( 92),
                             UINT8_C( 77), UINT8_C(157), UINT8_C(184), UINT8_C(138),
                             UINT8_C(172), UINT8_C( 66), UINT8_C(  9), UINT8_C(115),
                             UINT8_C(240), UINT8_C(175), UINT8_C(107), UINT8_C( 49),
                             UINT8_C( 50), UINT8_C(243), UINT8_C( 59), UINT8_C( 91),
                             UINT8_C(  0), UINT8_C( 76), UINT8_C(  9), UINT8_C(  2),
                             UINT8_C( 15), UINT8_C( 39), UINT8_C(150), UINT8_C( 31),
                             UINT8_C( 12), UINT8_C(247), UINT8_C(212), UINT8_C( 40),
                             UINT8_C(158), UINT8_C( 81), UINT8_C(244), UINT8_C( 20),
                             UINT8_C(204), UINT8_C( 92), UINT8_C(198), UINT8_C(205),
                             UINT8_C( 11), UINT8_C( 60), UINT8_C(191), UINT8_C( 47),
                             UINT8_C( 22), UINT8_C(151), UINT8_C(149), UINT8_C( 16),
                             UINT8_C(247), UINT8_C(164), UINT8_C( 21), UINT8_C( 75),
                             UINT8_C(153), UINT8_C(240), UINT8_C(253), UINT8_C(242)),
      UINT64_C(            56397128),
      simde_x_mm512_set_epu8(UINT8_C(183), UINT8_C(245), UINT8_C(114), UINT8_C(158),
                             UINT8_C( 37), UINT8_C(  8), UINT8_C(173), UINT8_C( 26),
                             UINT8_C(128), UINT8_C( 46), UINT8_C(239), UINT8_C(202),
                             UINT8_C( 36), UINT8_C(170), UINT8_C( 57), UINT8_C( 95),
                             UINT8_C(183), UINT8_C(182), UINT8_C( 41), UINT8_C(122),
                             UINT8_C(112), UINT8_C(137), UINT8_C(112), UINT8_C( 40),
                             UINT8_C(142), UINT8_C( 91), UINT8_C( 37), UINT8_C( 25),
                             UINT8_C(202), UINT8_C(195), UINT8_C(221), UINT8_C(250),
                             UINT8_C(146), UINT8_C(239), UINT8_C( 69), UINT8_C(186),
                             UINT8_C(170), UINT8_C(230), UINT8_C(161), UINT8_C(178),
                             UINT8_C( 40), UINT8_C(125), UINT8_C(237), UINT8_C(124),
                             UINT8_C(248), UINT8_C( 56), UINT8_C(  8), UINT8_C( 55),
                             UINT8_C(249), UINT8_C(227), UINT8_C(149), UINT8_C(232),
                             UINT8_C( 71), UINT8_C(244), UINT8_C(128), UINT8_C( 10),
                             UINT8_C(194), UINT8_C(169), UINT8_C(169), UINT8_C( 87),
                             UINT8_C(140), UINT8_C(131), UINT8_C( 55), UINT8_C(150)),
      simde_x_mm512_set_epu8(UINT8_C(110), UINT8_C( 33), UINT8_C(123), UINT8_C(125),
                             UINT8_C( 28), UINT8_C(250), UINT8_C(180), UINT8_C(218),
                             UINT8_C(138), UINT8_C(236), UINT8_C( 38), UINT8_C(136),
                             UINT8_C(156), UINT8_C(154), UINT8_C(163), UINT8_C(128),
                             UINT8_C(  3), UINT8_C( 20), UINT8_C(100), UINT8_C(126),
                             UINT8_C(164), UINT8_C( 42), UINT8_C(151), UINT8_C(206),
                             UINT8_C(  0), UINT8_C(  4), UINT8_C(235), UINT8_C(224),
                             UINT8_C( 89), UINT8_C(213), UINT8_C( 61), UINT8_C(138),
                             UINT8_C( 77), UINT8_C( 74), UINT8_C( 61), UINT8_C(173),
                             UINT8_C( 87), UINT8_C(142), UINT8_C( 26), UINT8_C(213),
                             UINT8_C( 90), UINT8_C(221), UINT8_C( 14), UINT8_C( 55),
                             UINT8_C(246), UINT8_C(136), UINT8_C(230), UINT8_C(198),
                             UINT8_C(193), UINT8_C(138), UINT8_C(163), UINT8_C( 46),
                             UINT8_C( 13), UINT8_C(134), UINT8_C(202), UINT8_C( 58),
                             UINT8_C( 24), UINT8_C(220), UINT8_C( 93), UINT8_C(159),
                             UINT8_C(158), UINT8_C(228), UINT8_C( 77), UINT8_C( 48)),
      simde_x_mm512_set_epu8(UINT8_C( 98), UINT8_C( 81), UINT8_C(150), UINT8_C(221),
                             UINT8_C( 96), UINT8_C( 40), UINT8_C(142), UINT8_C( 23),
                             UINT8_C( 87), UINT8_C(207), UINT8_C(191), UINT8_C( 92),
                             UINT8_C( 77), UINT8_C(157), UINT8_C(184), UINT8_C(138),
                             UINT8_C(172), UINT8_C( 66), UINT8_C(  9), UINT8_C(115),
                             UINT8_C(240), UINT8_C(175), UINT8_C(107), UINT8_C( 49),
                             UINT8_C( 50), UINT8_C(243), UINT8_C( 59), UINT8_C( 91),
                             UINT8_C(  0), UINT8_C( 76), UINT8_C(  9), UINT8_C(  2),
                             UINT8_C( 15), UINT8_C( 39), UINT8_C(150), UINT8_C( 31),
                             UINT8_C( 12), UINT8_C(247), UINT8_C(135), UINT8_C(  0),
                             UINT8_C(158), UINT8_C(  0), UINT8_C(244), UINT8_C( 69),
                             UINT8_C(  2), UINT8_C(  0), UINT8_C(198), UINT8_C(205),
                             UINT8_C( 56), UINT8_C( 60), UINT8_C(191), UINT8_C( 47),
                             UINT8_C( 58), UINT8_C(110), UINT8_C(149), UINT8_C(  0),
                             UINT8_C(247), UINT8_C(  0), UINT8_C( 21), UINT8_C( 75),
                             UINT8_C(  0), UINT8_C(240), UINT8_C(253), UINT8_C(242)) },
    { simde_x_mm512_set_epu8(UINT8_C( 53), UINT8_C(227), UINT8_C(166), UINT8_C(167),
                             UINT8_C(220), UINT8_C( 62), UINT8_C(127), UINT8_C(188),
                             UINT8_C(162), UINT8_C( 93), UINT8_C( 87), UINT8_C( 20),
                             UINT8_C(253), UINT8_C(151), UINT8_C(167), UINT8_C( 97),
                             UINT8_C(141), UINT8_C( 56), UINT8_C( 46), UINT8_C(112),
                             UINT8_C(183), UINT8_C(242), UINT8_C(234), UINT8_C(225),
                             UINT8_C( 17), UINT8_C(244), UINT8_C(208), UINT8_C(134),
                             UINT8_C( 62), UINT8_C(227), UINT8_C(122), UINT8_C(145),
                             UINT8_C( 35), UINT8_C(116), UINT8_C( 86), UINT8_C( 57),
                             UINT8_C( 43), UINT8_C(  6), UINT8_C( 33), UINT8_C(  4),
                             UINT8_C(148), UINT8_C( 62), UINT8_C( 78), UINT8_C(134),
                             UINT8_C( 59), UINT8_C(194), UINT8_C(251), UINT8_C(176),
                             UINT8_C(131), UINT8_C(  3), UINT8_C(158), UINT8_C( 64),
                             UINT8_C(  7), UINT8_C( 23), UINT8_C(141), UINT8_C( 30),
                             UINT8_C( 80), UINT8_C(118), UINT8_C(234), UINT8_C(166),
                             UINT8_C(190), UINT8_C(141), UINT8_C(  8), UINT8_C(147)),
      UINT64_C(            22184990),
      simde_x_mm512_set_epu8(UINT8_C( 84), UINT8_C( 30), UINT8_C(240), UINT8_C(  3),
                             UINT8_C( 77), UINT8_C(250), UINT8_C(105), UINT8_C( 84),
                             UINT8_C( 36), UINT8_C(146), UINT8_C(  3), UINT8_C( 91),
                             UINT8_C( 21), UINT8_C( 50), UINT8_C( 15), UINT8_C(197),
                             UINT8_C(184), UINT8_C(164), UINT8_C(243), UINT8_C( 49),
                             UINT8_C(139), UINT8_C(155), UINT8_C( 62), UINT8_C(216),
                             UINT8_C(245), UINT8_C( 40), UINT8_C( 99), UINT8_C(208),
                             UINT8_C(124), UINT8_C(170), UINT8_C(118), UINT8_C(243),
                             UINT8_C(134), UINT8_C( 41), UINT8_C(113), UINT8_C( 32),
                             UINT8_C(248), UINT8_C( 57), UINT8_C( 20), UINT8_C(118),
                             UINT8_C(143), UINT8_C(142), UINT8_C(167), UINT8_C(111),
                             UINT8_C( 61), UINT8_C(150), UINT8_C( 44), UINT8_C(181),
                             UINT8_C(206), UINT8_C(236), UINT8_C( 29), UINT8_C(231),
                             UINT8_C(142), UINT8_C( 18), UINT8_C( 45), UINT8_C(166),
                             UINT8_C( 68), UINT8_C(228), UINT8_C( 11), UINT8_C( 98),
                             UINT8_C(196), UINT8_C(139), UINT8_C( 34), UINT8_C( 25)),
      simde_x_mm512_set_epu8(UINT8_C(  5), UINT8_C( 56), UINT8_C(136), UINT8_C(206),
                             UINT8_C(185), UINT8_C( 86), UINT8_C(170), UINT8_C(156),
                             UINT8_C( 56), UINT8_C( 24), UINT8_C(243), UINT8_C( 74),
                             UINT8_C( 28), UINT8_C( 35), UINT8_C(114), UINT8_C(  4),
                             UINT8_C( 15), UINT8_C(140), UINT8_C(233), UINT8_C(248),
                             UINT8_C(211), UINT8_C(113), UINT8_C(132), UINT8_C( 79),
                             UINT8_C( 67), UINT8_C( 31), UINT8_C(151), UINT8_C(212),
                             UINT8_C( 77), UINT8_C(114), UINT8_C(132), UINT8_C(196),
                             UINT8_C(210), UINT8_C(113), UINT8_C(221), UINT8_C(195),
                             UINT8_C( 83), UINT8_C(114), UINT8_C(111), UINT8_C(219),
                             UINT8_C(131), UINT8_C(244), UINT8_C(252), UINT8_C(192),
                             UINT8_C(162), UINT8_C(101), UINT8_C(212), UINT8_C( 52),
                             UINT8_C( 99), UINT8_C(238), UINT8_C( 29), UINT8_C(150),
                             UINT8_C(119), UINT8_C( 43), UINT8_C( 64), UINT8_C(199),
                             UINT8_C(174), UINT8_C( 41), UINT8_C( 78), UINT8_C( 66),
                             UINT8_C(152), UINT8_C(112), UINT8_C( 89), UINT8_C(237)),
      simde_x_mm512_set_epu8(UINT8_C( 53), UINT8_C(227), UINT8_C(166), UINT8_C(167),
                             UINT8_C(220), UINT8_C( 62), UINT8_C(127), UINT8_C(188),
                             UINT8_C(162), UINT8_C( 93), UINT8_C( 87), UINT8_C( 20),
                             UINT8_C(253), UINT8_C(151), UINT8_C(167), UINT8_C( 97),
                             UINT8_C(141), UINT8_C( 56), UINT8_C( 46), UINT8_C(112),
                             UINT8_C(183), UINT8_C(242), UINT8_C(234), UINT8_C(225),
                             UINT8_C( 17), UINT8_C(244), UINT8_C(208), UINT8_C(134),
                             UINT8_C( 62), UINT8_C(227), UINT8_C(122), UINT8_C(145),
                             UINT8_C( 35), UINT8_C(116), UINT8_C( 86), UINT8_C( 57),
                             UINT8_C( 43), UINT8_C(  6), UINT8_C( 33), UINT8_C(  0),
                             UINT8_C(148), UINT8_C(  0), UINT8_C( 78), UINT8_C(  0),
                             UINT8_C( 59), UINT8_C(194), UINT8_C(  0), UINT8_C(176),
                             UINT8_C(107), UINT8_C(  3), UINT8_C(158), UINT8_C( 64),
                             UINT8_C(  7), UINT8_C(  0), UINT8_C(141), UINT8_C( 30),
                             UINT8_C( 80), UINT8_C(118), UINT8_C(234), UINT8_C( 32),
                             UINT8_C( 44), UINT8_C( 27), UINT8_C(  0), UINT8_C(147)) },
    { simde_x_mm512_set_epu8(UINT8_C(235), UINT8_C(117), UINT8_C(121), UINT8_C(105),
                             UINT8_C( 64), UINT8_C(  2), UINT8_C( 13), UINT8_C(246),
                             UINT8_C(161), UINT8_C(246), UINT8_C(247), UINT8_C( 22),
                             UINT8_C(159), UINT8_C( 42), UINT8_C(201), UINT8_C( 79),
                             UINT8_C( 21), UINT8_C(172), UINT8_C(230), UINT8_C(126),
                             UINT8_C(213), UINT8_C(157), UINT8_C(132), UINT8_C(237),
                             UINT8_C(124), UINT8_C(235), UINT8_C(111), UINT8_C( 29),
                             UINT8_C( 89), UINT8_C( 58), UINT8_C(255), UINT8_C(134),
                             UINT8_C(101), UINT8_C( 62), UINT8_C(180), UINT8_C(233),
                             UINT8_C(164), UINT8_C(115), UINT8_C(231), UINT8_C( 98),
                             UINT8_C(155), UINT8_C(153), UINT8_C(181), UINT8_C(181),
                             UINT8_C( 69), UINT8_C(210), UINT8_C(151), UINT8_C( 85),
                             UINT8_C( 48), UINT8_C( 82), UINT8_C( 52), UINT8_C( 54),
                             UINT8_C( 55), UINT8_C(158), UINT8_C(113), UINT8_C(247),
                             UINT8_C(228), UINT8_C(233), UINT8_C( 78), UINT8_C( 66),
                             UINT8_C( 93), UINT8_C(202), UINT8_C(157), UINT8_C(212)),
      UINT64_C(          2103571959),
      simde_x_mm512_set_epu8(UINT8_C(144), UINT8_C( 21), UINT8_C(157), UINT8_C( 81),
                             UINT8_C(156), UINT8_C(133), UINT8_C(103), UINT8_C(155),
                             UINT8_C(182), UINT8_C(168), UINT8_C(151), UINT8_C(201),
                             UINT8_C( 69), UINT8_C(193), UINT8_C(130), UINT8_C( 74),
                             UINT8_C(226), UINT8_C(223), UINT8_C(134), UINT8_C( 37),
                             UINT8_C( 29), UINT8_C( 47), UINT8_C( 30), UINT8_C(250),
                             UINT8_C(230), UINT8_C( 55), UINT8_C( 98), UINT8_C( 11),
                             UINT8_C(116), UINT8_C( 66), UINT8_C(237), UINT8_C(241),
                             UINT8_C(184), UINT8_C(235), UINT8_C(101), UINT8_C( 24),
                             UINT8_C(135), UINT8_C( 72), UINT8_C(219), UINT8_C(214),
                             UINT8_C( 61), UINT8_C(252), UINT8_C(209), UINT8_C(153),
                             UINT8_C( 26), UINT8_C( 69), UINT8_C(254), UINT8_C( 81),
                             UINT8_C(112), UINT8_C(  1), UINT8_C( 13), UINT8_C(163),
                             UINT8_C( 13), UINT8_C( 42), UINT8_C(243), UINT8_C(185),
                             UINT8_C( 74), UINT8_C( 36), UINT8_C(112), UINT8_C(104),
                             UINT8_C( 13), UINT8_C(101), UINT8_C(  7), UINT8_C( 51)),
      simde_x_mm512_set_epu8(UINT8_C(133), UINT8_C(195), UINT8_C( 74), UINT8_C( 77),
                             UINT8_C(127), UINT8_C(119), UINT8_C(202), UINT8_C( 85),
                             UINT8_C(236), UINT8_C( 29), UINT8_C(224), UINT8_C( 26),
                             UINT8_C(102), UINT8_C(226), UINT8_C(128), UINT8_C(173),
                             UINT8_C(247), UINT8_C(167), UINT8_C(253), UINT8_C(107),
                             UINT8_C(195), UINT8_C( 44), UINT8_C(250), UINT8_C( 78),
                             UINT8_C( 22), UINT8_C(248), UINT8_C( 49), UINT8_C(127),
                             UINT8_C(226), UINT8_C(177), UINT8_C(135), UINT8_C( 20),
                             UINT8_C(199), UINT8_C(239), UINT8_C(100), UINT8_C(134),
                             UINT8_C(164), UINT8_C(130), UINT8_C(104), UINT8_C(154),
                             UINT8_C( 70), UINT8_C(141), UINT8_C(181), UINT8_C(104),
                             UINT8_C(215), UINT8_C( 61), UINT8_C(212), UINT8_C( 26),
                             UINT8_C(110), UINT8_C(215), UINT8_C(220), UINT8_C(161),
                             UINT8_C( 37), UINT8_C( 95), UINT8_C(129), UINT8_C(178),
                             UINT8_C(134), UINT8_C( 99), UINT8_C(129), UINT8_C( 29),
                             UINT8_C(214), UINT8_C(225), UINT8_C(121), UINT8_C(165)),
      simde_x_mm512_set_epu8(UINT8_C(235), UINT8_C(117), UINT8_C(121), UINT8_C(105),
                             UINT8_C( 64), UINT8_C(  2), UINT8_C( 13), UINT8_C(246),
                             UINT8_C(161), UINT8_C(246), UINT8_C(247), UINT8_C( 22),
                             UINT8_C(159), UINT8_C( 42), UINT8_C(201), UINT8_C( 79),
                             UINT8_C( 21), UINT8_C(172), UINT8_C(230), UINT8_C(126),
                             UINT8_C(213), UINT8_C(157), UINT8_C(132), UINT8_C(237),
                             UINT8_C(124), UINT8_C(235), UINT8_C(111), UINT8_C( 29),
                             UINT8_C( 89), UINT8_C( 58), UINT8_C(255), UINT8_C(134),
                             UINT8_C(101), UINT8_C(  0), UINT8_C(  1), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(231), UINT8_C( 60),
                             UINT8_C(155), UINT8_C(111), UINT8_C( 28), UINT8_C(181),
                             UINT8_C( 69), UINT8_C(210), UINT8_C(151), UINT8_C( 55),
                             UINT8_C(  2), UINT8_C(  0), UINT8_C(  0), UINT8_C(  2),
                             UINT8_C( 55), UINT8_C(  0), UINT8_C(113), UINT8_C(  7),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C( 75),
                             UINT8_C( 93), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0)) }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])); i++) {
    simde__m512i r = simde_mm512_mask_subs_epu8(test_vec[i].src, test_vec[i].k, test_vec[i].a, test_vec[i].b);
    simde_assert_m512i_u8(r, ==, test_vec[i].r);
  }

  return 0;
}

static int
test_simde_mm512_maskz_subs_epu8(SIMDE_MUNIT_TEST_ARGS) {
  const struct {
    simde__mmask64 k;
    simde__m512i a;
    simde__m512i b;
    simde__m512i r;
  } test_vec[8] = {
    { UINT64_C(          1678504309),
      simde_x_mm512_set_epu8(UINT8_C(188), UINT8_C(227), UINT8_C(248), UINT8_C(  6),
                             UINT8_C(158), UINT8_C(170), UINT8_C( 99), UINT8_C(202),
                             UINT8_C(160), UINT8_C(209), UINT8_C( 53), UINT8_C(241),
                             UINT8_C(169), UINT8_C( 74), UINT8_C(195), UINT8_C(156),
                             UINT8_C(226), UINT8_C(114), UINT8_C(119), UINT8_C(203),
                             UINT8_C( 15), UINT8_C( 80), UINT8_C(207), UINT8_C(120),
                             UINT8_C(164), UINT8_C(171), UINT8_C( 95), UINT8_C(130),
                             UINT8_C(161), UINT8_C(  3), UINT8_C( 82), UINT8_C(197),
                             UINT8_C( 78), UINT8_C(216), UINT8_C(176), UINT8_C(131),
                             UINT8_C(213), UINT8_C( 21), UINT8_C( 48), UINT8_C(162),
                             UINT8_C(135), UINT8_C( 81), UINT8_C( 67), UINT8_C(242),
                             UINT8_C( 97), UINT8_C( 89), UINT8_C(174), UINT8_C( 64),
                             UINT8_C(170), UINT8_C(194), UINT8_C(235), UINT8_C(133),
                             UINT8_C( 33), UINT8_C(160), UINT8_C(236), UINT8_C(  7),
                             UINT8_C(224), UINT8_C( 63), UINT8_C(130), UINT8_C( 28),
                             UINT8_C( 83), UINT8_C(152), UINT8_C(149), UINT8_C(111)),
      simde_x_mm512_set_epu8(UINT8_C(164), UINT8_C( 45), UINT8_C(193), UINT8_C(111),
                             UINT8_C( 96), UINT8_C(220), UINT8_C( 54), UINT8_C(232),
                             UINT8_C(214), UINT8_C(244), UINT8_C(236), UINT8_C( 74),
                             UINT8_C( 47), UINT8_C(180), UINT8_C(143), UINT8_C(214),
                             UINT8_C(  6), UINT8_C(178), UINT8_C( 35), UINT8_C(129),
                             UINT8_C( 21), UINT8_C(157), UINT8_C( 30), UINT8_C( 29),
                             UINT8_C(226), UINT8_C(222), UINT8_C( 14), UINT8_C(170),
                             UINT8_C(223), UINT8_C(200), UINT8_C( 41), UINT8_C(245),
                             UINT8_C(  7), UINT8_C(251), UINT8_C( 30), UINT8_C(217),
                             UINT8_C( 93), UINT8_C(228), UINT8_C(143), UINT8_C(  9),
                             UINT8_C(221), UINT8_C( 49), UINT8_C(207), UINT8_C( 44),
                             UINT8_C( 52), UINT8_C(108), UINT8_C(124), UINT8_C( 14),
                             UINT8_C(144), UINT8_C(229), UINT8_C(102), UINT8_C( 16),
                             UINT8_C( 61), UINT8_C(  2), UINT8_C(169), UINT8_C( 72),
                             UINT8_C(194), UINT8_C(122), UINT8_C(216), UINT8_C(151),
                             UINT8_C(244), UINT8_C(227), UINT8_C(  5), UINT8_C( 98)),
      simde_x_mm512_set_epu8(UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(146), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C( 45), UINT8_C(  0), UINT8_C( 50), UINT8_C( 50),
                             UINT8_C( 26), UINT8_C(  0), UINT8_C(133), UINT8_C(117),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C( 13)) },
    { UINT64_C(          4292756020),
      simde_x_mm512_set_epu8(UINT8_C(177), UINT8_C(132), UINT8_C(179), UINT8_C(117),
                             UINT8_C(215), UINT8_C( 43), UINT8_C(143), UINT8_C( 75),
                             UINT8_C( 53), UINT8_C( 65), UINT8_C(131), UINT8_C(189),
                             UINT8_C(196), UINT8_C(200), UINT8_C(234), UINT8_C( 92),
                             UINT8_C( 99), UINT8_C(187), UINT8_C(123), UINT8_C(180),
                             UINT8_C(209), UINT8_C(163), UINT8_C( 86), UINT8_C( 26),
                             UINT8_C(192), UINT8_C( 36), UINT8_C(205), UINT8_C(108),
                             UINT8_C(173), UINT8_C( 71), UINT8_C(190), UINT8_C( 46),
                             UINT8_C(173), UINT8_C(156), UINT8_C( 59), UINT8_C(250),
                             UINT8_C( 13), UINT8_C(171), UINT8_C(  1), UINT8_C( 47),
                             UINT8_C(227), UINT8_C( 45), UINT8_C(181), UINT8_C( 45),
                             UINT8_C(116), UINT8_C( 89), UINT8_C(112), UINT8_C(127),
                             UINT8_C( 42), UINT8_C(134), UINT8_C(128), UINT8_C(206),
                             UINT8_C( 87), UINT8_C(206), UINT8_C( 39), UINT8_C(  7),
                             UINT8_C( 48), UINT8_C( 47), UINT8_C( 79), UINT8_C( 32),
                             UINT8_C( 39), UINT8_C(205), UINT8_C(174), UINT8_C(244)),
      simde_x_mm512_set_epu8(UINT8_C(103), UINT8_C( 74), UINT8_C( 78), UINT8_C(251),
                             UINT8_C( 78), UINT8_C( 92), UINT8_C( 94), UINT8_C(154),
                             UINT8_C(108), UINT8_C( 96), UINT8_C(  9), UINT8_C(145),
                             UINT8_C(131), UINT8_C(204), UINT8_C(151), UINT8_C(200),
                             UINT8_C(172), UINT8_C(193), UINT8_C(248), UINT8_C(227),
                             UINT8_C(159), UINT8_C( 34), UINT8_C( 70), UINT8_C( 14),
                             UINT8_C(229), UINT8_C( 98), UINT8_C( 73), UINT8_C(209),
                             UINT8_C( 59), UINT8_C(209), UINT8_C( 82), UINT8_C( 90),
                             UINT8_C(172), UINT8_C( 10), UINT8_C(185), UINT8_C(194),
                             UINT8_C(184), UINT8_C( 76), UINT8_C(173), UINT8_C( 75),
                             UINT8_C(136), UINT8_C(130), UINT8_C(227), UINT8_C(162),
                             UINT8_C(154), UINT8_C(158), UINT8_C(121), UINT8_C( 19),
                             UINT8_C(211), UINT8_C(197), UINT8_C( 15), UINT8_C( 80),
                             UINT8_C( 75), UINT8_C( 26), UINT8_C( 77), UINT8_C(210),
                             UINT8_C(117), UINT8_C( 85), UINT8_C(204), UINT8_C(  0),
                             UINT8_C(244), UINT8_C( 11), UINT8_C(128), UINT8_C(245)),
      simde_x_mm512_set_epu8(UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  1), UINT8_C(146), UINT8_C(  0), UINT8_C( 56),
                             UINT8_C(  0), UINT8_C( 95), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C( 91), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C( 32),
                             UINT8_C(  0), UINT8_C(194), UINT8_C(  0), UINT8_C(  0)) },
    { UINT64_C(          3647935965),
      simde_x_mm512_set_epu8(UINT8_C(141), UINT8_C( 95), UINT8_C(101), UINT8_C(146),
                             UINT8_C(141), UINT8_C( 37), UINT8_C( 41), UINT8_C(148),
                             UINT8_C(122), UINT8_C(121), UINT8_C( 15), UINT8_C(167),
                             UINT8_C(146), UINT8_C(  1), UINT8_C( 27), UINT8_C( 93),
                             UINT8_C(177), UINT8_C(197), UINT8_C(189), UINT8_C(233),
                             UINT8_C(110), UINT8_C( 47), UINT8_C( 66), UINT8_C( 91),
                             UINT8_C( 52), UINT8_C(  7), UINT8_C(197), UINT8_C( 20),
                             UINT8_C( 34), UINT8_C(208), UINT8_C(127), UINT8_C( 73),
                             UINT8_C(145), UINT8_C(  2), UINT8_C( 27), UINT8_C(235),
                             UINT8_C(109), UINT8_C(152), UINT8_C(220), UINT8_C(143),
                             UINT8_C(189), UINT8_C(222), UINT8_C(102), UINT8_C(126),
                             UINT8_C( 80), UINT8_C( 51), UINT8_C(253), UINT8_C(186),
                             UINT8_C( 51), UINT8_C(206), UINT8_C(118), UINT8_C( 48),
                             UINT8_C( 59), UINT8_C(184), UINT8_C(197), UINT8_C(107),
                             UINT8_C( 52), UINT8_C(  5), UINT8_C(208), UINT8_C(231),
                             UINT8_C(151), UINT8_C(166), UINT8_C(151), UINT8_C( 49)),
      simde_x_mm512_set_epu8(UINT8_C(255), UINT8_C(129), UINT8_C(219), UINT8_C(221),
                             UINT8_C(186), UINT8_C( 75), UINT8_C(231), UINT8_C(243),
                             UINT8_C( 54), UINT8_C( 10), UINT8_C( 52), UINT8_C(157),
                             UINT8_C( 51), UINT8_C( 63), UINT8_C(190), UINT8_C(105),
                             UINT8_C(159), UINT8_C( 57), UINT8_C(152), UINT8_C(  2),
                             UINT8_C(134), UINT8_C(112), UINT8_C( 29), UINT8_C(  8),
                             UINT8_C(240), UINT8_C( 55), UINT8_C(110), UINT8_C(144),
                             UINT8_C(247), UINT8_C( 78), UINT8_C(254), UINT8_C( 89),
                             UINT8_C(189), UINT8_C(169), UINT8_C(164), UINT8_C(239),
                             UINT8_C(227), UINT8_C(187), UINT8_C( 11), UINT8_C(211),
                             UINT8_C(183), UINT8_C(  9), UINT8_C(204), UINT8_C(138),
                             UINT8_C(223), UINT8_C( 91), UINT8_C(198), UINT8_C( 18),
                             UINT8_C(178), UINT8_C(209), UINT8_C(152), UINT8_C(100),
                             UINT8_C(247), UINT8_C(142), UINT8_C( 53), UINT8_C( 94),
                             UINT8_C(238), UINT8_C(239), UINT8_C(151), UINT8_C(119),
                             UINT8_C(229), UINT8_C( 96), UINT8_C(245), UINT8_C(  0)),
      simde_x_mm512_set_epu8(UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(213), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C( 55), UINT8_C(168),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C( 42), UINT8_C(  0), UINT8_C( 13),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(112),
                             UINT8_C(  0), UINT8_C( 70), UINT8_C(  0), UINT8_C( 49)) },
    { UINT64_C(          2805277521),
      simde_x_mm512_set_epu8(UINT8_C(241), UINT8_C(232), UINT8_C(128), UINT8_C(233),
                             UINT8_C(178), UINT8_C(  6), UINT8_C(154), UINT8_C(184),
                             UINT8_C(219), UINT8_C(217), UINT8_C( 22), UINT8_C( 47),
                             UINT8_C( 81), UINT8_C(179), UINT8_C( 53), UINT8_C( 28),
                             UINT8_C(206), UINT8_C(206), UINT8_C( 30), UINT8_C( 15),
                             UINT8_C(114), UINT8_C(103), UINT8_C( 13), UINT8_C(110),
                             UINT8_C(166), UINT8_C( 46), UINT8_C(130), UINT8_C(151),
                             UINT8_C( 16), UINT8_C( 40), UINT8_C(154), UINT8_C( 67),
                             UINT8_C(184), UINT8_C( 37), UINT8_C(207), UINT8_C( 94),
                             UINT8_C( 79), UINT8_C(202), UINT8_C(122), UINT8_C(203),
                             UINT8_C(179), UINT8_C(164), UINT8_C( 37), UINT8_C(173),
                             UINT8_C( 95), UINT8_C(170), UINT8_C( 47), UINT8_C(161),
                             UINT8_C(255), UINT8_C(185), UINT8_C(163), UINT8_C(181),
                             UINT8_C( 29), UINT8_C(148), UINT8_C(134), UINT8_C( 11),
                             UINT8_C(137), UINT8_C(213), UINT8_C(115), UINT8_C(139),
                             UINT8_C( 77), UINT8_C(129), UINT8_C( 55), UINT8_C(  6)),
      simde_x_mm512_set_epu8(UINT8_C( 39), UINT8_C(159), UINT8_C( 61), UINT8_C( 37),
                             UINT8_C(160), UINT8_C(166), UINT8_C( 87), UINT8_C(103),
                             UINT8_C(228), UINT8_C( 29), UINT8_C(156), UINT8_C(201),
                             UINT8_C(217), UINT8_C( 60), UINT8_C( 61), UINT8_C( 86),
                             UINT8_C(205), UINT8_C(204), UINT8_C( 26), UINT8_C( 35),
                             UINT8_C(113), UINT8_C( 54), UINT8_C( 44), UINT8_C(150),
                             UINT8_C(  5), UINT8_C(127), UINT8_C(118), UINT8_C(122),
                             UINT8_C(  8), UINT8_C( 76), UINT8_C( 62), UINT8_C( 54),
                             UINT8_C(171), UINT8_C(236), UINT8_C(228), UINT8_C( 23),
                             UINT8_C(167), UINT8_C( 85), UINT8_C(106), UINT8_C(203),
                             UINT8_C( 75), UINT8_C(211), UINT8_C(183), UINT8_C(233),
                             UINT8_C(230), UINT8_C(155), UINT8_C(159), UINT8_C(231),
                             UINT8_C( 53), UINT8_C( 16), UINT8_C(224), UINT8_C(218),
                             UINT8_C(254), UINT8_C(170), UINT8_C(229), UINT8_C(158),
                             UINT8_C(154), UINT8_C(108), UINT8_C(114), UINT8_C(193),
                             UINT8_C(254), UINT8_C( 39), UINT8_C(143), UINT8_C(155)),
      simde_x_mm512_set_epu8(UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C( 13), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(117), UINT8_C( 16), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C( 15), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(105), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0)) },
    { UINT64_C(          2080103780),
      simde_x_mm512_set_epu8(UINT8_C( 35), UINT8_C(245), UINT8_C(193), UINT8_C( 56),
                             UINT8_C(248), UINT8_C(186), UINT8_C( 68), UINT8_C(150),
                             UINT8_C(220), UINT8_C(248), UINT8_C(101), UINT8_C(  0),
                             UINT8_C(116), UINT8_C(116), UINT8_C( 64), UINT8_C(175),
                             UINT8_C(165), UINT8_C(173), UINT8_C(234), UINT8_C(165),
                             UINT8_C(146), UINT8_C(243), UINT8_C( 52), UINT8_C( 89),
                             UINT8_C(227), UINT8_C( 93), UINT8_C(108), UINT8_C( 47),
                             UINT8_C(207), UINT8_C(115), UINT8_C(178), UINT8_C(155),
                             UINT8_C(250), UINT8_C(115), UINT8_C(  2), UINT8_C( 73),
                             UINT8_C(254), UINT8_C(119), UINT8_C( 72), UINT8_C(108),
                             UINT8_C( 90), UINT8_C( 96), UINT8_C( 56), UINT8_C(182),
                             UINT8_C( 64), UINT8_C(  8), UINT8_C(172), UINT8_C(169),
                             UINT8_C( 32), UINT8_C( 75), UINT8_C( 92), UINT8_C(114),
                             UINT8_C( 16), UINT8_C( 36), UINT8_C(161), UINT8_C( 46),
                             UINT8_C(214), UINT8_C(247), UINT8_C(176), UINT8_C( 43),
                             UINT8_C(168), UINT8_C(161), UINT8_C(148), UINT8_C( 77)),
      simde_x_mm512_set_epu8(UINT8_C( 56), UINT8_C(209), UINT8_C( 90), UINT8_C(226),
                             UINT8_C(128), UINT8_C( 65), UINT8_C( 94), UINT8_C(244),
                             UINT8_C(183), UINT8_C( 61), UINT8_C(186), UINT8_C(254),
                             UINT8_C(239), UINT8_C( 84), UINT8_C(120), UINT8_C(211),
                             UINT8_C(215), UINT8_C( 43), UINT8_C(249), UINT8_C(194),
                             UINT8_C(157), UINT8_C(199), UINT8_C( 98), UINT8_C(233),
                             UINT8_C( 27), UINT8_C(181), UINT8_C(227), UINT8_C( 75),
                             UINT8_C( 73), UINT8_C( 96), UINT8_C(149), UINT8_C(223),
                             UINT8_C(104), UINT8_C( 32), UINT8_C( 22), UINT8_C(168),
                             UINT8_C( 89), UINT8_C( 99), UINT8_C(164), UINT8_C(153),
                             UINT8_C( 65), UINT8_C(170), UINT8_C( 53), UINT8_C( 47),
                             UINT8_C(191), UINT8_C(169), UINT8_C( 40), UINT8_C( 76),
                             UINT8_C(114), UINT8_C(220), UINT8_C( 85), UINT8_C(210),
                             UINT8_C(141), UINT8_C( 16), UINT8_C( 66), UINT8_C(216),
                             UINT8_C(211), UINT8_C(107), UINT8_C(217), UINT8_C(119),
                             UINT8_C(250), UINT8_C( 64), UINT8_C(254), UINT8_C( 91)),
      simde_x_mm512_set_epu8(UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C( 83), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(165), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C( 25), UINT8_C(  0), UINT8_C(  3), UINT8_C(135),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(132), UINT8_C( 93),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C( 20), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(140), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C( 97), UINT8_C(  0), UINT8_C(  0)) },
    { UINT64_C(          3123384269),
      simde_x_mm512_set_epu8(UINT8_C( 96), UINT8_C(111), UINT8_C( 93), UINT8_C(100),
                             UINT8_C(124), UINT8_C( 70), UINT8_C(116), UINT8_C(210),
                             UINT8_C( 69), UINT8_C(255), UINT8_C(157), UINT8_C(160),
                             UINT8_C( 53), UINT8_C( 12), UINT8_C(237), UINT8_C(134),
                             UINT8_C( 21), UINT8_C(153), UINT8_C(252), UINT8_C(180),
                             UINT8_C(184), UINT8_C( 70), UINT8_C( 16), UINT8_C(164),
                             UINT8_C( 32), UINT8_C(157), UINT8_C(177), UINT8_C(185),
                             UINT8_C( 75), UINT8_C(213), UINT8_C(118), UINT8_C( 48),
                             UINT8_C(250), UINT8_C(247), UINT8_C(144), UINT8_C(182),
                             UINT8_C( 89), UINT8_C(193), UINT8_C(215), UINT8_C(109),
                             UINT8_C( 32), UINT8_C( 44), UINT8_C( 30), UINT8_C(115),
                             UINT8_C(122), UINT8_C(173), UINT8_C( 22), UINT8_C(177),
                             UINT8_C(163), UINT8_C(190), UINT8_C(161), UINT8_C(157),
                             UINT8_C(186), UINT8_C(207), UINT8_C(230), UINT8_C( 94),
                             UINT8_C(188), UINT8_C( 54), UINT8_C(164), UINT8_C(150),
                             UINT8_C( 11), UINT8_C( 80), UINT8_C(167), UINT8_C(171)),
      simde_x_mm512_set_epu8(UINT8_C( 62), UINT8_C(166), UINT8_C(227), UINT8_C( 87),
                             UINT8_C(254), UINT8_C( 17), UINT8_C(235), UINT8_C(147),
                             UINT8_C(215), UINT8_C(  8), UINT8_C(107), UINT8_C( 75),
                             UINT8_C(237), UINT8_C(121), UINT8_C( 75), UINT8_C( 80),
                             UINT8_C( 31), UINT8_C( 58), UINT8_C(132), UINT8_C( 37),
                             UINT8_C(154), UINT8_C(  6), UINT8_C( 75), UINT8_C(156),
                             UINT8_C(149), UINT8_C(144), UINT8_C(181), UINT8_C(171),
                             UINT8_C(160), UINT8_C( 77), UINT8_C(155), UINT8_C(252),
                             UINT8_C(181), UINT8_C(149), UINT8_C( 69), UINT8_C( 75),
                             UINT8_C(202), UINT8_C( 32), UINT8_C( 21), UINT8_C( 82),
                             UINT8_C(184), UINT8_C(152), UINT8_C(217), UINT8_C( 20),
                             UINT8_C( 41), UINT8_C( 41), UINT8_C(  1), UINT8_C( 97),
                             UINT8_C(165), UINT8_C(111), UINT8_C(131), UINT8_C( 21),
                             UINT8_C( 63), UINT8_C( 20), UINT8_C(145), UINT8_C(147),
                             UINT8_C( 66), UINT8_C( 29), UINT8_C(208), UINT8_C( 15),
                             UINT8_C(209), UINT8_C(114), UINT8_C(194), UINT8_C(  3)),
      simde_x_mm512_set_epu8(UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C( 69), UINT8_C(  0), UINT8_C( 75), UINT8_C(107),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(194), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C( 81), UINT8_C(  0), UINT8_C( 21), UINT8_C( 80),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(123), UINT8_C(187), UINT8_C( 85), UINT8_C(  0),
                             UINT8_C(122), UINT8_C( 25), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(168)) },
    { UINT64_C(          3899248884),
      simde_x_mm512_set_epu8(UINT8_C(219), UINT8_C(209), UINT8_C(106), UINT8_C(223),
                             UINT8_C(220), UINT8_C(150), UINT8_C(243), UINT8_C( 88),
                             UINT8_C( 23), UINT8_C( 59), UINT8_C(210), UINT8_C(197),
                             UINT8_C( 39), UINT8_C(187), UINT8_C( 89), UINT8_C( 99),
                             UINT8_C( 19), UINT8_C(249), UINT8_C( 10), UINT8_C( 39),
                             UINT8_C(237), UINT8_C(106), UINT8_C( 56), UINT8_C( 28),
                             UINT8_C(181), UINT8_C( 56), UINT8_C(192), UINT8_C(150),
                             UINT8_C( 44), UINT8_C(209), UINT8_C( 13), UINT8_C(238),
                             UINT8_C(199), UINT8_C(135), UINT8_C(144), UINT8_C(  8),
                             UINT8_C( 13), UINT8_C(143), UINT8_C(242), UINT8_C(219),
                             UINT8_C(103), UINT8_C(252), UINT8_C(214), UINT8_C(167),
                             UINT8_C(  3), UINT8_C(136), UINT8_C(222), UINT8_C(241),
                             UINT8_C(  7), UINT8_C( 92), UINT8_C(141), UINT8_C(140),
                             UINT8_C(104), UINT8_C(125), UINT8_C(212), UINT8_C(114),
                             UINT8_C(114), UINT8_C(229), UINT8_C(235), UINT8_C(144),
                             UINT8_C(233), UINT8_C(188), UINT8_C( 95), UINT8_C(193)),
      simde_x_mm512_set_epu8(UINT8_C(198), UINT8_C( 49), UINT8_C(205), UINT8_C(189),
                             UINT8_C( 32), UINT8_C(168), UINT8_C(102), UINT8_C( 88),
                             UINT8_C( 86), UINT8_C(170), UINT8_C(185), UINT8_C( 98),
                             UINT8_C(232), UINT8_C( 43), UINT8_C( 26), UINT8_C(165),
                             UINT8_C(105), UINT8_C(165), UINT8_C(196), UINT8_C(175),
                             UINT8_C( 21), UINT8_C( 33), UINT8_C( 59), UINT8_C( 91),
                             UINT8_C(173), UINT8_C( 84), UINT8_C(102), UINT8_C(234),
                             UINT8_C(240), UINT8_C( 97), UINT8_C( 44), UINT8_C(117),
                             UINT8_C(253), UINT8_C( 63), UINT8_C(177), UINT8_C(  7),
                             UINT8_C( 84), UINT8_C(101), UINT8_C( 54), UINT8_C(237),
                             UINT8_C(110), UINT8_C( 66), UINT8_C( 52), UINT8_C(158),
                             UINT8_C(218), UINT8_C(146), UINT8_C(129), UINT8_C(  7),
                             UINT8_C(170), UINT8_C( 34), UINT8_C( 11), UINT8_C( 33),
                             UINT8_C(109), UINT8_C( 75), UINT8_C(249), UINT8_C(174),
                             UINT8_C( 89), UINT8_C(221), UINT8_C(115), UINT8_C(113),
                             UINT8_C(179), UINT8_C( 55), UINT8_C(200), UINT8_C( 84)),
      simde_x_mm512_set_epu8(UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C( 72), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(186), UINT8_C(162), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(234),
                             UINT8_C(  0), UINT8_C( 58), UINT8_C(  0), UINT8_C(107),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C( 25), UINT8_C(  8), UINT8_C(120), UINT8_C( 31),
                             UINT8_C(  0), UINT8_C(133), UINT8_C(  0), UINT8_C(  0)) },
    { UINT64_C(          1783299355),
      simde_x_mm512_set_epu8(UINT8_C(158), UINT8_C( 81), UINT8_C(244), UINT8_C( 20),
                             UINT8_C(204), UINT8_C( 92), UINT8_C(198), UINT8_C(205),
                             UINT8_C( 11), UINT8_C( 60), UINT8_C(191), UINT8_C( 47),
                             UINT8_C( 22), UINT8_C(151), UINT8_C(149), UINT8_C( 16),
                             UINT8_C(247), UINT8_C(164), UINT8_C( 21), UINT8_C( 75),
                             UINT8_C(153), UINT8_C(240), UINT8_C(253), UINT8_C(242),
                             UINT8_C(202), UINT8_C( 54), UINT8_C( 42), UINT8_C(168),
                             UINT8_C( 22), UINT8_C(221), UINT8_C( 17), UINT8_C(189),
                             UINT8_C( 39), UINT8_C(155), UINT8_C(135), UINT8_C(162),
                             UINT8_C(148), UINT8_C(181), UINT8_C(120), UINT8_C( 52),
                             UINT8_C(206), UINT8_C( 24), UINT8_C(206), UINT8_C(117),
                             UINT8_C(240), UINT8_C( 17), UINT8_C(210), UINT8_C(188),
                             UINT8_C(193), UINT8_C(112), UINT8_C( 80), UINT8_C(199),
                             UINT8_C(136), UINT8_C( 33), UINT8_C( 97), UINT8_C(247),
                             UINT8_C(161), UINT8_C( 97), UINT8_C( 42), UINT8_C(181),
                             UINT8_C( 25), UINT8_C( 62), UINT8_C( 47), UINT8_C( 32)),
      simde_x_mm512_set_epu8(UINT8_C(249), UINT8_C(227), UINT8_C(149), UINT8_C(232),
                             UINT8_C( 71), UINT8_C(244), UINT8_C(128), UINT8_C( 10),
                             UINT8_C(194), UINT8_C(169), UINT8_C(169), UINT8_C( 87),
                             UINT8_C(140), UINT8_C(131), UINT8_C( 55), UINT8_C(150),
                             UINT8_C(104), UINT8_C(180), UINT8_C(190), UINT8_C(178),
                             UINT8_C(  3), UINT8_C( 92), UINT8_C(141), UINT8_C( 72),
                             UINT8_C( 98), UINT8_C( 81), UINT8_C(150), UINT8_C(221),
                             UINT8_C( 96), UINT8_C( 40), UINT8_C(142), UINT8_C( 23),
                             UINT8_C( 87), UINT8_C(207), UINT8_C(191), UINT8_C( 92),
                             UINT8_C( 77), UINT8_C(157), UINT8_C(184), UINT8_C(138),
                             UINT8_C(172), UINT8_C( 66), UINT8_C(  9), UINT8_C(115),
                             UINT8_C(240), UINT8_C(175), UINT8_C(107), UINT8_C( 49),
                             UINT8_C( 50), UINT8_C(243), UINT8_C( 59), UINT8_C( 91),
                             UINT8_C(  0), UINT8_C( 76), UINT8_C(  9), UINT8_C(  2),
                             UINT8_C( 15), UINT8_C( 39), UINT8_C(150), UINT8_C( 31),
                             UINT8_C( 12), UINT8_C(247), UINT8_C(212), UINT8_C( 40)),
      simde_x_mm512_set_epu8(UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C( 71), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(103), UINT8_C(  0),
                             UINT8_C(143), UINT8_C(  0), UINT8_C( 21), UINT8_C(108),
                             UINT8_C(136), UINT8_C(  0), UINT8_C(  0), UINT8_C(245),
                             UINT8_C(  0), UINT8_C(  0), UINT8_C(  0), UINT8_C(150),
                             UINT8_C( 13), UINT8_C(  0), UINT8_C(  0), UINT8_C(  0)) }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])); i++) {
    simde__m512i r = simde_mm512_maskz_subs_epu8(test_vec[i].k, test_vec[i].a, test_vec[i].b);
    simde_assert_m512i_u8(r, ==, test_vec[i].r);
  }

  return 0;
}

static int
test_simde_mm512_subs_epu16(SIMDE_MUNIT_TEST_ARGS) {
  const struct {
    simde__m512i a;
    simde__m512i b;
    simde__m512i r;
  } test_vec[8] = {
    { simde_x_mm512_set_epu16(UINT16_C( 21075), UINT16_C( 30017), UINT16_C( 53638), UINT16_C( 29710),
                              UINT16_C( 19457), UINT16_C( 52740), UINT16_C( 21427), UINT16_C( 28826),
                              UINT16_C( 25482), UINT16_C( 53693), UINT16_C( 15582), UINT16_C( 20114),
                              UINT16_C( 50775), UINT16_C( 49946), UINT16_C( 61394), UINT16_C( 29932),
                              UINT16_C( 34864), UINT16_C(  6190), UINT16_C( 26590), UINT16_C( 10803),
                              UINT16_C( 48982), UINT16_C( 15816), UINT16_C( 14967), UINT16_C( 24063),
                              UINT16_C( 50823), UINT16_C( 57442), UINT16_C( 48719), UINT16_C( 25507),
                              UINT16_C( 19912), UINT16_C( 45607), UINT16_C( 52932), UINT16_C( 48380)),
      simde_x_mm512_set_epu16(UINT16_C( 27175), UINT16_C( 38414), UINT16_C( 58622), UINT16_C( 10212),
                              UINT16_C( 13894), UINT16_C( 60916), UINT16_C( 54812), UINT16_C( 62458),
                              UINT16_C( 29698), UINT16_C(  6009), UINT16_C( 28893), UINT16_C( 33802),
                              UINT16_C( 61579), UINT16_C(  6787), UINT16_C(  9325), UINT16_C(  7645),
                              UINT16_C( 63403), UINT16_C( 55903), UINT16_C( 43011), UINT16_C(  1124),
                              UINT16_C( 21781), UINT16_C( 17119), UINT16_C( 46075), UINT16_C( 33402),
                              UINT16_C( 58029), UINT16_C( 19092), UINT16_C( 21408), UINT16_C( 51092),
                              UINT16_C( 22843), UINT16_C( 28625), UINT16_C( 63214), UINT16_C(  5251)),
      simde_x_mm512_set_epu16(UINT16_C(     0), UINT16_C(     0), UINT16_C(     0), UINT16_C( 19498),
                              UINT16_C(  5563), UINT16_C(     0), UINT16_C(     0), UINT16_C(     0),
                              UINT16_C(     0), UINT16_C( 47684), UINT16_C(     0), UINT16_C(     0),
                              UINT16_C(     0), UINT16_C( 43159), UINT16_C( 52069), UINT16_C( 22287),
                              UINT16_C(     0), UINT16_C(     0), UINT16_C(     0), UINT16_C(  9679),
                              UINT16_C( 27201), UINT16_C(     0), UINT16_C(     0), UINT16_C(     0),
                              UINT16_C(     0), UINT16_C( 38350), UINT16_C( 27311), UINT16_C(     0),
                              UINT16_C(     0), UINT16_C( 16982), UINT16_C(     0), UINT16_C( 43129)) },
    { simde_x_mm512_set_epu16(UINT16_C( 38028), UINT16_C(  5509), UINT16_C( 52010), UINT16_C( 16909),
                              UINT16_C(  2419), UINT16_C( 22142), UINT16_C( 59427), UINT16_C( 64359),
                              UINT16_C(  9839), UINT16_C(  6329), UINT16_C( 65297), UINT16_C( 49651),
                              UINT16_C(  3666), UINT16_C( 20122), UINT16_C( 63837), UINT16_C(  6503),
                              UINT16_C( 29169), UINT16_C( 60855), UINT16_C( 62823), UINT16_C( 40827),
                              UINT16_C(  7221), UINT16_C( 61818), UINT16_C(   970), UINT16_C( 49978),
                              UINT16_C( 54525), UINT16_C( 54749), UINT16_C( 35566), UINT16_C(  3894),
                              UINT16_C( 39622), UINT16_C( 46778), UINT16_C( 11824), UINT16_C( 56668)),
      simde_x_mm512_set_epu16(UINT16_C(  1604), UINT16_C( 19874), UINT16_C( 53403), UINT16_C( 63570),
                              UINT16_C( 13041), UINT16_C(  1566), UINT16_C( 53745), UINT16_C( 62111),
                              UINT16_C(  7377), UINT16_C( 42156), UINT16_C( 56287), UINT16_C( 34285),
                              UINT16_C( 14877), UINT16_C( 24009), UINT16_C( 33220), UINT16_C(  8308),
                              UINT16_C( 53811), UINT16_C( 55306), UINT16_C(  1074), UINT16_C( 12341),
                              UINT16_C( 19989), UINT16_C( 16491), UINT16_C(  4144), UINT16_C( 53822),
                              UINT16_C( 19285), UINT16_C( 36338), UINT16_C( 40278), UINT16_C( 36022),
                              UINT16_C(  9755), UINT16_C( 36151), UINT16_C( 42425), UINT16_C( 62124)),
      simde_x_mm512_set_epu16(UINT16_C( 36424), UINT16_C(     0), UINT16_C(     0), UINT16_C(     0),
                              UINT16_C(     0), UINT16_C( 20576), UINT16_C(  5682), UINT16_C(  2248),
                              UINT16_C(  2462), UINT16_C(     0), UINT16_C(  9010), UINT16_C( 15366),
                              UINT16_C(     0), UINT16_C(     0), UINT16_C( 30617), UINT16_C(     0),
                              UINT16_C(     0), UINT16_C(  5549), UINT16_C( 61749), UINT16_C( 28486),
                              UINT16_C(     0), UINT16_C( 45327), UINT16_C(     0), UINT16_C(     0),
                              UINT16_C( 35240), UINT16_C( 18411), UINT16_C(     0), UINT16_C(     0),
                              UINT16_C( 29867), UINT16_C( 10627), UINT16_C(     0), UINT16_C(     0)) },
    { simde_x_mm512_set_epu16(UINT16_C(   691), UINT16_C( 60713), UINT16_C( 62283), UINT16_C( 34144),
                              UINT16_C( 43752), UINT16_C( 58796), UINT16_C(  9130), UINT16_C( 47263),
                              UINT16_C( 11275), UINT16_C( 38444), UINT16_C(    90), UINT16_C( 45403),
                              UINT16_C( 30523), UINT16_C( 27008), UINT16_C( 28387), UINT16_C( 17266),
                              UINT16_C( 55759), UINT16_C( 27096), UINT16_C( 57208), UINT16_C( 58724),
                              UINT16_C( 42582), UINT16_C( 61127), UINT16_C( 21734), UINT16_C( 45841),
                              UINT16_C( 53555), UINT16_C( 44341), UINT16_C( 18272), UINT16_C( 28327),
                              UINT16_C(  7123), UINT16_C( 33320), UINT16_C( 24489), UINT16_C( 49868)),
      simde_x_mm512_set_epu16(UINT16_C( 44159), UINT16_C( 15856), UINT16_C(  7686), UINT16_C( 36968),
                              UINT16_C( 50344), UINT16_C( 55789), UINT16_C( 11300), UINT16_C( 27000),
                              UINT16_C( 58901), UINT16_C(  3626), UINT16_C( 12716), UINT16_C( 34965),
                              UINT16_C( 31697), UINT16_C(  5622), UINT16_C( 24444), UINT16_C( 57310),
                              UINT16_C( 57273), UINT16_C(  2890), UINT16_C( 26732), UINT16_C( 56773),
                              UINT16_C( 51586), UINT16_C( 27415), UINT16_C(  7653), UINT16_C( 31511),
                              UINT16_C( 44454), UINT16_C(  2398), UINT16_C( 23365), UINT16_C( 52633),
                              UINT16_C( 47315), UINT16_C(  4204), UINT16_C( 45083), UINT16_C( 15021)),
      simde_x_mm512_set_epu16(UINT16_C(     0), UINT16_C( 44857), UINT16_C( 54597), UINT16_C(     0),
                              UINT16_C(     0), UINT16_C(  3007), UINT16_C(     0), UINT16_C( 20263),
                              UINT16_C(     0), UINT16_C( 34818), UINT16_C(     0), UINT16_C( 10438),
                              UINT16_C(     0), UINT16_C( 21386), UINT16_C(  3943), UINT16_C(     0),
                              UINT16_C(     0), UINT16_C( 24206), UINT16_C( 30476), UINT16_C(  1951),
                              UINT16_C(     0), UINT16_C( 33712), UINT16_C( 14081), UINT16_C( 14330),
                              UINT16_C(  9101), UINT16_C( 41943), UINT16_C(     0), UINT16_C(     0),
                              UINT16_C(     0), UINT16_C( 29116), UINT16_C(     0), UINT16_C( 34847)) },
    { simde_x_mm512_set_epu16(UINT16_C(  4451), UINT16_C( 62415), UINT16_C( 11648), UINT16_C( 14185),
                              UINT16_C( 57037), UINT16_C( 40857), UINT16_C( 33903), UINT16_C( 19019),
                              UINT16_C( 26210), UINT16_C( 35593), UINT16_C( 46653), UINT16_C( 25468),
                              UINT16_C( 20366), UINT16_C(  4961), UINT16_C( 40068), UINT16_C( 61378),
                              UINT16_C(  6653), UINT16_C( 63816), UINT16_C( 35813), UINT16_C( 51292),
                              UINT16_C( 60619), UINT16_C(   730), UINT16_C( 44859), UINT16_C( 16986),
                              UINT16_C(  9316), UINT16_C( 28795), UINT16_C( 47263), UINT16_C( 36113),
                              UINT16_C( 41862), UINT16_C(  7963), UINT16_C( 28019), UINT16_C( 13728)),
      simde_x_mm512_set_epu16(UINT16_C( 54766), UINT16_C( 29411), UINT16_C( 30463), UINT16_C( 60634),
                              UINT16_C( 45144), UINT16_C( 37285), UINT16_C( 11448), UINT16_C( 27155),
                              UINT16_C( 53867), UINT16_C( 11820), UINT16_C( 49024), UINT16_C( 10540),
                              UINT16_C( 17477), UINT16_C( 45777), UINT16_C( 28024), UINT16_C( 51105),
                              UINT16_C( 24400), UINT16_C( 57953), UINT16_C( 53407), UINT16_C( 28592),
                              UINT16_C( 34479), UINT16_C( 47445), UINT16_C( 19926), UINT16_C( 36275),
                              UINT16_C(  7501), UINT16_C( 16620), UINT16_C(  6953), UINT16_C(  3437),
                              UINT16_C(  5790), UINT16_C(  5348), UINT16_C( 17145), UINT16_C( 36745)),
      simde_x_mm512_set_epu16(UINT16_C(     0), UINT16_C( 33004), UINT16_C(     0), UINT16_C(     0),
                              UINT16_C( 11893), UINT16_C(  3572), UINT16_C( 22455), UINT16_C(     0),
                              UINT16_C(     0), UINT16_C( 23773), UINT16_C(     0), UINT16_C( 14928),
                              UINT16_C(  2889), UINT16_C(     0), UINT16_C( 12044), UINT16_C( 10273),
                              UINT16_C(     0), UINT16_C(  5863), UINT16_C(     0), UINT16_C( 22700),
                              UINT16_C( 26140), UINT16_C(     0), UINT16_C( 24933), UINT16_C(     0),
                              UINT16_C(  1815), UINT16_C( 12175), UINT16_C( 40310), UINT16_C( 32676),
                              UINT16_C( 36072), UINT16_C(  2615), UINT16_C( 10874), UINT16_C(     0)) },
    { simde_x_mm512_set_epu16(UINT16_C( 33975), UINT16_C( 18949), UINT16_C( 63249), UINT16_C( 45002),
                              UINT16_C( 64479), UINT16_C( 62490), UINT16_C( 22138), UINT16_C( 54505),
                              UINT16_C(    43), UINT16_C( 59270), UINT16_C( 45446), UINT16_C( 43143),
                              UINT16_C( 39490), UINT16_C( 41833), UINT16_C( 28092), UINT16_C(  6346),
                              UINT16_C( 10308), UINT16_C(   572), UINT16_C(     5), UINT16_C( 15306),
                              UINT16_C( 46107), UINT16_C( 59725), UINT16_C( 38116), UINT16_C( 36408),
                              UINT16_C( 51860), UINT16_C( 61863), UINT16_C( 39379), UINT16_C( 19197),
                              UINT16_C( 37943), UINT16_C( 45506), UINT16_C(  3690), UINT16_C( 61686)),
      simde_x_mm512_set_epu16(UINT16_C( 53628), UINT16_C( 14774), UINT16_C(  5244), UINT16_C( 18107),
                              UINT16_C( 49140), UINT16_C( 31910), UINT16_C( 36671), UINT16_C( 45498),
                              UINT16_C( 46302), UINT16_C( 50428), UINT16_C( 55100), UINT16_C( 19911),
                              UINT16_C(  3330), UINT16_C( 28633), UINT16_C( 10550), UINT16_C( 56178),
                              UINT16_C( 23697), UINT16_C( 19726), UINT16_C( 39129), UINT16_C( 46658),
                              UINT16_C(  4326), UINT16_C( 42894), UINT16_C( 48134), UINT16_C( 16035),
                              UINT16_C( 14223), UINT16_C( 50376), UINT16_C( 56066), UINT16_C( 61784),
                              UINT16_C(  6710), UINT16_C( 21116), UINT16_C( 55957), UINT16_C( 10253)),
      simde_x_mm512_set_epu16(UINT16_C(     0), UINT16_C(  4175), UINT16_C( 58005), UINT16_C( 26895),
                              UINT16_C( 15339), UINT16_C( 30580), UINT16_C(     0), UINT16_C(  9007),
                              UINT16_C(     0), UINT16_C(  8842), UINT16_C(     0), UINT16_C( 23232),
                              UINT16_C( 36160), UINT16_C( 13200), UINT16_C( 17542), UINT16_C(     0),
                              UINT16_C(     0), UINT16_C(     0), UINT16_C(     0), UINT16_C(     0),
                              UINT16_C( 41781), UINT16_C( 16831), UINT16_C(     0), UINT16_C( 20373),
                              UINT16_C( 37637), UINT16_C( 11487), UINT16_C(     0), UINT16_C(     0),
                              UINT16_C( 31233), UINT16_C( 24390), UINT16_C(     0), UINT16_C( 51433)) },
    { simde_x_mm512_set_epu16(UINT16_C(  1468), UINT16_C( 61147), UINT16_C(  1296), UINT16_C( 37821),
                              UINT16_C( 49916), UINT16_C(  3731), UINT16_C( 58247), UINT16_C( 37833),
                              UINT16_C(   474), UINT16_C( 27447), UINT16_C( 56500), UINT16_C(  9176),
                              UINT16_C(  2726), UINT16_C( 53392), UINT16_C( 63435), UINT16_C( 26907),
                              UINT16_C( 40836), UINT16_C(  1244), UINT16_C( 61609), UINT16_C( 42904),
                              UINT16_C( 58011), UINT16_C( 17743), UINT16_C( 15263), UINT16_C( 61713),
                              UINT16_C( 27307), UINT16_C( 32391), UINT16_C( 42266), UINT16_C( 36235),
                              UINT16_C( 23369), UINT16_C( 50245), UINT16_C( 59696), UINT16_C( 18168)),
      simde_x_mm512_set_epu16(UINT16_C( 23449), UINT16_C( 17725), UINT16_C( 44617), UINT16_C( 31466),
                              UINT16_C( 31308), UINT16_C( 63353), UINT16_C( 34185), UINT16_C( 33150),
                              UINT16_C( 26890), UINT16_C( 34945), UINT16_C( 52751), UINT16_C( 41898),
                              UINT16_C( 33581), UINT16_C( 55689), UINT16_C( 19108), UINT16_C( 45621),
                              UINT16_C(  4587), UINT16_C( 27034), UINT16_C( 65517), UINT16_C( 28332),
                              UINT16_C( 41747), UINT16_C( 40576), UINT16_C( 59697), UINT16_C( 25722),
                              UINT16_C( 41113), UINT16_C( 15592), UINT16_C(  6092), UINT16_C( 56264),
                              UINT16_C( 52740), UINT16_C( 47873), UINT16_C( 59382), UINT16_C( 23859)),
      simde_x_mm512_set_epu16(UINT16_C(     0), UINT16_C( 43422), UINT16_C(     0), UINT16_C(  6355),
                              UINT16_C( 18608), UINT16_C(     0), UINT16_C( 24062), UINT16_C(  4683),
                              UINT16_C(     0), UINT16_C(     0), UINT16_C(  3749), UINT16_C(     0),
                              UINT16_C(     0), UINT16_C(     0), UINT16_C( 44327), UINT16_C(     0),
                              UINT16_C( 36249), UINT16_C(     0), UINT16_C(     0), UINT16_C( 14572),
                              UINT16_C( 16264), UINT16_C(     0), UINT16_C(     0), UINT16_C( 35991),
                              UINT16_C(     0), UINT16_C( 16799), UINT16_C( 36174), UINT16_C(     0),
                              UINT16_C(     0), UINT16_C(  2372), UINT16_C(   314), UINT16_C(     0)) },
    { simde_x_mm512_set_epu16(UINT16_C( 42795), UINT16_C( 13394), UINT16_C( 56119), UINT16_C( 28906),
                              UINT16_C( 46556), UINT16_C( 57073), UINT16_C(  9174), UINT16_C( 39931),
                              UINT16_C(   547), UINT16_C(  3767), UINT16_C( 52959), UINT16_C( 48990),
                              UINT16_C( 64235), UINT16_C( 58389), UINT16_C( 26281), UINT16_C( 29309),
                              UINT16_C( 29052), UINT16_C( 34694), UINT16_C(  5995), UINT16_C(  6270),
                              UINT16_C( 20539), UINT16_C( 10179), UINT16_C( 38688), UINT16_C( 14327),
                              UINT16_C( 15491), UINT16_C( 18652), UINT16_C( 19903), UINT16_C( 30123),
                              UINT16_C( 25261), UINT16_C( 48076), UINT16_C( 10742), UINT16_C( 60984)),
      simde_x_mm512_set_epu16(UINT16_C(  5754), UINT16_C( 42498), UINT16_C( 48947), UINT16_C( 41678),
                              UINT16_C( 61715), UINT16_C( 60738), UINT16_C( 30602), UINT16_C( 37004),
                              UINT16_C( 11508), UINT16_C(  7979), UINT16_C( 61659), UINT16_C( 59616),
                              UINT16_C( 41386), UINT16_C( 41040), UINT16_C( 17421), UINT16_C( 63555),
                              UINT16_C( 27523), UINT16_C( 26800), UINT16_C( 25010), UINT16_C( 27339),
                              UINT16_C( 56486), UINT16_C( 19128), UINT16_C( 15279), UINT16_C( 63719),
                              UINT16_C( 51613), UINT16_C(  5129), UINT16_C( 42918), UINT16_C( 27704),
                              UINT16_C( 60753), UINT16_C( 31238), UINT16_C( 35194), UINT16_C( 56682)),
      simde_x_mm512_set_epu16(UINT16_C( 37041), UINT16_C(     0), UINT16_C(  7172), UINT16_C(     0),
                              UINT16_C(     0), UINT16_C(     0), UINT16_C(     0), UINT16_C(  2927),
                              UINT16_C(     0), UINT16_C(     0), UINT16_C(     0), UINT16_C(     0),
                              UINT16_C( 22849), UINT16_C( 17349), UINT16_C(  8860), UINT16_C(     0),
                              UINT16_C(  1529), UINT16_C(  7894), UINT16_C(     0), UINT16_C(     0),
                              UINT16_C(     0), UINT16_C(     0), UINT16_C( 23409), UINT16_C(     0),
                              UINT16_C(     0), UINT16_C( 13523), UINT16_C(     0), UINT16_C(  2419),
                              UINT16_C(     0), UINT16_C( 16838), UINT16_C(     0), UINT16_C(  4302)) },
    { simde_x_mm512_set_epu16(UINT16_C( 27021), UINT16_C( 31131), UINT16_C(    63), UINT16_C( 55006),
                              UINT16_C( 64465), UINT16_C( 34252), UINT16_C( 43748), UINT16_C( 49428),
                              UINT16_C( 50369), UINT16_C( 25422), UINT16_C( 14520), UINT16_C( 51640),
                              UINT16_C( 20399), UINT16_C( 31915), UINT16_C( 49018), UINT16_C( 59334),
                              UINT16_C( 49204), UINT16_C( 62465), UINT16_C( 49892), UINT16_C( 58520),
                              UINT16_C( 13977), UINT16_C( 51690), UINT16_C( 42246), UINT16_C( 63457),
                              UINT16_C(  4753), UINT16_C( 14919), UINT16_C( 47008), UINT16_C(  7420),
                              UINT16_C( 12098), UINT16_C( 31014), UINT16_C( 17813), UINT16_C( 51080)),
      simde_x_mm512_set_epu16(UINT16_C( 53007), UINT16_C( 61893), UINT16_C( 36710), UINT16_C( 53426),
                              UINT16_C(  8030), UINT16_C( 20316), UINT16_C( 27324), UINT16_C( 24735),
                              UINT16_C( 58762), UINT16_C( 62832), UINT16_C( 33606), UINT16_C(  6874),
                              UINT16_C( 61584), UINT16_C(  2658), UINT16_C( 64632), UINT16_C( 57217),
                              UINT16_C( 49112), UINT16_C( 22778), UINT16_C( 18985), UINT16_C( 10063),
                              UINT16_C( 33785), UINT16_C( 16016), UINT16_C( 35319), UINT16_C( 18364),
                              UINT16_C( 45360), UINT16_C( 60575), UINT16_C( 35960), UINT16_C( 48902),
                              UINT16_C( 57525), UINT16_C( 38426), UINT16_C( 41010), UINT16_C( 54032)),
      simde_x_mm512_set_epu16(UINT16_C(     0), UINT16_C(     0), UINT16_C(     0), UINT16_C(  1580),
                              UINT16_C( 56435), UINT16_C( 13936), UINT16_C( 16424), UINT16_C( 24693),
                              UINT16_C(     0), UINT16_C(     0), UINT16_C(     0), UINT16_C( 44766),
                              UINT16_C(     0), UINT16_C( 29257), UINT16_C(     0), UINT16_C(  2117),
                              UINT16_C(    92), UINT16_C( 39687), UINT16_C( 30907), UINT16_C( 48457),
                              UINT16_C(     0), UINT16_C( 35674), UINT16_C(  6927), UINT16_C( 45093),
                              UINT16_C(     0), UINT16_C(     0), UINT16_C( 11048), UINT16_C(     0),
                              UINT16_C(     0), UINT16_C(     0), UINT16_C(     0), UINT16_C(     0)) }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])); i++) {
    simde__m512i r = simde_mm512_subs_epu16(test_vec[i].a, test_vec[i].b);
    simde_assert_m512i_u16(r, ==, test_vec[i].r);
  }

  return 0;
}

static int
test_simde_mm512_unpacklo_epi8 (SIMDE_MUNIT_TEST_ARGS) {
  static const struct {
    const int8_t a[64];
    const int8_t b[64];
    const int8_t r[64];
  } test_vec[] = {
    { {  INT8_C(  80),  INT8_C(  87),  INT8_C(  13), -INT8_C( 102),  INT8_C(  22), -INT8_C( 121), -INT8_C(  61), -INT8_C(  74),
         INT8_C(  31),  INT8_C(  47), -INT8_C(  90), -INT8_C(  58), -INT8_C(  19), -INT8_C(  27),  INT8_C(  88), -INT8_C( 107),
         INT8_C(  92),  INT8_C(  47),  INT8_C( 105), -INT8_C( 121),  INT8_C(  54),  INT8_C(  74), -INT8_C(  28), -INT8_C( 100),
         INT8_C(   2), -INT8_C(  70),  INT8_C(  98),  INT8_C(  92),  INT8_C(  28),  INT8_C(  53),  INT8_C(  83),  INT8_C( 108),
        -INT8_C( 115),  INT8_C(  96),  INT8_C(   6), -INT8_C(  93), -INT8_C(  24), -INT8_C(  55),  INT8_C(  89),  INT8_C(   7),
        -INT8_C(   8),  INT8_C(   0), -INT8_C(  51), -INT8_C(  27), -INT8_C(  27),  INT8_C(  37),  INT8_C( 122),  INT8_C(  65),
         INT8_C(  85), -INT8_C(  29), -INT8_C(  56), -INT8_C( 117),  INT8_C(  45), -INT8_C(  84),  INT8_C(  39),  INT8_C(  47),
         INT8_C( 103), -INT8_C( 119), -INT8_C( 116), -INT8_C( 125), -INT8_C(  66), -INT8_C(  33), -INT8_C(  17),  INT8_C(  75) },
      {  INT8_C(  63), -INT8_C(  11), -INT8_C(  17),  INT8_C(  39), -INT8_C(  66),  INT8_C(  72),  INT8_C(  47), -INT8_C(  74),
         INT8_C(  72), -INT8_C(   4), -INT8_C( 100),  INT8_C(  45),  INT8_C(  34),  INT8_C(  22),  INT8_C( 110),  INT8_C( 119),
        -INT8_C(   6),  INT8_C(  54),  INT8_C(   2),  INT8_C(  39), -INT8_C(  29),  INT8_C(  41),  INT8_C(  87),  INT8_C(  74),
        -INT8_C(  78), -INT8_C(  29), -INT8_C(  51),  INT8_C( 112), -INT8_C(  62), -INT8_C(  68), -INT8_C(  68),  INT8_C(   1),
        -INT8_C(  79), -INT8_C(  85),  INT8_C(  41),  INT8_C( 111), -INT8_C(  13),  INT8_C(  88),  INT8_C(  37),  INT8_C(  60),
         INT8_C(  84), -INT8_C(  63),  INT8_C( 105),  INT8_C( 118), -INT8_C(  40), -INT8_C(  40), -INT8_C(  19), -INT8_C(  46),
         INT8_C(  14), -INT8_C(  17), -INT8_C(   7), -INT8_C(  15),  INT8_C(  24),  INT8_C(  80),  INT8_C(  59), -INT8_C(  54),
         INT8_C(  51),  INT8_C(   8),  INT8_C(  59), -INT8_C(  11), -INT8_C(  60), -INT8_C(   9), -INT8_C(   9),  INT8_C( 117) },
      {  INT8_C(  80),  INT8_C(  63),  INT8_C(  87), -INT8_C(  11),  INT8_C(  13), -INT8_C(  17), -INT8_C( 102),  INT8_C(  39),
         INT8_C(  22), -INT8_C(  66), -INT8_C( 121),  INT8_C(  72), -INT8_C(  61),  INT8_C(  47), -INT8_C(  74), -INT8_C(  74),
         INT8_C(  92), -INT8_C(   6),  INT8_C(  47),  INT8_C(  54),  INT8_C( 105),  INT8_C(   2), -INT8_C( 121),  INT8_C(  39),
         INT8_C(  54), -INT8_C(  29),  INT8_C(  74),  INT8_C(  41), -INT8_C(  28),  INT8_C(  87), -INT8_C( 100),  INT8_C(  74),
        -INT8_C( 115), -INT8_C(  79),  INT8_C(  96), -INT8_C(  85),  INT8_C(   6),  INT8_C(  41), -INT8_C(  93),  INT8_C( 111),
        -INT8_C(  24), -INT8_C(  13), -INT8_C(  55),  INT8_C(  88),  INT8_C(  89),  INT8_C(  37),  INT8_C(   7),  INT8_C(  60),
         INT8_C(  85),  INT8_C(  14), -INT8_C(  29), -INT8_C(  17), -INT8_C(  56), -INT8_C(   7), -INT8_C( 117), -INT8_C(  15),
         INT8_C(  45),  INT8_C(  24), -INT8_C(  84),  INT8_C(  80),  INT8_C(  39),  INT8_C(  59),  INT8_C(  47), -INT8_C(  54) } },
    { { -INT8_C(  94),  INT8_C(  32), -INT8_C(  28), -INT8_C( 107),  INT8_C( 120),  INT8_C(  10), -INT8_C(  47), -INT8_C(  52),
        -INT8_C(  53),  INT8_C(  59),  INT8_C(  67), -INT8_C(  93),  INT8_C(  19),  INT8_C(  48),  INT8_C( 117),  INT8_C(  33),
         INT8_C(  32),  INT8_C( 111),  INT8_C(  19),  INT8_C(  56), -INT8_C(  65),  INT8_C(  78),  INT8_C(   3), -INT8_C(  13),
         INT8_C(  87),  INT8_C(  62), -INT8_C(  24),  INT8_C(  27),  INT8_C(  53), -INT8_C(  33), -INT8_C( 111), -INT8_C(  41),
        -INT8_C(   1),  INT8_C( 117),  INT8_C( 108),  INT8_C( 119),      INT8_MAX,  INT8_C(  62),  INT8_C(  68),  INT8_C(  75),
         INT8_C( 121), -INT8_C( 121), -INT8_C(  18), -INT8_C( 116), -INT8_C(  73),  INT8_C( 100), -INT8_C(  83), -INT8_C(  41),
        -INT8_C(  45), -INT8_C(  64),  INT8_C(  16), -INT8_C( 110),  INT8_C(  15),  INT8_C(  19), -INT8_C( 123),  INT8_C( 102),
         INT8_C(  81),  INT8_C( 110), -INT8_C( 127), -INT8_C( 122),  INT8_C(  77),  INT8_C(  18),  INT8_C(  93),  INT8_C(  77) },
      { -INT8_C( 120), -INT8_C(  55), -INT8_C(  60),  INT8_C(   7),  INT8_C(   7),  INT8_C(   8),  INT8_C(  82),      INT8_MIN,
        -INT8_C( 113),  INT8_C(  65),  INT8_C(  12),  INT8_C(  71), -INT8_C(  91), -INT8_C(  70),  INT8_C(  30),  INT8_C( 120),
         INT8_C( 122),  INT8_C(  46),  INT8_C(  10), -INT8_C( 119),  INT8_C(  65), -INT8_C( 112), -INT8_C(  17), -INT8_C( 110),
        -INT8_C(   2),  INT8_C( 113),  INT8_C(  24),  INT8_C(  75), -INT8_C( 125),  INT8_C( 117), -INT8_C( 104),  INT8_C(  11),
         INT8_C(  63),  INT8_C(  93),  INT8_C(  19),  INT8_C(  70),  INT8_C( 101),  INT8_C( 101), -INT8_C(  57), -INT8_C(  11),
        -INT8_C(  90), -INT8_C(  45),  INT8_C(  60),  INT8_C(  75), -INT8_C( 115),  INT8_C(  90), -INT8_C(  61),  INT8_C(   8),
        -INT8_C( 119), -INT8_C(  50), -INT8_C( 111), -INT8_C(  54),  INT8_C(  94), -INT8_C( 127),  INT8_C(  93),  INT8_C(  92),
        -INT8_C(  14),  INT8_C( 117), -INT8_C(  89),  INT8_C( 117), -INT8_C(  21),  INT8_C(  64), -INT8_C( 127),  INT8_C(  42) },
      { -INT8_C(  94), -INT8_C( 120),  INT8_C(  32), -INT8_C(  55), -INT8_C(  28), -INT8_C(  60), -INT8_C( 107),  INT8_C(   7),
         INT8_C( 120),  INT8_C(   7),  INT8_C(  10),  INT8_C(   8), -INT8_C(  47),  INT8_C(  82), -INT8_C(  52),      INT8_MIN,
         INT8_C(  32),  INT8_C( 122),  INT8_C( 111),  INT8_C(  46),  INT8_C(  19),  INT8_C(  10),  INT8_C(  56), -INT8_C( 119),
        -INT8_C(  65),  INT8_C(  65),  INT8_C(  78), -INT8_C( 112),  INT8_C(   3), -INT8_C(  17), -INT8_C(  13), -INT8_C( 110),
        -INT8_C(   1),  INT8_C(  63),  INT8_C( 117),  INT8_C(  93),  INT8_C( 108),  INT8_C(  19),  INT8_C( 119),  INT8_C(  70),
             INT8_MAX,  INT8_C( 101),  INT8_C(  62),  INT8_C( 101),  INT8_C(  68), -INT8_C(  57),  INT8_C(  75), -INT8_C(  11),
        -INT8_C(  45), -INT8_C( 119), -INT8_C(  64), -INT8_C(  50),  INT8_C(  16), -INT8_C( 111), -INT8_C( 110), -INT8_C(  54),
         INT8_C(  15),  INT8_C(  94),  INT8_C(  19), -INT8_C( 127), -INT8_C( 123),  INT8_C(  93),  INT8_C( 102),  INT8_C(  92) } },
    { { -INT8_C(  99), -INT8_C( 108),  INT8_C( 112),  INT8_C(   2), -INT8_C(   7),  INT8_C(  55), -INT8_C(   9), -INT8_C(  96),
         INT8_C(  11),  INT8_C(  51), -INT8_C(  21), -INT8_C( 104), -INT8_C( 114), -INT8_C(  81), -INT8_C(  96),  INT8_C(  23),
         INT8_C( 125),  INT8_C(  50), -INT8_C(  31), -INT8_C(  37), -INT8_C(  77),  INT8_C(  62),  INT8_C(  55), -INT8_C(  91),
        -INT8_C(  76), -INT8_C(  34),  INT8_C(  26), -INT8_C(  97),  INT8_C(  30), -INT8_C( 101), -INT8_C(  55), -INT8_C(  69),
         INT8_C(  47),  INT8_C(  57), -INT8_C(  66),  INT8_C(  41),  INT8_C( 113), -INT8_C(  75), -INT8_C(  55),  INT8_C( 124),
        -INT8_C(  23), -INT8_C(  76),  INT8_C(  20),  INT8_C( 119),  INT8_C(  99), -INT8_C(  75), -INT8_C( 114), -INT8_C(  32),
        -INT8_C(  25),  INT8_C( 111), -INT8_C(  69), -INT8_C( 102), -INT8_C(  82), -INT8_C(  14),  INT8_C(  63),  INT8_C(  98),
        -INT8_C(  47),  INT8_C(  89),  INT8_C(   1), -INT8_C(  17), -INT8_C(  11), -INT8_C(  54), -INT8_C(  85),  INT8_C(  36) },
      {  INT8_C(   3),  INT8_C( 105),  INT8_C(  77),  INT8_C( 116),  INT8_C(  30),  INT8_C(  22), -INT8_C(  16),  INT8_C(   7),
        -INT8_C(  53),  INT8_C(   5),  INT8_C( 126),  INT8_C(  46), -INT8_C(  70),  INT8_C(  12),  INT8_C(  15), -INT8_C(  95),
         INT8_C( 124), -INT8_C(  54),  INT8_C(  59),  INT8_C(  42), -INT8_C(  67),  INT8_C( 122), -INT8_C( 116), -INT8_C( 114),
        -INT8_C(  45), -INT8_C( 115),  INT8_C( 125), -INT8_C(  56),  INT8_C(  87),  INT8_C(  40), -INT8_C(  19),  INT8_C(  90),
        -INT8_C( 111),  INT8_C(  58), -INT8_C(  49), -INT8_C(  80),  INT8_C(  81), -INT8_C(  65), -INT8_C(  73),  INT8_C(  28),
        -INT8_C(  60),  INT8_C(  54),  INT8_C(  74),  INT8_C( 126),  INT8_C(  66),  INT8_C(  89),  INT8_C(  31), -INT8_C(  66),
         INT8_C(  36),  INT8_C(  90), -INT8_C(  24), -INT8_C(  31), -INT8_C(  44),  INT8_C( 116),  INT8_C( 111), -INT8_C(  88),
         INT8_C(   1), -INT8_C(  20),  INT8_C( 112),  INT8_C(  88),  INT8_C(  21),  INT8_C(  93), -INT8_C(  77), -INT8_C(  90) },
      { -INT8_C(  99),  INT8_C(   3), -INT8_C( 108),  INT8_C( 105),  INT8_C( 112),  INT8_C(  77),  INT8_C(   2),  INT8_C( 116),
        -INT8_C(   7),  INT8_C(  30),  INT8_C(  55),  INT8_C(  22), -INT8_C(   9), -INT8_C(  16), -INT8_C(  96),  INT8_C(   7),
         INT8_C( 125),  INT8_C( 124),  INT8_C(  50), -INT8_C(  54), -INT8_C(  31),  INT8_C(  59), -INT8_C(  37),  INT8_C(  42),
        -INT8_C(  77), -INT8_C(  67),  INT8_C(  62),  INT8_C( 122),  INT8_C(  55), -INT8_C( 116), -INT8_C(  91), -INT8_C( 114),
         INT8_C(  47), -INT8_C( 111),  INT8_C(  57),  INT8_C(  58), -INT8_C(  66), -INT8_C(  49),  INT8_C(  41), -INT8_C(  80),
         INT8_C( 113),  INT8_C(  81), -INT8_C(  75), -INT8_C(  65), -INT8_C(  55), -INT8_C(  73),  INT8_C( 124),  INT8_C(  28),
        -INT8_C(  25),  INT8_C(  36),  INT8_C( 111),  INT8_C(  90), -INT8_C(  69), -INT8_C(  24), -INT8_C( 102), -INT8_C(  31),
        -INT8_C(  82), -INT8_C(  44), -INT8_C(  14),  INT8_C( 116),  INT8_C(  63),  INT8_C( 111),  INT8_C(  98), -INT8_C(  88) } },
    { { -INT8_C( 104), -INT8_C( 126),  INT8_C(  86), -INT8_C(  23),  INT8_C(  65),  INT8_C(  14),  INT8_C(   5),  INT8_C(   6),
         INT8_C(  68),  INT8_C(  79), -INT8_C( 124), -INT8_C( 122), -INT8_C(  87), -INT8_C(  92),  INT8_C(  69), -INT8_C(  51),
        -INT8_C(   2),  INT8_C(  45), -INT8_C(  82), -INT8_C(  45), -INT8_C(  94),  INT8_C(  29),  INT8_C( 123), -INT8_C(  93),
         INT8_C(   9), -INT8_C(  21), -INT8_C(   4),  INT8_C(  30),  INT8_C(  73), -INT8_C(  81), -INT8_C(  59), -INT8_C(  31),
         INT8_C(  49),  INT8_C(  27), -INT8_C(  54),  INT8_C( 114),  INT8_C(  41), -INT8_C(  49),  INT8_C( 120),  INT8_C( 109),
         INT8_C(  30), -INT8_C(   3), -INT8_C(  12), -INT8_C(  57), -INT8_C(  95),  INT8_C(  57), -INT8_C( 108), -INT8_C(  97),
         INT8_C( 102),  INT8_C(  66),  INT8_C( 114),  INT8_C(   8),  INT8_C(  95), -INT8_C(  19), -INT8_C(  84),  INT8_C( 105),
        -INT8_C(  39), -INT8_C(  88), -INT8_C( 121),  INT8_C(  34),  INT8_C(  87),  INT8_C(  76),  INT8_C(   3), -INT8_C( 120) },
      {  INT8_C( 104), -INT8_C(  51), -INT8_C(   6), -INT8_C( 111), -INT8_C( 100),  INT8_C( 115), -INT8_C(   1), -INT8_C(  70),
         INT8_C( 112), -INT8_C(  13), -INT8_C( 126),  INT8_C(  17),  INT8_C(  44),  INT8_C(  22), -INT8_C(  80), -INT8_C( 110),
         INT8_C(  89),  INT8_C(  35), -INT8_C( 101), -INT8_C(  72),  INT8_C(  16),  INT8_C(  71),  INT8_C(  33), -INT8_C(  23),
        -INT8_C(  17), -INT8_C(  87),  INT8_C(  11),  INT8_C(  70), -INT8_C(  11),  INT8_C(  14), -INT8_C(  50),  INT8_C(  93),
        -INT8_C(  37), -INT8_C(  56), -INT8_C(  17),  INT8_C( 119),  INT8_C(  59), -INT8_C(  18),  INT8_C(  50), -INT8_C(  85),
        -INT8_C(  31), -INT8_C(  76), -INT8_C(  68),  INT8_C(  13), -INT8_C(  54),  INT8_C( 109), -INT8_C(  97),  INT8_C(  35),
        -INT8_C( 112),  INT8_C(  58), -INT8_C(  36), -INT8_C(  96), -INT8_C( 127), -INT8_C(   3), -INT8_C( 118),  INT8_C( 112),
        -INT8_C(  90), -INT8_C( 107), -INT8_C(  74), -INT8_C( 100), -INT8_C(  92), -INT8_C( 124), -INT8_C(   7),      INT8_MAX },
      { -INT8_C( 104),  INT8_C( 104), -INT8_C( 126), -INT8_C(  51),  INT8_C(  86), -INT8_C(   6), -INT8_C(  23), -INT8_C( 111),
         INT8_C(  65), -INT8_C( 100),  INT8_C(  14),  INT8_C( 115),  INT8_C(   5), -INT8_C(   1),  INT8_C(   6), -INT8_C(  70),
        -INT8_C(   2),  INT8_C(  89),  INT8_C(  45),  INT8_C(  35), -INT8_C(  82), -INT8_C( 101), -INT8_C(  45), -INT8_C(  72),
        -INT8_C(  94),  INT8_C(  16),  INT8_C(  29),  INT8_C(  71),  INT8_C( 123),  INT8_C(  33), -INT8_C(  93), -INT8_C(  23),
         INT8_C(  49), -INT8_C(  37),  INT8_C(  27), -INT8_C(  56), -INT8_C(  54), -INT8_C(  17),  INT8_C( 114),  INT8_C( 119),
         INT8_C(  41),  INT8_C(  59), -INT8_C(  49), -INT8_C(  18),  INT8_C( 120),  INT8_C(  50),  INT8_C( 109), -INT8_C(  85),
         INT8_C( 102), -INT8_C( 112),  INT8_C(  66),  INT8_C(  58),  INT8_C( 114), -INT8_C(  36),  INT8_C(   8), -INT8_C(  96),
         INT8_C(  95), -INT8_C( 127), -INT8_C(  19), -INT8_C(   3), -INT8_C(  84), -INT8_C( 118),  INT8_C( 105),  INT8_C( 112) } },
    { {  INT8_C(  77), -INT8_C(  24), -INT8_C(   9), -INT8_C( 120), -INT8_C(  42),  INT8_C(  41),  INT8_C(  52), -INT8_C(  73),
        -INT8_C(  35), -INT8_C(  16), -INT8_C(  60), -INT8_C(  89),  INT8_C(  93),  INT8_C( 100), -INT8_C(  53), -INT8_C(  19),
        -INT8_C(  98), -INT8_C(  89), -INT8_C( 114),  INT8_C(  32), -INT8_C(  92),  INT8_C(  24), -INT8_C( 112),  INT8_C(  75),
        -INT8_C(  83),  INT8_C(  71), -INT8_C(  25),  INT8_C(  81), -INT8_C(  53), -INT8_C(  32), -INT8_C(  47),  INT8_C(  24),
        -INT8_C(  55), -INT8_C(  56), -INT8_C(  95), -INT8_C(  97), -INT8_C(  15), -INT8_C(  43),  INT8_C(  87), -INT8_C(  50),
        -INT8_C(  59),  INT8_C(  27),  INT8_C( 117),  INT8_C(  35),      INT8_MAX,  INT8_C(  64),  INT8_C(  16),  INT8_C(  30),
        -INT8_C(  25), -INT8_C(  98),  INT8_C(  62), -INT8_C( 116), -INT8_C(  74), -INT8_C(  50), -INT8_C(  41),  INT8_C( 100),
         INT8_C(  21), -INT8_C(  66), -INT8_C(  75), -INT8_C(  31), -INT8_C(  98), -INT8_C( 122), -INT8_C(   7),  INT8_C( 103) },
      {  INT8_C(  78), -INT8_C( 102),  INT8_C(   7),  INT8_C(  63),  INT8_C( 111),  INT8_C(  94),  INT8_C(  13),  INT8_C(  53),
         INT8_C( 121), -INT8_C( 125),  INT8_C(  88), -INT8_C(   7), -INT8_C(  61),  INT8_C( 104),  INT8_C(  23), -INT8_C(  85),
         INT8_C(   7),  INT8_C(  85),  INT8_C(  55), -INT8_C(  67),  INT8_C(  35),  INT8_C(  14),  INT8_C(  33),  INT8_C(  57),
        -INT8_C(  52), -INT8_C(  41),  INT8_C(  26),  INT8_C( 106),  INT8_C(  93),  INT8_C(  19), -INT8_C(  46), -INT8_C(  84),
        -INT8_C(  82), -INT8_C(  39), -INT8_C(  21),  INT8_C(  29),  INT8_C(  55), -INT8_C(   7),  INT8_C(  82), -INT8_C(  80),
         INT8_C( 124), -INT8_C(  86), -INT8_C(  87),  INT8_C(  63),  INT8_C(  19), -INT8_C(  64), -INT8_C(  22),  INT8_C(  26),
         INT8_C(  21),  INT8_C(  33), -INT8_C(  41),  INT8_C(  57),  INT8_C(  47), -INT8_C(   7),  INT8_C( 114), -INT8_C(   5),
        -INT8_C(  48), -INT8_C( 116),  INT8_C( 102),  INT8_C(  45), -INT8_C(  97),  INT8_C(  56), -INT8_C(  39),  INT8_C(  77) },
      {  INT8_C(  77),  INT8_C(  78), -INT8_C(  24), -INT8_C( 102), -INT8_C(   9),  INT8_C(   7), -INT8_C( 120),  INT8_C(  63),
        -INT8_C(  42),  INT8_C( 111),  INT8_C(  41),  INT8_C(  94),  INT8_C(  52),  INT8_C(  13), -INT8_C(  73),  INT8_C(  53),
        -INT8_C(  98),  INT8_C(   7), -INT8_C(  89),  INT8_C(  85), -INT8_C( 114),  INT8_C(  55),  INT8_C(  32), -INT8_C(  67),
        -INT8_C(  92),  INT8_C(  35),  INT8_C(  24),  INT8_C(  14), -INT8_C( 112),  INT8_C(  33),  INT8_C(  75),  INT8_C(  57),
        -INT8_C(  55), -INT8_C(  82), -INT8_C(  56), -INT8_C(  39), -INT8_C(  95), -INT8_C(  21), -INT8_C(  97),  INT8_C(  29),
        -INT8_C(  15),  INT8_C(  55), -INT8_C(  43), -INT8_C(   7),  INT8_C(  87),  INT8_C(  82), -INT8_C(  50), -INT8_C(  80),
        -INT8_C(  25),  INT8_C(  21), -INT8_C(  98),  INT8_C(  33),  INT8_C(  62), -INT8_C(  41), -INT8_C( 116),  INT8_C(  57),
        -INT8_C(  74),  INT8_C(  47), -INT8_C(  50), -INT8_C(   7), -INT8_C(  41),  INT8_C( 114),  INT8_C( 100), -INT8_C(   5) } },
    { {  INT8_C(  17), -INT8_C(  59),  INT8_C( 107),  INT8_C(  72), -INT8_C(  66), -INT8_C(  67), -INT8_C(   8),  INT8_C(  58),
         INT8_C( 104), -INT8_C(  94),  INT8_C( 121),  INT8_C( 123),  INT8_C(  98),  INT8_C( 100), -INT8_C( 107),  INT8_C( 120),
        -INT8_C( 123),  INT8_C( 108), -INT8_C(  79), -INT8_C(  75),  INT8_C( 101),  INT8_C(  35), -INT8_C(  80),  INT8_C(  53),
        -INT8_C(  81),  INT8_C(  22),  INT8_C(  99),  INT8_C(  78),  INT8_C(  78),  INT8_C(  60), -INT8_C( 100),  INT8_C(  95),
         INT8_C(   1),  INT8_C(   7), -INT8_C(  89), -INT8_C(  65), -INT8_C(  60), -INT8_C(  96), -INT8_C(   7),  INT8_C(  44),
         INT8_C(  66),  INT8_C( 115), -INT8_C(  89), -INT8_C(  92), -INT8_C(  41),  INT8_C(  60),  INT8_C(  28),  INT8_C(  92),
        -INT8_C(  87), -INT8_C(  51),  INT8_C(  17),  INT8_C(  14), -INT8_C(  16), -INT8_C(  62),  INT8_C(  68), -INT8_C(  97),
        -INT8_C(  40), -INT8_C(  89), -INT8_C(  18),  INT8_C(  39), -INT8_C(  29), -INT8_C( 118), -INT8_C( 122), -INT8_C(  27) },
      { -INT8_C( 111),  INT8_C(  46), -INT8_C(  92),  INT8_C(  85), -INT8_C(  50), -INT8_C(  98), -INT8_C( 126),  INT8_C(  16),
         INT8_C(  17),  INT8_C(  41), -INT8_C(  76), -INT8_C(  24),  INT8_C( 102), -INT8_C(  47),  INT8_C(  68),  INT8_C(  15),
        -INT8_C(  98),  INT8_C(  86),  INT8_C(  29), -INT8_C( 113),  INT8_C(  24),  INT8_C(  97),  INT8_C(  46), -INT8_C(  16),
         INT8_C(   8),  INT8_C(  28),  INT8_C(  23), -INT8_C(  20), -INT8_C(  90), -INT8_C(  98), -INT8_C(  47),  INT8_C(  55),
        -INT8_C(  52),  INT8_C( 117), -INT8_C( 115), -INT8_C( 102),  INT8_C(  19),  INT8_C(  15), -INT8_C(  86),  INT8_C(  36),
         INT8_C(  56),  INT8_C(  94),  INT8_C(  12), -INT8_C(  98),  INT8_C(  47),  INT8_C(  81), -INT8_C(  83), -INT8_C(  50),
        -INT8_C(  89), -INT8_C(  53),  INT8_C(  93), -INT8_C(  65),  INT8_C(  44), -INT8_C( 117), -INT8_C(  81),  INT8_C(  53),
        -INT8_C(  88), -INT8_C(  57),  INT8_C(  33),  INT8_C(  78),  INT8_C( 101), -INT8_C(  14), -INT8_C( 122),  INT8_C(  49) },
      {  INT8_C(  17), -INT8_C( 111), -INT8_C(  59),  INT8_C(  46),  INT8_C( 107), -INT8_C(  92),  INT8_C(  72),  INT8_C(  85),
        -INT8_C(  66), -INT8_C(  50), -INT8_C(  67), -INT8_C(  98), -INT8_C(   8), -INT8_C( 126),  INT8_C(  58),  INT8_C(  16),
        -INT8_C( 123), -INT8_C(  98),  INT8_C( 108),  INT8_C(  86), -INT8_C(  79),  INT8_C(  29), -INT8_C(  75), -INT8_C( 113),
         INT8_C( 101),  INT8_C(  24),  INT8_C(  35),  INT8_C(  97), -INT8_C(  80),  INT8_C(  46),  INT8_C(  53), -INT8_C(  16),
         INT8_C(   1), -INT8_C(  52),  INT8_C(   7),  INT8_C( 117), -INT8_C(  89), -INT8_C( 115), -INT8_C(  65), -INT8_C( 102),
        -INT8_C(  60),  INT8_C(  19), -INT8_C(  96),  INT8_C(  15), -INT8_C(   7), -INT8_C(  86),  INT8_C(  44),  INT8_C(  36),
        -INT8_C(  87), -INT8_C(  89), -INT8_C(  51), -INT8_C(  53),  INT8_C(  17),  INT8_C(  93),  INT8_C(  14), -INT8_C(  65),
        -INT8_C(  16),  INT8_C(  44), -INT8_C(  62), -INT8_C( 117),  INT8_C(  68), -INT8_C(  81), -INT8_C(  97),  INT8_C(  53) } },
    { {  INT8_C( 103),  INT8_C(  19), -INT8_C(  53),  INT8_C( 123),  INT8_C(  34),  INT8_C( 117), -INT8_C(  97),  INT8_C(  90),
        -INT8_C(  45), -INT8_C(  84), -INT8_C(   7),  INT8_C(   3), -INT8_C(   3), -INT8_C(  90), -INT8_C(  47), -INT8_C(  92),
         INT8_C( 113),  INT8_C(  46),  INT8_C(  99), -INT8_C(  98), -INT8_C(  71),  INT8_C(  18), -INT8_C(  45),  INT8_C(  97),
        -INT8_C(  39), -INT8_C(  12), -INT8_C(  80),  INT8_C(  62), -INT8_C(  26),  INT8_C(  54),  INT8_C( 111),  INT8_C(  77),
         INT8_C(  73),  INT8_C(  58), -INT8_C(  56),  INT8_C( 107), -INT8_C(  81),  INT8_C( 104), -INT8_C(  59), -INT8_C( 125),
         INT8_C(  20), -INT8_C(  66), -INT8_C( 122),  INT8_C(  17),  INT8_C( 101),  INT8_C(  87), -INT8_C(  75), -INT8_C(  42),
        -INT8_C( 123),  INT8_C(  24),  INT8_C( 116),  INT8_C(  62),  INT8_C(  42),  INT8_C(  71), -INT8_C(  96),  INT8_C(   4),
         INT8_C(  59),  INT8_C(  80),  INT8_C(  66),  INT8_C(  33), -INT8_C( 122), -INT8_C(  78),  INT8_C( 111), -INT8_C(  49) },
      { -INT8_C(  20),  INT8_C(  55),  INT8_C(  58), -INT8_C( 100), -INT8_C(  97), -INT8_C(   1),  INT8_C(  31), -INT8_C(  77),
        -INT8_C(  66), -INT8_C(  91), -INT8_C(  60),  INT8_C(  35), -INT8_C(   4),  INT8_C( 121), -INT8_C(   7), -INT8_C( 127),
        -INT8_C( 111),  INT8_C( 110), -INT8_C(  65), -INT8_C(  68), -INT8_C(  75),  INT8_C(  95), -INT8_C(  64), -INT8_C(  15),
        -INT8_C(  81),  INT8_C(   2),  INT8_C(  18),  INT8_C(  53), -INT8_C(  76), -INT8_C( 127),  INT8_C(   4), -INT8_C(  95),
        -INT8_C(  71),  INT8_C(  62),  INT8_C(  61),  INT8_C(  88),  INT8_C(  62),  INT8_C(  92),  INT8_C(  12), -INT8_C(   4),
         INT8_C(   1), -INT8_C(  48),  INT8_C(  31), -INT8_C(   3),  INT8_C(  74),  INT8_C(  24),  INT8_C( 126), -INT8_C(  37),
        -INT8_C( 122),  INT8_C(  61), -INT8_C( 105),  INT8_C(  60), -INT8_C(  99),  INT8_C(  87),  INT8_C(  45),  INT8_C(  76),
         INT8_C(  90),  INT8_C(  63), -INT8_C( 126),  INT8_C(  14), -INT8_C(  63), -INT8_C( 122), -INT8_C(  81),  INT8_C( 122) },
      {  INT8_C( 103), -INT8_C(  20),  INT8_C(  19),  INT8_C(  55), -INT8_C(  53),  INT8_C(  58),  INT8_C( 123), -INT8_C( 100),
         INT8_C(  34), -INT8_C(  97),  INT8_C( 117), -INT8_C(   1), -INT8_C(  97),  INT8_C(  31),  INT8_C(  90), -INT8_C(  77),
         INT8_C( 113), -INT8_C( 111),  INT8_C(  46),  INT8_C( 110),  INT8_C(  99), -INT8_C(  65), -INT8_C(  98), -INT8_C(  68),
        -INT8_C(  71), -INT8_C(  75),  INT8_C(  18),  INT8_C(  95), -INT8_C(  45), -INT8_C(  64),  INT8_C(  97), -INT8_C(  15),
         INT8_C(  73), -INT8_C(  71),  INT8_C(  58),  INT8_C(  62), -INT8_C(  56),  INT8_C(  61),  INT8_C( 107),  INT8_C(  88),
        -INT8_C(  81),  INT8_C(  62),  INT8_C( 104),  INT8_C(  92), -INT8_C(  59),  INT8_C(  12), -INT8_C( 125), -INT8_C(   4),
        -INT8_C( 123), -INT8_C( 122),  INT8_C(  24),  INT8_C(  61),  INT8_C( 116), -INT8_C( 105),  INT8_C(  62),  INT8_C(  60),
         INT8_C(  42), -INT8_C(  99),  INT8_C(  71),  INT8_C(  87), -INT8_C(  96),  INT8_C(  45),  INT8_C(   4),  INT8_C(  76) } },
    { { -INT8_C(  59), -INT8_C(  20), -INT8_C(  46),  INT8_C(   3),  INT8_C(  72), -INT8_C(  34), -INT8_C(   1),  INT8_C(  73),
        -INT8_C(  81),  INT8_C(  30),  INT8_C(  70), -INT8_C(   7),  INT8_C(  54), -INT8_C(  60), -INT8_C(  44), -INT8_C(  67),
         INT8_C(   2),  INT8_C( 108), -INT8_C(   7), -INT8_C(  97), -INT8_C(  61),  INT8_C(  38), -INT8_C(  21),  INT8_C(  29),
         INT8_C( 101),  INT8_C( 109),  INT8_C(  44),  INT8_C(  38), -INT8_C(  12), -INT8_C(  37), -INT8_C(  96), -INT8_C(  71),
        -INT8_C(  56),  INT8_C( 115), -INT8_C(  68),  INT8_C(  16),  INT8_C(  81), -INT8_C(  69),  INT8_C(  90),  INT8_C(   0),
        -INT8_C(  39), -INT8_C(  96), -INT8_C(   7),  INT8_C(  15),  INT8_C( 101), -INT8_C(  50), -INT8_C(  52),  INT8_C( 103),
         INT8_C(  58), -INT8_C(  59),  INT8_C(   6), -INT8_C(   3), -INT8_C(  21), -INT8_C(  15),  INT8_C(  27),  INT8_C(  81),
         INT8_C(  95),  INT8_C(  71),  INT8_C( 119),  INT8_C(  83),  INT8_C(  34),  INT8_C(  24),  INT8_C(  12), -INT8_C(  22) },
      { -INT8_C( 117), -INT8_C(  56), -INT8_C(   5), -INT8_C(  36), -INT8_C( 125),  INT8_C(  85), -INT8_C(  35),  INT8_C(  92),
        -INT8_C(  11), -INT8_C(  42),  INT8_C( 107),  INT8_C(  90), -INT8_C(  92),  INT8_C(  56), -INT8_C(  63), -INT8_C(  34),
        -INT8_C(   3), -INT8_C(  57), -INT8_C(  36), -INT8_C(  23), -INT8_C(  71), -INT8_C(   9),  INT8_C(  58),  INT8_C(  24),
         INT8_C(  62), -INT8_C(  79),  INT8_C( 107),  INT8_C(  96), -INT8_C(  55),  INT8_C( 119),  INT8_C(  75),  INT8_C(  84),
         INT8_C(  63),  INT8_C(  70),  INT8_C(  49), -INT8_C(  62), -INT8_C( 101),  INT8_C(  14),  INT8_C(  30), -INT8_C( 112),
        -INT8_C(  28), -INT8_C( 119), -INT8_C(  21), -INT8_C( 119), -INT8_C(  63), -INT8_C(  84),  INT8_C( 103), -INT8_C(  65),
         INT8_C( 116),  INT8_C(  67), -INT8_C(  88),  INT8_C(  45),  INT8_C(  58), -INT8_C(  30),  INT8_C(  69),  INT8_C( 120),
        -INT8_C( 109), -INT8_C(  80), -INT8_C(  39),  INT8_C(  93),  INT8_C(  39),  INT8_C(  36), -INT8_C(  79),  INT8_C( 102) },
      { -INT8_C(  59), -INT8_C( 117), -INT8_C(  20), -INT8_C(  56), -INT8_C(  46), -INT8_C(   5),  INT8_C(   3), -INT8_C(  36),
         INT8_C(  72), -INT8_C( 125), -INT8_C(  34),  INT8_C(  85), -INT8_C(   1), -INT8_C(  35),  INT8_C(  73),  INT8_C(  92),
         INT8_C(   2), -INT8_C(   3),  INT8_C( 108), -INT8_C(  57), -INT8_C(   7), -INT8_C(  36), -INT8_C(  97), -INT8_C(  23),
        -INT8_C(  61), -INT8_C(  71),  INT8_C(  38), -INT8_C(   9), -INT8_C(  21),  INT8_C(  58),  INT8_C(  29),  INT8_C(  24),
        -INT8_C(  56),  INT8_C(  63),  INT8_C( 115),  INT8_C(  70), -INT8_C(  68),  INT8_C(  49),  INT8_C(  16), -INT8_C(  62),
         INT8_C(  81), -INT8_C( 101), -INT8_C(  69),  INT8_C(  14),  INT8_C(  90),  INT8_C(  30),  INT8_C(   0), -INT8_C( 112),
         INT8_C(  58),  INT8_C( 116), -INT8_C(  59),  INT8_C(  67),  INT8_C(   6), -INT8_C(  88), -INT8_C(   3),  INT8_C(  45),
        -INT8_C(  21),  INT8_C(  58), -INT8_C(  15), -INT8_C(  30),  INT8_C(  27),  INT8_C(  69),  INT8_C(  81),  INT8_C( 120) } }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
    simde__m512i a = simde_mm512_loadu_epi8(test_vec[i].a);
    simde__m512i b = simde_mm512_loadu_epi8(test_vec[i].b);
    simde__m512i r = simde_mm512_unpacklo_epi8(a, b);
    simde_test_x86_assert_equal_i8x64(r, simde_mm512_loadu_epi8(test_vec[i].r));
  }

  return 0;
}

static int
test_simde_mm512_unpacklo_epi16 (SIMDE_MUNIT_TEST_ARGS) {
  static const struct {
    const int16_t a[32];
    const int16_t b[32];
    const int16_t r[32];
  } test_vec[] = {
    { { -INT16_C( 31331), -INT16_C( 31002),  INT16_C( 23655),  INT16_C( 30198),  INT16_C( 10179), -INT16_C(  9689),  INT16_C( 31352),  INT16_C( 27403),
         INT16_C(  9684), -INT16_C( 30117), -INT16_C(  8450),  INT16_C( 25365), -INT16_C(  3020), -INT16_C( 21287),  INT16_C( 13982),  INT16_C( 15230),
         INT16_C( 26043),  INT16_C(  8898), -INT16_C( 18239), -INT16_C( 31593), -INT16_C( 16417),  INT16_C( 22367),  INT16_C( 27193),  INT16_C(  3779),
         INT16_C(  7824), -INT16_C( 29032), -INT16_C( 20996),  INT16_C( 12530), -INT16_C( 13406),  INT16_C( 16604),  INT16_C( 23297), -INT16_C( 17029) },
      {  INT16_C( 15808), -INT16_C( 32289),  INT16_C( 30709), -INT16_C( 11258),  INT16_C( 25910),  INT16_C( 28460), -INT16_C(  4145),  INT16_C( 24445),
         INT16_C(  5645),  INT16_C(  2798), -INT16_C(  7997),  INT16_C( 25914),  INT16_C(  6059), -INT16_C( 21083),  INT16_C(  8562),  INT16_C( 12906),
         INT16_C( 18782),  INT16_C( 21683), -INT16_C( 17984), -INT16_C(  2520),  INT16_C( 21534), -INT16_C(  4506), -INT16_C(  7357),  INT16_C( 20813),
         INT16_C( 15353), -INT16_C( 17061), -INT16_C( 27365), -INT16_C( 14558), -INT16_C( 14164),  INT16_C(  7796), -INT16_C(  8471),  INT16_C( 18256) },
      { -INT16_C( 31331),  INT16_C( 15808), -INT16_C( 31002), -INT16_C( 32289),  INT16_C( 23655),  INT16_C( 30709),  INT16_C( 30198), -INT16_C( 11258),
         INT16_C(  9684),  INT16_C(  5645), -INT16_C( 30117),  INT16_C(  2798), -INT16_C(  8450), -INT16_C(  7997),  INT16_C( 25365),  INT16_C( 25914),
         INT16_C( 26043),  INT16_C( 18782),  INT16_C(  8898),  INT16_C( 21683), -INT16_C( 18239), -INT16_C( 17984), -INT16_C( 31593), -INT16_C(  2520),
         INT16_C(  7824),  INT16_C( 15353), -INT16_C( 29032), -INT16_C( 17061), -INT16_C( 20996), -INT16_C( 27365),  INT16_C( 12530), -INT16_C( 14558) } },
    { {  INT16_C(  1063), -INT16_C(  5989), -INT16_C( 15171), -INT16_C(  8994),  INT16_C( 17432),  INT16_C( 23754),  INT16_C(  5928),  INT16_C(  8621),
         INT16_C(  2131),  INT16_C( 28382),  INT16_C(   413),  INT16_C( 18997), -INT16_C( 22071), -INT16_C( 19864), -INT16_C( 18041), -INT16_C( 20487),
        -INT16_C( 27203),  INT16_C( 31383),  INT16_C( 30041),  INT16_C( 29014),  INT16_C(  8378), -INT16_C(  7475),  INT16_C( 31288), -INT16_C( 29949),
        -INT16_C(  7550),  INT16_C(  8441),  INT16_C( 12259), -INT16_C( 21398), -INT16_C( 11560),  INT16_C( 24670),  INT16_C( 22411),  INT16_C( 18447) },
      { -INT16_C( 22804),  INT16_C( 17859),  INT16_C(  6427), -INT16_C( 10825), -INT16_C( 31686),  INT16_C( 29367), -INT16_C( 17409), -INT16_C( 32259),
        -INT16_C(  2403), -INT16_C( 32607),  INT16_C(  2853), -INT16_C(   468), -INT16_C( 29986),  INT16_C( 26974),  INT16_C( 28129), -INT16_C( 12622),
         INT16_C( 29971),  INT16_C( 11795), -INT16_C( 13682), -INT16_C( 14332), -INT16_C( 17585),  INT16_C( 20026),  INT16_C( 14198),  INT16_C(  5071),
         INT16_C( 28974),  INT16_C( 21395), -INT16_C( 16516),  INT16_C( 23121), -INT16_C( 20663),  INT16_C( 11204),  INT16_C( 30236),  INT16_C( 12281) },
      {  INT16_C(  1063), -INT16_C( 22804), -INT16_C(  5989),  INT16_C( 17859), -INT16_C( 15171),  INT16_C(  6427), -INT16_C(  8994), -INT16_C( 10825),
         INT16_C(  2131), -INT16_C(  2403),  INT16_C( 28382), -INT16_C( 32607),  INT16_C(   413),  INT16_C(  2853),  INT16_C( 18997), -INT16_C(   468),
        -INT16_C( 27203),  INT16_C( 29971),  INT16_C( 31383),  INT16_C( 11795),  INT16_C( 30041), -INT16_C( 13682),  INT16_C( 29014), -INT16_C( 14332),
        -INT16_C(  7550),  INT16_C( 28974),  INT16_C(  8441),  INT16_C( 21395),  INT16_C( 12259), -INT16_C( 16516), -INT16_C( 21398),  INT16_C( 23121) } },
    { {  INT16_C(  3307),  INT16_C( 31070),  INT16_C( 25303),  INT16_C(  9794),  INT16_C( 31773), -INT16_C( 27532),  INT16_C( 17332), -INT16_C(  7513),
         INT16_C( 15284),  INT16_C( 12597), -INT16_C( 30726),  INT16_C( 17547),  INT16_C( 20278),  INT16_C( 21359),  INT16_C( 26821), -INT16_C( 20350),
        -INT16_C(  8076),  INT16_C( 19242),  INT16_C( 27714),  INT16_C( 24689), -INT16_C(  6680), -INT16_C( 25356), -INT16_C( 25815), -INT16_C(  8834),
        -INT16_C( 19242), -INT16_C( 12018), -INT16_C( 26053),  INT16_C( 28949), -INT16_C( 31511), -INT16_C( 20540),  INT16_C( 18412),  INT16_C( 24671) },
      { -INT16_C( 30425),  INT16_C( 27308),  INT16_C(  7669), -INT16_C(  8502), -INT16_C( 16893),  INT16_C( 11386), -INT16_C(  1703),  INT16_C( 12297),
         INT16_C(  6317), -INT16_C(  6143),  INT16_C(  5810), -INT16_C( 25767),  INT16_C(  7834), -INT16_C( 31158), -INT16_C( 21915), -INT16_C( 29466),
        -INT16_C( 28109),  INT16_C( 10742), -INT16_C( 16208), -INT16_C( 19705), -INT16_C( 32386), -INT16_C( 10017), -INT16_C(  6022),  INT16_C(  9992),
         INT16_C(  2304), -INT16_C( 19953),  INT16_C( 26911), -INT16_C( 18098), -INT16_C( 26489), -INT16_C(  5057),  INT16_C(  9538),  INT16_C( 30328) },
      {  INT16_C(  3307), -INT16_C( 30425),  INT16_C( 31070),  INT16_C( 27308),  INT16_C( 25303),  INT16_C(  7669),  INT16_C(  9794), -INT16_C(  8502),
         INT16_C( 15284),  INT16_C(  6317),  INT16_C( 12597), -INT16_C(  6143), -INT16_C( 30726),  INT16_C(  5810),  INT16_C( 17547), -INT16_C( 25767),
        -INT16_C(  8076), -INT16_C( 28109),  INT16_C( 19242),  INT16_C( 10742),  INT16_C( 27714), -INT16_C( 16208),  INT16_C( 24689), -INT16_C( 19705),
        -INT16_C( 19242),  INT16_C(  2304), -INT16_C( 12018), -INT16_C( 19953), -INT16_C( 26053),  INT16_C( 26911),  INT16_C( 28949), -INT16_C( 18098) } },
    { {  INT16_C( 28600),  INT16_C( 26783), -INT16_C( 22993), -INT16_C( 20965), -INT16_C(  1497), -INT16_C( 23930), -INT16_C( 28958), -INT16_C(  7223),
        -INT16_C(  9833), -INT16_C( 18795), -INT16_C(  7358), -INT16_C( 13969), -INT16_C( 20868), -INT16_C( 16715),  INT16_C( 11731), -INT16_C( 29900),
        -INT16_C( 11364), -INT16_C( 13069),  INT16_C(  3705), -INT16_C( 24198),  INT16_C(     8), -INT16_C(  5309),  INT16_C(  3214),  INT16_C(  9678),
         INT16_C( 25573),  INT16_C( 10203),  INT16_C( 19015), -INT16_C( 15376), -INT16_C( 23048), -INT16_C( 13439), -INT16_C( 18733),  INT16_C( 28503) },
      {  INT16_C( 19081),  INT16_C(   827), -INT16_C( 19111),  INT16_C( 24996), -INT16_C(  6219),  INT16_C( 17228),  INT16_C(  6899), -INT16_C(  9880),
         INT16_C( 17278), -INT16_C( 15104), -INT16_C(  3699), -INT16_C( 31352),  INT16_C(  2454),  INT16_C( 26961), -INT16_C( 22337),  INT16_C( 18905),
         INT16_C(  5362),  INT16_C( 19276), -INT16_C(  3894),  INT16_C( 32685), -INT16_C(  1577), -INT16_C( 13629),  INT16_C( 11028), -INT16_C( 27997),
        -INT16_C( 23441), -INT16_C(   937), -INT16_C(  8299),  INT16_C( 11138), -INT16_C( 11288), -INT16_C( 22379),  INT16_C( 28283),  INT16_C( 28145) },
      {  INT16_C( 28600),  INT16_C( 19081),  INT16_C( 26783),  INT16_C(   827), -INT16_C( 22993), -INT16_C( 19111), -INT16_C( 20965),  INT16_C( 24996),
        -INT16_C(  9833),  INT16_C( 17278), -INT16_C( 18795), -INT16_C( 15104), -INT16_C(  7358), -INT16_C(  3699), -INT16_C( 13969), -INT16_C( 31352),
        -INT16_C( 11364),  INT16_C(  5362), -INT16_C( 13069),  INT16_C( 19276),  INT16_C(  3705), -INT16_C(  3894), -INT16_C( 24198),  INT16_C( 32685),
         INT16_C( 25573), -INT16_C( 23441),  INT16_C( 10203), -INT16_C(   937),  INT16_C( 19015), -INT16_C(  8299), -INT16_C( 15376),  INT16_C( 11138) } },
    { {  INT16_C( 15746),  INT16_C( 19641),  INT16_C( 26157),  INT16_C(  1228), -INT16_C( 28833),  INT16_C( 29646),  INT16_C( 29370),  INT16_C( 10501),
         INT16_C( 23574), -INT16_C( 21722), -INT16_C( 22469),  INT16_C(  9430),  INT16_C( 27515), -INT16_C(  2356), -INT16_C( 16935),  INT16_C( 23651),
         INT16_C(  7418),  INT16_C( 10152),  INT16_C( 29826), -INT16_C(  7637), -INT16_C(  1789), -INT16_C( 16811),  INT16_C( 23403), -INT16_C( 32281),
         INT16_C(  3511), -INT16_C(  3284),  INT16_C(   949),  INT16_C( 12311), -INT16_C(  7314),  INT16_C( 18470), -INT16_C( 30048), -INT16_C( 25948) },
      {  INT16_C( 19622),  INT16_C( 10689), -INT16_C(  4927), -INT16_C( 15349),  INT16_C( 24805),  INT16_C( 20866),  INT16_C( 27323),  INT16_C( 29650),
        -INT16_C(   137),  INT16_C( 11622),  INT16_C( 32002),  INT16_C( 28765), -INT16_C( 31648),  INT16_C(   184),  INT16_C( 23566), -INT16_C( 19302),
         INT16_C( 23465),  INT16_C( 27357), -INT16_C(  6073),  INT16_C( 11310), -INT16_C( 20151),  INT16_C(  1149),  INT16_C( 20507), -INT16_C( 28041),
        -INT16_C(  8881),  INT16_C( 20927),  INT16_C(  7514), -INT16_C( 17727),  INT16_C( 31393), -INT16_C( 20550),  INT16_C( 21718),  INT16_C( 32611) },
      {  INT16_C( 15746),  INT16_C( 19622),  INT16_C( 19641),  INT16_C( 10689),  INT16_C( 26157), -INT16_C(  4927),  INT16_C(  1228), -INT16_C( 15349),
         INT16_C( 23574), -INT16_C(   137), -INT16_C( 21722),  INT16_C( 11622), -INT16_C( 22469),  INT16_C( 32002),  INT16_C(  9430),  INT16_C( 28765),
         INT16_C(  7418),  INT16_C( 23465),  INT16_C( 10152),  INT16_C( 27357),  INT16_C( 29826), -INT16_C(  6073), -INT16_C(  7637),  INT16_C( 11310),
         INT16_C(  3511), -INT16_C(  8881), -INT16_C(  3284),  INT16_C( 20927),  INT16_C(   949),  INT16_C(  7514),  INT16_C( 12311), -INT16_C( 17727) } },
    { {  INT16_C( 16815), -INT16_C(  2327),  INT16_C(  6185),  INT16_C( 29219), -INT16_C( 24375), -INT16_C(  7049), -INT16_C(  4368),  INT16_C( 16246),
         INT16_C( 14028),  INT16_C(  9872),  INT16_C( 21075), -INT16_C(  2847), -INT16_C( 25652), -INT16_C( 23901),  INT16_C(  1776), -INT16_C( 24798),
         INT16_C(  2887),  INT16_C( 29078), -INT16_C( 18141), -INT16_C(  4893),  INT16_C( 23129),  INT16_C( 19152),  INT16_C( 18249),  INT16_C(  5513),
         INT16_C(  6781), -INT16_C( 12229),  INT16_C(  7276),  INT16_C( 14532),  INT16_C( 26552), -INT16_C( 22310), -INT16_C(   915), -INT16_C( 19129) },
      { -INT16_C(  8952),  INT16_C( 11046),  INT16_C(  2454), -INT16_C(  4072), -INT16_C(  6044), -INT16_C( 21190), -INT16_C( 15569), -INT16_C( 21310),
        -INT16_C(   547),  INT16_C( 18812),  INT16_C( 16410), -INT16_C( 11647),  INT16_C( 23719),  INT16_C(  5498), -INT16_C( 16040),  INT16_C( 24778),
        -INT16_C(  3937),  INT16_C( 13708), -INT16_C( 23303),  INT16_C( 23845),  INT16_C( 24460), -INT16_C( 17398), -INT16_C( 13277),  INT16_C(   104),
        -INT16_C(  6710), -INT16_C(  7094), -INT16_C( 13531), -INT16_C( 12874),  INT16_C( 12327), -INT16_C( 32542), -INT16_C( 21263), -INT16_C( 28448) },
      {  INT16_C( 16815), -INT16_C(  8952), -INT16_C(  2327),  INT16_C( 11046),  INT16_C(  6185),  INT16_C(  2454),  INT16_C( 29219), -INT16_C(  4072),
         INT16_C( 14028), -INT16_C(   547),  INT16_C(  9872),  INT16_C( 18812),  INT16_C( 21075),  INT16_C( 16410), -INT16_C(  2847), -INT16_C( 11647),
         INT16_C(  2887), -INT16_C(  3937),  INT16_C( 29078),  INT16_C( 13708), -INT16_C( 18141), -INT16_C( 23303), -INT16_C(  4893),  INT16_C( 23845),
         INT16_C(  6781), -INT16_C(  6710), -INT16_C( 12229), -INT16_C(  7094),  INT16_C(  7276), -INT16_C( 13531),  INT16_C( 14532), -INT16_C( 12874) } },
    { {  INT16_C( 27804), -INT16_C( 27194), -INT16_C(  5360), -INT16_C( 25101), -INT16_C(   693),  INT16_C( 28249), -INT16_C( 15926), -INT16_C( 27538),
        -INT16_C( 18266), -INT16_C( 13192),  INT16_C( 11908), -INT16_C( 21607),  INT16_C( 31582),  INT16_C( 20267),  INT16_C(  3111), -INT16_C( 15392),
        -INT16_C( 22920), -INT16_C( 30376),  INT16_C( 19345), -INT16_C(  9178),  INT16_C( 32585),  INT16_C(  4938), -INT16_C( 18112), -INT16_C(  6233),
         INT16_C(  8049), -INT16_C(  2637),  INT16_C( 19533), -INT16_C( 21599), -INT16_C( 13113), -INT16_C(  4358), -INT16_C(  9512),  INT16_C( 20913) },
      {  INT16_C(  2432),  INT16_C(  4826),  INT16_C(    85), -INT16_C( 24850),  INT16_C( 14719), -INT16_C( 16463),  INT16_C( 22770),  INT16_C( 25510),
         INT16_C( 22903), -INT16_C( 15271), -INT16_C(  1371),  INT16_C( 27759),  INT16_C( 27078), -INT16_C( 24742),  INT16_C(  2884), -INT16_C( 15120),
        -INT16_C( 13803),  INT16_C( 27350), -INT16_C( 14902),  INT16_C( 18696), -INT16_C( 17922), -INT16_C(  4088), -INT16_C( 20719), -INT16_C( 30637),
        -INT16_C( 21496), -INT16_C( 20916), -INT16_C( 17498),  INT16_C( 27930),  INT16_C( 29988),  INT16_C( 26636), -INT16_C(   896), -INT16_C( 27347) },
      {  INT16_C( 27804),  INT16_C(  2432), -INT16_C( 27194),  INT16_C(  4826), -INT16_C(  5360),  INT16_C(    85), -INT16_C( 25101), -INT16_C( 24850),
        -INT16_C( 18266),  INT16_C( 22903), -INT16_C( 13192), -INT16_C( 15271),  INT16_C( 11908), -INT16_C(  1371), -INT16_C( 21607),  INT16_C( 27759),
        -INT16_C( 22920), -INT16_C( 13803), -INT16_C( 30376),  INT16_C( 27350),  INT16_C( 19345), -INT16_C( 14902), -INT16_C(  9178),  INT16_C( 18696),
         INT16_C(  8049), -INT16_C( 21496), -INT16_C(  2637), -INT16_C( 20916),  INT16_C( 19533), -INT16_C( 17498), -INT16_C( 21599),  INT16_C( 27930) } },
    { {  INT16_C(   966), -INT16_C( 28417),  INT16_C(  1992), -INT16_C( 14631), -INT16_C(  7744), -INT16_C( 11850),  INT16_C(  2704), -INT16_C( 26279),
        -INT16_C( 23114),  INT16_C( 23879),  INT16_C( 24928), -INT16_C( 31286), -INT16_C( 10538),  INT16_C( 22509),  INT16_C(  6866), -INT16_C( 26388),
        -INT16_C(  5090), -INT16_C(  6616),  INT16_C(   499), -INT16_C( 19283),  INT16_C( 25570),  INT16_C( 29573), -INT16_C(  8339),  INT16_C(  9228),
         INT16_C( 21380), -INT16_C(  6783),  INT16_C( 19380), -INT16_C( 29846),  INT16_C( 22305), -INT16_C(  3102), -INT16_C( 12686), -INT16_C( 28533) },
      { -INT16_C( 19526), -INT16_C( 20874),  INT16_C(  9140), -INT16_C( 27038), -INT16_C(  6265), -INT16_C(  3063),  INT16_C(  5574),  INT16_C( 19224),
        -INT16_C( 26264),  INT16_C(  7472), -INT16_C( 25884),  INT16_C(  1448), -INT16_C( 29967),  INT16_C( 25592), -INT16_C( 31912),  INT16_C(  5107),
         INT16_C( 27190), -INT16_C(  5439),  INT16_C(  9101),  INT16_C(  5249), -INT16_C( 30198), -INT16_C( 12023),  INT16_C(  8608),  INT16_C(  2076),
         INT16_C( 19643), -INT16_C( 24795), -INT16_C( 12826), -INT16_C( 10331), -INT16_C( 25257), -INT16_C( 20421),  INT16_C( 11809),  INT16_C( 22467) },
      {  INT16_C(   966), -INT16_C( 19526), -INT16_C( 28417), -INT16_C( 20874),  INT16_C(  1992),  INT16_C(  9140), -INT16_C( 14631), -INT16_C( 27038),
        -INT16_C( 23114), -INT16_C( 26264),  INT16_C( 23879),  INT16_C(  7472),  INT16_C( 24928), -INT16_C( 25884), -INT16_C( 31286),  INT16_C(  1448),
        -INT16_C(  5090),  INT16_C( 27190), -INT16_C(  6616), -INT16_C(  5439),  INT16_C(   499),  INT16_C(  9101), -INT16_C( 19283),  INT16_C(  5249),
         INT16_C( 21380),  INT16_C( 19643), -INT16_C(  6783), -INT16_C( 24795),  INT16_C( 19380), -INT16_C( 12826), -INT16_C( 29846), -INT16_C( 10331) } }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
    simde__m512i a = simde_mm512_loadu_epi16(test_vec[i].a);
    simde__m512i b = simde_mm512_loadu_epi16(test_vec[i].b);
    simde__m512i r = simde_mm512_unpacklo_epi16(a, b);
    simde_test_x86_assert_equal_i16x32(r, simde_mm512_loadu_epi16(test_vec[i].r));
  }

  return 0;
}

static int
test_simde_mm512_unpackhi_epi8 (SIMDE_MUNIT_TEST_ARGS) {
  static const struct {
    const int8_t a[64];
    const int8_t b[64];
    const int8_t r[64];
  } test_vec[] = {
    { { -INT8_C(  38), -INT8_C( 108),  INT8_C(  78), -INT8_C(  75),  INT8_C(  17), -INT8_C( 126), -INT8_C(  86), -INT8_C( 124),
        -INT8_C(   8),  INT8_C(  83), -INT8_C( 101), -INT8_C(   3),  INT8_C(   9),  INT8_C( 117),  INT8_C(  11),  INT8_C(  58),
        -INT8_C(  88),  INT8_C(  72), -INT8_C( 104), -INT8_C(   2),  INT8_C(  22),  INT8_C(  10), -INT8_C(  57), -INT8_C(  70),
         INT8_C( 115), -INT8_C(   6), -INT8_C(  90), -INT8_C( 111), -INT8_C(  44),  INT8_C(  11), -INT8_C(  33), -INT8_C(  82),
        -INT8_C(  97),  INT8_C(  45),  INT8_C(  99), -INT8_C(  80), -INT8_C(  80),  INT8_C(  13),  INT8_C(  52), -INT8_C(  88),
         INT8_C(  96), -INT8_C(  49), -INT8_C(  91),  INT8_C( 105),  INT8_C(  68), -INT8_C(  80), -INT8_C(  92), -INT8_C(  19),
        -INT8_C(   8),  INT8_C(  60), -INT8_C(  21),  INT8_C(  14),  INT8_C(  70), -INT8_C(  78), -INT8_C(  56), -INT8_C(  70),
        -INT8_C(  84),  INT8_C( 111),  INT8_C(  75),      INT8_MIN,  INT8_C( 122),  INT8_C(  42),  INT8_C(  46),  INT8_C(  25) },
      {  INT8_C(  88), -INT8_C( 111), -INT8_C(  55),  INT8_C(   8), -INT8_C(  97), -INT8_C(   3), -INT8_C(  80), -INT8_C(   1),
        -INT8_C(  52),  INT8_C(  85),  INT8_C( 105),  INT8_C(  16),  INT8_C(   6),  INT8_C(  13), -INT8_C(   3), -INT8_C(   2),
         INT8_C(  73), -INT8_C(  24),  INT8_C(  13), -INT8_C( 112), -INT8_C( 102), -INT8_C(  43),  INT8_C(  74),  INT8_C(  70),
         INT8_C(  68), -INT8_C( 107), -INT8_C(  58), -INT8_C(  66), -INT8_C(  64), -INT8_C(  12), -INT8_C(  41),  INT8_C(  24),
        -INT8_C( 122), -INT8_C(  96),  INT8_C(  32),  INT8_C(  37), -INT8_C(  99), -INT8_C(  48),  INT8_C(  36),  INT8_C( 105),
         INT8_C(  37), -INT8_C( 115),  INT8_C( 122),  INT8_C(  43), -INT8_C( 102),  INT8_C( 119),  INT8_C(  42), -INT8_C(  28),
         INT8_C(  96),  INT8_C(  55),  INT8_C( 116), -INT8_C(   6),  INT8_C(  12), -INT8_C(  66),  INT8_C(  65),  INT8_C(  81),
         INT8_C(  83),  INT8_C(   7),  INT8_C(  15),  INT8_C(  19), -INT8_C(   4), -INT8_C(  25),  INT8_C(  43), -INT8_C( 126) },
      { -INT8_C(   8), -INT8_C(  52),  INT8_C(  83),  INT8_C(  85), -INT8_C( 101),  INT8_C( 105), -INT8_C(   3),  INT8_C(  16),
         INT8_C(   9),  INT8_C(   6),  INT8_C( 117),  INT8_C(  13),  INT8_C(  11), -INT8_C(   3),  INT8_C(  58), -INT8_C(   2),
         INT8_C( 115),  INT8_C(  68), -INT8_C(   6), -INT8_C( 107), -INT8_C(  90), -INT8_C(  58), -INT8_C( 111), -INT8_C(  66),
        -INT8_C(  44), -INT8_C(  64),  INT8_C(  11), -INT8_C(  12), -INT8_C(  33), -INT8_C(  41), -INT8_C(  82),  INT8_C(  24),
         INT8_C(  96),  INT8_C(  37), -INT8_C(  49), -INT8_C( 115), -INT8_C(  91),  INT8_C( 122),  INT8_C( 105),  INT8_C(  43),
         INT8_C(  68), -INT8_C( 102), -INT8_C(  80),  INT8_C( 119), -INT8_C(  92),  INT8_C(  42), -INT8_C(  19), -INT8_C(  28),
        -INT8_C(  84),  INT8_C(  83),  INT8_C( 111),  INT8_C(   7),  INT8_C(  75),  INT8_C(  15),      INT8_MIN,  INT8_C(  19),
         INT8_C( 122), -INT8_C(   4),  INT8_C(  42), -INT8_C(  25),  INT8_C(  46),  INT8_C(  43),  INT8_C(  25), -INT8_C( 126) } },
    { { -INT8_C( 121),  INT8_C(  75), -INT8_C(  89),  INT8_C(  37),  INT8_C(  27), -INT8_C(  53), -INT8_C( 114),  INT8_C(  65),
         INT8_C(  89),  INT8_C(   8),  INT8_C( 108), -INT8_C(  13),      INT8_MIN, -INT8_C( 106), -INT8_C(  41), -INT8_C(  32),
        -INT8_C(  51),  INT8_C(  75), -INT8_C(  38), -INT8_C(  38),  INT8_C(   9),  INT8_C(  27),  INT8_C(  43),  INT8_C(  93),
         INT8_C(  35),  INT8_C(  58),  INT8_C( 112),  INT8_C(  31),  INT8_C(  33), -INT8_C( 100), -INT8_C(  95), -INT8_C(  87),
        -INT8_C(  25),  INT8_C(  72), -INT8_C(  50),  INT8_C(   3),  INT8_C(  19),  INT8_C(  92),  INT8_C(  68),  INT8_C( 108),
         INT8_C( 101), -INT8_C(  80),  INT8_C(  96), -INT8_C(  27),  INT8_C(  71),  INT8_C(  55), -INT8_C(  59),  INT8_C(  20),
        -INT8_C( 125), -INT8_C(  97), -INT8_C(  18), -INT8_C( 116), -INT8_C(  69),  INT8_C(  25), -INT8_C(  23), -INT8_C(  34),
         INT8_C(  84),  INT8_C(  90), -INT8_C(   3),  INT8_C( 117), -INT8_C(  10), -INT8_C(  98),  INT8_C(  30), -INT8_C(  35) },
      { -INT8_C(  26), -INT8_C(  20), -INT8_C(  32), -INT8_C(   7),  INT8_C(  73),  INT8_C(  36),  INT8_C( 102), -INT8_C(  82),
        -INT8_C(  43), -INT8_C(  58), -INT8_C( 109),  INT8_C(  28), -INT8_C(   3),  INT8_C(  88),  INT8_C(  48),      INT8_MIN,
        -INT8_C(   9),  INT8_C(  31),  INT8_C(  13), -INT8_C(  78),  INT8_C(  56), -INT8_C(  10), -INT8_C( 112), -INT8_C( 116),
         INT8_C(  80), -INT8_C( 115),  INT8_C(   2),  INT8_C(  70),  INT8_C(  43),  INT8_C(  32),  INT8_C(  36),  INT8_C(  17),
         INT8_C(  13),  INT8_C(   4),  INT8_C(  11),  INT8_C(  86),  INT8_C(  41),  INT8_C( 113),  INT8_C(   4), -INT8_C(   2),
         INT8_C(  55), -INT8_C( 105),  INT8_C(  26),  INT8_C(  52), -INT8_C(  17),  INT8_C(  74), -INT8_C(  75), -INT8_C(  26),
         INT8_C( 105), -INT8_C(  62), -INT8_C( 103), -INT8_C(  94), -INT8_C(  72),  INT8_C(  41),  INT8_C(  46),  INT8_C(   9),
        -INT8_C(  73),  INT8_C(  48),  INT8_C(  79), -INT8_C(  30),  INT8_C(  81),  INT8_C( 115), -INT8_C(  12),  INT8_C(  94) },
      {  INT8_C(  89), -INT8_C(  43),  INT8_C(   8), -INT8_C(  58),  INT8_C( 108), -INT8_C( 109), -INT8_C(  13),  INT8_C(  28),
             INT8_MIN, -INT8_C(   3), -INT8_C( 106),  INT8_C(  88), -INT8_C(  41),  INT8_C(  48), -INT8_C(  32),      INT8_MIN,
         INT8_C(  35),  INT8_C(  80),  INT8_C(  58), -INT8_C( 115),  INT8_C( 112),  INT8_C(   2),  INT8_C(  31),  INT8_C(  70),
         INT8_C(  33),  INT8_C(  43), -INT8_C( 100),  INT8_C(  32), -INT8_C(  95),  INT8_C(  36), -INT8_C(  87),  INT8_C(  17),
         INT8_C( 101),  INT8_C(  55), -INT8_C(  80), -INT8_C( 105),  INT8_C(  96),  INT8_C(  26), -INT8_C(  27),  INT8_C(  52),
         INT8_C(  71), -INT8_C(  17),  INT8_C(  55),  INT8_C(  74), -INT8_C(  59), -INT8_C(  75),  INT8_C(  20), -INT8_C(  26),
         INT8_C(  84), -INT8_C(  73),  INT8_C(  90),  INT8_C(  48), -INT8_C(   3),  INT8_C(  79),  INT8_C( 117), -INT8_C(  30),
        -INT8_C(  10),  INT8_C(  81), -INT8_C(  98),  INT8_C( 115),  INT8_C(  30), -INT8_C(  12), -INT8_C(  35),  INT8_C(  94) } },
    { {  INT8_C( 120), -INT8_C(   1), -INT8_C(  76), -INT8_C(  95),  INT8_C( 112), -INT8_C(  72), -INT8_C(  97), -INT8_C(  89),
         INT8_C(  79), -INT8_C(  71), -INT8_C(  37),  INT8_C(  62),  INT8_C(   3), -INT8_C( 112),  INT8_C(  36),  INT8_C( 109),
         INT8_C(  82), -INT8_C(  67),  INT8_C(  15),  INT8_C(  11), -INT8_C(  25),  INT8_C(  61),  INT8_C(  20), -INT8_C(  98),
         INT8_C( 110),  INT8_C(  99),      INT8_MIN, -INT8_C(  65), -INT8_C(  41),  INT8_C( 116),  INT8_C(  29),  INT8_C(  79),
         INT8_C( 115), -INT8_C(  47), -INT8_C(  16), -INT8_C(  29), -INT8_C( 119), -INT8_C( 113), -INT8_C( 118), -INT8_C(  40),
         INT8_C(  72),  INT8_C( 102),  INT8_C(  22),  INT8_C(  75), -INT8_C(  10),  INT8_C(  58), -INT8_C(  72),  INT8_C(  73),
        -INT8_C(   8), -INT8_C(  57),  INT8_C(  84), -INT8_C(  33),  INT8_C(   5),  INT8_C( 104),  INT8_C( 125),  INT8_C( 115),
        -INT8_C(  53), -INT8_C(   3),  INT8_C(  50), -INT8_C(  94),  INT8_C( 114),  INT8_C(  79), -INT8_C(  15), -INT8_C(  27) },
      {  INT8_C(  32), -INT8_C(  31), -INT8_C(  55), -INT8_C(  87),  INT8_C( 112),  INT8_C(  83), -INT8_C( 127), -INT8_C(  72),
        -INT8_C(  71), -INT8_C( 105),  INT8_C(   4), -INT8_C(  80), -INT8_C(  47), -INT8_C(  68), -INT8_C(   7), -INT8_C(  55),
        -INT8_C( 124),  INT8_C(  77), -INT8_C(  88), -INT8_C( 119), -INT8_C(  75),  INT8_C(  37), -INT8_C(   4),      INT8_MIN,
         INT8_C(  35),  INT8_C(  46),  INT8_C(  35), -INT8_C( 107),  INT8_C( 125),  INT8_C(  20),  INT8_C( 122), -INT8_C(  99),
        -INT8_C(  10),  INT8_C(  67),  INT8_C(  70),  INT8_C( 102), -INT8_C( 105), -INT8_C(  57),  INT8_C(  31),  INT8_C(  80),
         INT8_C(  94),  INT8_C(  35),  INT8_C(   0),  INT8_C(  47), -INT8_C(  33), -INT8_C(   7), -INT8_C(   7),  INT8_C(  99),
         INT8_C(  70), -INT8_C(  95), -INT8_C(  20), -INT8_C(   5), -INT8_C(  57), -INT8_C(  24),  INT8_C( 124), -INT8_C(  22),
         INT8_C(  22), -INT8_C(  97),      INT8_MAX, -INT8_C( 109), -INT8_C(  77), -INT8_C(   7),  INT8_C(  48), -INT8_C(  87) },
      {  INT8_C(  79), -INT8_C(  71), -INT8_C(  71), -INT8_C( 105), -INT8_C(  37),  INT8_C(   4),  INT8_C(  62), -INT8_C(  80),
         INT8_C(   3), -INT8_C(  47), -INT8_C( 112), -INT8_C(  68),  INT8_C(  36), -INT8_C(   7),  INT8_C( 109), -INT8_C(  55),
         INT8_C( 110),  INT8_C(  35),  INT8_C(  99),  INT8_C(  46),      INT8_MIN,  INT8_C(  35), -INT8_C(  65), -INT8_C( 107),
        -INT8_C(  41),  INT8_C( 125),  INT8_C( 116),  INT8_C(  20),  INT8_C(  29),  INT8_C( 122),  INT8_C(  79), -INT8_C(  99),
         INT8_C(  72),  INT8_C(  94),  INT8_C( 102),  INT8_C(  35),  INT8_C(  22),  INT8_C(   0),  INT8_C(  75),  INT8_C(  47),
        -INT8_C(  10), -INT8_C(  33),  INT8_C(  58), -INT8_C(   7), -INT8_C(  72), -INT8_C(   7),  INT8_C(  73),  INT8_C(  99),
        -INT8_C(  53),  INT8_C(  22), -INT8_C(   3), -INT8_C(  97),  INT8_C(  50),      INT8_MAX, -INT8_C(  94), -INT8_C( 109),
         INT8_C( 114), -INT8_C(  77),  INT8_C(  79), -INT8_C(   7), -INT8_C(  15),  INT8_C(  48), -INT8_C(  27), -INT8_C(  87) } },
    { {  INT8_C(  61),  INT8_C( 118),  INT8_C(  16), -INT8_C(  44),  INT8_C(  61),  INT8_C(  47),  INT8_C(  36), -INT8_C( 101),
         INT8_C(  82),  INT8_C(  37), -INT8_C(  53),  INT8_C(  49),  INT8_C(  30), -INT8_C(  60), -INT8_C( 107),  INT8_C( 101),
         INT8_C( 101), -INT8_C( 127),  INT8_C(  96),  INT8_C(  44),  INT8_C( 106), -INT8_C(  36),  INT8_C(  22),      INT8_MIN,
         INT8_C( 123), -INT8_C( 107),  INT8_C(  20),  INT8_C(  47), -INT8_C( 113),  INT8_C(  68), -INT8_C(  40), -INT8_C(  52),
        -INT8_C(  69), -INT8_C(  24), -INT8_C(  96), -INT8_C(   8),  INT8_C(  23), -INT8_C(  60), -INT8_C( 108),  INT8_C( 105),
        -INT8_C(  23),  INT8_C(  95), -INT8_C( 101),  INT8_C(   8),  INT8_C(  35),  INT8_C(  48),  INT8_C( 109), -INT8_C( 120),
        -INT8_C(  79), -INT8_C(  51), -INT8_C(  75),  INT8_C(  27), -INT8_C(  86), -INT8_C(  53), -INT8_C( 100),  INT8_C(  37),
         INT8_C(  97), -INT8_C(  80),  INT8_C(  84), -INT8_C(  16), -INT8_C(  12),  INT8_C(  45), -INT8_C(  68), -INT8_C(  81) },
      {  INT8_C(  21),  INT8_C(  92), -INT8_C(  88),  INT8_C(  45),  INT8_C(  32),  INT8_C(  60), -INT8_C( 106),  INT8_C(  10),
        -INT8_C( 101),  INT8_C(  49),  INT8_C(  18), -INT8_C(  66),  INT8_C(  97),      INT8_MAX,  INT8_C(  70),  INT8_C(  19),
         INT8_C(  76), -INT8_C(   5),  INT8_C(  46), -INT8_C(  10), -INT8_C(  57), -INT8_C(  54),  INT8_C(  28),  INT8_C(  40),
         INT8_C( 122),  INT8_C( 112),  INT8_C(  24),  INT8_C( 111), -INT8_C(  99), -INT8_C(  44),  INT8_C(  30), -INT8_C(  77),
         INT8_C(  48), -INT8_C(  58), -INT8_C(  32),  INT8_C(  80),  INT8_C(   2),  INT8_C( 118),  INT8_C(  90), -INT8_C(  99),
        -INT8_C(  88),  INT8_C( 108),  INT8_C(  91),  INT8_C(   9), -INT8_C(  21), -INT8_C(  94),  INT8_C(  28),  INT8_C(  56),
        -INT8_C(  99),  INT8_C(  75),  INT8_C(  46),  INT8_C( 100),  INT8_C(  21),  INT8_C(  74), -INT8_C( 116), -INT8_C( 112),
        -INT8_C(  69), -INT8_C(  92), -INT8_C(   1),  INT8_C(  88),  INT8_C( 120),  INT8_C(  29),  INT8_C(  11), -INT8_C(  88) },
      {  INT8_C(  82), -INT8_C( 101),  INT8_C(  37),  INT8_C(  49), -INT8_C(  53),  INT8_C(  18),  INT8_C(  49), -INT8_C(  66),
         INT8_C(  30),  INT8_C(  97), -INT8_C(  60),      INT8_MAX, -INT8_C( 107),  INT8_C(  70),  INT8_C( 101),  INT8_C(  19),
         INT8_C( 123),  INT8_C( 122), -INT8_C( 107),  INT8_C( 112),  INT8_C(  20),  INT8_C(  24),  INT8_C(  47),  INT8_C( 111),
        -INT8_C( 113), -INT8_C(  99),  INT8_C(  68), -INT8_C(  44), -INT8_C(  40),  INT8_C(  30), -INT8_C(  52), -INT8_C(  77),
        -INT8_C(  23), -INT8_C(  88),  INT8_C(  95),  INT8_C( 108), -INT8_C( 101),  INT8_C(  91),  INT8_C(   8),  INT8_C(   9),
         INT8_C(  35), -INT8_C(  21),  INT8_C(  48), -INT8_C(  94),  INT8_C( 109),  INT8_C(  28), -INT8_C( 120),  INT8_C(  56),
         INT8_C(  97), -INT8_C(  69), -INT8_C(  80), -INT8_C(  92),  INT8_C(  84), -INT8_C(   1), -INT8_C(  16),  INT8_C(  88),
        -INT8_C(  12),  INT8_C( 120),  INT8_C(  45),  INT8_C(  29), -INT8_C(  68),  INT8_C(  11), -INT8_C(  81), -INT8_C(  88) } },
    { { -INT8_C(  28), -INT8_C(  21), -INT8_C(   7), -INT8_C(  26),  INT8_C(  98),  INT8_C(  83), -INT8_C( 124),  INT8_C(  10),
        -INT8_C(  64), -INT8_C(  33),  INT8_C(  19), -INT8_C(  85), -INT8_C( 127),  INT8_C(  48), -INT8_C(  29),  INT8_C(  31),
         INT8_C( 123),  INT8_C(  18), -INT8_C( 125), -INT8_C( 112),  INT8_C(  92),  INT8_C(  16),  INT8_C(  32),  INT8_C(  23),
        -INT8_C(  76),  INT8_C(  31),  INT8_C( 112),  INT8_C(  45),  INT8_C(  61),  INT8_C( 123), -INT8_C(  43),  INT8_C(  33),
         INT8_C( 103), -INT8_C(  50),  INT8_C(   7), -INT8_C(  55),  INT8_C(  34), -INT8_C( 117), -INT8_C(  45), -INT8_C(  30),
         INT8_C( 107), -INT8_C(  26), -INT8_C( 115), -INT8_C(  20),  INT8_C(  22),  INT8_C( 113),  INT8_C(  11), -INT8_C( 111),
        -INT8_C( 125), -INT8_C( 113),  INT8_C(  34), -INT8_C(  33), -INT8_C(  97),  INT8_C(  66), -INT8_C(   9),  INT8_C(  83),
         INT8_C(  98),  INT8_C( 103),      INT8_MIN, -INT8_C(  97), -INT8_C(  30),  INT8_C(  86), -INT8_C(  64),  INT8_C(  73) },
      {  INT8_C(  36), -INT8_C(  57),  INT8_C(  18),  INT8_C(  70),  INT8_C(  83), -INT8_C(  27),  INT8_C(  40), -INT8_C(  66),
        -INT8_C(  52), -INT8_C(  74), -INT8_C(  86), -INT8_C(  30),  INT8_C(  39), -INT8_C(  74),  INT8_C( 116), -INT8_C(  86),
         INT8_C(  69), -INT8_C( 106), -INT8_C( 119), -INT8_C(  28), -INT8_C(  40),      INT8_MIN,  INT8_C(  55),  INT8_C(  58),
        -INT8_C(  25), -INT8_C(  72), -INT8_C(  39), -INT8_C(  54),  INT8_C(  14), -INT8_C( 103),  INT8_C(  19),  INT8_C(  50),
         INT8_C(  97),  INT8_C(  38),  INT8_C( 121), -INT8_C(  76),  INT8_C(  11), -INT8_C(  95),  INT8_C( 114), -INT8_C(  41),
         INT8_C(  87),  INT8_C(  28), -INT8_C(  70),  INT8_C( 126), -INT8_C(  46),  INT8_C(  46),  INT8_C(  40),  INT8_C(  23),
        -INT8_C(  60), -INT8_C(  78), -INT8_C(   5), -INT8_C( 100),  INT8_C(  50),  INT8_C(  51), -INT8_C(  41),  INT8_C(  26),
        -INT8_C(  21), -INT8_C(  80), -INT8_C(  28), -INT8_C(   7),  INT8_C(  74), -INT8_C(   9),  INT8_C(  43), -INT8_C(  85) },
      { -INT8_C(  64), -INT8_C(  52), -INT8_C(  33), -INT8_C(  74),  INT8_C(  19), -INT8_C(  86), -INT8_C(  85), -INT8_C(  30),
        -INT8_C( 127),  INT8_C(  39),  INT8_C(  48), -INT8_C(  74), -INT8_C(  29),  INT8_C( 116),  INT8_C(  31), -INT8_C(  86),
        -INT8_C(  76), -INT8_C(  25),  INT8_C(  31), -INT8_C(  72),  INT8_C( 112), -INT8_C(  39),  INT8_C(  45), -INT8_C(  54),
         INT8_C(  61),  INT8_C(  14),  INT8_C( 123), -INT8_C( 103), -INT8_C(  43),  INT8_C(  19),  INT8_C(  33),  INT8_C(  50),
         INT8_C( 107),  INT8_C(  87), -INT8_C(  26),  INT8_C(  28), -INT8_C( 115), -INT8_C(  70), -INT8_C(  20),  INT8_C( 126),
         INT8_C(  22), -INT8_C(  46),  INT8_C( 113),  INT8_C(  46),  INT8_C(  11),  INT8_C(  40), -INT8_C( 111),  INT8_C(  23),
         INT8_C(  98), -INT8_C(  21),  INT8_C( 103), -INT8_C(  80),      INT8_MIN, -INT8_C(  28), -INT8_C(  97), -INT8_C(   7),
        -INT8_C(  30),  INT8_C(  74),  INT8_C(  86), -INT8_C(   9), -INT8_C(  64),  INT8_C(  43),  INT8_C(  73), -INT8_C(  85) } },
    { {  INT8_C(  29), -INT8_C(  92),  INT8_C(  95),  INT8_C(  41),  INT8_C(  70), -INT8_C(  47),  INT8_C(   0), -INT8_C(  99),
        -INT8_C(  19), -INT8_C(  70),  INT8_C(  28), -INT8_C(  64), -INT8_C(  24),  INT8_C(  68), -INT8_C(  41), -INT8_C(  84),
        -INT8_C(  10), -INT8_C(  45),  INT8_C(  73),  INT8_C(  41),  INT8_C(   6),  INT8_C(  32),  INT8_C(  67), -INT8_C(  15),
        -INT8_C(  48),  INT8_C(  39), -INT8_C(  22),  INT8_C(  26),  INT8_C(  30),  INT8_C(  21), -INT8_C(  59),  INT8_C(  60),
        -INT8_C(  70),  INT8_C(  36),  INT8_C( 101),  INT8_C(   0), -INT8_C(  11),  INT8_C( 101), -INT8_C(  99), -INT8_C(  29),
         INT8_C(  32), -INT8_C(  71), -INT8_C(  93),  INT8_C(   8), -INT8_C(   2),  INT8_C( 122), -INT8_C(  75), -INT8_C(  12),
         INT8_C(  77), -INT8_C(   2),  INT8_C(  29),  INT8_C(  83),  INT8_C(  30),  INT8_C(  96),  INT8_C(  68), -INT8_C(  18),
        -INT8_C( 121),  INT8_C(  46),  INT8_C(   9), -INT8_C(  90),  INT8_C(  68), -INT8_C(  50), -INT8_C(  30), -INT8_C(   2) },
      { -INT8_C(  13),  INT8_C(  71), -INT8_C(   2), -INT8_C(  24), -INT8_C(  84), -INT8_C( 101), -INT8_C(  53), -INT8_C(  52),
         INT8_C(  85),  INT8_C( 110), -INT8_C(  43),  INT8_C(  83), -INT8_C(  23), -INT8_C( 118),  INT8_C(  71),  INT8_C(  54),
        -INT8_C( 120),  INT8_C( 101), -INT8_C( 118), -INT8_C(  90), -INT8_C(  59), -INT8_C(  50), -INT8_C( 108),  INT8_C(  77),
        -INT8_C(   3), -INT8_C(  99), -INT8_C(  13),  INT8_C(  65),  INT8_C( 108), -INT8_C(  43),  INT8_C(  63),  INT8_C(  95),
         INT8_C(  28),  INT8_C(  61),  INT8_C(  71), -INT8_C(  56), -INT8_C(  40),  INT8_C(  19), -INT8_C( 107),  INT8_C(  45),
        -INT8_C( 127),  INT8_C( 106),      INT8_MIN,  INT8_C( 106), -INT8_C(  12), -INT8_C(  56), -INT8_C(  95),  INT8_C( 124),
         INT8_C(  45),  INT8_C(  43),  INT8_C(  34), -INT8_C(  14), -INT8_C(   7), -INT8_C(  74),  INT8_C(  63), -INT8_C(  10),
         INT8_C(  84),  INT8_C(  50),  INT8_C(  55), -INT8_C(  64),  INT8_C(   7),  INT8_C( 118),  INT8_C(  31),  INT8_C(  35) },
      { -INT8_C(  19),  INT8_C(  85), -INT8_C(  70),  INT8_C( 110),  INT8_C(  28), -INT8_C(  43), -INT8_C(  64),  INT8_C(  83),
        -INT8_C(  24), -INT8_C(  23),  INT8_C(  68), -INT8_C( 118), -INT8_C(  41),  INT8_C(  71), -INT8_C(  84),  INT8_C(  54),
        -INT8_C(  48), -INT8_C(   3),  INT8_C(  39), -INT8_C(  99), -INT8_C(  22), -INT8_C(  13),  INT8_C(  26),  INT8_C(  65),
         INT8_C(  30),  INT8_C( 108),  INT8_C(  21), -INT8_C(  43), -INT8_C(  59),  INT8_C(  63),  INT8_C(  60),  INT8_C(  95),
         INT8_C(  32), -INT8_C( 127), -INT8_C(  71),  INT8_C( 106), -INT8_C(  93),      INT8_MIN,  INT8_C(   8),  INT8_C( 106),
        -INT8_C(   2), -INT8_C(  12),  INT8_C( 122), -INT8_C(  56), -INT8_C(  75), -INT8_C(  95), -INT8_C(  12),  INT8_C( 124),
        -INT8_C( 121),  INT8_C(  84),  INT8_C(  46),  INT8_C(  50),  INT8_C(   9),  INT8_C(  55), -INT8_C(  90), -INT8_C(  64),
         INT8_C(  68),  INT8_C(   7), -INT8_C(  50),  INT8_C( 118), -INT8_C(  30),  INT8_C(  31), -INT8_C(   2),  INT8_C(  35) } },
    { { -INT8_C(  77),  INT8_C( 102), -INT8_C(  20), -INT8_C( 116),  INT8_C( 121), -INT8_C( 127), -INT8_C(  71), -INT8_C(   5),
        -INT8_C(  21),  INT8_C(  58),  INT8_C( 101), -INT8_C(  33),  INT8_C(   2),  INT8_C(   6),  INT8_C(  91),  INT8_C(  47),
         INT8_C(  49),  INT8_C( 125),  INT8_C(  33),  INT8_C(  43),  INT8_C(  51),  INT8_C(  97),  INT8_C(  33), -INT8_C( 121),
        -INT8_C( 109),  INT8_C(  89),  INT8_C(  71), -INT8_C( 101), -INT8_C(  49),  INT8_C( 102), -INT8_C(  66), -INT8_C( 125),
        -INT8_C(  51), -INT8_C(  86),  INT8_C(  15),  INT8_C(  70),  INT8_C(  43), -INT8_C(  56),  INT8_C(  65),  INT8_C(  22),
         INT8_C(   2), -INT8_C(  89), -INT8_C(  11),  INT8_C(   4), -INT8_C(  83),  INT8_C(  80),  INT8_C(  51), -INT8_C(  33),
        -INT8_C(  51),  INT8_C(  85),  INT8_C(  10),  INT8_C(   1), -INT8_C(  74),  INT8_C(  43), -INT8_C( 120),  INT8_C(  73),
        -INT8_C( 124), -INT8_C(  48), -INT8_C(  28),  INT8_C(  84),  INT8_C(  54), -INT8_C(  93), -INT8_C(  41),  INT8_C(   3) },
      {  INT8_C(  77), -INT8_C(  26),  INT8_C(  74),  INT8_C( 121), -INT8_C(  82), -INT8_C( 117), -INT8_C( 113), -INT8_C(  79),
         INT8_C(  50), -INT8_C( 123), -INT8_C(  75), -INT8_C(  32), -INT8_C(  43), -INT8_C(  23), -INT8_C(  65), -INT8_C(  93),
         INT8_C(  62), -INT8_C(  55), -INT8_C(  92), -INT8_C(  12), -INT8_C(  12),  INT8_C(  44),  INT8_C(  61),  INT8_C( 121),
        -INT8_C(   4),  INT8_C(  34), -INT8_C(  51),  INT8_C(  51), -INT8_C(  59), -INT8_C(  92),  INT8_C(  54),  INT8_C(  18),
        -INT8_C( 118),      INT8_MIN, -INT8_C( 117),  INT8_C(  56),  INT8_C(  12),  INT8_C(  27), -INT8_C(  23),  INT8_C(  62),
        -INT8_C(  96), -INT8_C(  97),  INT8_C(  30),  INT8_C( 117), -INT8_C( 120), -INT8_C(  35),  INT8_C(  24), -INT8_C(  58),
        -INT8_C(  90), -INT8_C(  68), -INT8_C(  70), -INT8_C( 101), -INT8_C(  23), -INT8_C(   9),  INT8_C(  20), -INT8_C(  27),
         INT8_C(  25), -INT8_C(  31),  INT8_C(  24), -INT8_C(  34), -INT8_C( 123),  INT8_C(  79), -INT8_C(  15),  INT8_C(  15) },
      { -INT8_C(  21),  INT8_C(  50),  INT8_C(  58), -INT8_C( 123),  INT8_C( 101), -INT8_C(  75), -INT8_C(  33), -INT8_C(  32),
         INT8_C(   2), -INT8_C(  43),  INT8_C(   6), -INT8_C(  23),  INT8_C(  91), -INT8_C(  65),  INT8_C(  47), -INT8_C(  93),
        -INT8_C( 109), -INT8_C(   4),  INT8_C(  89),  INT8_C(  34),  INT8_C(  71), -INT8_C(  51), -INT8_C( 101),  INT8_C(  51),
        -INT8_C(  49), -INT8_C(  59),  INT8_C( 102), -INT8_C(  92), -INT8_C(  66),  INT8_C(  54), -INT8_C( 125),  INT8_C(  18),
         INT8_C(   2), -INT8_C(  96), -INT8_C(  89), -INT8_C(  97), -INT8_C(  11),  INT8_C(  30),  INT8_C(   4),  INT8_C( 117),
        -INT8_C(  83), -INT8_C( 120),  INT8_C(  80), -INT8_C(  35),  INT8_C(  51),  INT8_C(  24), -INT8_C(  33), -INT8_C(  58),
        -INT8_C( 124),  INT8_C(  25), -INT8_C(  48), -INT8_C(  31), -INT8_C(  28),  INT8_C(  24),  INT8_C(  84), -INT8_C(  34),
         INT8_C(  54), -INT8_C( 123), -INT8_C(  93),  INT8_C(  79), -INT8_C(  41), -INT8_C(  15),  INT8_C(   3),  INT8_C(  15) } },
    { { -INT8_C(  49),  INT8_C( 124),  INT8_C(  71), -INT8_C(  37), -INT8_C( 105),  INT8_C(  49),  INT8_C(  26),  INT8_C(  55),
        -INT8_C(  48),  INT8_C(  56), -INT8_C(  83),  INT8_C(  88),  INT8_C(  22), -INT8_C(  59),  INT8_C(  30), -INT8_C(  68),
        -INT8_C( 126), -INT8_C(  40),  INT8_C(  87),  INT8_C( 107), -INT8_C(  49),  INT8_C( 107),  INT8_C(  80), -INT8_C(  23),
         INT8_C(  76),  INT8_C( 105), -INT8_C(  57), -INT8_C(  47), -INT8_C(  72), -INT8_C(  72), -INT8_C(  32), -INT8_C( 121),
         INT8_C(  53),  INT8_C(  40),  INT8_C(  99), -INT8_C(  52),  INT8_C(  89),  INT8_C( 125),  INT8_C(   4),  INT8_C(  41),
        -INT8_C(  75), -INT8_C(  79), -INT8_C( 127), -INT8_C(  53),  INT8_C( 118), -INT8_C(  97), -INT8_C( 120), -INT8_C(   8),
         INT8_C( 119), -INT8_C(  33),  INT8_C(  99),  INT8_C(  70),  INT8_C(  75), -INT8_C(  76),  INT8_C(  47), -INT8_C( 105),
         INT8_C(  29), -INT8_C(   9),  INT8_C( 105), -INT8_C(  43), -INT8_C(  81),  INT8_C(  73),  INT8_C(  92), -INT8_C(  28) },
      {  INT8_C( 113), -INT8_C(  65), -INT8_C(  79), -INT8_C(  54),  INT8_C(  60), -INT8_C(  75), -INT8_C(  13), -INT8_C(  14),
         INT8_C( 102),  INT8_C( 116), -INT8_C(  67), -INT8_C(  36),  INT8_C(  19),  INT8_C(  69), -INT8_C(  43), -INT8_C( 118),
         INT8_C(  37),  INT8_C(  56), -INT8_C(  47),  INT8_C( 112), -INT8_C(  20),  INT8_C(   0),  INT8_C(   7),  INT8_C(   9),
        -INT8_C(   9),  INT8_C( 112), -INT8_C(  34), -INT8_C(  89), -INT8_C(  70),  INT8_C(  59), -INT8_C( 117),  INT8_C(  43),
        -INT8_C(   6),  INT8_C(  60), -INT8_C(  10),  INT8_C(  55), -INT8_C(  15), -INT8_C(  23),  INT8_C(  41),  INT8_C(  87),
         INT8_C(  94), -INT8_C(  26),  INT8_C(  52),  INT8_C( 113),  INT8_C(  44),  INT8_C(   9), -INT8_C(   4),  INT8_C(  81),
         INT8_C(  65), -INT8_C(  51), -INT8_C(  63),  INT8_C(  46), -INT8_C(  51), -INT8_C(  56),  INT8_C(  55), -INT8_C(  59),
         INT8_C(  57),  INT8_C(  22),  INT8_C( 108), -INT8_C(  13),  INT8_C(  81), -INT8_C(   9),  INT8_C(  30),  INT8_C(  75) },
      { -INT8_C(  48),  INT8_C( 102),  INT8_C(  56),  INT8_C( 116), -INT8_C(  83), -INT8_C(  67),  INT8_C(  88), -INT8_C(  36),
         INT8_C(  22),  INT8_C(  19), -INT8_C(  59),  INT8_C(  69),  INT8_C(  30), -INT8_C(  43), -INT8_C(  68), -INT8_C( 118),
         INT8_C(  76), -INT8_C(   9),  INT8_C( 105),  INT8_C( 112), -INT8_C(  57), -INT8_C(  34), -INT8_C(  47), -INT8_C(  89),
        -INT8_C(  72), -INT8_C(  70), -INT8_C(  72),  INT8_C(  59), -INT8_C(  32), -INT8_C( 117), -INT8_C( 121),  INT8_C(  43),
        -INT8_C(  75),  INT8_C(  94), -INT8_C(  79), -INT8_C(  26), -INT8_C( 127),  INT8_C(  52), -INT8_C(  53),  INT8_C( 113),
         INT8_C( 118),  INT8_C(  44), -INT8_C(  97),  INT8_C(   9), -INT8_C( 120), -INT8_C(   4), -INT8_C(   8),  INT8_C(  81),
         INT8_C(  29),  INT8_C(  57), -INT8_C(   9),  INT8_C(  22),  INT8_C( 105),  INT8_C( 108), -INT8_C(  43), -INT8_C(  13),
        -INT8_C(  81),  INT8_C(  81),  INT8_C(  73), -INT8_C(   9),  INT8_C(  92),  INT8_C(  30), -INT8_C(  28),  INT8_C(  75) } }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
    simde__m512i a = simde_mm512_loadu_epi8(test_vec[i].a);
    simde__m512i b = simde_mm512_loadu_epi8(test_vec[i].b);
    simde__m512i r = simde_mm512_unpackhi_epi8(a, b);
    simde_test_x86_assert_equal_i8x64(r, simde_mm512_loadu_epi8(test_vec[i].r));
  }

  return 0;
}

static int
test_simde_mm512_unpackhi_epi16 (SIMDE_MUNIT_TEST_ARGS) {
  static const struct {
    const int16_t a[32];
    const int16_t b[32];
    const int16_t r[32];
  } test_vec[] = {
    { { -INT16_C( 31862), -INT16_C( 28008), -INT16_C( 17358), -INT16_C(  9367), -INT16_C(  8035),  INT16_C( 28789),  INT16_C(  9734),  INT16_C( 32189),
        -INT16_C( 29888),  INT16_C( 14371),  INT16_C( 13788), -INT16_C( 27397),  INT16_C( 24497), -INT16_C(  8132), -INT16_C( 27140), -INT16_C( 30909),
        -INT16_C(  9447),  INT16_C( 19225), -INT16_C( 32105),  INT16_C( 13350), -INT16_C( 25502),  INT16_C( 26788),  INT16_C( 25026),  INT16_C(   741),
         INT16_C(  2541), -INT16_C( 14021),  INT16_C( 13886), -INT16_C(  4003), -INT16_C( 26219), -INT16_C( 28208),  INT16_C(  5167),  INT16_C( 18456) },
      {  INT16_C( 12783), -INT16_C( 30829), -INT16_C( 17997),  INT16_C(  5563),  INT16_C( 24661),  INT16_C(  6270),  INT16_C( 25537), -INT16_C( 20966),
         INT16_C( 21868), -INT16_C( 21641), -INT16_C( 10869),  INT16_C(  8347),  INT16_C( 27502), -INT16_C( 25166), -INT16_C( 13697),  INT16_C( 28645),
         INT16_C( 30972), -INT16_C( 20490), -INT16_C( 20174), -INT16_C( 30779),  INT16_C( 17169), -INT16_C( 11361), -INT16_C( 17754),  INT16_C(  4993),
        -INT16_C(  1777), -INT16_C( 25666),  INT16_C( 22990),  INT16_C( 15547),  INT16_C( 28100),  INT16_C( 17626), -INT16_C( 16584),  INT16_C( 13491) },
      { -INT16_C(  8035),  INT16_C( 24661),  INT16_C( 28789),  INT16_C(  6270),  INT16_C(  9734),  INT16_C( 25537),  INT16_C( 32189), -INT16_C( 20966),
         INT16_C( 24497),  INT16_C( 27502), -INT16_C(  8132), -INT16_C( 25166), -INT16_C( 27140), -INT16_C( 13697), -INT16_C( 30909),  INT16_C( 28645),
        -INT16_C( 25502),  INT16_C( 17169),  INT16_C( 26788), -INT16_C( 11361),  INT16_C( 25026), -INT16_C( 17754),  INT16_C(   741),  INT16_C(  4993),
        -INT16_C( 26219),  INT16_C( 28100), -INT16_C( 28208),  INT16_C( 17626),  INT16_C(  5167), -INT16_C( 16584),  INT16_C( 18456),  INT16_C( 13491) } },
    { { -INT16_C( 22216),  INT16_C( 27363), -INT16_C( 22438),  INT16_C( 27889), -INT16_C( 28181), -INT16_C( 28097), -INT16_C( 16309),  INT16_C( 23205),
         INT16_C( 25529), -INT16_C( 30731), -INT16_C( 20036), -INT16_C( 32572), -INT16_C( 25058),  INT16_C( 22212),  INT16_C( 30557), -INT16_C( 27254),
         INT16_C( 28192),  INT16_C( 31743), -INT16_C(  3818),  INT16_C(   743),  INT16_C(  9858), -INT16_C( 12908),  INT16_C( 14822), -INT16_C( 24537),
         INT16_C(  7580),  INT16_C( 22567), -INT16_C(  5170), -INT16_C(  4904), -INT16_C( 25207), -INT16_C(  6333), -INT16_C( 13036),  INT16_C( 13692) },
      {  INT16_C( 31803),  INT16_C( 21168), -INT16_C( 26771), -INT16_C(  4268), -INT16_C(  5955), -INT16_C( 23620), -INT16_C(  7391), -INT16_C( 17085),
         INT16_C( 27392), -INT16_C( 12779), -INT16_C(  4778), -INT16_C(  8005), -INT16_C(   374), -INT16_C( 24633),  INT16_C( 17355),  INT16_C(  2004),
        -INT16_C( 31553),  INT16_C( 11353), -INT16_C( 21221), -INT16_C( 10213), -INT16_C( 10347), -INT16_C( 18821), -INT16_C( 16453), -INT16_C( 17549),
        -INT16_C( 30678), -INT16_C( 32630),  INT16_C( 17781),  INT16_C(    96),  INT16_C( 10051),  INT16_C(  3743),  INT16_C( 29547),  INT16_C( 10773) },
      { -INT16_C( 28181), -INT16_C(  5955), -INT16_C( 28097), -INT16_C( 23620), -INT16_C( 16309), -INT16_C(  7391),  INT16_C( 23205), -INT16_C( 17085),
        -INT16_C( 25058), -INT16_C(   374),  INT16_C( 22212), -INT16_C( 24633),  INT16_C( 30557),  INT16_C( 17355), -INT16_C( 27254),  INT16_C(  2004),
         INT16_C(  9858), -INT16_C( 10347), -INT16_C( 12908), -INT16_C( 18821),  INT16_C( 14822), -INT16_C( 16453), -INT16_C( 24537), -INT16_C( 17549),
        -INT16_C( 25207),  INT16_C( 10051), -INT16_C(  6333),  INT16_C(  3743), -INT16_C( 13036),  INT16_C( 29547),  INT16_C( 13692),  INT16_C( 10773) } },
    { {  INT16_C( 28407),  INT16_C(  4695),  INT16_C( 29211), -INT16_C( 20246),  INT16_C( 25930),  INT16_C(  1382), -INT16_C(  9948),  INT16_C( 20160),
         INT16_C( 19041), -INT16_C( 10289),  INT16_C( 12175), -INT16_C( 11561),  INT16_C( 30295), -INT16_C( 15647), -INT16_C(  2327), -INT16_C(  7956),
         INT16_C( 17253), -INT16_C( 32526), -INT16_C(  9034),  INT16_C(    49), -INT16_C( 26815),  INT16_C( 26117), -INT16_C( 14991), -INT16_C( 11596),
        -INT16_C( 31984), -INT16_C( 24663), -INT16_C( 32589),  INT16_C(  2674),  INT16_C( 21494), -INT16_C(  8244), -INT16_C( 18359), -INT16_C( 20801) },
      { -INT16_C( 19972), -INT16_C( 19921),  INT16_C( 24717), -INT16_C( 12366), -INT16_C( 18441),  INT16_C( 26677), -INT16_C(  5764), -INT16_C( 29637),
        -INT16_C(  7059),  INT16_C(  8236), -INT16_C( 24987),  INT16_C( 23338), -INT16_C(  2319),  INT16_C( 14907), -INT16_C(  1362), -INT16_C( 21783),
         INT16_C(  6316),  INT16_C( 14684),  INT16_C(  3704),  INT16_C( 28424),  INT16_C( 15813),  INT16_C( 17112),  INT16_C(  4903), -INT16_C( 27442),
        -INT16_C(  1289),  INT16_C( 23732), -INT16_C(  8552), -INT16_C( 30280), -INT16_C(  3116), -INT16_C( 32060), -INT16_C( 21011), -INT16_C( 26323) },
      {  INT16_C( 25930), -INT16_C( 18441),  INT16_C(  1382),  INT16_C( 26677), -INT16_C(  9948), -INT16_C(  5764),  INT16_C( 20160), -INT16_C( 29637),
         INT16_C( 30295), -INT16_C(  2319), -INT16_C( 15647),  INT16_C( 14907), -INT16_C(  2327), -INT16_C(  1362), -INT16_C(  7956), -INT16_C( 21783),
        -INT16_C( 26815),  INT16_C( 15813),  INT16_C( 26117),  INT16_C( 17112), -INT16_C( 14991),  INT16_C(  4903), -INT16_C( 11596), -INT16_C( 27442),
         INT16_C( 21494), -INT16_C(  3116), -INT16_C(  8244), -INT16_C( 32060), -INT16_C( 18359), -INT16_C( 21011), -INT16_C( 20801), -INT16_C( 26323) } },
    { { -INT16_C( 30267),  INT16_C( 15827), -INT16_C(  9320),  INT16_C( 23980), -INT16_C( 31719),  INT16_C( 16543),  INT16_C( 28311), -INT16_C( 28716),
        -INT16_C( 30616),  INT16_C(   491), -INT16_C( 23706),  INT16_C( 14986),  INT16_C( 20118), -INT16_C( 31556), -INT16_C(  5637), -INT16_C( 16355),
        -INT16_C(  3981),  INT16_C(  3069), -INT16_C( 21812), -INT16_C(  6808),  INT16_C(  2094), -INT16_C( 14811), -INT16_C(  1674), -INT16_C(  8619),
         INT16_C( 16513), -INT16_C(  6177),  INT16_C( 27364),  INT16_C( 31265), -INT16_C(  8776), -INT16_C( 19202),  INT16_C(  7367),  INT16_C( 14964) },
      {  INT16_C( 29196), -INT16_C( 10171), -INT16_C( 21220),  INT16_C( 19133), -INT16_C(  7499),  INT16_C( 11024),  INT16_C( 26075),  INT16_C( 23562),
        -INT16_C(  5722), -INT16_C( 30141),  INT16_C( 25683),  INT16_C(  3076),  INT16_C(   834),  INT16_C(  2496),  INT16_C( 13343),  INT16_C( 11075),
        -INT16_C( 30554), -INT16_C( 15868), -INT16_C( 16075), -INT16_C(  5363),  INT16_C(  7588),  INT16_C( 32534),  INT16_C(  8323),  INT16_C( 10716),
         INT16_C(  7946),  INT16_C( 23987), -INT16_C( 18556), -INT16_C( 14743),  INT16_C( 10682), -INT16_C(  9777),  INT16_C(  4702),  INT16_C(  1029) },
      { -INT16_C( 31719), -INT16_C(  7499),  INT16_C( 16543),  INT16_C( 11024),  INT16_C( 28311),  INT16_C( 26075), -INT16_C( 28716),  INT16_C( 23562),
         INT16_C( 20118),  INT16_C(   834), -INT16_C( 31556),  INT16_C(  2496), -INT16_C(  5637),  INT16_C( 13343), -INT16_C( 16355),  INT16_C( 11075),
         INT16_C(  2094),  INT16_C(  7588), -INT16_C( 14811),  INT16_C( 32534), -INT16_C(  1674),  INT16_C(  8323), -INT16_C(  8619),  INT16_C( 10716),
        -INT16_C(  8776),  INT16_C( 10682), -INT16_C( 19202), -INT16_C(  9777),  INT16_C(  7367),  INT16_C(  4702),  INT16_C( 14964),  INT16_C(  1029) } },
    { {  INT16_C(  2458), -INT16_C( 12345), -INT16_C( 11062),  INT16_C( 28346), -INT16_C( 11791),  INT16_C( 29934), -INT16_C( 13583), -INT16_C(  1123),
         INT16_C( 20713),  INT16_C( 27993), -INT16_C( 15864), -INT16_C( 15821),  INT16_C(   748),  INT16_C( 19100), -INT16_C( 24300), -INT16_C( 20914),
         INT16_C(  5546),  INT16_C( 29822),  INT16_C( 14569), -INT16_C(  9245), -INT16_C( 12023), -INT16_C(  1201), -INT16_C(  4709), -INT16_C( 31498),
         INT16_C( 20285),  INT16_C( 17906),  INT16_C(  9490), -INT16_C(   504), -INT16_C( 23512),  INT16_C( 15432), -INT16_C( 27067), -INT16_C(  4117) },
      {  INT16_C( 27052), -INT16_C( 27293),  INT16_C( 18081), -INT16_C( 21648), -INT16_C( 16361), -INT16_C( 19802), -INT16_C( 25427), -INT16_C(  5577),
         INT16_C( 10732), -INT16_C(   464),  INT16_C( 14414),  INT16_C( 30460),  INT16_C( 17628),  INT16_C(  8627), -INT16_C( 24870), -INT16_C( 31216),
         INT16_C( 29447), -INT16_C( 22500), -INT16_C( 29510), -INT16_C( 11949), -INT16_C(  1716), -INT16_C(  1660), -INT16_C( 17514), -INT16_C( 32028),
         INT16_C(  5348),  INT16_C( 12928),  INT16_C( 31820),  INT16_C( 10409),  INT16_C( 23744), -INT16_C( 26039),  INT16_C( 23034),  INT16_C(   289) },
      { -INT16_C( 11791), -INT16_C( 16361),  INT16_C( 29934), -INT16_C( 19802), -INT16_C( 13583), -INT16_C( 25427), -INT16_C(  1123), -INT16_C(  5577),
         INT16_C(   748),  INT16_C( 17628),  INT16_C( 19100),  INT16_C(  8627), -INT16_C( 24300), -INT16_C( 24870), -INT16_C( 20914), -INT16_C( 31216),
        -INT16_C( 12023), -INT16_C(  1716), -INT16_C(  1201), -INT16_C(  1660), -INT16_C(  4709), -INT16_C( 17514), -INT16_C( 31498), -INT16_C( 32028),
        -INT16_C( 23512),  INT16_C( 23744),  INT16_C( 15432), -INT16_C( 26039), -INT16_C( 27067),  INT16_C( 23034), -INT16_C(  4117),  INT16_C(   289) } },
    { {  INT16_C( 15820), -INT16_C( 31063), -INT16_C(   567),  INT16_C(  5720), -INT16_C(  8970), -INT16_C( 29681), -INT16_C(  3177),  INT16_C( 31502),
        -INT16_C( 29177),  INT16_C( 21421),  INT16_C( 22026), -INT16_C( 13701), -INT16_C( 15182), -INT16_C( 21403), -INT16_C( 31203), -INT16_C(  5459),
         INT16_C( 22467), -INT16_C( 29584), -INT16_C( 14252),  INT16_C( 19106), -INT16_C( 19804),  INT16_C( 15319), -INT16_C(  6747), -INT16_C( 21066),
         INT16_C( 25716),  INT16_C( 32256),  INT16_C( 31930),  INT16_C( 27977), -INT16_C( 20928),  INT16_C( 24089), -INT16_C( 14540), -INT16_C(  2232) },
      { -INT16_C( 18402),  INT16_C( 29315),  INT16_C(  9857),  INT16_C(  9660), -INT16_C( 27688),  INT16_C( 32097),  INT16_C(  6009), -INT16_C(  4822),
         INT16_C( 11131),  INT16_C( 13931), -INT16_C( 19289), -INT16_C(  6237), -INT16_C( 17310), -INT16_C( 27067), -INT16_C( 29309), -INT16_C( 24179),
         INT16_C(  4422), -INT16_C( 14573), -INT16_C( 12233),  INT16_C(  4076),  INT16_C( 19811), -INT16_C(  9076), -INT16_C( 18587), -INT16_C(  7991),
         INT16_C( 13794), -INT16_C( 30442), -INT16_C( 17943),  INT16_C( 19568), -INT16_C( 18826), -INT16_C(  1566),  INT16_C( 28739), -INT16_C( 30309) },
      { -INT16_C(  8970), -INT16_C( 27688), -INT16_C( 29681),  INT16_C( 32097), -INT16_C(  3177),  INT16_C(  6009),  INT16_C( 31502), -INT16_C(  4822),
        -INT16_C( 15182), -INT16_C( 17310), -INT16_C( 21403), -INT16_C( 27067), -INT16_C( 31203), -INT16_C( 29309), -INT16_C(  5459), -INT16_C( 24179),
        -INT16_C( 19804),  INT16_C( 19811),  INT16_C( 15319), -INT16_C(  9076), -INT16_C(  6747), -INT16_C( 18587), -INT16_C( 21066), -INT16_C(  7991),
        -INT16_C( 20928), -INT16_C( 18826),  INT16_C( 24089), -INT16_C(  1566), -INT16_C( 14540),  INT16_C( 28739), -INT16_C(  2232), -INT16_C( 30309) } },
    { { -INT16_C( 20863), -INT16_C( 18352),  INT16_C( 15742), -INT16_C(  7481),  INT16_C( 21386), -INT16_C(  4162), -INT16_C( 30710), -INT16_C(  4912),
        -INT16_C(  6467), -INT16_C( 22923), -INT16_C(  6496),  INT16_C(  5874), -INT16_C( 10852), -INT16_C(  8433), -INT16_C( 21947), -INT16_C( 14743),
        -INT16_C( 18087), -INT16_C( 10370),  INT16_C( 17910), -INT16_C( 32327),  INT16_C( 30872), -INT16_C( 23696),  INT16_C( 16384), -INT16_C( 17009),
         INT16_C(  1319), -INT16_C( 14493),  INT16_C( 22251), -INT16_C( 30755), -INT16_C(  5077),  INT16_C( 28774), -INT16_C( 12393), -INT16_C(  4042) },
      { -INT16_C( 19319),  INT16_C( 32711), -INT16_C( 32263), -INT16_C( 28416),  INT16_C( 29177), -INT16_C(  1740), -INT16_C( 15183), -INT16_C( 10058),
         INT16_C(  6601), -INT16_C( 19297),  INT16_C( 31855), -INT16_C( 26053), -INT16_C( 24215),  INT16_C(    10),  INT16_C( 16497), -INT16_C(  1296),
        -INT16_C( 18444), -INT16_C(  4743),  INT16_C( 31288),  INT16_C( 12671), -INT16_C( 19477), -INT16_C( 25558), -INT16_C(  8073),  INT16_C( 16501),
         INT16_C(  5370),  INT16_C( 27124),  INT16_C( 12177), -INT16_C(  1532),  INT16_C(  3793),  INT16_C( 17146), -INT16_C(  5553),  INT16_C( 17212) },
      {  INT16_C( 21386),  INT16_C( 29177), -INT16_C(  4162), -INT16_C(  1740), -INT16_C( 30710), -INT16_C( 15183), -INT16_C(  4912), -INT16_C( 10058),
        -INT16_C( 10852), -INT16_C( 24215), -INT16_C(  8433),  INT16_C(    10), -INT16_C( 21947),  INT16_C( 16497), -INT16_C( 14743), -INT16_C(  1296),
         INT16_C( 30872), -INT16_C( 19477), -INT16_C( 23696), -INT16_C( 25558),  INT16_C( 16384), -INT16_C(  8073), -INT16_C( 17009),  INT16_C( 16501),
        -INT16_C(  5077),  INT16_C(  3793),  INT16_C( 28774),  INT16_C( 17146), -INT16_C( 12393), -INT16_C(  5553), -INT16_C(  4042),  INT16_C( 17212) } },
    { { -INT16_C( 19039), -INT16_C(  9679), -INT16_C( 20433),  INT16_C(  6667),  INT16_C( 13923), -INT16_C(  9289),  INT16_C( 11286),  INT16_C(  4123),
         INT16_C(  4160), -INT16_C( 11910),  INT16_C( 32319),  INT16_C(  4299), -INT16_C( 14964), -INT16_C(  9390), -INT16_C( 29009),  INT16_C( 20767),
         INT16_C( 20548),  INT16_C( 29483),  INT16_C( 13824),  INT16_C( 25486),  INT16_C( 17772), -INT16_C( 31938),  INT16_C( 23153), -INT16_C( 20077),
         INT16_C(  3434), -INT16_C( 22141),  INT16_C( 20107),  INT16_C(  6330),  INT16_C(  3092), -INT16_C( 15373),  INT16_C(  4763), -INT16_C(  8428) },
      {  INT16_C( 16226),  INT16_C( 25170), -INT16_C(  8074), -INT16_C(  7482),  INT16_C(  1061), -INT16_C( 27035), -INT16_C(  1698), -INT16_C( 14264),
        -INT16_C( 13562), -INT16_C( 28046),  INT16_C( 11289),  INT16_C( 11690), -INT16_C( 25288), -INT16_C( 11279),  INT16_C(  1456),  INT16_C(  4786),
         INT16_C(  1349), -INT16_C( 17547),  INT16_C( 15333),  INT16_C(  2973),  INT16_C(   831), -INT16_C( 24927), -INT16_C(  5636),  INT16_C(   614),
        -INT16_C( 10060), -INT16_C( 12652),  INT16_C( 15876),  INT16_C( 15867), -INT16_C(  4900), -INT16_C( 29680), -INT16_C( 15374),  INT16_C( 14238) },
      {  INT16_C( 13923),  INT16_C(  1061), -INT16_C(  9289), -INT16_C( 27035),  INT16_C( 11286), -INT16_C(  1698),  INT16_C(  4123), -INT16_C( 14264),
        -INT16_C( 14964), -INT16_C( 25288), -INT16_C(  9390), -INT16_C( 11279), -INT16_C( 29009),  INT16_C(  1456),  INT16_C( 20767),  INT16_C(  4786),
         INT16_C( 17772),  INT16_C(   831), -INT16_C( 31938), -INT16_C( 24927),  INT16_C( 23153), -INT16_C(  5636), -INT16_C( 20077),  INT16_C(   614),
         INT16_C(  3092), -INT16_C(  4900), -INT16_C( 15373), -INT16_C( 29680),  INT16_C(  4763), -INT16_C( 15374), -INT16_C(  8428),  INT16_C( 14238) } }
  };

  for (size_t i = 0 ; i < (sizeof(test_vec) / sizeof(test_vec[0])) ; i++) {
    simde__m512i a = simde_mm512_loadu_epi16(test_vec[i].a);
    simde__m512i b = simde_mm512_loadu_epi16(test_vec[i].b);
    simde__m512i r = simde_mm512_unpackhi_epi16(a, b);
    simde_test_x86_assert_equal_i16x32(r, simde_mm512_loadu_epi16(test_vec[i].r));
  }

  return 0;
}

SIMDE_TEST_FUNC_LIST_BEGIN
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_mask_set1_epi8)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_mask_set1_epi16)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_maskz_set1_epi8)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_maskz_set1_epi16)

  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_abs_epi8)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_mask_abs_epi8)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_maskz_abs_epi8)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_abs_epi16)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_mask_abs_epi16)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_maskz_abs_epi16)

  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_add_epi8)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_mask_add_epi8)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_maskz_add_epi8)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_add_epi16)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_mask_add_epi16)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_maskz_add_epi16)

  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_adds_epi8)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_mask_adds_epi8)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_maskz_adds_epi8)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_adds_epi16)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_mask_adds_epi16)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_maskz_adds_epi16)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_adds_epu8)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_mask_adds_epu8)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_maskz_adds_epu8)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_adds_epu16)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_mask_adds_epu16)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_maskz_adds_epu16)

  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_avg_epu8)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_mask_avg_epu8)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_maskz_avg_epu8)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_avg_epu16)

  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_broadcastb_epi8)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_mask_broadcastb_epi8)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_maskz_broadcastb_epi8)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_broadcastw_epi16)

  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_shuffle_epi8)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_mask_shuffle_epi8)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_maskz_shuffle_epi8)

  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_cmpeq_epi8_mask)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_cmpge_epi8_mask)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_cmpge_epu8_mask)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_cmpgt_epi8_mask)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_cmpgt_epu8_mask)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_cmple_epi8_mask)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_cmple_epu8_mask)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_cmplt_epi8_mask)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_cmplt_epu8_mask)

  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_cvtepi8_epi16)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_cvtepi16_epi8)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_mask_cvtepi16_epi8)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_maskz_cvtepi16_epi8)

  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_cvtsepi16_epi8)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_mask_cvtsepi16_epi8)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_maskz_cvtsepi16_epi8)

  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_min_epi8)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_mask_min_epi8)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_maskz_min_epi8)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_min_epu8)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_mask_min_epu8)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_maskz_min_epu8)

  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_max_epi8)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_mask_max_epi8)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_maskz_max_epi8)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_max_epu8)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_mask_max_epu8)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_maskz_max_epu8)

  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_min_epi16)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_mask_min_epi16)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_maskz_min_epi16)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_min_epu16)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_mask_min_epu16)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_maskz_min_epu16)

  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_max_epi16)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_mask_max_epi16)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_maskz_max_epi16)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_max_epu16)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_mask_max_epu16)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_maskz_max_epu16)

  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_mulhi_epi16)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_mulhrs_epi16)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_mullo_epi16)

  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_packs_epi16)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_packs_epi32)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_packus_epi16)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_packus_epi32)

  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_sad_epu8)

  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_sll_epi16)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_slli_epi16)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_sllv_epi16)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_srl_epi16)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_sra_epi16)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_srai_epi16)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_srav_epi16)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_srli_epi16)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_srlv_epi16)

  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_sub_epi8)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_mask_sub_epi8)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_maskz_sub_epi8)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_sub_epi16)

  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_subs_epi8)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_mask_subs_epi8)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_maskz_subs_epi8)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_subs_epi16)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_subs_epu8)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_mask_subs_epu8)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_maskz_subs_epu8)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_subs_epu16)

  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_unpacklo_epi8)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_unpacklo_epi16)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_unpackhi_epi8)
  SIMDE_TEST_FUNC_LIST_ENTRY(mm512_unpackhi_epi16)
SIMDE_TEST_FUNC_LIST_END

#include <test/x86/test-x86-footer.h>
